//------------------------------------------------------------------------------
// <auto-generated />
//
// This file was automatically generated by SWIG (https://www.swig.org).
// Version 4.1.1
//
// Do not make changes to this file unless you know what you are doing - modify
// the SWIG interface file instead.
//------------------------------------------------------------------------------

namespace QuantLib {

public enum BusinessDayConvention {
  Following,
  ModifiedFollowing,
  Preceding,
  ModifiedPreceding,
  Unadjusted,
  HalfMonthModifiedFollowing,
  Nearest
}

}
