/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class PartialTimeBarrierOption extends OneAssetOption {
  private transient long swigCPtr;
  private transient boolean swigCMemOwnDerived;

  protected PartialTimeBarrierOption(long cPtr, boolean cMemoryOwn) {
    super(QuantLibJNI.PartialTimeBarrierOption_SWIGSmartPtrUpcast(cPtr), true);
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(PartialTimeBarrierOption obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwnDerived = own;
    super.swigSetCMemOwn(own);
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwnDerived) {
        swigCMemOwnDerived = false;
        QuantLibJNI.delete_PartialTimeBarrierOption(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public PartialTimeBarrierOption(Barrier.Type barrierType, PartialBarrier.Range barrierRange, double barrier, double rebate, Date coverEventDate, StrikedTypePayoff payoff, Exercise exercise) {
    this(QuantLibJNI.new_PartialTimeBarrierOption(barrierType.swigValue(), barrierRange.swigValue(), barrier, rebate, Date.getCPtr(coverEventDate), coverEventDate, StrikedTypePayoff.getCPtr(payoff), payoff, Exercise.getCPtr(exercise), exercise), true);
  }

}
