/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class BinaryFunctionDelegate {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected BinaryFunctionDelegate(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(BinaryFunctionDelegate obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected static long swigRelease(BinaryFunctionDelegate obj) {
    long ptr = 0;
    if (obj != null) {
      if (!obj.swigCMemOwn)
        throw new RuntimeException("Cannot release ownership as memory is not owned");
      ptr = obj.swigCPtr;
      obj.swigCMemOwn = false;
      obj.delete();
    }
    return ptr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_BinaryFunctionDelegate(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  protected void swigDirectorDisconnect() {
    swigCMemOwn = false;
    delete();
  }

  public void swigReleaseOwnership() {
    swigCMemOwn = false;
    QuantLibJNI.BinaryFunctionDelegate_change_ownership(this, swigCPtr, false);
  }

  public void swigTakeOwnership() {
    swigCMemOwn = true;
    QuantLibJNI.BinaryFunctionDelegate_change_ownership(this, swigCPtr, true);
  }

  public double value(double arg0, double arg1) {
    return (getClass() == BinaryFunctionDelegate.class) ? QuantLibJNI.BinaryFunctionDelegate_value(swigCPtr, this, arg0, arg1) : QuantLibJNI.BinaryFunctionDelegate_valueSwigExplicitBinaryFunctionDelegate(swigCPtr, this, arg0, arg1);
  }

  public BinaryFunctionDelegate() {
    this(QuantLibJNI.new_BinaryFunctionDelegate(), true);
    QuantLibJNI.BinaryFunctionDelegate_director_connect(this, swigCPtr, true, true);
  }

}
