//------------------------------------------------------------------------------
// <auto-generated />
//
// This file was automatically generated by SWIG (https://www.swig.org).
// Version 4.1.1
//
// Do not make changes to this file unless you know what you are doing - modify
// the SWIG interface file instead.
//------------------------------------------------------------------------------

namespace QuantLib {

public class FdBlackScholesRebateEngine : PricingEngine {
  private global::System.Runtime.InteropServices.HandleRef swigCPtr;
  private bool swigCMemOwnDerived;

  internal FdBlackScholesRebateEngine(global::System.IntPtr cPtr, bool cMemoryOwn) : base(NQuantLibcPINVOKE.FdBlackScholesRebateEngine_SWIGSmartPtrUpcast(cPtr), true) {
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = new global::System.Runtime.InteropServices.HandleRef(this, cPtr);
  }

  internal static global::System.Runtime.InteropServices.HandleRef getCPtr(FdBlackScholesRebateEngine obj) {
    return (obj == null) ? new global::System.Runtime.InteropServices.HandleRef(null, global::System.IntPtr.Zero) : obj.swigCPtr;
  }

  protected override void Dispose(bool disposing) {
    lock(this) {
      if (swigCPtr.Handle != global::System.IntPtr.Zero) {
        if (swigCMemOwnDerived) {
          swigCMemOwnDerived = false;
          NQuantLibcPINVOKE.delete_FdBlackScholesRebateEngine(swigCPtr);
        }
        swigCPtr = new global::System.Runtime.InteropServices.HandleRef(null, global::System.IntPtr.Zero);
      }
      base.Dispose(disposing);
    }
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, uint tGrid, uint xGrid, uint dampingSteps, FdmSchemeDesc schemeDesc, bool localVol, double illegalLocalVolOverwrite) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_0(GeneralizedBlackScholesProcess.getCPtr(process), tGrid, xGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), localVol, illegalLocalVolOverwrite), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, uint tGrid, uint xGrid, uint dampingSteps, FdmSchemeDesc schemeDesc, bool localVol) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_1(GeneralizedBlackScholesProcess.getCPtr(process), tGrid, xGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), localVol), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, uint tGrid, uint xGrid, uint dampingSteps, FdmSchemeDesc schemeDesc) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_2(GeneralizedBlackScholesProcess.getCPtr(process), tGrid, xGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc)), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, uint tGrid, uint xGrid, uint dampingSteps) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_3(GeneralizedBlackScholesProcess.getCPtr(process), tGrid, xGrid, dampingSteps), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, uint tGrid, uint xGrid) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_4(GeneralizedBlackScholesProcess.getCPtr(process), tGrid, xGrid), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, uint tGrid) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_5(GeneralizedBlackScholesProcess.getCPtr(process), tGrid), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_6(GeneralizedBlackScholesProcess.getCPtr(process)), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends, uint tGrid, uint xGrid, uint dampingSteps, FdmSchemeDesc schemeDesc, bool localVol, double illegalLocalVolOverwrite) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_7(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends), tGrid, xGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), localVol, illegalLocalVolOverwrite), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends, uint tGrid, uint xGrid, uint dampingSteps, FdmSchemeDesc schemeDesc, bool localVol) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_8(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends), tGrid, xGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), localVol), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends, uint tGrid, uint xGrid, uint dampingSteps, FdmSchemeDesc schemeDesc) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_9(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends), tGrid, xGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc)), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends, uint tGrid, uint xGrid, uint dampingSteps) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_10(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends), tGrid, xGrid, dampingSteps), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends, uint tGrid, uint xGrid) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_11(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends), tGrid, xGrid), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends, uint tGrid) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_12(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends), tGrid), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

  public FdBlackScholesRebateEngine(GeneralizedBlackScholesProcess process, DividendSchedule dividends) : this(NQuantLibcPINVOKE.new_FdBlackScholesRebateEngine__SWIG_13(GeneralizedBlackScholesProcess.getCPtr(process), DividendSchedule.getCPtr(dividends)), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
  }

}

}
