/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class IterativeBootstrap {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected IterativeBootstrap(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(IterativeBootstrap obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected static long swigRelease(IterativeBootstrap obj) {
    long ptr = 0;
    if (obj != null) {
      if (!obj.swigCMemOwn)
        throw new RuntimeException("Cannot release ownership as memory is not owned");
      ptr = obj.swigCPtr;
      obj.swigCMemOwn = false;
      obj.delete();
    }
    return ptr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_IterativeBootstrap(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue, long maxAttempts, double maxFactor, double minFactor, boolean dontThrow, long dontThrowSteps, long maxEvaluations) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_0(accuracy, minValue, maxValue, maxAttempts, maxFactor, minFactor, dontThrow, dontThrowSteps, maxEvaluations), true);
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue, long maxAttempts, double maxFactor, double minFactor, boolean dontThrow, long dontThrowSteps) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_1(accuracy, minValue, maxValue, maxAttempts, maxFactor, minFactor, dontThrow, dontThrowSteps), true);
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue, long maxAttempts, double maxFactor, double minFactor, boolean dontThrow) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_2(accuracy, minValue, maxValue, maxAttempts, maxFactor, minFactor, dontThrow), true);
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue, long maxAttempts, double maxFactor, double minFactor) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_3(accuracy, minValue, maxValue, maxAttempts, maxFactor, minFactor), true);
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue, long maxAttempts, double maxFactor) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_4(accuracy, minValue, maxValue, maxAttempts, maxFactor), true);
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue, long maxAttempts) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_5(accuracy, minValue, maxValue, maxAttempts), true);
  }

  public IterativeBootstrap(double accuracy, double minValue, double maxValue) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_6(accuracy, minValue, maxValue), true);
  }

  public IterativeBootstrap(double accuracy, double minValue) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_7(accuracy, minValue), true);
  }

  public IterativeBootstrap(double accuracy) {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_8(accuracy), true);
  }

  public IterativeBootstrap() {
    this(QuantLibJNI.new_IterativeBootstrap__SWIG_9(), true);
  }

}
