/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class InterpolatedYoYInflationOptionletVolatilityCurve extends YoYOptionletVolatilitySurface {
  private transient long swigCPtr;
  private transient boolean swigCMemOwnDerived;

  protected InterpolatedYoYInflationOptionletVolatilityCurve(long cPtr, boolean cMemoryOwn) {
    super(QuantLibJNI.InterpolatedYoYInflationOptionletVolatilityCurve_SWIGSmartPtrUpcast(cPtr), true);
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(InterpolatedYoYInflationOptionletVolatilityCurve obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwnDerived = own;
    super.swigSetCMemOwn(own);
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwnDerived) {
        swigCMemOwnDerived = false;
        QuantLibJNI.delete_InterpolatedYoYInflationOptionletVolatilityCurve(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public InterpolatedYoYInflationOptionletVolatilityCurve(long settlementDays, Calendar arg1, BusinessDayConvention bdc, DayCounter dc, Period lag, Frequency frequency, boolean indexIsInterpolated, DateVector d, DoubleVector v, double minStrike, double maxStrike, Linear i) {
    this(QuantLibJNI.new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_0(settlementDays, Calendar.getCPtr(arg1), arg1, bdc.swigValue(), DayCounter.getCPtr(dc), dc, Period.getCPtr(lag), lag, frequency.swigValue(), indexIsInterpolated, DateVector.getCPtr(d), d, DoubleVector.getCPtr(v), v, minStrike, maxStrike, Linear.getCPtr(i), i), true);
  }

  public InterpolatedYoYInflationOptionletVolatilityCurve(long settlementDays, Calendar arg1, BusinessDayConvention bdc, DayCounter dc, Period lag, Frequency frequency, boolean indexIsInterpolated, DateVector d, DoubleVector v, double minStrike, double maxStrike) {
    this(QuantLibJNI.new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_1(settlementDays, Calendar.getCPtr(arg1), arg1, bdc.swigValue(), DayCounter.getCPtr(dc), dc, Period.getCPtr(lag), lag, frequency.swigValue(), indexIsInterpolated, DateVector.getCPtr(d), d, DoubleVector.getCPtr(v), v, minStrike, maxStrike), true);
  }

}
