/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class GarmanKlassSigma1 {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected GarmanKlassSigma1(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(GarmanKlassSigma1 obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected static long swigRelease(GarmanKlassSigma1 obj) {
    long ptr = 0;
    if (obj != null) {
      if (!obj.swigCMemOwn)
        throw new RuntimeException("Cannot release ownership as memory is not owned");
      ptr = obj.swigCPtr;
      obj.swigCMemOwn = false;
      obj.delete();
    }
    return ptr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_GarmanKlassSigma1(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public GarmanKlassSigma1(double yearFraction, double marketOpenFraction) {
    this(QuantLibJNI.new_GarmanKlassSigma1(yearFraction, marketOpenFraction), true);
  }

  public RealTimeSeries calculate(IntervalPriceTimeSeries arg0) {
    return new RealTimeSeries(QuantLibJNI.GarmanKlassSigma1_calculate(swigCPtr, this, IntervalPriceTimeSeries.getCPtr(arg0), arg0), true);
  }

}
