/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class PiecewiseConvexMonotoneForward extends YieldTermStructure {
  private transient long swigCPtr;
  private transient boolean swigCMemOwnDerived;

  protected PiecewiseConvexMonotoneForward(long cPtr, boolean cMemoryOwn) {
    super(QuantLibJNI.PiecewiseConvexMonotoneForward_SWIGSmartPtrUpcast(cPtr), true);
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(PiecewiseConvexMonotoneForward obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwnDerived = own;
    super.swigSetCMemOwn(own);
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwnDerived) {
        swigCMemOwnDerived = false;
        QuantLibJNI.delete_PiecewiseConvexMonotoneForward(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps, DateVector jumpDates, ConvexMonotone i, IterativeBootstrap b) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_0(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps, DateVector.getCPtr(jumpDates), jumpDates, ConvexMonotone.getCPtr(i), i, IterativeBootstrap.getCPtr(b), b), true);
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps, DateVector jumpDates, ConvexMonotone i) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_1(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps, DateVector.getCPtr(jumpDates), jumpDates, ConvexMonotone.getCPtr(i), i), true);
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps, DateVector jumpDates) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_2(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps, DateVector.getCPtr(jumpDates), jumpDates), true);
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_3(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps), true);
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_4(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps, DateVector jumpDates, ConvexMonotone i, IterativeBootstrap b) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_5(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps, DateVector.getCPtr(jumpDates), jumpDates, ConvexMonotone.getCPtr(i), i, IterativeBootstrap.getCPtr(b), b), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps, DateVector jumpDates, ConvexMonotone i) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_6(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps, DateVector.getCPtr(jumpDates), jumpDates, ConvexMonotone.getCPtr(i), i), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps, DateVector jumpDates) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_7(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps, DateVector.getCPtr(jumpDates), jumpDates), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter, QuoteHandleVector jumps) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_8(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandleVector.getCPtr(jumps), jumps), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_9(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter), true);
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter, IterativeBootstrap b, ConvexMonotone i) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_10(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, IterativeBootstrap.getCPtr(b), b, ConvexMonotone.getCPtr(i), i), true);
  }

  public PiecewiseConvexMonotoneForward(Date referenceDate, RateHelperVector instruments, DayCounter dayCounter, IterativeBootstrap b) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_11(Date.getCPtr(referenceDate), referenceDate, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, IterativeBootstrap.getCPtr(b), b), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter, IterativeBootstrap b, ConvexMonotone i) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_12(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, IterativeBootstrap.getCPtr(b), b, ConvexMonotone.getCPtr(i), i), true);
  }

  public PiecewiseConvexMonotoneForward(int settlementDays, Calendar calendar, RateHelperVector instruments, DayCounter dayCounter, IterativeBootstrap b) {
    this(QuantLibJNI.new_PiecewiseConvexMonotoneForward__SWIG_13(settlementDays, Calendar.getCPtr(calendar), calendar, RateHelperVector.getCPtr(instruments), instruments, DayCounter.getCPtr(dayCounter), dayCounter, IterativeBootstrap.getCPtr(b), b), true);
  }

  public DateVector dates() {
    return new DateVector(QuantLibJNI.PiecewiseConvexMonotoneForward_dates(swigCPtr, this), false);
  }

  public DoubleVector times() {
    return new DoubleVector(QuantLibJNI.PiecewiseConvexMonotoneForward_times(swigCPtr, this), false);
  }

  public NodeVector nodes() {
    return new NodeVector(QuantLibJNI.PiecewiseConvexMonotoneForward_nodes(swigCPtr, this), true);
  }

  public void recalculate() {
    QuantLibJNI.PiecewiseConvexMonotoneForward_recalculate(swigCPtr, this);
  }

  public void freeze() {
    QuantLibJNI.PiecewiseConvexMonotoneForward_freeze(swigCPtr, this);
  }

  public void unfreeze() {
    QuantLibJNI.PiecewiseConvexMonotoneForward_unfreeze(swigCPtr, this);
  }

}
