/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class FdHestonVanillaEngine extends PricingEngine {
  private transient long swigCPtr;
  private transient boolean swigCMemOwnDerived;

  protected FdHestonVanillaEngine(long cPtr, boolean cMemoryOwn) {
    super(QuantLibJNI.FdHestonVanillaEngine_SWIGSmartPtrUpcast(cPtr), true);
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(FdHestonVanillaEngine obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwnDerived = own;
    super.swigSetCMemOwn(own);
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwnDerived) {
        swigCMemOwnDerived = false;
        QuantLibJNI.delete_FdHestonVanillaEngine(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct, double mixingFactor) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_0(HestonModel.getCPtr(model), model, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct, mixingFactor), true);
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_1(HestonModel.getCPtr(model), model, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct), true);
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_2(HestonModel.getCPtr(model), model, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc), true);
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid, long xGrid, long vGrid, long dampingSteps) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_3(HestonModel.getCPtr(model), model, tGrid, xGrid, vGrid, dampingSteps), true);
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid, long xGrid, long vGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_4(HestonModel.getCPtr(model), model, tGrid, xGrid, vGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid, long xGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_5(HestonModel.getCPtr(model), model, tGrid, xGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, long tGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_6(HestonModel.getCPtr(model), model, tGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_7(HestonModel.getCPtr(model), model), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct, double mixingFactor) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_8(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct, mixingFactor), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_9(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_10(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_11(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_12(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid, long xGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_13(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper, long tGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_14(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, FdmQuantoHelper quantoHelper) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_15(HestonModel.getCPtr(model), model, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct, double mixingFactor) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_16(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct, mixingFactor), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_17(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_18(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid, long xGrid, long vGrid, long dampingSteps) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_19(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid, xGrid, vGrid, dampingSteps), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid, long xGrid, long vGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_20(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid, xGrid, vGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid, long xGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_21(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid, xGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, long tGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_22(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, tGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_23(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct, double mixingFactor) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_24(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct, mixingFactor), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc, LocalVolTermStructure leverageFct) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_25(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc, LocalVolTermStructure.getCPtr(leverageFct), leverageFct), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps, FdmSchemeDesc schemeDesc) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_26(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid, long dampingSteps) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_27(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid, dampingSteps), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid, long xGrid, long vGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_28(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid, vGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid, long xGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_29(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid, xGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper, long tGrid) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_30(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper, tGrid), true);
  }

  public FdHestonVanillaEngine(HestonModel model, DividendSchedule dividends, FdmQuantoHelper quantoHelper) {
    this(QuantLibJNI.new_FdHestonVanillaEngine__SWIG_31(HestonModel.getCPtr(model), model, DividendSchedule.getCPtr(dividends), dividends, FdmQuantoHelper.getCPtr(quantoHelper), quantoHelper), true);
  }

}
