/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class LocalVolTermStructureHandle {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected LocalVolTermStructureHandle(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(LocalVolTermStructureHandle obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected static long swigRelease(LocalVolTermStructureHandle obj) {
    long ptr = 0;
    if (obj != null) {
      if (!obj.swigCMemOwn)
        throw new RuntimeException("Cannot release ownership as memory is not owned");
      ptr = obj.swigCPtr;
      obj.swigCMemOwn = false;
      obj.delete();
    }
    return ptr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_LocalVolTermStructureHandle(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public LocalVolTermStructureHandle(LocalVolTermStructure arg0) {
    this(QuantLibJNI.new_LocalVolTermStructureHandle__SWIG_0(LocalVolTermStructure.getCPtr(arg0), arg0), true);
  }

  public LocalVolTermStructureHandle() {
    this(QuantLibJNI.new_LocalVolTermStructureHandle__SWIG_1(), true);
  }

  public LocalVolTermStructure __deref__() {
    long cPtr = QuantLibJNI.LocalVolTermStructureHandle___deref__(swigCPtr, this);
    return (cPtr == 0) ? null : new LocalVolTermStructure(cPtr, true);
  }

  public LocalVolTermStructure currentLink() {
    long cPtr = QuantLibJNI.LocalVolTermStructureHandle_currentLink(swigCPtr, this);
    return (cPtr == 0) ? null : new LocalVolTermStructure(cPtr, true);
  }

  public boolean empty() {
    return QuantLibJNI.LocalVolTermStructureHandle_empty(swigCPtr, this);
  }

  public Observable asObservable() {
    long cPtr = QuantLibJNI.LocalVolTermStructureHandle_asObservable(swigCPtr, this);
    return (cPtr == 0) ? null : new Observable(cPtr, true);
  }

  public double localVol(Date arg0, double u, boolean extrapolate) {
    return QuantLibJNI.LocalVolTermStructureHandle_localVol__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, u, extrapolate);
  }

  public double localVol(Date arg0, double u) {
    return QuantLibJNI.LocalVolTermStructureHandle_localVol__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0, u);
  }

  public double localVol(double arg0, double u, boolean extrapolate) {
    return QuantLibJNI.LocalVolTermStructureHandle_localVol__SWIG_2(swigCPtr, this, arg0, u, extrapolate);
  }

  public double localVol(double arg0, double u) {
    return QuantLibJNI.LocalVolTermStructureHandle_localVol__SWIG_3(swigCPtr, this, arg0, u);
  }

  public double minStrike() {
    return QuantLibJNI.LocalVolTermStructureHandle_minStrike(swigCPtr, this);
  }

  public double maxStrike() {
    return QuantLibJNI.LocalVolTermStructureHandle_maxStrike(swigCPtr, this);
  }

  public DayCounter dayCounter() {
    return new DayCounter(QuantLibJNI.LocalVolTermStructureHandle_dayCounter(swigCPtr, this), true);
  }

  public double timeFromReference(Date date) {
    return QuantLibJNI.LocalVolTermStructureHandle_timeFromReference(swigCPtr, this, Date.getCPtr(date), date);
  }

  public Calendar calendar() {
    return new Calendar(QuantLibJNI.LocalVolTermStructureHandle_calendar(swigCPtr, this), true);
  }

  public Date referenceDate() {
    return new Date(QuantLibJNI.LocalVolTermStructureHandle_referenceDate(swigCPtr, this), true);
  }

  public Date maxDate() {
    return new Date(QuantLibJNI.LocalVolTermStructureHandle_maxDate(swigCPtr, this), true);
  }

  public double maxTime() {
    return QuantLibJNI.LocalVolTermStructureHandle_maxTime(swigCPtr, this);
  }

  public void enableExtrapolation() {
    QuantLibJNI.LocalVolTermStructureHandle_enableExtrapolation(swigCPtr, this);
  }

  public void disableExtrapolation() {
    QuantLibJNI.LocalVolTermStructureHandle_disableExtrapolation(swigCPtr, this);
  }

  public boolean allowsExtrapolation() {
    return QuantLibJNI.LocalVolTermStructureHandle_allowsExtrapolation(swigCPtr, this);
  }

}
