/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.1.1
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class QuantLibJNI {

  /// Load the JNI library
  static {
    System.loadLibrary("QuantLibJNI");
  }

  public final static native long new_OptionalBool(boolean jarg1);
  public final static native void delete_OptionalBool(long jarg1);
  public final static native long new_OptionalFrequency(int jarg1);
  public final static native void delete_OptionalFrequency(long jarg1);
  public final static native long new_Period__SWIG_0();
  public final static native long new_Period__SWIG_1(int jarg1, int jarg2);
  public final static native long new_Period__SWIG_2(int jarg1);
  public final static native int Period_length(long jarg1, Period jarg1_);
  public final static native int Period_units(long jarg1, Period jarg1_);
  public final static native int Period_frequency(long jarg1, Period jarg1_);
  public final static native long Period_normalized(long jarg1, Period jarg1_);
  public final static native long new_Period__SWIG_3(String jarg1);
  public final static native String Period_toString(long jarg1, Period jarg1_);
  public final static native String Period_repr(long jarg1, Period jarg1_);
  public final static native void delete_Period(long jarg1);
  public final static native long new_PeriodVector__SWIG_0();
  public final static native long new_PeriodVector__SWIG_1(long jarg1, PeriodVector jarg1_);
  public final static native long PeriodVector_capacity(long jarg1, PeriodVector jarg1_);
  public final static native void PeriodVector_reserve(long jarg1, PeriodVector jarg1_, long jarg2);
  public final static native boolean PeriodVector_isEmpty(long jarg1, PeriodVector jarg1_);
  public final static native void PeriodVector_clear(long jarg1, PeriodVector jarg1_);
  public final static native long new_PeriodVector__SWIG_2(int jarg1, long jarg2, Period jarg2_);
  public final static native int PeriodVector_doSize(long jarg1, PeriodVector jarg1_);
  public final static native void PeriodVector_doAdd__SWIG_0(long jarg1, PeriodVector jarg1_, long jarg2, Period jarg2_);
  public final static native void PeriodVector_doAdd__SWIG_1(long jarg1, PeriodVector jarg1_, int jarg2, long jarg3, Period jarg3_);
  public final static native long PeriodVector_doRemove(long jarg1, PeriodVector jarg1_, int jarg2);
  public final static native long PeriodVector_doGet(long jarg1, PeriodVector jarg1_, int jarg2);
  public final static native long PeriodVector_doSet(long jarg1, PeriodVector jarg1_, int jarg2, long jarg3, Period jarg3_);
  public final static native void PeriodVector_doRemoveRange(long jarg1, PeriodVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_PeriodVector(long jarg1);
  public final static native long new_Date__SWIG_0();
  public final static native long new_Date__SWIG_1(int jarg1, int jarg2, int jarg3);
  public final static native long new_Date__SWIG_2(int jarg1, int jarg2, int jarg3, int jarg4, int jarg5, int jarg6, int jarg7, int jarg8);
  public final static native long new_Date__SWIG_3(int jarg1, int jarg2, int jarg3, int jarg4, int jarg5, int jarg6, int jarg7);
  public final static native long new_Date__SWIG_4(int jarg1, int jarg2, int jarg3, int jarg4, int jarg5, int jarg6);
  public final static native long new_Date__SWIG_5(int jarg1);
  public final static native int Date_weekday(long jarg1, Date jarg1_);
  public final static native int Date_dayOfMonth(long jarg1, Date jarg1_);
  public final static native int Date_dayOfYear(long jarg1, Date jarg1_);
  public final static native int Date_month(long jarg1, Date jarg1_);
  public final static native int Date_year(long jarg1, Date jarg1_);
  public final static native int Date_hours(long jarg1, Date jarg1_);
  public final static native int Date_minutes(long jarg1, Date jarg1_);
  public final static native int Date_seconds(long jarg1, Date jarg1_);
  public final static native int Date_milliseconds(long jarg1, Date jarg1_);
  public final static native int Date_microseconds(long jarg1, Date jarg1_);
  public final static native double Date_fractionOfDay(long jarg1, Date jarg1_);
  public final static native double Date_fractionOfSecond(long jarg1, Date jarg1_);
  public final static native int Date_serialNumber(long jarg1, Date jarg1_);
  public final static native boolean Date_isLeap(int jarg1);
  public final static native long Date_minDate();
  public final static native long Date_maxDate();
  public final static native long Date_todaysDate();
  public final static native long Date_localDateTime();
  public final static native long Date_universalDateTime();
  public final static native long Date_endOfMonth(long jarg1, Date jarg1_);
  public final static native boolean Date_isEndOfMonth(long jarg1, Date jarg1_);
  public final static native long Date_nextWeekday(long jarg1, Date jarg1_, int jarg2);
  public final static native long Date_nthWeekday(long jarg1, int jarg2, int jarg3, int jarg4);
  public final static native long Date_add__SWIG_0(long jarg1, Date jarg1_, int jarg2);
  public final static native long Date_subtract__SWIG_0(long jarg1, Date jarg1_, int jarg2);
  public final static native long Date_add__SWIG_1(long jarg1, Date jarg1_, long jarg2, Period jarg2_);
  public final static native long Date_subtract__SWIG_1(long jarg1, Date jarg1_, long jarg2, Period jarg2_);
  public final static native long new_Date__SWIG_6(String jarg1, String jarg2);
  public final static native int Date_weekdayNumber(long jarg1, Date jarg1_);
  public final static native String Date_toString(long jarg1, Date jarg1_);
  public final static native String Date___repr__(long jarg1, Date jarg1_);
  public final static native String Date_ISO(long jarg1, Date jarg1_);
  public final static native int Date_subtract__SWIG_2(long jarg1, Date jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_Date(long jarg1);
  public final static native long DateParser_parseFormatted(String jarg1, String jarg2);
  public final static native long DateParser_parseISO(String jarg1);
  public final static native long DateParser_parse(String jarg1, String jarg2);
  public final static native long new_DateParser();
  public final static native void delete_DateParser(long jarg1);
  public final static native long PeriodParser_parse(String jarg1);
  public final static native long new_PeriodParser();
  public final static native void delete_PeriodParser(long jarg1);
  public final static native long new_DateVector__SWIG_0();
  public final static native long new_DateVector__SWIG_1(long jarg1, DateVector jarg1_);
  public final static native long DateVector_capacity(long jarg1, DateVector jarg1_);
  public final static native void DateVector_reserve(long jarg1, DateVector jarg1_, long jarg2);
  public final static native boolean DateVector_isEmpty(long jarg1, DateVector jarg1_);
  public final static native void DateVector_clear(long jarg1, DateVector jarg1_);
  public final static native long new_DateVector__SWIG_2(int jarg1, long jarg2, Date jarg2_);
  public final static native int DateVector_doSize(long jarg1, DateVector jarg1_);
  public final static native void DateVector_doAdd__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, Date jarg2_);
  public final static native void DateVector_doAdd__SWIG_1(long jarg1, DateVector jarg1_, int jarg2, long jarg3, Date jarg3_);
  public final static native long DateVector_doRemove(long jarg1, DateVector jarg1_, int jarg2);
  public final static native long DateVector_doGet(long jarg1, DateVector jarg1_, int jarg2);
  public final static native long DateVector_doSet(long jarg1, DateVector jarg1_, int jarg2, long jarg3, Date jarg3_);
  public final static native void DateVector_doRemoveRange(long jarg1, DateVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_DateVector(long jarg1);
  public final static native double daysBetween(long jarg1, Date jarg1_, long jarg2, Date jarg2_);
  public final static native int IMM_F_get();
  public final static native int IMM_G_get();
  public final static native int IMM_H_get();
  public final static native int IMM_J_get();
  public final static native int IMM_K_get();
  public final static native int IMM_M_get();
  public final static native int IMM_N_get();
  public final static native int IMM_Q_get();
  public final static native int IMM_U_get();
  public final static native int IMM_V_get();
  public final static native int IMM_X_get();
  public final static native int IMM_Z_get();
  public final static native boolean IMM_isIMMdate__SWIG_0(long jarg1, Date jarg1_, boolean jarg2);
  public final static native boolean IMM_isIMMdate__SWIG_1(long jarg1, Date jarg1_);
  public final static native boolean IMM_isIMMcode__SWIG_0(String jarg1, boolean jarg2);
  public final static native boolean IMM_isIMMcode__SWIG_1(String jarg1);
  public final static native String IMM_code(long jarg1, Date jarg1_);
  public final static native long IMM_date__SWIG_0(String jarg1, long jarg2, Date jarg2_);
  public final static native long IMM_date__SWIG_1(String jarg1);
  public final static native long IMM_nextDate__SWIG_0(long jarg1, Date jarg1_, boolean jarg2);
  public final static native long IMM_nextDate__SWIG_1(long jarg1, Date jarg1_);
  public final static native long IMM_nextDate__SWIG_2();
  public final static native long IMM_nextDate__SWIG_3(String jarg1, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long IMM_nextDate__SWIG_4(String jarg1, boolean jarg2);
  public final static native long IMM_nextDate__SWIG_5(String jarg1);
  public final static native String IMM_nextCode__SWIG_0(long jarg1, Date jarg1_, boolean jarg2);
  public final static native String IMM_nextCode__SWIG_1(long jarg1, Date jarg1_);
  public final static native String IMM_nextCode__SWIG_2();
  public final static native String IMM_nextCode__SWIG_3(String jarg1, boolean jarg2, long jarg3, Date jarg3_);
  public final static native String IMM_nextCode__SWIG_4(String jarg1, boolean jarg2);
  public final static native String IMM_nextCode__SWIG_5(String jarg1);
  public final static native long new_IMM();
  public final static native void delete_IMM(long jarg1);
  public final static native int ASX_F_get();
  public final static native int ASX_G_get();
  public final static native int ASX_H_get();
  public final static native int ASX_J_get();
  public final static native int ASX_K_get();
  public final static native int ASX_M_get();
  public final static native int ASX_N_get();
  public final static native int ASX_Q_get();
  public final static native int ASX_U_get();
  public final static native int ASX_V_get();
  public final static native int ASX_X_get();
  public final static native int ASX_Z_get();
  public final static native boolean ASX_isASXdate__SWIG_0(long jarg1, Date jarg1_, boolean jarg2);
  public final static native boolean ASX_isASXdate__SWIG_1(long jarg1, Date jarg1_);
  public final static native boolean ASX_isASXcode__SWIG_0(String jarg1, boolean jarg2);
  public final static native boolean ASX_isASXcode__SWIG_1(String jarg1);
  public final static native String ASX_code(long jarg1, Date jarg1_);
  public final static native long ASX_date__SWIG_0(String jarg1, long jarg2, Date jarg2_);
  public final static native long ASX_date__SWIG_1(String jarg1);
  public final static native long ASX_nextDate__SWIG_0(long jarg1, Date jarg1_, boolean jarg2);
  public final static native long ASX_nextDate__SWIG_1(long jarg1, Date jarg1_);
  public final static native long ASX_nextDate__SWIG_2();
  public final static native long ASX_nextDate__SWIG_3(String jarg1, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long ASX_nextDate__SWIG_4(String jarg1, boolean jarg2);
  public final static native long ASX_nextDate__SWIG_5(String jarg1);
  public final static native String ASX_nextCode__SWIG_0(long jarg1, Date jarg1_, boolean jarg2);
  public final static native String ASX_nextCode__SWIG_1(long jarg1, Date jarg1_);
  public final static native String ASX_nextCode__SWIG_2();
  public final static native String ASX_nextCode__SWIG_3(String jarg1, boolean jarg2, long jarg3, Date jarg3_);
  public final static native String ASX_nextCode__SWIG_4(String jarg1, boolean jarg2);
  public final static native String ASX_nextCode__SWIG_5(String jarg1);
  public final static native long new_ASX();
  public final static native void delete_ASX(long jarg1);
  public final static native long new_IntVector__SWIG_0();
  public final static native long new_IntVector__SWIG_1(long jarg1, IntVector jarg1_);
  public final static native long IntVector_capacity(long jarg1, IntVector jarg1_);
  public final static native void IntVector_reserve(long jarg1, IntVector jarg1_, long jarg2);
  public final static native boolean IntVector_isEmpty(long jarg1, IntVector jarg1_);
  public final static native void IntVector_clear(long jarg1, IntVector jarg1_);
  public final static native long new_IntVector__SWIG_2(int jarg1, int jarg2);
  public final static native int IntVector_doSize(long jarg1, IntVector jarg1_);
  public final static native void IntVector_doAdd__SWIG_0(long jarg1, IntVector jarg1_, int jarg2);
  public final static native void IntVector_doAdd__SWIG_1(long jarg1, IntVector jarg1_, int jarg2, int jarg3);
  public final static native int IntVector_doRemove(long jarg1, IntVector jarg1_, int jarg2);
  public final static native int IntVector_doGet(long jarg1, IntVector jarg1_, int jarg2);
  public final static native int IntVector_doSet(long jarg1, IntVector jarg1_, int jarg2, int jarg3);
  public final static native void IntVector_doRemoveRange(long jarg1, IntVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_IntVector(long jarg1);
  public final static native long new_UnsignedIntVector__SWIG_0();
  public final static native long new_UnsignedIntVector__SWIG_1(long jarg1, UnsignedIntVector jarg1_);
  public final static native long UnsignedIntVector_capacity(long jarg1, UnsignedIntVector jarg1_);
  public final static native void UnsignedIntVector_reserve(long jarg1, UnsignedIntVector jarg1_, long jarg2);
  public final static native boolean UnsignedIntVector_isEmpty(long jarg1, UnsignedIntVector jarg1_);
  public final static native void UnsignedIntVector_clear(long jarg1, UnsignedIntVector jarg1_);
  public final static native long new_UnsignedIntVector__SWIG_2(int jarg1, long jarg2);
  public final static native int UnsignedIntVector_doSize(long jarg1, UnsignedIntVector jarg1_);
  public final static native void UnsignedIntVector_doAdd__SWIG_0(long jarg1, UnsignedIntVector jarg1_, long jarg2);
  public final static native void UnsignedIntVector_doAdd__SWIG_1(long jarg1, UnsignedIntVector jarg1_, int jarg2, long jarg3);
  public final static native long UnsignedIntVector_doRemove(long jarg1, UnsignedIntVector jarg1_, int jarg2);
  public final static native long UnsignedIntVector_doGet(long jarg1, UnsignedIntVector jarg1_, int jarg2);
  public final static native long UnsignedIntVector_doSet(long jarg1, UnsignedIntVector jarg1_, int jarg2, long jarg3);
  public final static native void UnsignedIntVector_doRemoveRange(long jarg1, UnsignedIntVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_UnsignedIntVector(long jarg1);
  public final static native long new_DoubleVector__SWIG_0();
  public final static native long new_DoubleVector__SWIG_1(long jarg1, DoubleVector jarg1_);
  public final static native long DoubleVector_capacity(long jarg1, DoubleVector jarg1_);
  public final static native void DoubleVector_reserve(long jarg1, DoubleVector jarg1_, long jarg2);
  public final static native boolean DoubleVector_isEmpty(long jarg1, DoubleVector jarg1_);
  public final static native void DoubleVector_clear(long jarg1, DoubleVector jarg1_);
  public final static native long new_DoubleVector__SWIG_2(int jarg1, double jarg2);
  public final static native int DoubleVector_doSize(long jarg1, DoubleVector jarg1_);
  public final static native void DoubleVector_doAdd__SWIG_0(long jarg1, DoubleVector jarg1_, double jarg2);
  public final static native void DoubleVector_doAdd__SWIG_1(long jarg1, DoubleVector jarg1_, int jarg2, double jarg3);
  public final static native double DoubleVector_doRemove(long jarg1, DoubleVector jarg1_, int jarg2);
  public final static native double DoubleVector_doGet(long jarg1, DoubleVector jarg1_, int jarg2);
  public final static native double DoubleVector_doSet(long jarg1, DoubleVector jarg1_, int jarg2, double jarg3);
  public final static native void DoubleVector_doRemoveRange(long jarg1, DoubleVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_DoubleVector(long jarg1);
  public final static native long new_StrVector__SWIG_0();
  public final static native long new_StrVector__SWIG_1(long jarg1, StrVector jarg1_);
  public final static native long StrVector_capacity(long jarg1, StrVector jarg1_);
  public final static native void StrVector_reserve(long jarg1, StrVector jarg1_, long jarg2);
  public final static native boolean StrVector_isEmpty(long jarg1, StrVector jarg1_);
  public final static native void StrVector_clear(long jarg1, StrVector jarg1_);
  public final static native long new_StrVector__SWIG_2(int jarg1, String jarg2);
  public final static native int StrVector_doSize(long jarg1, StrVector jarg1_);
  public final static native void StrVector_doAdd__SWIG_0(long jarg1, StrVector jarg1_, String jarg2);
  public final static native void StrVector_doAdd__SWIG_1(long jarg1, StrVector jarg1_, int jarg2, String jarg3);
  public final static native String StrVector_doRemove(long jarg1, StrVector jarg1_, int jarg2);
  public final static native String StrVector_doGet(long jarg1, StrVector jarg1_, int jarg2);
  public final static native String StrVector_doSet(long jarg1, StrVector jarg1_, int jarg2, String jarg3);
  public final static native void StrVector_doRemoveRange(long jarg1, StrVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_StrVector(long jarg1);
  public final static native long new_BoolVector__SWIG_0();
  public final static native long new_BoolVector__SWIG_1(long jarg1, BoolVector jarg1_);
  public final static native long BoolVector_capacity(long jarg1, BoolVector jarg1_);
  public final static native void BoolVector_reserve(long jarg1, BoolVector jarg1_, long jarg2);
  public final static native boolean BoolVector_isEmpty(long jarg1, BoolVector jarg1_);
  public final static native void BoolVector_clear(long jarg1, BoolVector jarg1_);
  public final static native long new_BoolVector__SWIG_2(int jarg1, boolean jarg2);
  public final static native int BoolVector_doSize(long jarg1, BoolVector jarg1_);
  public final static native void BoolVector_doAdd__SWIG_0(long jarg1, BoolVector jarg1_, boolean jarg2);
  public final static native void BoolVector_doAdd__SWIG_1(long jarg1, BoolVector jarg1_, int jarg2, boolean jarg3);
  public final static native boolean BoolVector_doRemove(long jarg1, BoolVector jarg1_, int jarg2);
  public final static native boolean BoolVector_doGet(long jarg1, BoolVector jarg1_, int jarg2);
  public final static native boolean BoolVector_doSet(long jarg1, BoolVector jarg1_, int jarg2, boolean jarg3);
  public final static native void BoolVector_doRemoveRange(long jarg1, BoolVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_BoolVector(long jarg1);
  public final static native long new_DoubleVectorVector__SWIG_0();
  public final static native long new_DoubleVectorVector__SWIG_1(long jarg1, DoubleVectorVector jarg1_);
  public final static native long DoubleVectorVector_capacity(long jarg1, DoubleVectorVector jarg1_);
  public final static native void DoubleVectorVector_reserve(long jarg1, DoubleVectorVector jarg1_, long jarg2);
  public final static native boolean DoubleVectorVector_isEmpty(long jarg1, DoubleVectorVector jarg1_);
  public final static native void DoubleVectorVector_clear(long jarg1, DoubleVectorVector jarg1_);
  public final static native long new_DoubleVectorVector__SWIG_2(int jarg1, long jarg2, DoubleVector jarg2_);
  public final static native int DoubleVectorVector_doSize(long jarg1, DoubleVectorVector jarg1_);
  public final static native void DoubleVectorVector_doAdd__SWIG_0(long jarg1, DoubleVectorVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void DoubleVectorVector_doAdd__SWIG_1(long jarg1, DoubleVectorVector jarg1_, int jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long DoubleVectorVector_doRemove(long jarg1, DoubleVectorVector jarg1_, int jarg2);
  public final static native long DoubleVectorVector_doGet(long jarg1, DoubleVectorVector jarg1_, int jarg2);
  public final static native long DoubleVectorVector_doSet(long jarg1, DoubleVectorVector jarg1_, int jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void DoubleVectorVector_doRemoveRange(long jarg1, DoubleVectorVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_DoubleVectorVector(long jarg1);
  public final static native long new_DoublePair__SWIG_0();
  public final static native long new_DoublePair__SWIG_1(double jarg1, double jarg2);
  public final static native long new_DoublePair__SWIG_2(long jarg1, DoublePair jarg1_);
  public final static native void DoublePair_first_set(long jarg1, DoublePair jarg1_, double jarg2);
  public final static native double DoublePair_first_get(long jarg1, DoublePair jarg1_);
  public final static native void DoublePair_second_set(long jarg1, DoublePair jarg1_, double jarg2);
  public final static native double DoublePair_second_get(long jarg1, DoublePair jarg1_);
  public final static native void delete_DoublePair(long jarg1);
  public final static native long new_DoublePairVector__SWIG_0();
  public final static native long new_DoublePairVector__SWIG_1(long jarg1, DoublePairVector jarg1_);
  public final static native long DoublePairVector_capacity(long jarg1, DoublePairVector jarg1_);
  public final static native void DoublePairVector_reserve(long jarg1, DoublePairVector jarg1_, long jarg2);
  public final static native boolean DoublePairVector_isEmpty(long jarg1, DoublePairVector jarg1_);
  public final static native void DoublePairVector_clear(long jarg1, DoublePairVector jarg1_);
  public final static native long new_DoublePairVector__SWIG_2(int jarg1, long jarg2, DoublePair jarg2_);
  public final static native int DoublePairVector_doSize(long jarg1, DoublePairVector jarg1_);
  public final static native void DoublePairVector_doAdd__SWIG_0(long jarg1, DoublePairVector jarg1_, long jarg2, DoublePair jarg2_);
  public final static native void DoublePairVector_doAdd__SWIG_1(long jarg1, DoublePairVector jarg1_, int jarg2, long jarg3, DoublePair jarg3_);
  public final static native long DoublePairVector_doRemove(long jarg1, DoublePairVector jarg1_, int jarg2);
  public final static native long DoublePairVector_doGet(long jarg1, DoublePairVector jarg1_, int jarg2);
  public final static native long DoublePairVector_doSet(long jarg1, DoublePairVector jarg1_, int jarg2, long jarg3, DoublePair jarg3_);
  public final static native void DoublePairVector_doRemoveRange(long jarg1, DoublePairVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_DoublePairVector(long jarg1);
  public final static native long new_PairDoubleVector__SWIG_0();
  public final static native long new_PairDoubleVector__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long new_PairDoubleVector__SWIG_2(long jarg1, PairDoubleVector jarg1_);
  public final static native void PairDoubleVector_first_set(long jarg1, PairDoubleVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long PairDoubleVector_first_get(long jarg1, PairDoubleVector jarg1_);
  public final static native void PairDoubleVector_second_set(long jarg1, PairDoubleVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long PairDoubleVector_second_get(long jarg1, PairDoubleVector jarg1_);
  public final static native void delete_PairDoubleVector(long jarg1);
  public final static native long new_UnsignedIntPair__SWIG_0();
  public final static native long new_UnsignedIntPair__SWIG_1(long jarg1, long jarg2);
  public final static native long new_UnsignedIntPair__SWIG_2(long jarg1, UnsignedIntPair jarg1_);
  public final static native void UnsignedIntPair_first_set(long jarg1, UnsignedIntPair jarg1_, long jarg2);
  public final static native long UnsignedIntPair_first_get(long jarg1, UnsignedIntPair jarg1_);
  public final static native void UnsignedIntPair_second_set(long jarg1, UnsignedIntPair jarg1_, long jarg2);
  public final static native long UnsignedIntPair_second_get(long jarg1, UnsignedIntPair jarg1_);
  public final static native void delete_UnsignedIntPair(long jarg1);
  public final static native long new_UnsignedIntPairVector__SWIG_0();
  public final static native long new_UnsignedIntPairVector__SWIG_1(long jarg1, UnsignedIntPairVector jarg1_);
  public final static native long UnsignedIntPairVector_capacity(long jarg1, UnsignedIntPairVector jarg1_);
  public final static native void UnsignedIntPairVector_reserve(long jarg1, UnsignedIntPairVector jarg1_, long jarg2);
  public final static native boolean UnsignedIntPairVector_isEmpty(long jarg1, UnsignedIntPairVector jarg1_);
  public final static native void UnsignedIntPairVector_clear(long jarg1, UnsignedIntPairVector jarg1_);
  public final static native long new_UnsignedIntPairVector__SWIG_2(int jarg1, long jarg2, UnsignedIntPair jarg2_);
  public final static native int UnsignedIntPairVector_doSize(long jarg1, UnsignedIntPairVector jarg1_);
  public final static native void UnsignedIntPairVector_doAdd__SWIG_0(long jarg1, UnsignedIntPairVector jarg1_, long jarg2, UnsignedIntPair jarg2_);
  public final static native void UnsignedIntPairVector_doAdd__SWIG_1(long jarg1, UnsignedIntPairVector jarg1_, int jarg2, long jarg3, UnsignedIntPair jarg3_);
  public final static native long UnsignedIntPairVector_doRemove(long jarg1, UnsignedIntPairVector jarg1_, int jarg2);
  public final static native long UnsignedIntPairVector_doGet(long jarg1, UnsignedIntPairVector jarg1_, int jarg2);
  public final static native long UnsignedIntPairVector_doSet(long jarg1, UnsignedIntPairVector jarg1_, int jarg2, long jarg3, UnsignedIntPair jarg3_);
  public final static native void UnsignedIntPairVector_doRemoveRange(long jarg1, UnsignedIntPairVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_UnsignedIntPairVector(long jarg1);
  public final static native long new_NodePair__SWIG_0();
  public final static native long new_NodePair__SWIG_1(long jarg1, Date jarg1_, double jarg2);
  public final static native long new_NodePair__SWIG_2(long jarg1, NodePair jarg1_);
  public final static native void NodePair_first_set(long jarg1, NodePair jarg1_, long jarg2, Date jarg2_);
  public final static native long NodePair_first_get(long jarg1, NodePair jarg1_);
  public final static native void NodePair_second_set(long jarg1, NodePair jarg1_, double jarg2);
  public final static native double NodePair_second_get(long jarg1, NodePair jarg1_);
  public final static native void delete_NodePair(long jarg1);
  public final static native long new_NodeVector__SWIG_0();
  public final static native long new_NodeVector__SWIG_1(long jarg1, NodeVector jarg1_);
  public final static native long NodeVector_capacity(long jarg1, NodeVector jarg1_);
  public final static native void NodeVector_reserve(long jarg1, NodeVector jarg1_, long jarg2);
  public final static native boolean NodeVector_isEmpty(long jarg1, NodeVector jarg1_);
  public final static native void NodeVector_clear(long jarg1, NodeVector jarg1_);
  public final static native long new_NodeVector__SWIG_2(int jarg1, long jarg2, NodePair jarg2_);
  public final static native int NodeVector_doSize(long jarg1, NodeVector jarg1_);
  public final static native void NodeVector_doAdd__SWIG_0(long jarg1, NodeVector jarg1_, long jarg2, NodePair jarg2_);
  public final static native void NodeVector_doAdd__SWIG_1(long jarg1, NodeVector jarg1_, int jarg2, long jarg3, NodePair jarg3_);
  public final static native long NodeVector_doRemove(long jarg1, NodeVector jarg1_, int jarg2);
  public final static native long NodeVector_doGet(long jarg1, NodeVector jarg1_, int jarg2);
  public final static native long NodeVector_doSet(long jarg1, NodeVector jarg1_, int jarg2, long jarg3, NodePair jarg3_);
  public final static native void NodeVector_doRemoveRange(long jarg1, NodeVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_NodeVector(long jarg1);
  public final static native boolean Calendar_isWeekend(long jarg1, Calendar jarg1_, int jarg2);
  public final static native long Calendar_endOfMonth(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native boolean Calendar_isBusinessDay(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native boolean Calendar_isHoliday(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native boolean Calendar_isEndOfMonth(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native void Calendar_addHoliday(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native void Calendar_removeHoliday(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native void Calendar_resetAddedAndRemovedHolidays(long jarg1, Calendar jarg1_);
  public final static native long Calendar_adjust__SWIG_0(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, int jarg3);
  public final static native long Calendar_adjust__SWIG_1(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_);
  public final static native long Calendar_advance__SWIG_0(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, int jarg3, int jarg4, int jarg5, boolean jarg6);
  public final static native long Calendar_advance__SWIG_1(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, int jarg3, int jarg4, int jarg5);
  public final static native long Calendar_advance__SWIG_2(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, int jarg3, int jarg4);
  public final static native long Calendar_advance__SWIG_3(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, int jarg4, boolean jarg5);
  public final static native long Calendar_advance__SWIG_4(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, int jarg4);
  public final static native long Calendar_advance__SWIG_5(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native int Calendar_businessDaysBetween__SWIG_0(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, boolean jarg4, boolean jarg5);
  public final static native int Calendar_businessDaysBetween__SWIG_1(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, boolean jarg4);
  public final static native int Calendar_businessDaysBetween__SWIG_2(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native long Calendar_holidayList__SWIG_0(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, boolean jarg4);
  public final static native long Calendar_holidayList__SWIG_1(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native long Calendar_businessDayList(long jarg1, Calendar jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native String Calendar_name(long jarg1, Calendar jarg1_);
  public final static native String Calendar_toString(long jarg1, Calendar jarg1_);
  public final static native boolean Calendar_equals(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_);
  public final static native boolean Calendar_unEquals(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_);
  public final static native void delete_Calendar(long jarg1);
  public final static native long new_CalendarVector__SWIG_0();
  public final static native long new_CalendarVector__SWIG_1(long jarg1, CalendarVector jarg1_);
  public final static native long CalendarVector_capacity(long jarg1, CalendarVector jarg1_);
  public final static native void CalendarVector_reserve(long jarg1, CalendarVector jarg1_, long jarg2);
  public final static native boolean CalendarVector_isEmpty(long jarg1, CalendarVector jarg1_);
  public final static native void CalendarVector_clear(long jarg1, CalendarVector jarg1_);
  public final static native long new_CalendarVector__SWIG_2(int jarg1, long jarg2, Calendar jarg2_);
  public final static native int CalendarVector_doSize(long jarg1, CalendarVector jarg1_);
  public final static native void CalendarVector_doAdd__SWIG_0(long jarg1, CalendarVector jarg1_, long jarg2, Calendar jarg2_);
  public final static native void CalendarVector_doAdd__SWIG_1(long jarg1, CalendarVector jarg1_, int jarg2, long jarg3, Calendar jarg3_);
  public final static native long CalendarVector_doRemove(long jarg1, CalendarVector jarg1_, int jarg2);
  public final static native long CalendarVector_doGet(long jarg1, CalendarVector jarg1_, int jarg2);
  public final static native long CalendarVector_doSet(long jarg1, CalendarVector jarg1_, int jarg2, long jarg3, Calendar jarg3_);
  public final static native void CalendarVector_doRemoveRange(long jarg1, CalendarVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_CalendarVector(long jarg1);
  public final static native long new_Argentina__SWIG_0(int jarg1);
  public final static native long new_Argentina__SWIG_1();
  public final static native void delete_Argentina(long jarg1);
  public final static native long new_Australia__SWIG_0(int jarg1);
  public final static native long new_Australia__SWIG_1();
  public final static native void delete_Australia(long jarg1);
  public final static native long new_Austria__SWIG_0(int jarg1);
  public final static native long new_Austria__SWIG_1();
  public final static native void delete_Austria(long jarg1);
  public final static native long new_Botswana();
  public final static native void delete_Botswana(long jarg1);
  public final static native long new_Brazil__SWIG_0(int jarg1);
  public final static native long new_Brazil__SWIG_1();
  public final static native void delete_Brazil(long jarg1);
  public final static native long new_Canada__SWIG_0(int jarg1);
  public final static native long new_Canada__SWIG_1();
  public final static native void delete_Canada(long jarg1);
  public final static native long new_Chile__SWIG_0(int jarg1);
  public final static native long new_Chile__SWIG_1();
  public final static native void delete_Chile(long jarg1);
  public final static native long new_China__SWIG_0(int jarg1);
  public final static native long new_China__SWIG_1();
  public final static native void delete_China(long jarg1);
  public final static native long new_CzechRepublic__SWIG_0(int jarg1);
  public final static native long new_CzechRepublic__SWIG_1();
  public final static native void delete_CzechRepublic(long jarg1);
  public final static native long new_Denmark();
  public final static native void delete_Denmark(long jarg1);
  public final static native long new_Finland();
  public final static native void delete_Finland(long jarg1);
  public final static native long new_France__SWIG_0(int jarg1);
  public final static native long new_France__SWIG_1();
  public final static native void delete_France(long jarg1);
  public final static native long new_Germany__SWIG_0(int jarg1);
  public final static native long new_Germany__SWIG_1();
  public final static native void delete_Germany(long jarg1);
  public final static native long new_HongKong__SWIG_0(int jarg1);
  public final static native long new_HongKong__SWIG_1();
  public final static native void delete_HongKong(long jarg1);
  public final static native long new_Hungary();
  public final static native void delete_Hungary(long jarg1);
  public final static native long new_Iceland__SWIG_0(int jarg1);
  public final static native long new_Iceland__SWIG_1();
  public final static native void delete_Iceland(long jarg1);
  public final static native long new_India__SWIG_0(int jarg1);
  public final static native long new_India__SWIG_1();
  public final static native void delete_India(long jarg1);
  public final static native long new_Indonesia__SWIG_0(int jarg1);
  public final static native long new_Indonesia__SWIG_1();
  public final static native void delete_Indonesia(long jarg1);
  public final static native long new_Israel__SWIG_0(int jarg1);
  public final static native long new_Israel__SWIG_1();
  public final static native void delete_Israel(long jarg1);
  public final static native long new_Italy__SWIG_0(int jarg1);
  public final static native long new_Italy__SWIG_1();
  public final static native void delete_Italy(long jarg1);
  public final static native long new_Japan();
  public final static native void delete_Japan(long jarg1);
  public final static native long new_Mexico__SWIG_0(int jarg1);
  public final static native long new_Mexico__SWIG_1();
  public final static native void delete_Mexico(long jarg1);
  public final static native long new_NewZealand();
  public final static native void delete_NewZealand(long jarg1);
  public final static native long new_Norway();
  public final static native void delete_Norway(long jarg1);
  public final static native long new_Poland();
  public final static native void delete_Poland(long jarg1);
  public final static native long new_Romania__SWIG_0(int jarg1);
  public final static native long new_Romania__SWIG_1();
  public final static native void delete_Romania(long jarg1);
  public final static native long new_Russia__SWIG_0(int jarg1);
  public final static native long new_Russia__SWIG_1();
  public final static native void delete_Russia(long jarg1);
  public final static native long new_SaudiArabia__SWIG_0(int jarg1);
  public final static native long new_SaudiArabia__SWIG_1();
  public final static native void delete_SaudiArabia(long jarg1);
  public final static native long new_Singapore__SWIG_0(int jarg1);
  public final static native long new_Singapore__SWIG_1();
  public final static native void delete_Singapore(long jarg1);
  public final static native long new_Slovakia__SWIG_0(int jarg1);
  public final static native long new_Slovakia__SWIG_1();
  public final static native void delete_Slovakia(long jarg1);
  public final static native long new_SouthAfrica();
  public final static native void delete_SouthAfrica(long jarg1);
  public final static native long new_SouthKorea__SWIG_0(int jarg1);
  public final static native long new_SouthKorea__SWIG_1();
  public final static native void delete_SouthKorea(long jarg1);
  public final static native long new_Sweden();
  public final static native void delete_Sweden(long jarg1);
  public final static native long new_Switzerland();
  public final static native void delete_Switzerland(long jarg1);
  public final static native long new_Taiwan__SWIG_0(int jarg1);
  public final static native long new_Taiwan__SWIG_1();
  public final static native void delete_Taiwan(long jarg1);
  public final static native long new_TARGET();
  public final static native void delete_TARGET(long jarg1);
  public final static native long new_Thailand();
  public final static native void delete_Thailand(long jarg1);
  public final static native long new_Turkey();
  public final static native void delete_Turkey(long jarg1);
  public final static native long new_Ukraine__SWIG_0(int jarg1);
  public final static native long new_Ukraine__SWIG_1();
  public final static native void delete_Ukraine(long jarg1);
  public final static native long new_UnitedKingdom__SWIG_0(int jarg1);
  public final static native long new_UnitedKingdom__SWIG_1();
  public final static native void delete_UnitedKingdom(long jarg1);
  public final static native long new_UnitedStates(int jarg1);
  public final static native void delete_UnitedStates(long jarg1);
  public final static native long new_NullCalendar();
  public final static native void delete_NullCalendar(long jarg1);
  public final static native long new_WeekendsOnly();
  public final static native void delete_WeekendsOnly(long jarg1);
  public final static native long new_JointCalendar__SWIG_0(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_, int jarg3);
  public final static native long new_JointCalendar__SWIG_1(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_);
  public final static native long new_JointCalendar__SWIG_2(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_, long jarg3, Calendar jarg3_, int jarg4);
  public final static native long new_JointCalendar__SWIG_3(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_, long jarg3, Calendar jarg3_);
  public final static native long new_JointCalendar__SWIG_4(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_, long jarg3, Calendar jarg3_, long jarg4, Calendar jarg4_, int jarg5);
  public final static native long new_JointCalendar__SWIG_5(long jarg1, Calendar jarg1_, long jarg2, Calendar jarg2_, long jarg3, Calendar jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_JointCalendar__SWIG_6(long jarg1, CalendarVector jarg1_, int jarg2);
  public final static native long new_JointCalendar__SWIG_7(long jarg1, CalendarVector jarg1_);
  public final static native void delete_JointCalendar(long jarg1);
  public final static native long new_BespokeCalendar(String jarg1);
  public final static native void BespokeCalendar_addWeekend(long jarg1, BespokeCalendar jarg1_, int jarg2);
  public final static native void delete_BespokeCalendar(long jarg1);
  public final static native int nullInt();
  public final static native double nullDouble();
  public final static native int DayCounter_dayCount(long jarg1, DayCounter jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double DayCounter_yearFraction__SWIG_0(long jarg1, DayCounter jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double DayCounter_yearFraction__SWIG_1(long jarg1, DayCounter jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_);
  public final static native double DayCounter_yearFraction__SWIG_2(long jarg1, DayCounter jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native String DayCounter_name(long jarg1, DayCounter jarg1_);
  public final static native String DayCounter_toString(long jarg1, DayCounter jarg1_);
  public final static native boolean DayCounter_equals(long jarg1, DayCounter jarg1_, long jarg2, DayCounter jarg2_);
  public final static native boolean DayCounter_unEquals(long jarg1, DayCounter jarg1_, long jarg2, DayCounter jarg2_);
  public final static native void delete_DayCounter(long jarg1);
  public final static native long new_Actual360__SWIG_0(boolean jarg1);
  public final static native long new_Actual360__SWIG_1();
  public final static native void delete_Actual360(long jarg1);
  public final static native long new_Actual366__SWIG_0(boolean jarg1);
  public final static native long new_Actual366__SWIG_1();
  public final static native void delete_Actual366(long jarg1);
  public final static native long new_Actual36525__SWIG_0(boolean jarg1);
  public final static native long new_Actual36525__SWIG_1();
  public final static native void delete_Actual36525(long jarg1);
  public final static native long new_Actual364();
  public final static native void delete_Actual364(long jarg1);
  public final static native long new_Actual365Fixed__SWIG_0(int jarg1);
  public final static native long new_Actual365Fixed__SWIG_1();
  public final static native void delete_Actual365Fixed(long jarg1);
  public final static native long new_Thirty360__SWIG_0(int jarg1, long jarg2, Date jarg2_);
  public final static native long new_Thirty360__SWIG_1(int jarg1);
  public final static native void delete_Thirty360(long jarg1);
  public final static native long new_Thirty365();
  public final static native void delete_Thirty365(long jarg1);
  public final static native long new_ActualActual__SWIG_0(int jarg1, long jarg2, Schedule jarg2_);
  public final static native long new_ActualActual__SWIG_1(int jarg1);
  public final static native void delete_ActualActual(long jarg1);
  public final static native long new_OneDayCounter();
  public final static native void delete_OneDayCounter(long jarg1);
  public final static native long new_SimpleDayCounter();
  public final static native void delete_SimpleDayCounter(long jarg1);
  public final static native long new_Business252__SWIG_0(long jarg1, Calendar jarg1_);
  public final static native long new_Business252__SWIG_1();
  public final static native void delete_Business252(long jarg1);
  public final static native long yearFractionToDate(long jarg1, DayCounter jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native long new_Rounding();
  public final static native double Rounding_getValue(long jarg1, Rounding jarg1_, double jarg2);
  public final static native void delete_Rounding(long jarg1);
  public final static native long new_UpRounding__SWIG_0(int jarg1, int jarg2);
  public final static native long new_UpRounding__SWIG_1(int jarg1);
  public final static native void delete_UpRounding(long jarg1);
  public final static native long new_DownRounding__SWIG_0(int jarg1, int jarg2);
  public final static native long new_DownRounding__SWIG_1(int jarg1);
  public final static native void delete_DownRounding(long jarg1);
  public final static native long new_ClosestRounding__SWIG_0(int jarg1, int jarg2);
  public final static native long new_ClosestRounding__SWIG_1(int jarg1);
  public final static native void delete_ClosestRounding(long jarg1);
  public final static native long new_CeilingTruncation__SWIG_0(int jarg1, int jarg2);
  public final static native long new_CeilingTruncation__SWIG_1(int jarg1);
  public final static native void delete_CeilingTruncation(long jarg1);
  public final static native long new_FloorTruncation__SWIG_0(int jarg1, int jarg2);
  public final static native long new_FloorTruncation__SWIG_1(int jarg1);
  public final static native void delete_FloorTruncation(long jarg1);
  public final static native long new_Currency__SWIG_0();
  public final static native long new_Currency__SWIG_1(String jarg1, String jarg2, int jarg3, String jarg4, String jarg5, int jarg6, long jarg7, Rounding jarg7_, String jarg8, long jarg9, Currency jarg9_);
  public final static native long new_Currency__SWIG_2(String jarg1, String jarg2, int jarg3, String jarg4, String jarg5, int jarg6, long jarg7, Rounding jarg7_, String jarg8);
  public final static native String Currency_name(long jarg1, Currency jarg1_);
  public final static native String Currency_code(long jarg1, Currency jarg1_);
  public final static native int Currency_numericCode(long jarg1, Currency jarg1_);
  public final static native String Currency_symbol(long jarg1, Currency jarg1_);
  public final static native String Currency_fractionSymbol(long jarg1, Currency jarg1_);
  public final static native int Currency_fractionsPerUnit(long jarg1, Currency jarg1_);
  public final static native long Currency_rounding(long jarg1, Currency jarg1_);
  public final static native String Currency_format(long jarg1, Currency jarg1_);
  public final static native boolean Currency_empty(long jarg1, Currency jarg1_);
  public final static native long Currency_triangulationCurrency(long jarg1, Currency jarg1_);
  public final static native String Currency_toString(long jarg1, Currency jarg1_);
  public final static native boolean Currency_equals(long jarg1, Currency jarg1_, long jarg2, Currency jarg2_);
  public final static native boolean Currency_unEquals(long jarg1, Currency jarg1_, long jarg2, Currency jarg2_);
  public final static native void delete_Currency(long jarg1);
  public final static native long new_AEDCurrency();
  public final static native void delete_AEDCurrency(long jarg1);
  public final static native long new_AOACurrency();
  public final static native void delete_AOACurrency(long jarg1);
  public final static native long new_ARSCurrency();
  public final static native void delete_ARSCurrency(long jarg1);
  public final static native long new_ATSCurrency();
  public final static native void delete_ATSCurrency(long jarg1);
  public final static native long new_AUDCurrency();
  public final static native void delete_AUDCurrency(long jarg1);
  public final static native long new_BDTCurrency();
  public final static native void delete_BDTCurrency(long jarg1);
  public final static native long new_BEFCurrency();
  public final static native void delete_BEFCurrency(long jarg1);
  public final static native long new_BHDCurrency();
  public final static native void delete_BHDCurrency(long jarg1);
  public final static native long new_BGLCurrency();
  public final static native void delete_BGLCurrency(long jarg1);
  public final static native long new_BGNCurrency();
  public final static native void delete_BGNCurrency(long jarg1);
  public final static native long new_BRLCurrency();
  public final static native void delete_BRLCurrency(long jarg1);
  public final static native long new_BWPCurrency();
  public final static native void delete_BWPCurrency(long jarg1);
  public final static native long new_BYRCurrency();
  public final static native void delete_BYRCurrency(long jarg1);
  public final static native long new_CADCurrency();
  public final static native void delete_CADCurrency(long jarg1);
  public final static native long new_CHFCurrency();
  public final static native void delete_CHFCurrency(long jarg1);
  public final static native long new_CLFCurrency();
  public final static native void delete_CLFCurrency(long jarg1);
  public final static native long new_CLPCurrency();
  public final static native void delete_CLPCurrency(long jarg1);
  public final static native long new_CNHCurrency();
  public final static native void delete_CNHCurrency(long jarg1);
  public final static native long new_CNYCurrency();
  public final static native void delete_CNYCurrency(long jarg1);
  public final static native long new_COPCurrency();
  public final static native void delete_COPCurrency(long jarg1);
  public final static native long new_COUCurrency();
  public final static native void delete_COUCurrency(long jarg1);
  public final static native long new_CYPCurrency();
  public final static native void delete_CYPCurrency(long jarg1);
  public final static native long new_CZKCurrency();
  public final static native void delete_CZKCurrency(long jarg1);
  public final static native long new_DEMCurrency();
  public final static native void delete_DEMCurrency(long jarg1);
  public final static native long new_DKKCurrency();
  public final static native void delete_DKKCurrency(long jarg1);
  public final static native long new_EEKCurrency();
  public final static native void delete_EEKCurrency(long jarg1);
  public final static native long new_EGPCurrency();
  public final static native void delete_EGPCurrency(long jarg1);
  public final static native long new_ESPCurrency();
  public final static native void delete_ESPCurrency(long jarg1);
  public final static native long new_ETBCurrency();
  public final static native void delete_ETBCurrency(long jarg1);
  public final static native long new_EURCurrency();
  public final static native void delete_EURCurrency(long jarg1);
  public final static native long new_FIMCurrency();
  public final static native void delete_FIMCurrency(long jarg1);
  public final static native long new_FRFCurrency();
  public final static native void delete_FRFCurrency(long jarg1);
  public final static native long new_GELCurrency();
  public final static native void delete_GELCurrency(long jarg1);
  public final static native long new_GBPCurrency();
  public final static native void delete_GBPCurrency(long jarg1);
  public final static native long new_GHSCurrency();
  public final static native void delete_GHSCurrency(long jarg1);
  public final static native long new_GRDCurrency();
  public final static native void delete_GRDCurrency(long jarg1);
  public final static native long new_HKDCurrency();
  public final static native void delete_HKDCurrency(long jarg1);
  public final static native long new_HRKCurrency();
  public final static native void delete_HRKCurrency(long jarg1);
  public final static native long new_HUFCurrency();
  public final static native void delete_HUFCurrency(long jarg1);
  public final static native long new_IDRCurrency();
  public final static native void delete_IDRCurrency(long jarg1);
  public final static native long new_IEPCurrency();
  public final static native void delete_IEPCurrency(long jarg1);
  public final static native long new_ILSCurrency();
  public final static native void delete_ILSCurrency(long jarg1);
  public final static native long new_INRCurrency();
  public final static native void delete_INRCurrency(long jarg1);
  public final static native long new_IQDCurrency();
  public final static native void delete_IQDCurrency(long jarg1);
  public final static native long new_IRRCurrency();
  public final static native void delete_IRRCurrency(long jarg1);
  public final static native long new_ISKCurrency();
  public final static native void delete_ISKCurrency(long jarg1);
  public final static native long new_ITLCurrency();
  public final static native void delete_ITLCurrency(long jarg1);
  public final static native long new_JODCurrency();
  public final static native void delete_JODCurrency(long jarg1);
  public final static native long new_JPYCurrency();
  public final static native void delete_JPYCurrency(long jarg1);
  public final static native long new_KESCurrency();
  public final static native void delete_KESCurrency(long jarg1);
  public final static native long new_KRWCurrency();
  public final static native void delete_KRWCurrency(long jarg1);
  public final static native long new_KWDCurrency();
  public final static native void delete_KWDCurrency(long jarg1);
  public final static native long new_KZTCurrency();
  public final static native void delete_KZTCurrency(long jarg1);
  public final static native long new_LKRCurrency();
  public final static native void delete_LKRCurrency(long jarg1);
  public final static native long new_LTLCurrency();
  public final static native void delete_LTLCurrency(long jarg1);
  public final static native long new_LUFCurrency();
  public final static native void delete_LUFCurrency(long jarg1);
  public final static native long new_LVLCurrency();
  public final static native void delete_LVLCurrency(long jarg1);
  public final static native long new_MADCurrency();
  public final static native void delete_MADCurrency(long jarg1);
  public final static native long new_MTLCurrency();
  public final static native void delete_MTLCurrency(long jarg1);
  public final static native long new_MURCurrency();
  public final static native void delete_MURCurrency(long jarg1);
  public final static native long new_MXNCurrency();
  public final static native void delete_MXNCurrency(long jarg1);
  public final static native long new_MXVCurrency();
  public final static native void delete_MXVCurrency(long jarg1);
  public final static native long new_MYRCurrency();
  public final static native void delete_MYRCurrency(long jarg1);
  public final static native long new_NGNCurrency();
  public final static native void delete_NGNCurrency(long jarg1);
  public final static native long new_NLGCurrency();
  public final static native void delete_NLGCurrency(long jarg1);
  public final static native long new_NOKCurrency();
  public final static native void delete_NOKCurrency(long jarg1);
  public final static native long new_NPRCurrency();
  public final static native void delete_NPRCurrency(long jarg1);
  public final static native long new_NZDCurrency();
  public final static native void delete_NZDCurrency(long jarg1);
  public final static native long new_OMRCurrency();
  public final static native void delete_OMRCurrency(long jarg1);
  public final static native long new_PEHCurrency();
  public final static native void delete_PEHCurrency(long jarg1);
  public final static native long new_PEICurrency();
  public final static native void delete_PEICurrency(long jarg1);
  public final static native long new_PENCurrency();
  public final static native void delete_PENCurrency(long jarg1);
  public final static native long new_PHPCurrency();
  public final static native void delete_PHPCurrency(long jarg1);
  public final static native long new_PKRCurrency();
  public final static native void delete_PKRCurrency(long jarg1);
  public final static native long new_PLNCurrency();
  public final static native void delete_PLNCurrency(long jarg1);
  public final static native long new_PTECurrency();
  public final static native void delete_PTECurrency(long jarg1);
  public final static native long new_QARCurrency();
  public final static native void delete_QARCurrency(long jarg1);
  public final static native long new_ROLCurrency();
  public final static native void delete_ROLCurrency(long jarg1);
  public final static native long new_RONCurrency();
  public final static native void delete_RONCurrency(long jarg1);
  public final static native long new_RSDCurrency();
  public final static native void delete_RSDCurrency(long jarg1);
  public final static native long new_RUBCurrency();
  public final static native void delete_RUBCurrency(long jarg1);
  public final static native long new_SARCurrency();
  public final static native void delete_SARCurrency(long jarg1);
  public final static native long new_SEKCurrency();
  public final static native void delete_SEKCurrency(long jarg1);
  public final static native long new_SGDCurrency();
  public final static native void delete_SGDCurrency(long jarg1);
  public final static native long new_SITCurrency();
  public final static native void delete_SITCurrency(long jarg1);
  public final static native long new_SKKCurrency();
  public final static native void delete_SKKCurrency(long jarg1);
  public final static native long new_THBCurrency();
  public final static native void delete_THBCurrency(long jarg1);
  public final static native long new_TNDCurrency();
  public final static native void delete_TNDCurrency(long jarg1);
  public final static native long new_TRLCurrency();
  public final static native void delete_TRLCurrency(long jarg1);
  public final static native long new_TRYCurrency();
  public final static native void delete_TRYCurrency(long jarg1);
  public final static native long new_TTDCurrency();
  public final static native void delete_TTDCurrency(long jarg1);
  public final static native long new_TWDCurrency();
  public final static native void delete_TWDCurrency(long jarg1);
  public final static native long new_UAHCurrency();
  public final static native void delete_UAHCurrency(long jarg1);
  public final static native long new_UGXCurrency();
  public final static native void delete_UGXCurrency(long jarg1);
  public final static native long new_USDCurrency();
  public final static native void delete_USDCurrency(long jarg1);
  public final static native long new_UYUCurrency();
  public final static native void delete_UYUCurrency(long jarg1);
  public final static native long new_VEBCurrency();
  public final static native void delete_VEBCurrency(long jarg1);
  public final static native long new_VNDCurrency();
  public final static native void delete_VNDCurrency(long jarg1);
  public final static native long new_XOFCurrency();
  public final static native void delete_XOFCurrency(long jarg1);
  public final static native long new_ZARCurrency();
  public final static native void delete_ZARCurrency(long jarg1);
  public final static native long new_ZMWCurrency();
  public final static native void delete_ZMWCurrency(long jarg1);
  public final static native long new_BCHCurrency();
  public final static native void delete_BCHCurrency(long jarg1);
  public final static native long new_BTCCurrency();
  public final static native void delete_BTCCurrency(long jarg1);
  public final static native long new_DASHCurrency();
  public final static native void delete_DASHCurrency(long jarg1);
  public final static native long new_ETCCurrency();
  public final static native void delete_ETCCurrency(long jarg1);
  public final static native long new_ETHCurrency();
  public final static native void delete_ETHCurrency(long jarg1);
  public final static native long new_LTCCurrency();
  public final static native void delete_LTCCurrency(long jarg1);
  public final static native long new_XRPCurrency();
  public final static native void delete_XRPCurrency(long jarg1);
  public final static native long new_ZECCurrency();
  public final static native void delete_ZECCurrency(long jarg1);
  public final static native long new_InterestRate__SWIG_0();
  public final static native long new_InterestRate__SWIG_1(double jarg1, long jarg2, DayCounter jarg2_, int jarg3, int jarg4);
  public final static native double InterestRate_rate(long jarg1, InterestRate jarg1_);
  public final static native long InterestRate_dayCounter(long jarg1, InterestRate jarg1_);
  public final static native int InterestRate_compounding(long jarg1, InterestRate jarg1_);
  public final static native int InterestRate_frequency(long jarg1, InterestRate jarg1_);
  public final static native double InterestRate_discountFactor__SWIG_0(long jarg1, InterestRate jarg1_, double jarg2);
  public final static native double InterestRate_discountFactor__SWIG_1(long jarg1, InterestRate jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double InterestRate_discountFactor__SWIG_2(long jarg1, InterestRate jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_);
  public final static native double InterestRate_discountFactor__SWIG_3(long jarg1, InterestRate jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double InterestRate_compoundFactor__SWIG_0(long jarg1, InterestRate jarg1_, double jarg2);
  public final static native double InterestRate_compoundFactor__SWIG_1(long jarg1, InterestRate jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double InterestRate_compoundFactor__SWIG_2(long jarg1, InterestRate jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_);
  public final static native double InterestRate_compoundFactor__SWIG_3(long jarg1, InterestRate jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native long InterestRate_impliedRate__SWIG_0(double jarg1, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, double jarg5);
  public final static native long InterestRate_impliedRate__SWIG_1(double jarg1, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native long InterestRate_impliedRate__SWIG_2(double jarg1, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_);
  public final static native long InterestRate_impliedRate__SWIG_3(double jarg1, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_);
  public final static native long InterestRate_equivalentRate__SWIG_0(long jarg1, InterestRate jarg1_, int jarg2, int jarg3, double jarg4);
  public final static native long InterestRate_equivalentRate__SWIG_1(long jarg1, InterestRate jarg1_, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native long InterestRate_equivalentRate__SWIG_2(long jarg1, InterestRate jarg1_, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_);
  public final static native long InterestRate_equivalentRate__SWIG_3(long jarg1, InterestRate jarg1_, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_);
  public final static native String InterestRate_toString(long jarg1, InterestRate jarg1_);
  public final static native void delete_InterestRate(long jarg1);
  public final static native long new_InterestRateVector__SWIG_0();
  public final static native long new_InterestRateVector__SWIG_1(long jarg1, InterestRateVector jarg1_);
  public final static native long InterestRateVector_capacity(long jarg1, InterestRateVector jarg1_);
  public final static native void InterestRateVector_reserve(long jarg1, InterestRateVector jarg1_, long jarg2);
  public final static native boolean InterestRateVector_isEmpty(long jarg1, InterestRateVector jarg1_);
  public final static native void InterestRateVector_clear(long jarg1, InterestRateVector jarg1_);
  public final static native long new_InterestRateVector__SWIG_2(int jarg1, long jarg2, InterestRate jarg2_);
  public final static native int InterestRateVector_doSize(long jarg1, InterestRateVector jarg1_);
  public final static native void InterestRateVector_doAdd__SWIG_0(long jarg1, InterestRateVector jarg1_, long jarg2, InterestRate jarg2_);
  public final static native void InterestRateVector_doAdd__SWIG_1(long jarg1, InterestRateVector jarg1_, int jarg2, long jarg3, InterestRate jarg3_);
  public final static native long InterestRateVector_doRemove(long jarg1, InterestRateVector jarg1_, int jarg2);
  public final static native long InterestRateVector_doGet(long jarg1, InterestRateVector jarg1_, int jarg2);
  public final static native long InterestRateVector_doSet(long jarg1, InterestRateVector jarg1_, int jarg2, long jarg3, InterestRate jarg3_);
  public final static native void InterestRateVector_doRemoveRange(long jarg1, InterestRateVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_InterestRateVector(long jarg1);
  public final static native long new_Observable();
  public final static native void delete_Observable(long jarg1);
  public final static native long new_Array__SWIG_0();
  public final static native long new_Array__SWIG_1(long jarg1, double jarg2);
  public final static native long new_Array__SWIG_2(long jarg1);
  public final static native long new_Array__SWIG_3(long jarg1, Array jarg1_);
  public final static native long Array_size(long jarg1, Array jarg1_);
  public final static native String Array_toString(long jarg1, Array jarg1_);
  public final static native double Array_get(long jarg1, Array jarg1_, long jarg2);
  public final static native void Array_set(long jarg1, Array jarg1_, long jarg2, double jarg3);
  public final static native void delete_Array(long jarg1);
  public final static native long new_Matrix__SWIG_0();
  public final static native long new_Matrix__SWIG_1(long jarg1, long jarg2, double jarg3);
  public final static native long new_Matrix__SWIG_2(long jarg1, long jarg2);
  public final static native long new_Matrix__SWIG_3(long jarg1, Matrix jarg1_);
  public final static native long Matrix_rows(long jarg1, Matrix jarg1_);
  public final static native long Matrix_columns(long jarg1, Matrix jarg1_);
  public final static native String Matrix_toString(long jarg1, Matrix jarg1_);
  public final static native double Matrix_get(long jarg1, Matrix jarg1_, long jarg2, long jarg3);
  public final static native void Matrix_set(long jarg1, Matrix jarg1_, long jarg2, long jarg3, double jarg4);
  public final static native void delete_Matrix(long jarg1);
  public final static native long new_SalvagingAlgorithm();
  public final static native void delete_SalvagingAlgorithm(long jarg1);
  public final static native long inverse(long jarg1, Matrix jarg1_);
  public final static native long transpose(long jarg1, Matrix jarg1_);
  public final static native long outerProduct(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native long pseudoSqrt(long jarg1, Matrix jarg1_, int jarg2);
  public final static native long new_SVD(long jarg1, Matrix jarg1_);
  public final static native long SVD_U(long jarg1, SVD jarg1_);
  public final static native long SVD_V(long jarg1, SVD jarg1_);
  public final static native long SVD_S(long jarg1, SVD jarg1_);
  public final static native long SVD_singularValues(long jarg1, SVD jarg1_);
  public final static native void delete_SVD(long jarg1);
  public final static native void delete_MatrixMultiplicationDelegate(long jarg1);
  public final static native long MatrixMultiplicationDelegate_apply(long jarg1, MatrixMultiplicationDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long new_MatrixMultiplicationDelegate();
  public final static native long BiCGstab_solve__SWIG_0(long jarg1, BiCGstab jarg1_, long jarg2, Array jarg2_, long jarg3, Array jarg3_);
  public final static native long BiCGstab_solve__SWIG_1(long jarg1, BiCGstab jarg1_, long jarg2, Array jarg2_);
  public final static native long new_BiCGstab__SWIG_0(long jarg1, MatrixMultiplicationDelegate jarg1_, long jarg2, double jarg3);
  public final static native long new_BiCGstab__SWIG_1(long jarg1, MatrixMultiplicationDelegate jarg1_, long jarg2, double jarg3, long jarg4, MatrixMultiplicationDelegate jarg4_);
  public final static native void delete_BiCGstab(long jarg1);
  public final static native long GMRES_solve__SWIG_0(long jarg1, GMRES jarg1_, long jarg2, Array jarg2_, long jarg3, Array jarg3_);
  public final static native long GMRES_solve__SWIG_1(long jarg1, GMRES jarg1_, long jarg2, Array jarg2_);
  public final static native long GMRES_solveWithRestart__SWIG_0(long jarg1, GMRES jarg1_, long jarg2, long jarg3, Array jarg3_, long jarg4, Array jarg4_);
  public final static native long GMRES_solveWithRestart__SWIG_1(long jarg1, GMRES jarg1_, long jarg2, long jarg3, Array jarg3_);
  public final static native long new_GMRES__SWIG_0(long jarg1, MatrixMultiplicationDelegate jarg1_, long jarg2, double jarg3);
  public final static native long new_GMRES__SWIG_1(long jarg1, MatrixMultiplicationDelegate jarg1_, long jarg2, double jarg3, long jarg4);
  public final static native void delete_GMRES(long jarg1);
  public final static native boolean close__SWIG_0(double jarg1, double jarg2);
  public final static native boolean close__SWIG_1(double jarg1, double jarg2, long jarg3);
  public final static native boolean close_enough__SWIG_0(double jarg1, double jarg2);
  public final static native boolean close_enough__SWIG_1(double jarg1, double jarg2, long jarg3);
  public final static native long new_UnaryFunction(long jarg1, UnaryFunctionDelegate jarg1_);
  public final static native double UnaryFunction_getValue(long jarg1, UnaryFunction jarg1_, double jarg2);
  public final static native void delete_UnaryFunction(long jarg1);
  public final static native void delete_UnaryFunctionDelegate(long jarg1);
  public final static native double UnaryFunctionDelegate_value(long jarg1, UnaryFunctionDelegate jarg1_, double jarg2);
  public final static native double UnaryFunctionDelegate_valueSwigExplicitUnaryFunctionDelegate(long jarg1, UnaryFunctionDelegate jarg1_, double jarg2);
  public final static native long new_UnaryFunctionDelegate();
  public final static native void UnaryFunctionDelegate_director_connect(UnaryFunctionDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void UnaryFunctionDelegate_change_ownership(UnaryFunctionDelegate obj, long cptr, boolean take_or_release);
  public final static native long new_BinaryFunction(long jarg1, BinaryFunctionDelegate jarg1_);
  public final static native double BinaryFunction_getValue(long jarg1, BinaryFunction jarg1_, double jarg2, double jarg3);
  public final static native void delete_BinaryFunction(long jarg1);
  public final static native void delete_BinaryFunctionDelegate(long jarg1);
  public final static native double BinaryFunctionDelegate_value(long jarg1, BinaryFunctionDelegate jarg1_, double jarg2, double jarg3);
  public final static native double BinaryFunctionDelegate_valueSwigExplicitBinaryFunctionDelegate(long jarg1, BinaryFunctionDelegate jarg1_, double jarg2, double jarg3);
  public final static native long new_BinaryFunctionDelegate();
  public final static native void BinaryFunctionDelegate_director_connect(BinaryFunctionDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void BinaryFunctionDelegate_change_ownership(BinaryFunctionDelegate obj, long cptr, boolean take_or_release);
  public final static native long new_JavaCostFunction(long jarg1, CostFunctionDelegate jarg1_);
  public final static native void delete_JavaCostFunction(long jarg1);
  public final static native double JavaCostFunction_value(long jarg1, JavaCostFunction jarg1_, long jarg2, Array jarg2_);
  public final static native long JavaCostFunction_values(long jarg1, JavaCostFunction jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_CostFunctionDelegate(long jarg1);
  public final static native double CostFunctionDelegate_value(long jarg1, CostFunctionDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native double CostFunctionDelegate_valueSwigExplicitCostFunctionDelegate(long jarg1, CostFunctionDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long CostFunctionDelegate_values(long jarg1, CostFunctionDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long CostFunctionDelegate_valuesSwigExplicitCostFunctionDelegate(long jarg1, CostFunctionDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long new_CostFunctionDelegate();
  public final static native void CostFunctionDelegate_director_connect(CostFunctionDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void CostFunctionDelegate_change_ownership(CostFunctionDelegate obj, long cptr, boolean take_or_release);
  public final static native double Quote_value(long jarg1, Quote jarg1_);
  public final static native boolean Quote_isValid(long jarg1, Quote jarg1_);
  public final static native void delete_Quote(long jarg1);
  public final static native long new_QuoteHandle__SWIG_0(long jarg1, Quote jarg1_);
  public final static native long new_QuoteHandle__SWIG_1();
  public final static native long QuoteHandle___deref__(long jarg1, QuoteHandle jarg1_);
  public final static native long QuoteHandle_currentLink(long jarg1, QuoteHandle jarg1_);
  public final static native boolean QuoteHandle_empty(long jarg1, QuoteHandle jarg1_);
  public final static native long QuoteHandle_asObservable(long jarg1, QuoteHandle jarg1_);
  public final static native void delete_QuoteHandle(long jarg1);
  public final static native double QuoteHandle_value(long jarg1, QuoteHandle jarg1_);
  public final static native boolean QuoteHandle_isValid(long jarg1, QuoteHandle jarg1_);
  public final static native long new_RelinkableQuoteHandle__SWIG_0(long jarg1, Quote jarg1_);
  public final static native long new_RelinkableQuoteHandle__SWIG_1();
  public final static native void RelinkableQuoteHandle_linkTo(long jarg1, RelinkableQuoteHandle jarg1_, long jarg2, Quote jarg2_);
  public final static native void RelinkableQuoteHandle_reset(long jarg1, RelinkableQuoteHandle jarg1_);
  public final static native void delete_RelinkableQuoteHandle(long jarg1);
  public final static native long new_SimpleQuote(double jarg1);
  public final static native void SimpleQuote_setValue(long jarg1, SimpleQuote jarg1_, double jarg2);
  public final static native void delete_SimpleQuote(long jarg1);
  public final static native long new_LastFixingQuote(long jarg1);
  public final static native long LastFixingQuote_index(long jarg1, LastFixingQuote jarg1_);
  public final static native long LastFixingQuote_referenceDate(long jarg1, LastFixingQuote jarg1_);
  public final static native void delete_LastFixingQuote(long jarg1);
  public final static native long new_QuoteVector__SWIG_0();
  public final static native long new_QuoteVector__SWIG_1(long jarg1, QuoteVector jarg1_);
  public final static native long QuoteVector_capacity(long jarg1, QuoteVector jarg1_);
  public final static native void QuoteVector_reserve(long jarg1, QuoteVector jarg1_, long jarg2);
  public final static native boolean QuoteVector_isEmpty(long jarg1, QuoteVector jarg1_);
  public final static native void QuoteVector_clear(long jarg1, QuoteVector jarg1_);
  public final static native long new_QuoteVector__SWIG_2(int jarg1, long jarg2, Quote jarg2_);
  public final static native int QuoteVector_doSize(long jarg1, QuoteVector jarg1_);
  public final static native void QuoteVector_doAdd__SWIG_0(long jarg1, QuoteVector jarg1_, long jarg2, Quote jarg2_);
  public final static native void QuoteVector_doAdd__SWIG_1(long jarg1, QuoteVector jarg1_, int jarg2, long jarg3, Quote jarg3_);
  public final static native long QuoteVector_doRemove(long jarg1, QuoteVector jarg1_, int jarg2);
  public final static native long QuoteVector_doGet(long jarg1, QuoteVector jarg1_, int jarg2);
  public final static native long QuoteVector_doSet(long jarg1, QuoteVector jarg1_, int jarg2, long jarg3, Quote jarg3_);
  public final static native void QuoteVector_doRemoveRange(long jarg1, QuoteVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_QuoteVector(long jarg1);
  public final static native long new_QuoteVectorVector__SWIG_0();
  public final static native long new_QuoteVectorVector__SWIG_1(long jarg1, QuoteVectorVector jarg1_);
  public final static native long QuoteVectorVector_capacity(long jarg1, QuoteVectorVector jarg1_);
  public final static native void QuoteVectorVector_reserve(long jarg1, QuoteVectorVector jarg1_, long jarg2);
  public final static native boolean QuoteVectorVector_isEmpty(long jarg1, QuoteVectorVector jarg1_);
  public final static native void QuoteVectorVector_clear(long jarg1, QuoteVectorVector jarg1_);
  public final static native long new_QuoteVectorVector__SWIG_2(int jarg1, long jarg2, QuoteVector jarg2_);
  public final static native int QuoteVectorVector_doSize(long jarg1, QuoteVectorVector jarg1_);
  public final static native void QuoteVectorVector_doAdd__SWIG_0(long jarg1, QuoteVectorVector jarg1_, long jarg2, QuoteVector jarg2_);
  public final static native void QuoteVectorVector_doAdd__SWIG_1(long jarg1, QuoteVectorVector jarg1_, int jarg2, long jarg3, QuoteVector jarg3_);
  public final static native long QuoteVectorVector_doRemove(long jarg1, QuoteVectorVector jarg1_, int jarg2);
  public final static native long QuoteVectorVector_doGet(long jarg1, QuoteVectorVector jarg1_, int jarg2);
  public final static native long QuoteVectorVector_doSet(long jarg1, QuoteVectorVector jarg1_, int jarg2, long jarg3, QuoteVector jarg3_);
  public final static native void QuoteVectorVector_doRemoveRange(long jarg1, QuoteVectorVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_QuoteVectorVector(long jarg1);
  public final static native long new_QuoteHandleVector__SWIG_0();
  public final static native long new_QuoteHandleVector__SWIG_1(long jarg1, QuoteHandleVector jarg1_);
  public final static native long QuoteHandleVector_capacity(long jarg1, QuoteHandleVector jarg1_);
  public final static native void QuoteHandleVector_reserve(long jarg1, QuoteHandleVector jarg1_, long jarg2);
  public final static native boolean QuoteHandleVector_isEmpty(long jarg1, QuoteHandleVector jarg1_);
  public final static native void QuoteHandleVector_clear(long jarg1, QuoteHandleVector jarg1_);
  public final static native long new_QuoteHandleVector__SWIG_2(int jarg1, long jarg2, QuoteHandle jarg2_);
  public final static native int QuoteHandleVector_doSize(long jarg1, QuoteHandleVector jarg1_);
  public final static native void QuoteHandleVector_doAdd__SWIG_0(long jarg1, QuoteHandleVector jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native void QuoteHandleVector_doAdd__SWIG_1(long jarg1, QuoteHandleVector jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native long QuoteHandleVector_doRemove(long jarg1, QuoteHandleVector jarg1_, int jarg2);
  public final static native long QuoteHandleVector_doGet(long jarg1, QuoteHandleVector jarg1_, int jarg2);
  public final static native long QuoteHandleVector_doSet(long jarg1, QuoteHandleVector jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void QuoteHandleVector_doRemoveRange(long jarg1, QuoteHandleVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_QuoteHandleVector(long jarg1);
  public final static native long new_QuoteHandleVectorVector__SWIG_0();
  public final static native long new_QuoteHandleVectorVector__SWIG_1(long jarg1, QuoteHandleVectorVector jarg1_);
  public final static native long QuoteHandleVectorVector_capacity(long jarg1, QuoteHandleVectorVector jarg1_);
  public final static native void QuoteHandleVectorVector_reserve(long jarg1, QuoteHandleVectorVector jarg1_, long jarg2);
  public final static native boolean QuoteHandleVectorVector_isEmpty(long jarg1, QuoteHandleVectorVector jarg1_);
  public final static native void QuoteHandleVectorVector_clear(long jarg1, QuoteHandleVectorVector jarg1_);
  public final static native long new_QuoteHandleVectorVector__SWIG_2(int jarg1, long jarg2, QuoteHandleVector jarg2_);
  public final static native int QuoteHandleVectorVector_doSize(long jarg1, QuoteHandleVectorVector jarg1_);
  public final static native void QuoteHandleVectorVector_doAdd__SWIG_0(long jarg1, QuoteHandleVectorVector jarg1_, long jarg2, QuoteHandleVector jarg2_);
  public final static native void QuoteHandleVectorVector_doAdd__SWIG_1(long jarg1, QuoteHandleVectorVector jarg1_, int jarg2, long jarg3, QuoteHandleVector jarg3_);
  public final static native long QuoteHandleVectorVector_doRemove(long jarg1, QuoteHandleVectorVector jarg1_, int jarg2);
  public final static native long QuoteHandleVectorVector_doGet(long jarg1, QuoteHandleVectorVector jarg1_, int jarg2);
  public final static native long QuoteHandleVectorVector_doSet(long jarg1, QuoteHandleVectorVector jarg1_, int jarg2, long jarg3, QuoteHandleVector jarg3_);
  public final static native void QuoteHandleVectorVector_doRemoveRange(long jarg1, QuoteHandleVectorVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_QuoteHandleVectorVector(long jarg1);
  public final static native long new_RelinkableQuoteHandleVector__SWIG_0();
  public final static native long new_RelinkableQuoteHandleVector__SWIG_1(long jarg1, RelinkableQuoteHandleVector jarg1_);
  public final static native long RelinkableQuoteHandleVector_capacity(long jarg1, RelinkableQuoteHandleVector jarg1_);
  public final static native void RelinkableQuoteHandleVector_reserve(long jarg1, RelinkableQuoteHandleVector jarg1_, long jarg2);
  public final static native boolean RelinkableQuoteHandleVector_isEmpty(long jarg1, RelinkableQuoteHandleVector jarg1_);
  public final static native void RelinkableQuoteHandleVector_clear(long jarg1, RelinkableQuoteHandleVector jarg1_);
  public final static native long new_RelinkableQuoteHandleVector__SWIG_2(int jarg1, long jarg2, RelinkableQuoteHandle jarg2_);
  public final static native int RelinkableQuoteHandleVector_doSize(long jarg1, RelinkableQuoteHandleVector jarg1_);
  public final static native void RelinkableQuoteHandleVector_doAdd__SWIG_0(long jarg1, RelinkableQuoteHandleVector jarg1_, long jarg2, RelinkableQuoteHandle jarg2_);
  public final static native void RelinkableQuoteHandleVector_doAdd__SWIG_1(long jarg1, RelinkableQuoteHandleVector jarg1_, int jarg2, long jarg3, RelinkableQuoteHandle jarg3_);
  public final static native long RelinkableQuoteHandleVector_doRemove(long jarg1, RelinkableQuoteHandleVector jarg1_, int jarg2);
  public final static native long RelinkableQuoteHandleVector_doGet(long jarg1, RelinkableQuoteHandleVector jarg1_, int jarg2);
  public final static native long RelinkableQuoteHandleVector_doSet(long jarg1, RelinkableQuoteHandleVector jarg1_, int jarg2, long jarg3, RelinkableQuoteHandle jarg3_);
  public final static native void RelinkableQuoteHandleVector_doRemoveRange(long jarg1, RelinkableQuoteHandleVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_RelinkableQuoteHandleVector(long jarg1);
  public final static native long new_RelinkableQuoteHandleVectorVector__SWIG_0();
  public final static native long new_RelinkableQuoteHandleVectorVector__SWIG_1(long jarg1, RelinkableQuoteHandleVectorVector jarg1_);
  public final static native long RelinkableQuoteHandleVectorVector_capacity(long jarg1, RelinkableQuoteHandleVectorVector jarg1_);
  public final static native void RelinkableQuoteHandleVectorVector_reserve(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, long jarg2);
  public final static native boolean RelinkableQuoteHandleVectorVector_isEmpty(long jarg1, RelinkableQuoteHandleVectorVector jarg1_);
  public final static native void RelinkableQuoteHandleVectorVector_clear(long jarg1, RelinkableQuoteHandleVectorVector jarg1_);
  public final static native long new_RelinkableQuoteHandleVectorVector__SWIG_2(int jarg1, long jarg2, RelinkableQuoteHandleVector jarg2_);
  public final static native int RelinkableQuoteHandleVectorVector_doSize(long jarg1, RelinkableQuoteHandleVectorVector jarg1_);
  public final static native void RelinkableQuoteHandleVectorVector_doAdd__SWIG_0(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, long jarg2, RelinkableQuoteHandleVector jarg2_);
  public final static native void RelinkableQuoteHandleVectorVector_doAdd__SWIG_1(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, int jarg2, long jarg3, RelinkableQuoteHandleVector jarg3_);
  public final static native long RelinkableQuoteHandleVectorVector_doRemove(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, int jarg2);
  public final static native long RelinkableQuoteHandleVectorVector_doGet(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, int jarg2);
  public final static native long RelinkableQuoteHandleVectorVector_doSet(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, int jarg2, long jarg3, RelinkableQuoteHandleVector jarg3_);
  public final static native void RelinkableQuoteHandleVectorVector_doRemoveRange(long jarg1, RelinkableQuoteHandleVectorVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_RelinkableQuoteHandleVectorVector(long jarg1);
  public final static native void Brent_setMaxEvaluations(long jarg1, Brent jarg1_, long jarg2);
  public final static native void Brent_setLowerBound(long jarg1, Brent jarg1_, double jarg2);
  public final static native void Brent_setUpperBound(long jarg1, Brent jarg1_, double jarg2);
  public final static native double Brent_solve__SWIG_0(long jarg1, Brent jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native double Brent_solve__SWIG_1(long jarg1, Brent jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_Brent();
  public final static native void delete_Brent(long jarg1);
  public final static native void Bisection_setMaxEvaluations(long jarg1, Bisection jarg1_, long jarg2);
  public final static native void Bisection_setLowerBound(long jarg1, Bisection jarg1_, double jarg2);
  public final static native void Bisection_setUpperBound(long jarg1, Bisection jarg1_, double jarg2);
  public final static native double Bisection_solve__SWIG_0(long jarg1, Bisection jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native double Bisection_solve__SWIG_1(long jarg1, Bisection jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_Bisection();
  public final static native void delete_Bisection(long jarg1);
  public final static native void FalsePosition_setMaxEvaluations(long jarg1, FalsePosition jarg1_, long jarg2);
  public final static native void FalsePosition_setLowerBound(long jarg1, FalsePosition jarg1_, double jarg2);
  public final static native void FalsePosition_setUpperBound(long jarg1, FalsePosition jarg1_, double jarg2);
  public final static native double FalsePosition_solve__SWIG_0(long jarg1, FalsePosition jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native double FalsePosition_solve__SWIG_1(long jarg1, FalsePosition jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_FalsePosition();
  public final static native void delete_FalsePosition(long jarg1);
  public final static native void Ridder_setMaxEvaluations(long jarg1, Ridder jarg1_, long jarg2);
  public final static native void Ridder_setLowerBound(long jarg1, Ridder jarg1_, double jarg2);
  public final static native void Ridder_setUpperBound(long jarg1, Ridder jarg1_, double jarg2);
  public final static native double Ridder_solve__SWIG_0(long jarg1, Ridder jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native double Ridder_solve__SWIG_1(long jarg1, Ridder jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_Ridder();
  public final static native void delete_Ridder(long jarg1);
  public final static native void Secant_setMaxEvaluations(long jarg1, Secant jarg1_, long jarg2);
  public final static native void Secant_setLowerBound(long jarg1, Secant jarg1_, double jarg2);
  public final static native void Secant_setUpperBound(long jarg1, Secant jarg1_, double jarg2);
  public final static native double Secant_solve__SWIG_0(long jarg1, Secant jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native double Secant_solve__SWIG_1(long jarg1, Secant jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_Secant();
  public final static native void delete_Secant(long jarg1);
  public final static native void Newton_setMaxEvaluations(long jarg1, Newton jarg1_, long jarg2);
  public final static native void Newton_setLowerBound(long jarg1, Newton jarg1_, double jarg2);
  public final static native void Newton_setUpperBound(long jarg1, Newton jarg1_, double jarg2);
  public final static native double Newton_solve__SWIG_0(long jarg1, Newton jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, long jarg3, UnaryFunctionDelegate jarg3_, double jarg4, double jarg5, double jarg6);
  public final static native double Newton_solve__SWIG_1(long jarg1, Newton jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, long jarg3, UnaryFunctionDelegate jarg3_, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native long new_Newton();
  public final static native void delete_Newton(long jarg1);
  public final static native void NewtonSafe_setMaxEvaluations(long jarg1, NewtonSafe jarg1_, long jarg2);
  public final static native void NewtonSafe_setLowerBound(long jarg1, NewtonSafe jarg1_, double jarg2);
  public final static native void NewtonSafe_setUpperBound(long jarg1, NewtonSafe jarg1_, double jarg2);
  public final static native double NewtonSafe_solve__SWIG_0(long jarg1, NewtonSafe jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, long jarg3, UnaryFunctionDelegate jarg3_, double jarg4, double jarg5, double jarg6);
  public final static native double NewtonSafe_solve__SWIG_1(long jarg1, NewtonSafe jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, long jarg3, UnaryFunctionDelegate jarg3_, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native long new_NewtonSafe();
  public final static native void delete_NewtonSafe(long jarg1);
  public final static native void delete_Constraint(long jarg1);
  public final static native long new_BoundaryConstraint(double jarg1, double jarg2);
  public final static native void delete_BoundaryConstraint(long jarg1);
  public final static native long new_NoConstraint();
  public final static native void delete_NoConstraint(long jarg1);
  public final static native long new_PositiveConstraint();
  public final static native void delete_PositiveConstraint(long jarg1);
  public final static native long new_CompositeConstraint(long jarg1, Constraint jarg1_, long jarg2, Constraint jarg2_);
  public final static native void delete_CompositeConstraint(long jarg1);
  public final static native long new_NonhomogeneousBoundaryConstraint(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_NonhomogeneousBoundaryConstraint(long jarg1);
  public final static native long new_EndCriteria(long jarg1, long jarg2, double jarg3, double jarg4, double jarg5);
  public final static native boolean EndCriteria_getValue(long jarg1, EndCriteria jarg1_, long jarg2, long jarg3, boolean jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9);
  public final static native void delete_EndCriteria(long jarg1);
  public final static native void delete_OptimizationMethod(long jarg1);
  public final static native long new_ConjugateGradient();
  public final static native void delete_ConjugateGradient(long jarg1);
  public final static native long new_Simplex(double jarg1);
  public final static native double Simplex_lambda(long jarg1, Simplex jarg1_);
  public final static native void delete_Simplex(long jarg1);
  public final static native long new_SteepestDescent();
  public final static native void delete_SteepestDescent(long jarg1);
  public final static native long new_BFGS();
  public final static native void delete_BFGS(long jarg1);
  public final static native long new_LevenbergMarquardt__SWIG_0(double jarg1, double jarg2, double jarg3, boolean jarg4);
  public final static native long new_LevenbergMarquardt__SWIG_1(double jarg1, double jarg2, double jarg3);
  public final static native long new_LevenbergMarquardt__SWIG_2(double jarg1, double jarg2);
  public final static native long new_LevenbergMarquardt__SWIG_3(double jarg1);
  public final static native long new_LevenbergMarquardt__SWIG_4();
  public final static native void delete_LevenbergMarquardt(long jarg1);
  public final static native long new_DifferentialEvolution();
  public final static native void delete_DifferentialEvolution(long jarg1);
  public final static native long new_SamplerGaussian__SWIG_0(long jarg1);
  public final static native long new_SamplerGaussian__SWIG_1();
  public final static native void delete_SamplerGaussian(long jarg1);
  public final static native long new_SamplerLogNormal__SWIG_0(long jarg1);
  public final static native long new_SamplerLogNormal__SWIG_1();
  public final static native void delete_SamplerLogNormal(long jarg1);
  public final static native long new_SamplerMirrorGaussian__SWIG_0(long jarg1, Array jarg1_, long jarg2, Array jarg2_, long jarg3);
  public final static native long new_SamplerMirrorGaussian__SWIG_1(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_SamplerMirrorGaussian(long jarg1);
  public final static native long new_ProbabilityBoltzmannDownhill__SWIG_0(long jarg1);
  public final static native long new_ProbabilityBoltzmannDownhill__SWIG_1();
  public final static native void delete_ProbabilityBoltzmannDownhill(long jarg1);
  public final static native long new_TemperatureExponential__SWIG_0(double jarg1, long jarg2, double jarg3);
  public final static native long new_TemperatureExponential__SWIG_1(double jarg1, long jarg2);
  public final static native void delete_TemperatureExponential(long jarg1);
  public final static native long new_ReannealingTrivial();
  public final static native void delete_ReannealingTrivial(long jarg1);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_0(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7, int jarg8, long jarg9);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_1(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7, int jarg8);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_2(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_3(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_4(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_5(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_);
  public final static native long new_GaussianSimulatedAnnealing__SWIG_6(long jarg1, SamplerGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_);
  public final static native void delete_GaussianSimulatedAnnealing(long jarg1);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_0(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7, int jarg8, long jarg9);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_1(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7, int jarg8);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_2(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_3(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_4(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_5(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_);
  public final static native long new_MirrorGaussianSimulatedAnnealing__SWIG_6(long jarg1, SamplerMirrorGaussian jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_);
  public final static native void delete_MirrorGaussianSimulatedAnnealing(long jarg1);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_0(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7, int jarg8, long jarg9);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_1(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7, int jarg8);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_2(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6, long jarg7);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_3(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5, double jarg6);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_4(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_, double jarg5);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_5(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_, long jarg4, ReannealingTrivial jarg4_);
  public final static native long new_LogNormalSimulatedAnnealing__SWIG_6(long jarg1, SamplerLogNormal jarg1_, long jarg2, ProbabilityBoltzmannDownhill jarg2_, long jarg3, TemperatureExponential jarg3_);
  public final static native void delete_LogNormalSimulatedAnnealing(long jarg1);
  public final static native long Optimizer_solve(long jarg1, Optimizer jarg1_, long jarg2, CostFunctionDelegate jarg2_, long jarg3, Constraint jarg3_, long jarg4, OptimizationMethod jarg4_, long jarg5, EndCriteria jarg5_, long jarg6, Array jarg6_);
  public final static native long new_Optimizer();
  public final static native void delete_Optimizer(long jarg1);
  public final static native long new_LinearInterpolation(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double LinearInterpolation_getValue__SWIG_0(long jarg1, LinearInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double LinearInterpolation_getValue__SWIG_1(long jarg1, LinearInterpolation jarg1_, double jarg2);
  public final static native void delete_LinearInterpolation(long jarg1);
  public final static native long new_LogLinearInterpolation(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double LogLinearInterpolation_getValue__SWIG_0(long jarg1, LogLinearInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double LogLinearInterpolation_getValue__SWIG_1(long jarg1, LogLinearInterpolation jarg1_, double jarg2);
  public final static native void delete_LogLinearInterpolation(long jarg1);
  public final static native long new_BackwardFlatInterpolation(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double BackwardFlatInterpolation_getValue__SWIG_0(long jarg1, BackwardFlatInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double BackwardFlatInterpolation_getValue__SWIG_1(long jarg1, BackwardFlatInterpolation jarg1_, double jarg2);
  public final static native void delete_BackwardFlatInterpolation(long jarg1);
  public final static native long new_ForwardFlatInterpolation(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double ForwardFlatInterpolation_getValue__SWIG_0(long jarg1, ForwardFlatInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double ForwardFlatInterpolation_getValue__SWIG_1(long jarg1, ForwardFlatInterpolation jarg1_, double jarg2);
  public final static native void delete_ForwardFlatInterpolation(long jarg1);
  public final static native long new_CubicNaturalSpline(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double CubicNaturalSpline_getValue__SWIG_0(long jarg1, CubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double CubicNaturalSpline_getValue__SWIG_1(long jarg1, CubicNaturalSpline jarg1_, double jarg2);
  public final static native double CubicNaturalSpline_derivative__SWIG_0(long jarg1, CubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double CubicNaturalSpline_derivative__SWIG_1(long jarg1, CubicNaturalSpline jarg1_, double jarg2);
  public final static native double CubicNaturalSpline_secondDerivative__SWIG_0(long jarg1, CubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double CubicNaturalSpline_secondDerivative__SWIG_1(long jarg1, CubicNaturalSpline jarg1_, double jarg2);
  public final static native double CubicNaturalSpline_primitive__SWIG_0(long jarg1, CubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double CubicNaturalSpline_primitive__SWIG_1(long jarg1, CubicNaturalSpline jarg1_, double jarg2);
  public final static native void delete_CubicNaturalSpline(long jarg1);
  public final static native long new_LogCubicNaturalSpline(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double LogCubicNaturalSpline_getValue__SWIG_0(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double LogCubicNaturalSpline_getValue__SWIG_1(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2);
  public final static native double LogCubicNaturalSpline_derivative__SWIG_0(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double LogCubicNaturalSpline_derivative__SWIG_1(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2);
  public final static native double LogCubicNaturalSpline_secondDerivative__SWIG_0(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double LogCubicNaturalSpline_secondDerivative__SWIG_1(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2);
  public final static native double LogCubicNaturalSpline_primitive__SWIG_0(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double LogCubicNaturalSpline_primitive__SWIG_1(long jarg1, LogCubicNaturalSpline jarg1_, double jarg2);
  public final static native void delete_LogCubicNaturalSpline(long jarg1);
  public final static native long new_MonotonicCubicNaturalSpline(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double MonotonicCubicNaturalSpline_getValue__SWIG_0(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicCubicNaturalSpline_getValue__SWIG_1(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2);
  public final static native double MonotonicCubicNaturalSpline_derivative__SWIG_0(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicCubicNaturalSpline_derivative__SWIG_1(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2);
  public final static native double MonotonicCubicNaturalSpline_secondDerivative__SWIG_0(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicCubicNaturalSpline_secondDerivative__SWIG_1(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2);
  public final static native double MonotonicCubicNaturalSpline_primitive__SWIG_0(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicCubicNaturalSpline_primitive__SWIG_1(long jarg1, MonotonicCubicNaturalSpline jarg1_, double jarg2);
  public final static native void delete_MonotonicCubicNaturalSpline(long jarg1);
  public final static native long new_MonotonicLogCubicNaturalSpline(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double MonotonicLogCubicNaturalSpline_getValue__SWIG_0(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogCubicNaturalSpline_getValue__SWIG_1(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2);
  public final static native double MonotonicLogCubicNaturalSpline_derivative__SWIG_0(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogCubicNaturalSpline_derivative__SWIG_1(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2);
  public final static native double MonotonicLogCubicNaturalSpline_secondDerivative__SWIG_0(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogCubicNaturalSpline_secondDerivative__SWIG_1(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2);
  public final static native double MonotonicLogCubicNaturalSpline_primitive__SWIG_0(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogCubicNaturalSpline_primitive__SWIG_1(long jarg1, MonotonicLogCubicNaturalSpline jarg1_, double jarg2);
  public final static native void delete_MonotonicLogCubicNaturalSpline(long jarg1);
  public final static native long new_KrugerCubic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double KrugerCubic_getValue__SWIG_0(long jarg1, KrugerCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerCubic_getValue__SWIG_1(long jarg1, KrugerCubic jarg1_, double jarg2);
  public final static native double KrugerCubic_derivative__SWIG_0(long jarg1, KrugerCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerCubic_derivative__SWIG_1(long jarg1, KrugerCubic jarg1_, double jarg2);
  public final static native double KrugerCubic_secondDerivative__SWIG_0(long jarg1, KrugerCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerCubic_secondDerivative__SWIG_1(long jarg1, KrugerCubic jarg1_, double jarg2);
  public final static native double KrugerCubic_primitive__SWIG_0(long jarg1, KrugerCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerCubic_primitive__SWIG_1(long jarg1, KrugerCubic jarg1_, double jarg2);
  public final static native void delete_KrugerCubic(long jarg1);
  public final static native long new_KrugerLogCubic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double KrugerLogCubic_getValue__SWIG_0(long jarg1, KrugerLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerLogCubic_getValue__SWIG_1(long jarg1, KrugerLogCubic jarg1_, double jarg2);
  public final static native double KrugerLogCubic_derivative__SWIG_0(long jarg1, KrugerLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerLogCubic_derivative__SWIG_1(long jarg1, KrugerLogCubic jarg1_, double jarg2);
  public final static native double KrugerLogCubic_secondDerivative__SWIG_0(long jarg1, KrugerLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerLogCubic_secondDerivative__SWIG_1(long jarg1, KrugerLogCubic jarg1_, double jarg2);
  public final static native double KrugerLogCubic_primitive__SWIG_0(long jarg1, KrugerLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double KrugerLogCubic_primitive__SWIG_1(long jarg1, KrugerLogCubic jarg1_, double jarg2);
  public final static native void delete_KrugerLogCubic(long jarg1);
  public final static native long new_FritschButlandCubic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double FritschButlandCubic_getValue__SWIG_0(long jarg1, FritschButlandCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandCubic_getValue__SWIG_1(long jarg1, FritschButlandCubic jarg1_, double jarg2);
  public final static native double FritschButlandCubic_derivative__SWIG_0(long jarg1, FritschButlandCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandCubic_derivative__SWIG_1(long jarg1, FritschButlandCubic jarg1_, double jarg2);
  public final static native double FritschButlandCubic_secondDerivative__SWIG_0(long jarg1, FritschButlandCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandCubic_secondDerivative__SWIG_1(long jarg1, FritschButlandCubic jarg1_, double jarg2);
  public final static native double FritschButlandCubic_primitive__SWIG_0(long jarg1, FritschButlandCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandCubic_primitive__SWIG_1(long jarg1, FritschButlandCubic jarg1_, double jarg2);
  public final static native void delete_FritschButlandCubic(long jarg1);
  public final static native long new_FritschButlandLogCubic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double FritschButlandLogCubic_getValue__SWIG_0(long jarg1, FritschButlandLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandLogCubic_getValue__SWIG_1(long jarg1, FritschButlandLogCubic jarg1_, double jarg2);
  public final static native double FritschButlandLogCubic_derivative__SWIG_0(long jarg1, FritschButlandLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandLogCubic_derivative__SWIG_1(long jarg1, FritschButlandLogCubic jarg1_, double jarg2);
  public final static native double FritschButlandLogCubic_secondDerivative__SWIG_0(long jarg1, FritschButlandLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandLogCubic_secondDerivative__SWIG_1(long jarg1, FritschButlandLogCubic jarg1_, double jarg2);
  public final static native double FritschButlandLogCubic_primitive__SWIG_0(long jarg1, FritschButlandLogCubic jarg1_, double jarg2, boolean jarg3);
  public final static native double FritschButlandLogCubic_primitive__SWIG_1(long jarg1, FritschButlandLogCubic jarg1_, double jarg2);
  public final static native void delete_FritschButlandLogCubic(long jarg1);
  public final static native long new_Parabolic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double Parabolic_getValue__SWIG_0(long jarg1, Parabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double Parabolic_getValue__SWIG_1(long jarg1, Parabolic jarg1_, double jarg2);
  public final static native double Parabolic_derivative__SWIG_0(long jarg1, Parabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double Parabolic_derivative__SWIG_1(long jarg1, Parabolic jarg1_, double jarg2);
  public final static native double Parabolic_secondDerivative__SWIG_0(long jarg1, Parabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double Parabolic_secondDerivative__SWIG_1(long jarg1, Parabolic jarg1_, double jarg2);
  public final static native double Parabolic_primitive__SWIG_0(long jarg1, Parabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double Parabolic_primitive__SWIG_1(long jarg1, Parabolic jarg1_, double jarg2);
  public final static native void delete_Parabolic(long jarg1);
  public final static native long new_LogParabolic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double LogParabolic_getValue__SWIG_0(long jarg1, LogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double LogParabolic_getValue__SWIG_1(long jarg1, LogParabolic jarg1_, double jarg2);
  public final static native double LogParabolic_derivative__SWIG_0(long jarg1, LogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double LogParabolic_derivative__SWIG_1(long jarg1, LogParabolic jarg1_, double jarg2);
  public final static native double LogParabolic_secondDerivative__SWIG_0(long jarg1, LogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double LogParabolic_secondDerivative__SWIG_1(long jarg1, LogParabolic jarg1_, double jarg2);
  public final static native double LogParabolic_primitive__SWIG_0(long jarg1, LogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double LogParabolic_primitive__SWIG_1(long jarg1, LogParabolic jarg1_, double jarg2);
  public final static native void delete_LogParabolic(long jarg1);
  public final static native long new_MonotonicParabolic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double MonotonicParabolic_getValue__SWIG_0(long jarg1, MonotonicParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicParabolic_getValue__SWIG_1(long jarg1, MonotonicParabolic jarg1_, double jarg2);
  public final static native double MonotonicParabolic_derivative__SWIG_0(long jarg1, MonotonicParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicParabolic_derivative__SWIG_1(long jarg1, MonotonicParabolic jarg1_, double jarg2);
  public final static native double MonotonicParabolic_secondDerivative__SWIG_0(long jarg1, MonotonicParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicParabolic_secondDerivative__SWIG_1(long jarg1, MonotonicParabolic jarg1_, double jarg2);
  public final static native double MonotonicParabolic_primitive__SWIG_0(long jarg1, MonotonicParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicParabolic_primitive__SWIG_1(long jarg1, MonotonicParabolic jarg1_, double jarg2);
  public final static native void delete_MonotonicParabolic(long jarg1);
  public final static native long new_MonotonicLogParabolic(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double MonotonicLogParabolic_getValue__SWIG_0(long jarg1, MonotonicLogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogParabolic_getValue__SWIG_1(long jarg1, MonotonicLogParabolic jarg1_, double jarg2);
  public final static native double MonotonicLogParabolic_derivative__SWIG_0(long jarg1, MonotonicLogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogParabolic_derivative__SWIG_1(long jarg1, MonotonicLogParabolic jarg1_, double jarg2);
  public final static native double MonotonicLogParabolic_secondDerivative__SWIG_0(long jarg1, MonotonicLogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogParabolic_secondDerivative__SWIG_1(long jarg1, MonotonicLogParabolic jarg1_, double jarg2);
  public final static native double MonotonicLogParabolic_primitive__SWIG_0(long jarg1, MonotonicLogParabolic jarg1_, double jarg2, boolean jarg3);
  public final static native double MonotonicLogParabolic_primitive__SWIG_1(long jarg1, MonotonicLogParabolic jarg1_, double jarg2);
  public final static native void delete_MonotonicLogParabolic(long jarg1);
  public final static native long new_LagrangeInterpolation(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double LagrangeInterpolation_getValue__SWIG_0(long jarg1, LagrangeInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double LagrangeInterpolation_getValue__SWIG_1(long jarg1, LagrangeInterpolation jarg1_, double jarg2);
  public final static native void delete_LagrangeInterpolation(long jarg1);
  public final static native long new_BilinearInterpolation(long jarg1, Array jarg1_, long jarg2, Array jarg2_, long jarg3, Matrix jarg3_);
  public final static native double BilinearInterpolation_getValue__SWIG_0(long jarg1, BilinearInterpolation jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double BilinearInterpolation_getValue__SWIG_1(long jarg1, BilinearInterpolation jarg1_, double jarg2, double jarg3);
  public final static native void delete_BilinearInterpolation(long jarg1);
  public final static native long new_BicubicSpline(long jarg1, Array jarg1_, long jarg2, Array jarg2_, long jarg3, Matrix jarg3_);
  public final static native double BicubicSpline_getValue__SWIG_0(long jarg1, BicubicSpline jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double BicubicSpline_getValue__SWIG_1(long jarg1, BicubicSpline jarg1_, double jarg2, double jarg3);
  public final static native void delete_BicubicSpline(long jarg1);
  public final static native void delete_CubicInterpolation(long jarg1);
  public final static native void delete_MixedInterpolation(long jarg1);
  public final static native long new_BackwardFlat();
  public final static native void delete_BackwardFlat(long jarg1);
  public final static native long new_ForwardFlat();
  public final static native void delete_ForwardFlat(long jarg1);
  public final static native long new_Linear();
  public final static native void delete_Linear(long jarg1);
  public final static native long new_LogLinear();
  public final static native void delete_LogLinear(long jarg1);
  public final static native long new_Cubic();
  public final static native void delete_Cubic(long jarg1);
  public final static native long new_Bicubic();
  public final static native void delete_Bicubic(long jarg1);
  public final static native long new_MonotonicCubic();
  public final static native void delete_MonotonicCubic(long jarg1);
  public final static native long new_DefaultLogCubic();
  public final static native void delete_DefaultLogCubic(long jarg1);
  public final static native long new_MonotonicLogCubic();
  public final static native void delete_MonotonicLogCubic(long jarg1);
  public final static native long new_SplineCubic();
  public final static native void delete_SplineCubic(long jarg1);
  public final static native long new_SplineLogCubic();
  public final static native void delete_SplineLogCubic(long jarg1);
  public final static native long new_Kruger();
  public final static native void delete_Kruger(long jarg1);
  public final static native long new_KrugerLog();
  public final static native void delete_KrugerLog(long jarg1);
  public final static native long new_ConvexMonotone__SWIG_0(double jarg1, double jarg2, boolean jarg3);
  public final static native long new_ConvexMonotone__SWIG_1(double jarg1, double jarg2);
  public final static native long new_ConvexMonotone__SWIG_2(double jarg1);
  public final static native long new_ConvexMonotone__SWIG_3();
  public final static native void delete_ConvexMonotone(long jarg1);
  public final static native long new_LogMixedLinearCubic__SWIG_0(long jarg1, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_LogMixedLinearCubic__SWIG_1(long jarg1, int jarg2, int jarg3);
  public final static native long new_LogMixedLinearCubic__SWIG_2(long jarg1, int jarg2);
  public final static native long new_LogMixedLinearCubic__SWIG_3(long jarg1);
  public final static native long new_LogMixedLinearCubic__SWIG_4();
  public final static native void delete_LogMixedLinearCubic(long jarg1);
  public final static native long new_SABRInterpolation__SWIG_0(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13, long jarg14, EndCriteria jarg14_, long jarg15, OptimizationMethod jarg15_, double jarg16, boolean jarg17, long jarg18, double jarg19);
  public final static native long new_SABRInterpolation__SWIG_1(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13, long jarg14, EndCriteria jarg14_, long jarg15, OptimizationMethod jarg15_, double jarg16, boolean jarg17, long jarg18);
  public final static native long new_SABRInterpolation__SWIG_2(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13, long jarg14, EndCriteria jarg14_, long jarg15, OptimizationMethod jarg15_, double jarg16, boolean jarg17);
  public final static native long new_SABRInterpolation__SWIG_3(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13, long jarg14, EndCriteria jarg14_, long jarg15, OptimizationMethod jarg15_, double jarg16);
  public final static native long new_SABRInterpolation__SWIG_4(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13, long jarg14, EndCriteria jarg14_, long jarg15, OptimizationMethod jarg15_);
  public final static native long new_SABRInterpolation__SWIG_5(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13, long jarg14, EndCriteria jarg14_);
  public final static native long new_SABRInterpolation__SWIG_6(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_SABRInterpolation__SWIG_7(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11, boolean jarg12);
  public final static native long new_SABRInterpolation__SWIG_8(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10, boolean jarg11);
  public final static native long new_SABRInterpolation__SWIG_9(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9, boolean jarg10);
  public final static native long new_SABRInterpolation__SWIG_10(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, boolean jarg9);
  public final static native long new_SABRInterpolation__SWIG_11(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native double SABRInterpolation_getValue__SWIG_0(long jarg1, SABRInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double SABRInterpolation_getValue__SWIG_1(long jarg1, SABRInterpolation jarg1_, double jarg2);
  public final static native double SABRInterpolation_alpha(long jarg1, SABRInterpolation jarg1_);
  public final static native double SABRInterpolation_beta(long jarg1, SABRInterpolation jarg1_);
  public final static native double SABRInterpolation_rho(long jarg1, SABRInterpolation jarg1_);
  public final static native double SABRInterpolation_nu(long jarg1, SABRInterpolation jarg1_);
  public final static native void delete_SABRInterpolation(long jarg1);
  public final static native double RichardsonExtrapolation_getValue__SWIG_0(long jarg1, RichardsonExtrapolation jarg1_, double jarg2);
  public final static native double RichardsonExtrapolation_getValue__SWIG_1(long jarg1, RichardsonExtrapolation jarg1_);
  public final static native double RichardsonExtrapolation_getValue__SWIG_2(long jarg1, RichardsonExtrapolation jarg1_, double jarg2, double jarg3);
  public final static native long new_RichardsonExtrapolation__SWIG_0(long jarg1, UnaryFunctionDelegate jarg1_, double jarg2, double jarg3);
  public final static native long new_RichardsonExtrapolation__SWIG_1(long jarg1, UnaryFunctionDelegate jarg1_, double jarg2);
  public final static native void delete_RichardsonExtrapolation(long jarg1);
  public final static native long new_ChebyshevInterpolation__SWIG_0(long jarg1, Array jarg1_, int jarg2);
  public final static native long new_ChebyshevInterpolation__SWIG_1(long jarg1, Array jarg1_);
  public final static native long new_ChebyshevInterpolation__SWIG_2(long jarg1, long jarg2, UnaryFunctionDelegate jarg2_, int jarg3);
  public final static native long new_ChebyshevInterpolation__SWIG_3(long jarg1, long jarg2, UnaryFunctionDelegate jarg2_);
  public final static native double ChebyshevInterpolation_getValue__SWIG_0(long jarg1, ChebyshevInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double ChebyshevInterpolation_getValue__SWIG_1(long jarg1, ChebyshevInterpolation jarg1_, double jarg2);
  public final static native long ChebyshevInterpolation_nodes(long jarg1, int jarg2);
  public final static native void delete_ChebyshevInterpolation(long jarg1);
  public final static native long new_ConvexMonotoneInterpolation__SWIG_0(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, boolean jarg5);
  public final static native long new_ConvexMonotoneInterpolation__SWIG_1(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4);
  public final static native long new_ConvexMonotoneInterpolation__SWIG_2(long jarg1, Array jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native long new_ConvexMonotoneInterpolation__SWIG_3(long jarg1, Array jarg1_, long jarg2, Array jarg2_);
  public final static native double ConvexMonotoneInterpolation_getValue__SWIG_0(long jarg1, ConvexMonotoneInterpolation jarg1_, double jarg2, boolean jarg3);
  public final static native double ConvexMonotoneInterpolation_getValue__SWIG_1(long jarg1, ConvexMonotoneInterpolation jarg1_, double jarg2);
  public final static native void delete_ConvexMonotoneInterpolation(long jarg1);
  public final static native long TermStructure_dayCounter(long jarg1, TermStructure jarg1_);
  public final static native double TermStructure_timeFromReference(long jarg1, TermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native long TermStructure_calendar(long jarg1, TermStructure jarg1_);
  public final static native long TermStructure_referenceDate(long jarg1, TermStructure jarg1_);
  public final static native long TermStructure_maxDate(long jarg1, TermStructure jarg1_);
  public final static native double TermStructure_maxTime(long jarg1, TermStructure jarg1_);
  public final static native void TermStructure_enableExtrapolation(long jarg1, TermStructure jarg1_);
  public final static native void TermStructure_disableExtrapolation(long jarg1, TermStructure jarg1_);
  public final static native boolean TermStructure_allowsExtrapolation(long jarg1, TermStructure jarg1_);
  public final static native void delete_TermStructure(long jarg1);
  public final static native double YieldTermStructure_discount__SWIG_0(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double YieldTermStructure_discount__SWIG_1(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double YieldTermStructure_discount__SWIG_2(long jarg1, YieldTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double YieldTermStructure_discount__SWIG_3(long jarg1, YieldTermStructure jarg1_, double jarg2);
  public final static native long YieldTermStructure_zeroRate__SWIG_0(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native long YieldTermStructure_zeroRate__SWIG_1(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native long YieldTermStructure_zeroRate__SWIG_2(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, int jarg4);
  public final static native long YieldTermStructure_zeroRate__SWIG_3(long jarg1, YieldTermStructure jarg1_, double jarg2, int jarg3, int jarg4, boolean jarg5);
  public final static native long YieldTermStructure_zeroRate__SWIG_4(long jarg1, YieldTermStructure jarg1_, double jarg2, int jarg3, int jarg4);
  public final static native long YieldTermStructure_zeroRate__SWIG_5(long jarg1, YieldTermStructure jarg1_, double jarg2, int jarg3);
  public final static native long YieldTermStructure_forwardRate__SWIG_0(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7);
  public final static native long YieldTermStructure_forwardRate__SWIG_1(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long YieldTermStructure_forwardRate__SWIG_2(long jarg1, YieldTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long YieldTermStructure_forwardRate__SWIG_3(long jarg1, YieldTermStructure jarg1_, double jarg2, double jarg3, int jarg4, int jarg5, boolean jarg6);
  public final static native long YieldTermStructure_forwardRate__SWIG_4(long jarg1, YieldTermStructure jarg1_, double jarg2, double jarg3, int jarg4, int jarg5);
  public final static native long YieldTermStructure_forwardRate__SWIG_5(long jarg1, YieldTermStructure jarg1_, double jarg2, double jarg3, int jarg4);
  public final static native void delete_YieldTermStructure(long jarg1);
  public final static native long new_YieldTermStructureHandle__SWIG_0(long jarg1, YieldTermStructure jarg1_);
  public final static native long new_YieldTermStructureHandle__SWIG_1();
  public final static native long YieldTermStructureHandle___deref__(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long YieldTermStructureHandle_currentLink(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native boolean YieldTermStructureHandle_empty(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long YieldTermStructureHandle_asObservable(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native void delete_YieldTermStructureHandle(long jarg1);
  public final static native double YieldTermStructureHandle_discount__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double YieldTermStructureHandle_discount__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double YieldTermStructureHandle_discount__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double YieldTermStructureHandle_discount__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, double jarg2);
  public final static native long YieldTermStructureHandle_zeroRate__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native long YieldTermStructureHandle_zeroRate__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native long YieldTermStructureHandle_zeroRate__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, int jarg4);
  public final static native long YieldTermStructureHandle_zeroRate__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, int jarg3, int jarg4, boolean jarg5);
  public final static native long YieldTermStructureHandle_zeroRate__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, int jarg3, int jarg4);
  public final static native long YieldTermStructureHandle_zeroRate__SWIG_5(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, int jarg3);
  public final static native long YieldTermStructureHandle_forwardRate__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7);
  public final static native long YieldTermStructureHandle_forwardRate__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long YieldTermStructureHandle_forwardRate__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long YieldTermStructureHandle_forwardRate__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, int jarg4, int jarg5, boolean jarg6);
  public final static native long YieldTermStructureHandle_forwardRate__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, int jarg4, int jarg5);
  public final static native long YieldTermStructureHandle_forwardRate__SWIG_5(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, int jarg4);
  public final static native long YieldTermStructureHandle_dayCounter(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native double YieldTermStructureHandle_timeFromReference(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long YieldTermStructureHandle_calendar(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long YieldTermStructureHandle_referenceDate(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long YieldTermStructureHandle_maxDate(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native double YieldTermStructureHandle_maxTime(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native void YieldTermStructureHandle_enableExtrapolation(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native void YieldTermStructureHandle_disableExtrapolation(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native boolean YieldTermStructureHandle_allowsExtrapolation(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_RelinkableYieldTermStructureHandle__SWIG_0(long jarg1, YieldTermStructure jarg1_);
  public final static native long new_RelinkableYieldTermStructureHandle__SWIG_1();
  public final static native void RelinkableYieldTermStructureHandle_linkTo(long jarg1, RelinkableYieldTermStructureHandle jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native void RelinkableYieldTermStructureHandle_reset(long jarg1, RelinkableYieldTermStructureHandle jarg1_);
  public final static native void delete_RelinkableYieldTermStructureHandle(long jarg1);
  public final static native long new_ImpliedTermStructure(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_ImpliedTermStructure(long jarg1);
  public final static native long new_ZeroSpreadedTermStructure__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, int jarg3, int jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_ZeroSpreadedTermStructure__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, int jarg3, int jarg4);
  public final static native long new_ZeroSpreadedTermStructure__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, int jarg3);
  public final static native long new_ZeroSpreadedTermStructure__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native void delete_ZeroSpreadedTermStructure(long jarg1);
  public final static native long new_ForwardSpreadedTermStructure(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native void delete_ForwardSpreadedTermStructure(long jarg1);
  public final static native long new_PiecewiseZeroSpreadedTermStructure__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Linear jarg7_);
  public final static native long new_PiecewiseZeroSpreadedTermStructure__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_);
  public final static native long new_PiecewiseZeroSpreadedTermStructure__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5);
  public final static native long new_PiecewiseZeroSpreadedTermStructure__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4);
  public final static native long new_PiecewiseZeroSpreadedTermStructure__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_);
  public final static native void delete_PiecewiseZeroSpreadedTermStructure(long jarg1);
  public final static native long new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Linear jarg7_);
  public final static native long new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_);
  public final static native long new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5);
  public final static native long new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4);
  public final static native long new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_);
  public final static native void delete_SpreadedLinearZeroInterpolatedTermStructure(long jarg1);
  public final static native long new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, BackwardFlat jarg7_);
  public final static native long new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_);
  public final static native long new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4, int jarg5);
  public final static native long new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_, int jarg4);
  public final static native long new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandleVector jarg2_, long jarg3, DateVector jarg3_);
  public final static native void delete_SpreadedBackwardFlatZeroInterpolatedTermStructure(long jarg1);
  public final static native long new_FlatForward__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native long new_FlatForward__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_, int jarg4);
  public final static native long new_FlatForward__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_FlatForward__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native long new_FlatForward__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4);
  public final static native long new_FlatForward__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_);
  public final static native long new_FlatForward__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long new_FlatForward__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long new_FlatForward__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_FlatForward__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long new_FlatForward__SWIG_10(int jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long new_FlatForward__SWIG_11(int jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, DayCounter jarg4_);
  public final static native void delete_FlatForward(long jarg1);
  public final static native long new_UltimateForwardTermStructure(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, double jarg5);
  public final static native void delete_UltimateForwardTermStructure(long jarg1);
  public final static native long new_QuantoTermStructure(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, BlackVolTermStructureHandle jarg4_, double jarg5, long jarg6, BlackVolTermStructureHandle jarg6_, double jarg7, double jarg8);
  public final static native void delete_QuantoTermStructure(long jarg1);
  public final static native long new_RealTimeSeries__SWIG_0();
  public final static native long new_RealTimeSeries__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long RealTimeSeries_dates(long jarg1, RealTimeSeries jarg1_);
  public final static native long RealTimeSeries_values(long jarg1, RealTimeSeries jarg1_);
  public final static native long RealTimeSeries_size(long jarg1, RealTimeSeries jarg1_);
  public final static native void delete_RealTimeSeries(long jarg1);
  public final static native long new_IntervalPriceTimeSeries__SWIG_0();
  public final static native long new_IntervalPriceTimeSeries__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, IntervalPriceVector jarg2_);
  public final static native long IntervalPriceTimeSeries_dates(long jarg1, IntervalPriceTimeSeries jarg1_);
  public final static native long IntervalPriceTimeSeries_values(long jarg1, IntervalPriceTimeSeries jarg1_);
  public final static native long IntervalPriceTimeSeries_size(long jarg1, IntervalPriceTimeSeries jarg1_);
  public final static native void delete_IntervalPriceTimeSeries(long jarg1);
  public final static native long new_IntervalPriceVector__SWIG_0();
  public final static native long new_IntervalPriceVector__SWIG_1(long jarg1, IntervalPriceVector jarg1_);
  public final static native long IntervalPriceVector_capacity(long jarg1, IntervalPriceVector jarg1_);
  public final static native void IntervalPriceVector_reserve(long jarg1, IntervalPriceVector jarg1_, long jarg2);
  public final static native boolean IntervalPriceVector_isEmpty(long jarg1, IntervalPriceVector jarg1_);
  public final static native void IntervalPriceVector_clear(long jarg1, IntervalPriceVector jarg1_);
  public final static native long new_IntervalPriceVector__SWIG_2(int jarg1, long jarg2, IntervalPrice jarg2_);
  public final static native int IntervalPriceVector_doSize(long jarg1, IntervalPriceVector jarg1_);
  public final static native void IntervalPriceVector_doAdd__SWIG_0(long jarg1, IntervalPriceVector jarg1_, long jarg2, IntervalPrice jarg2_);
  public final static native void IntervalPriceVector_doAdd__SWIG_1(long jarg1, IntervalPriceVector jarg1_, int jarg2, long jarg3, IntervalPrice jarg3_);
  public final static native long IntervalPriceVector_doRemove(long jarg1, IntervalPriceVector jarg1_, int jarg2);
  public final static native long IntervalPriceVector_doGet(long jarg1, IntervalPriceVector jarg1_, int jarg2);
  public final static native long IntervalPriceVector_doSet(long jarg1, IntervalPriceVector jarg1_, int jarg2, long jarg3, IntervalPrice jarg3_);
  public final static native void IntervalPriceVector_doRemoveRange(long jarg1, IntervalPriceVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_IntervalPriceVector(long jarg1);
  public final static native long new_IntervalPrice(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native void IntervalPrice_setValue(long jarg1, IntervalPrice jarg1_, double jarg2, int jarg3);
  public final static native void IntervalPrice_setValues(long jarg1, IntervalPrice jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double IntervalPrice_value(long jarg1, IntervalPrice jarg1_, int jarg2);
  public final static native double IntervalPrice_open(long jarg1, IntervalPrice jarg1_);
  public final static native double IntervalPrice_close(long jarg1, IntervalPrice jarg1_);
  public final static native double IntervalPrice_high(long jarg1, IntervalPrice jarg1_);
  public final static native double IntervalPrice_low(long jarg1, IntervalPrice jarg1_);
  public final static native long IntervalPrice_makeSeries(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long IntervalPrice_extractValues(long jarg1, IntervalPriceTimeSeries jarg1_, int jarg2);
  public final static native long IntervalPrice_extractComponent(long jarg1, IntervalPriceTimeSeries jarg1_, int jarg2);
  public final static native void delete_IntervalPrice(long jarg1);
  public final static native long IndexManager_instance();
  public final static native void IndexManager_setHistory(long jarg1, IndexManager jarg1_, String jarg2, long jarg3, RealTimeSeries jarg3_);
  public final static native long IndexManager_getHistory(long jarg1, IndexManager jarg1_, String jarg2);
  public final static native boolean IndexManager_hasHistory(long jarg1, IndexManager jarg1_, String jarg2);
  public final static native long IndexManager_histories(long jarg1, IndexManager jarg1_);
  public final static native void IndexManager_clearHistory(long jarg1, IndexManager jarg1_, String jarg2);
  public final static native void IndexManager_clearHistories(long jarg1, IndexManager jarg1_);
  public final static native boolean IndexManager_hasHistoricalFixing(long jarg1, IndexManager jarg1_, String jarg2, long jarg3, Date jarg3_);
  public final static native void delete_IndexManager(long jarg1);
  public final static native String Index_name(long jarg1, Index jarg1_);
  public final static native long Index_fixingCalendar(long jarg1, Index jarg1_);
  public final static native boolean Index_isValidFixingDate(long jarg1, Index jarg1_, long jarg2, Date jarg2_);
  public final static native boolean Index_hasHistoricalFixing(long jarg1, Index jarg1_, long jarg2, Date jarg2_);
  public final static native double Index_fixing__SWIG_0(long jarg1, Index jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double Index_fixing__SWIG_1(long jarg1, Index jarg1_, long jarg2, Date jarg2_);
  public final static native void Index_addFixing__SWIG_0(long jarg1, Index jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native void Index_addFixing__SWIG_1(long jarg1, Index jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native long Index_timeSeries(long jarg1, Index jarg1_);
  public final static native void Index_clearFixings(long jarg1, Index jarg1_);
  public final static native void Index_addFixings__SWIG_0(long jarg1, Index jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4);
  public final static native void Index_addFixings__SWIG_1(long jarg1, Index jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native String Index_toString(long jarg1, Index jarg1_);
  public final static native void delete_Index(long jarg1);
  public final static native String InterestRateIndex_familyName(long jarg1, InterestRateIndex jarg1_);
  public final static native long InterestRateIndex_tenor(long jarg1, InterestRateIndex jarg1_);
  public final static native long InterestRateIndex_fixingDays(long jarg1, InterestRateIndex jarg1_);
  public final static native long InterestRateIndex_fixingDate(long jarg1, InterestRateIndex jarg1_, long jarg2, Date jarg2_);
  public final static native long InterestRateIndex_currency(long jarg1, InterestRateIndex jarg1_);
  public final static native long InterestRateIndex_dayCounter(long jarg1, InterestRateIndex jarg1_);
  public final static native long InterestRateIndex_maturityDate(long jarg1, InterestRateIndex jarg1_, long jarg2, Date jarg2_);
  public final static native long InterestRateIndex_valueDate(long jarg1, InterestRateIndex jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_InterestRateIndex(long jarg1);
  public final static native long new_IborIndex__SWIG_0(String jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Currency jarg4_, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, long jarg9, YieldTermStructureHandle jarg9_);
  public final static native long new_IborIndex__SWIG_1(String jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Currency jarg4_, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_);
  public final static native int IborIndex_businessDayConvention(long jarg1, IborIndex jarg1_);
  public final static native boolean IborIndex_endOfMonth(long jarg1, IborIndex jarg1_);
  public final static native long IborIndex_forwardingTermStructure(long jarg1, IborIndex jarg1_);
  public final static native long IborIndex_clone(long jarg1, IborIndex jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_IborIndex(long jarg1);
  public final static native long as_iborindex(long jarg1, InterestRateIndex jarg1_);
  public final static native long new_OvernightIndex__SWIG_0(String jarg1, int jarg2, long jarg3, Currency jarg3_, long jarg4, Calendar jarg4_, long jarg5, DayCounter jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_OvernightIndex__SWIG_1(String jarg1, int jarg2, long jarg3, Currency jarg3_, long jarg4, Calendar jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long OvernightIndex_clone(long jarg1, OvernightIndex jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_OvernightIndex(long jarg1);
  public final static native long new_Libor__SWIG_0(String jarg1, long jarg2, Period jarg2_, long jarg3, long jarg4, Currency jarg4_, long jarg5, Calendar jarg5_, long jarg6, DayCounter jarg6_, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native long new_Libor__SWIG_1(String jarg1, long jarg2, Period jarg2_, long jarg3, long jarg4, Currency jarg4_, long jarg5, Calendar jarg5_, long jarg6, DayCounter jarg6_);
  public final static native void delete_Libor(long jarg1);
  public final static native long new_DailyTenorLibor__SWIG_0(String jarg1, long jarg2, long jarg3, Currency jarg3_, long jarg4, Calendar jarg4_, long jarg5, DayCounter jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_DailyTenorLibor__SWIG_1(String jarg1, long jarg2, long jarg3, Currency jarg3_, long jarg4, Calendar jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void delete_DailyTenorLibor(long jarg1);
  public final static native long new_SwapIndex__SWIG_0(String jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Currency jarg4_, long jarg5, Calendar jarg5_, long jarg6, Period jarg6_, int jarg7, long jarg8, DayCounter jarg8_, long jarg9, IborIndex jarg9_);
  public final static native long new_SwapIndex__SWIG_1(String jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Currency jarg4_, long jarg5, Calendar jarg5_, long jarg6, Period jarg6_, int jarg7, long jarg8, DayCounter jarg8_, long jarg9, IborIndex jarg9_, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native long SwapIndex_fixedLegTenor(long jarg1, SwapIndex jarg1_);
  public final static native int SwapIndex_fixedLegConvention(long jarg1, SwapIndex jarg1_);
  public final static native long SwapIndex_iborIndex(long jarg1, SwapIndex jarg1_);
  public final static native long SwapIndex_forwardingTermStructure(long jarg1, SwapIndex jarg1_);
  public final static native long SwapIndex_discountingTermStructure(long jarg1, SwapIndex jarg1_);
  public final static native long SwapIndex_clone__SWIG_0(long jarg1, SwapIndex jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long SwapIndex_clone__SWIG_1(long jarg1, SwapIndex jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long SwapIndex_clone__SWIG_2(long jarg1, SwapIndex jarg1_, long jarg2, Period jarg2_);
  public final static native void delete_SwapIndex(long jarg1);
  public final static native long new_SwapIndexVector__SWIG_0();
  public final static native long new_SwapIndexVector__SWIG_1(long jarg1, SwapIndexVector jarg1_);
  public final static native long SwapIndexVector_capacity(long jarg1, SwapIndexVector jarg1_);
  public final static native void SwapIndexVector_reserve(long jarg1, SwapIndexVector jarg1_, long jarg2);
  public final static native boolean SwapIndexVector_isEmpty(long jarg1, SwapIndexVector jarg1_);
  public final static native void SwapIndexVector_clear(long jarg1, SwapIndexVector jarg1_);
  public final static native long new_SwapIndexVector__SWIG_2(int jarg1, long jarg2, SwapIndex jarg2_);
  public final static native int SwapIndexVector_doSize(long jarg1, SwapIndexVector jarg1_);
  public final static native void SwapIndexVector_doAdd__SWIG_0(long jarg1, SwapIndexVector jarg1_, long jarg2, SwapIndex jarg2_);
  public final static native void SwapIndexVector_doAdd__SWIG_1(long jarg1, SwapIndexVector jarg1_, int jarg2, long jarg3, SwapIndex jarg3_);
  public final static native long SwapIndexVector_doRemove(long jarg1, SwapIndexVector jarg1_, int jarg2);
  public final static native long SwapIndexVector_doGet(long jarg1, SwapIndexVector jarg1_, int jarg2);
  public final static native long SwapIndexVector_doSet(long jarg1, SwapIndexVector jarg1_, int jarg2, long jarg3, SwapIndex jarg3_);
  public final static native void SwapIndexVector_doRemoveRange(long jarg1, SwapIndexVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_SwapIndexVector(long jarg1);
  public final static native long as_swap_index(long jarg1, InterestRateIndex jarg1_);
  public final static native long new_SwapSpreadIndex__SWIG_0(String jarg1, long jarg2, SwapIndex jarg2_, long jarg3, SwapIndex jarg3_, double jarg4, double jarg5);
  public final static native long new_SwapSpreadIndex__SWIG_1(String jarg1, long jarg2, SwapIndex jarg2_, long jarg3, SwapIndex jarg3_, double jarg4);
  public final static native long new_SwapSpreadIndex__SWIG_2(String jarg1, long jarg2, SwapIndex jarg2_, long jarg3, SwapIndex jarg3_);
  public final static native double SwapSpreadIndex_forecastFixing(long jarg1, SwapSpreadIndex jarg1_, long jarg2, Date jarg2_);
  public final static native double SwapSpreadIndex_pastFixing(long jarg1, SwapSpreadIndex jarg1_, long jarg2, Date jarg2_);
  public final static native long SwapSpreadIndex_swapIndex1(long jarg1, SwapSpreadIndex jarg1_);
  public final static native long SwapSpreadIndex_swapIndex2(long jarg1, SwapSpreadIndex jarg1_);
  public final static native double SwapSpreadIndex_gearing1(long jarg1, SwapSpreadIndex jarg1_);
  public final static native double SwapSpreadIndex_gearing2(long jarg1, SwapSpreadIndex jarg1_);
  public final static native void delete_SwapSpreadIndex(long jarg1);
  public final static native long new_EquityIndex__SWIG_0(String jarg1, long jarg2, Calendar jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, long jarg5, QuoteHandle jarg5_);
  public final static native long new_EquityIndex__SWIG_1(String jarg1, long jarg2, Calendar jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native long new_EquityIndex__SWIG_2(String jarg1, long jarg2, Calendar jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_EquityIndex__SWIG_3(String jarg1, long jarg2, Calendar jarg2_);
  public final static native long EquityIndex_equityInterestRateCurve(long jarg1, EquityIndex jarg1_);
  public final static native long EquityIndex_equityDividendCurve(long jarg1, EquityIndex jarg1_);
  public final static native long EquityIndex_spot(long jarg1, EquityIndex jarg1_);
  public final static native long EquityIndex_clone(long jarg1, EquityIndex jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native void delete_EquityIndex(long jarg1);
  public final static native long new_AUDLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_AUDLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_AUDLibor(long jarg1);
  public final static native long new_CADLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_CADLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_CADLibor(long jarg1);
  public final static native long new_CADLiborON__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_CADLiborON__SWIG_1();
  public final static native void delete_CADLiborON(long jarg1);
  public final static native long new_Cdor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Cdor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Cdor(long jarg1);
  public final static native long new_CHFLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_CHFLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_CHFLibor(long jarg1);
  public final static native long new_DKKLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_DKKLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_DKKLibor(long jarg1);
  public final static native long new_Bbsw__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Bbsw__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Bbsw(long jarg1);
  public final static native long new_Bbsw1M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bbsw1M__SWIG_1();
  public final static native void delete_Bbsw1M(long jarg1);
  public final static native long new_Bbsw2M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bbsw2M__SWIG_1();
  public final static native void delete_Bbsw2M(long jarg1);
  public final static native long new_Bbsw3M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bbsw3M__SWIG_1();
  public final static native void delete_Bbsw3M(long jarg1);
  public final static native long new_Bbsw4M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bbsw4M__SWIG_1();
  public final static native void delete_Bbsw4M(long jarg1);
  public final static native long new_Bbsw5M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bbsw5M__SWIG_1();
  public final static native void delete_Bbsw5M(long jarg1);
  public final static native long new_Bbsw6M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bbsw6M__SWIG_1();
  public final static native void delete_Bbsw6M(long jarg1);
  public final static native long new_Bkbm__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Bkbm__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Bkbm(long jarg1);
  public final static native long new_Bkbm1M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bkbm1M__SWIG_1();
  public final static native void delete_Bkbm1M(long jarg1);
  public final static native long new_Bkbm2M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bkbm2M__SWIG_1();
  public final static native void delete_Bkbm2M(long jarg1);
  public final static native long new_Bkbm3M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bkbm3M__SWIG_1();
  public final static native void delete_Bkbm3M(long jarg1);
  public final static native long new_Bkbm4M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bkbm4M__SWIG_1();
  public final static native void delete_Bkbm4M(long jarg1);
  public final static native long new_Bkbm5M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bkbm5M__SWIG_1();
  public final static native void delete_Bkbm5M(long jarg1);
  public final static native long new_Bkbm6M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bkbm6M__SWIG_1();
  public final static native void delete_Bkbm6M(long jarg1);
  public final static native long new_Euribor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Euribor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Euribor(long jarg1);
  public final static native long new_EuriborSW__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EuriborSW__SWIG_1();
  public final static native void delete_EuriborSW(long jarg1);
  public final static native long new_Euribor2W__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor2W__SWIG_1();
  public final static native void delete_Euribor2W(long jarg1);
  public final static native long new_Euribor3W__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor3W__SWIG_1();
  public final static native void delete_Euribor3W(long jarg1);
  public final static native long new_Euribor1M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor1M__SWIG_1();
  public final static native void delete_Euribor1M(long jarg1);
  public final static native long new_Euribor2M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor2M__SWIG_1();
  public final static native void delete_Euribor2M(long jarg1);
  public final static native long new_Euribor3M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor3M__SWIG_1();
  public final static native void delete_Euribor3M(long jarg1);
  public final static native long new_Euribor4M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor4M__SWIG_1();
  public final static native void delete_Euribor4M(long jarg1);
  public final static native long new_Euribor5M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor5M__SWIG_1();
  public final static native void delete_Euribor5M(long jarg1);
  public final static native long new_Euribor6M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor6M__SWIG_1();
  public final static native void delete_Euribor6M(long jarg1);
  public final static native long new_Euribor7M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor7M__SWIG_1();
  public final static native void delete_Euribor7M(long jarg1);
  public final static native long new_Euribor8M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor8M__SWIG_1();
  public final static native void delete_Euribor8M(long jarg1);
  public final static native long new_Euribor9M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor9M__SWIG_1();
  public final static native void delete_Euribor9M(long jarg1);
  public final static native long new_Euribor10M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor10M__SWIG_1();
  public final static native void delete_Euribor10M(long jarg1);
  public final static native long new_Euribor11M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor11M__SWIG_1();
  public final static native void delete_Euribor11M(long jarg1);
  public final static native long new_Euribor1Y__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor1Y__SWIG_1();
  public final static native void delete_Euribor1Y(long jarg1);
  public final static native long new_Euribor365__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Euribor365__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Euribor365(long jarg1);
  public final static native long new_Euribor365_SW__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_SW__SWIG_1();
  public final static native void delete_Euribor365_SW(long jarg1);
  public final static native long new_Euribor365_2W__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_2W__SWIG_1();
  public final static native void delete_Euribor365_2W(long jarg1);
  public final static native long new_Euribor365_3W__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_3W__SWIG_1();
  public final static native void delete_Euribor365_3W(long jarg1);
  public final static native long new_Euribor365_1M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_1M__SWIG_1();
  public final static native void delete_Euribor365_1M(long jarg1);
  public final static native long new_Euribor365_2M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_2M__SWIG_1();
  public final static native void delete_Euribor365_2M(long jarg1);
  public final static native long new_Euribor365_3M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_3M__SWIG_1();
  public final static native void delete_Euribor365_3M(long jarg1);
  public final static native long new_Euribor365_4M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_4M__SWIG_1();
  public final static native void delete_Euribor365_4M(long jarg1);
  public final static native long new_Euribor365_5M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_5M__SWIG_1();
  public final static native void delete_Euribor365_5M(long jarg1);
  public final static native long new_Euribor365_6M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_6M__SWIG_1();
  public final static native void delete_Euribor365_6M(long jarg1);
  public final static native long new_Euribor365_7M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_7M__SWIG_1();
  public final static native void delete_Euribor365_7M(long jarg1);
  public final static native long new_Euribor365_8M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_8M__SWIG_1();
  public final static native void delete_Euribor365_8M(long jarg1);
  public final static native long new_Euribor365_9M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_9M__SWIG_1();
  public final static native void delete_Euribor365_9M(long jarg1);
  public final static native long new_Euribor365_10M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_10M__SWIG_1();
  public final static native void delete_Euribor365_10M(long jarg1);
  public final static native long new_Euribor365_11M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_11M__SWIG_1();
  public final static native void delete_Euribor365_11M(long jarg1);
  public final static native long new_Euribor365_1Y__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Euribor365_1Y__SWIG_1();
  public final static native void delete_Euribor365_1Y(long jarg1);
  public final static native long new_EURLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EURLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_EURLibor(long jarg1);
  public final static native long new_EURLiborSW__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLiborSW__SWIG_1();
  public final static native void delete_EURLiborSW(long jarg1);
  public final static native long new_EURLibor2W__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor2W__SWIG_1();
  public final static native void delete_EURLibor2W(long jarg1);
  public final static native long new_EURLibor1M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor1M__SWIG_1();
  public final static native void delete_EURLibor1M(long jarg1);
  public final static native long new_EURLibor2M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor2M__SWIG_1();
  public final static native void delete_EURLibor2M(long jarg1);
  public final static native long new_EURLibor3M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor3M__SWIG_1();
  public final static native void delete_EURLibor3M(long jarg1);
  public final static native long new_EURLibor4M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor4M__SWIG_1();
  public final static native void delete_EURLibor4M(long jarg1);
  public final static native long new_EURLibor5M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor5M__SWIG_1();
  public final static native void delete_EURLibor5M(long jarg1);
  public final static native long new_EURLibor6M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor6M__SWIG_1();
  public final static native void delete_EURLibor6M(long jarg1);
  public final static native long new_EURLibor7M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor7M__SWIG_1();
  public final static native void delete_EURLibor7M(long jarg1);
  public final static native long new_EURLibor8M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor8M__SWIG_1();
  public final static native void delete_EURLibor8M(long jarg1);
  public final static native long new_EURLibor9M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor9M__SWIG_1();
  public final static native void delete_EURLibor9M(long jarg1);
  public final static native long new_EURLibor10M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor10M__SWIG_1();
  public final static native void delete_EURLibor10M(long jarg1);
  public final static native long new_EURLibor11M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor11M__SWIG_1();
  public final static native void delete_EURLibor11M(long jarg1);
  public final static native long new_EURLibor1Y__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_EURLibor1Y__SWIG_1();
  public final static native void delete_EURLibor1Y(long jarg1);
  public final static native long new_GBPLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_GBPLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_GBPLibor(long jarg1);
  public final static native long new_GBPLiborON__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_GBPLiborON__SWIG_1();
  public final static native void delete_GBPLiborON(long jarg1);
  public final static native long new_Jibar__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Jibar__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Jibar(long jarg1);
  public final static native long new_JPYLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_JPYLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_JPYLibor(long jarg1);
  public final static native long new_Mosprime__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Mosprime__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Mosprime(long jarg1);
  public final static native long new_NZDLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_NZDLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_NZDLibor(long jarg1);
  public final static native long new_Pribor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Pribor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Pribor(long jarg1);
  public final static native long new_Robor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Robor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Robor(long jarg1);
  public final static native long new_SEKLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_SEKLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_SEKLibor(long jarg1);
  public final static native long new_Shibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Shibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Shibor(long jarg1);
  public final static native long new_Tibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Tibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Tibor(long jarg1);
  public final static native long new_THBFIX__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_THBFIX__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_THBFIX(long jarg1);
  public final static native long new_TRLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_TRLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_TRLibor(long jarg1);
  public final static native long new_USDLibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_USDLibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_USDLibor(long jarg1);
  public final static native long new_USDLiborON__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_USDLiborON__SWIG_1();
  public final static native void delete_USDLiborON(long jarg1);
  public final static native long new_Wibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Wibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Wibor(long jarg1);
  public final static native long new_Zibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Zibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Zibor(long jarg1);
  public final static native long new_Aonia__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Aonia__SWIG_1();
  public final static native void delete_Aonia(long jarg1);
  public final static native long new_Corra__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Corra__SWIG_1();
  public final static native void delete_Corra(long jarg1);
  public final static native long new_Destr__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Destr__SWIG_1();
  public final static native void delete_Destr(long jarg1);
  public final static native long new_Eonia__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Eonia__SWIG_1();
  public final static native void delete_Eonia(long jarg1);
  public final static native long new_Estr__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Estr__SWIG_1();
  public final static native void delete_Estr(long jarg1);
  public final static native long new_FedFunds__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_FedFunds__SWIG_1();
  public final static native void delete_FedFunds(long jarg1);
  public final static native long new_Nzocr__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Nzocr__SWIG_1();
  public final static native void delete_Nzocr(long jarg1);
  public final static native long new_Sofr__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Sofr__SWIG_1();
  public final static native void delete_Sofr(long jarg1);
  public final static native long new_Sonia__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Sonia__SWIG_1();
  public final static native void delete_Sonia(long jarg1);
  public final static native long new_Swestr__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Swestr__SWIG_1();
  public final static native void delete_Swestr(long jarg1);
  public final static native long new_EuriborSwapIsdaFixA__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EuriborSwapIsdaFixA__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_EuriborSwapIsdaFixA__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_EuriborSwapIsdaFixA(long jarg1);
  public final static native long new_EuriborSwapIsdaFixB__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EuriborSwapIsdaFixB__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_EuriborSwapIsdaFixB__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_EuriborSwapIsdaFixB(long jarg1);
  public final static native long new_EuriborSwapIfrFix__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EuriborSwapIfrFix__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_EuriborSwapIfrFix__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_EuriborSwapIfrFix(long jarg1);
  public final static native long new_EurLiborSwapIsdaFixA__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EurLiborSwapIsdaFixA__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_EurLiborSwapIsdaFixA__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_EurLiborSwapIsdaFixA(long jarg1);
  public final static native long new_EurLiborSwapIsdaFixB__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EurLiborSwapIsdaFixB__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_EurLiborSwapIsdaFixB__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_EurLiborSwapIsdaFixB(long jarg1);
  public final static native long new_EurLiborSwapIfrFix__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_EurLiborSwapIfrFix__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_EurLiborSwapIfrFix__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_EurLiborSwapIfrFix(long jarg1);
  public final static native long new_ChfLiborSwapIsdaFix__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_ChfLiborSwapIsdaFix__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_ChfLiborSwapIsdaFix__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_ChfLiborSwapIsdaFix(long jarg1);
  public final static native long new_GbpLiborSwapIsdaFix__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_GbpLiborSwapIsdaFix__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_GbpLiborSwapIsdaFix__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_GbpLiborSwapIsdaFix(long jarg1);
  public final static native long new_JpyLiborSwapIsdaFixAm__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_JpyLiborSwapIsdaFixAm__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_JpyLiborSwapIsdaFixAm__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_JpyLiborSwapIsdaFixAm(long jarg1);
  public final static native long new_JpyLiborSwapIsdaFixPm__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_JpyLiborSwapIsdaFixPm__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_JpyLiborSwapIsdaFixPm__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_JpyLiborSwapIsdaFixPm(long jarg1);
  public final static native long new_UsdLiborSwapIsdaFixAm__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_UsdLiborSwapIsdaFixAm__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_UsdLiborSwapIsdaFixAm__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_UsdLiborSwapIsdaFixAm(long jarg1);
  public final static native long new_UsdLiborSwapIsdaFixPm__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_UsdLiborSwapIsdaFixPm__SWIG_1(long jarg1, Period jarg1_);
  public final static native long new_UsdLiborSwapIsdaFixPm__SWIG_2(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_UsdLiborSwapIsdaFixPm(long jarg1);
  public final static native long new_Bibor__SWIG_0(long jarg1, Period jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_Bibor__SWIG_1(long jarg1, Period jarg1_);
  public final static native void delete_Bibor(long jarg1);
  public final static native long new_BiborSW__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_BiborSW__SWIG_1();
  public final static native void delete_BiborSW(long jarg1);
  public final static native long new_Bibor1M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bibor1M__SWIG_1();
  public final static native void delete_Bibor1M(long jarg1);
  public final static native long new_Bibor2M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bibor2M__SWIG_1();
  public final static native void delete_Bibor2M(long jarg1);
  public final static native long new_Bibor3M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bibor3M__SWIG_1();
  public final static native void delete_Bibor3M(long jarg1);
  public final static native long new_Bibor6M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bibor6M__SWIG_1();
  public final static native void delete_Bibor6M(long jarg1);
  public final static native long new_Bibor9M__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bibor9M__SWIG_1();
  public final static native void delete_Bibor9M(long jarg1);
  public final static native long new_Bibor1Y__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long new_Bibor1Y__SWIG_1();
  public final static native void delete_Bibor1Y(long jarg1);
  public final static native long new_DateGeneration();
  public final static native void delete_DateGeneration(long jarg1);
  public final static native long new_Schedule__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, Calendar jarg2_, int jarg3);
  public final static native long new_Schedule__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, Calendar jarg2_);
  public final static native long new_Schedule__SWIG_2(long jarg1, DateVector jarg1_);
  public final static native long new_Schedule__SWIG_3(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, boolean jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_);
  public final static native long new_Schedule__SWIG_4(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, boolean jarg8, long jarg9, Date jarg9_);
  public final static native long new_Schedule__SWIG_5(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, boolean jarg8);
  public final static native long new_Schedule__SWIG_6();
  public final static native long Schedule_size(long jarg1, Schedule jarg1_);
  public final static native long Schedule_date(long jarg1, Schedule jarg1_, long jarg2);
  public final static native long Schedule_previousDate(long jarg1, Schedule jarg1_, long jarg2, Date jarg2_);
  public final static native long Schedule_nextDate(long jarg1, Schedule jarg1_, long jarg2, Date jarg2_);
  public final static native long Schedule_dates(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_hasIsRegular(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_isRegular__SWIG_0(long jarg1, Schedule jarg1_, long jarg2);
  public final static native long Schedule_isRegular__SWIG_1(long jarg1, Schedule jarg1_);
  public final static native long Schedule_calendar(long jarg1, Schedule jarg1_);
  public final static native long Schedule_startDate(long jarg1, Schedule jarg1_);
  public final static native long Schedule_endDate(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_hasTenor(long jarg1, Schedule jarg1_);
  public final static native long Schedule_tenor(long jarg1, Schedule jarg1_);
  public final static native int Schedule_businessDayConvention(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_hasTerminationDateBusinessDayConvention(long jarg1, Schedule jarg1_);
  public final static native int Schedule_terminationDateBusinessDayConvention(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_hasRule(long jarg1, Schedule jarg1_);
  public final static native int Schedule_rule(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_hasEndOfMonth(long jarg1, Schedule jarg1_);
  public final static native boolean Schedule_endOfMonth(long jarg1, Schedule jarg1_);
  public final static native long Schedule_after(long jarg1, Schedule jarg1_, long jarg2, Date jarg2_);
  public final static native long Schedule_until(long jarg1, Schedule jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_Schedule(long jarg1);
  public final static native long new_MakeSchedule();
  public final static native long MakeSchedule_from(long jarg1, MakeSchedule jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeSchedule_to(long jarg1, MakeSchedule jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeSchedule_withTenor(long jarg1, MakeSchedule jarg1_, long jarg2, Period jarg2_);
  public final static native long MakeSchedule_withFrequency(long jarg1, MakeSchedule jarg1_, int jarg2);
  public final static native long MakeSchedule_withCalendar(long jarg1, MakeSchedule jarg1_, long jarg2, Calendar jarg2_);
  public final static native long MakeSchedule_withConvention(long jarg1, MakeSchedule jarg1_, int jarg2);
  public final static native long MakeSchedule_withTerminationDateConvention(long jarg1, MakeSchedule jarg1_, int jarg2);
  public final static native long MakeSchedule_withRule(long jarg1, MakeSchedule jarg1_, int jarg2);
  public final static native long MakeSchedule_forwards(long jarg1, MakeSchedule jarg1_);
  public final static native long MakeSchedule_backwards(long jarg1, MakeSchedule jarg1_);
  public final static native long MakeSchedule_endOfMonth__SWIG_0(long jarg1, MakeSchedule jarg1_, boolean jarg2);
  public final static native long MakeSchedule_endOfMonth__SWIG_1(long jarg1, MakeSchedule jarg1_);
  public final static native long MakeSchedule_withFirstDate(long jarg1, MakeSchedule jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeSchedule_withNextToLastDate(long jarg1, MakeSchedule jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeSchedule_schedule(long jarg1, MakeSchedule jarg1_);
  public final static native void delete_MakeSchedule(long jarg1);
  public final static native double VolatilityTermStructure_minStrike(long jarg1, VolatilityTermStructure jarg1_);
  public final static native double VolatilityTermStructure_maxStrike(long jarg1, VolatilityTermStructure jarg1_);
  public final static native void delete_VolatilityTermStructure(long jarg1);
  public final static native double BlackVolTermStructure_blackVol__SWIG_0(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructure_blackVol__SWIG_1(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double BlackVolTermStructure_blackVol__SWIG_2(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructure_blackVol__SWIG_3(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3);
  public final static native double BlackVolTermStructure_blackVariance__SWIG_0(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructure_blackVariance__SWIG_1(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double BlackVolTermStructure_blackVariance__SWIG_2(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructure_blackVariance__SWIG_3(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3);
  public final static native double BlackVolTermStructure_blackForwardVol__SWIG_0(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructure_blackForwardVol__SWIG_1(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double BlackVolTermStructure_blackForwardVol__SWIG_2(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructure_blackForwardVol__SWIG_3(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double BlackVolTermStructure_blackForwardVariance__SWIG_0(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructure_blackForwardVariance__SWIG_1(long jarg1, BlackVolTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double BlackVolTermStructure_blackForwardVariance__SWIG_2(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructure_blackForwardVariance__SWIG_3(long jarg1, BlackVolTermStructure jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void delete_BlackVolTermStructure(long jarg1);
  public final static native long new_BlackVolTermStructureHandle__SWIG_0(long jarg1, BlackVolTermStructure jarg1_);
  public final static native long new_BlackVolTermStructureHandle__SWIG_1();
  public final static native long BlackVolTermStructureHandle___deref__(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native long BlackVolTermStructureHandle_currentLink(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native boolean BlackVolTermStructureHandle_empty(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native long BlackVolTermStructureHandle_asObservable(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native void delete_BlackVolTermStructureHandle(long jarg1);
  public final static native double BlackVolTermStructureHandle_blackVol__SWIG_0(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructureHandle_blackVol__SWIG_1(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double BlackVolTermStructureHandle_blackVol__SWIG_2(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructureHandle_blackVol__SWIG_3(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double BlackVolTermStructureHandle_blackVariance__SWIG_0(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructureHandle_blackVariance__SWIG_1(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double BlackVolTermStructureHandle_blackVariance__SWIG_2(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double BlackVolTermStructureHandle_blackVariance__SWIG_3(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double BlackVolTermStructureHandle_blackForwardVol__SWIG_0(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructureHandle_blackForwardVol__SWIG_1(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double BlackVolTermStructureHandle_blackForwardVol__SWIG_2(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructureHandle_blackForwardVol__SWIG_3(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double BlackVolTermStructureHandle_blackForwardVariance__SWIG_0(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructureHandle_blackForwardVariance__SWIG_1(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double BlackVolTermStructureHandle_blackForwardVariance__SWIG_2(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double BlackVolTermStructureHandle_blackForwardVariance__SWIG_3(long jarg1, BlackVolTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double BlackVolTermStructureHandle_minStrike(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native double BlackVolTermStructureHandle_maxStrike(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native long BlackVolTermStructureHandle_dayCounter(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native double BlackVolTermStructureHandle_timeFromReference(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long BlackVolTermStructureHandle_calendar(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native long BlackVolTermStructureHandle_referenceDate(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native long BlackVolTermStructureHandle_maxDate(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native double BlackVolTermStructureHandle_maxTime(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native void BlackVolTermStructureHandle_enableExtrapolation(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native void BlackVolTermStructureHandle_disableExtrapolation(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native boolean BlackVolTermStructureHandle_allowsExtrapolation(long jarg1, BlackVolTermStructureHandle jarg1_);
  public final static native long new_RelinkableBlackVolTermStructureHandle__SWIG_0(long jarg1, BlackVolTermStructure jarg1_);
  public final static native long new_RelinkableBlackVolTermStructureHandle__SWIG_1();
  public final static native void RelinkableBlackVolTermStructureHandle_linkTo(long jarg1, RelinkableBlackVolTermStructureHandle jarg1_, long jarg2, BlackVolTermStructure jarg2_);
  public final static native void RelinkableBlackVolTermStructureHandle_reset(long jarg1, RelinkableBlackVolTermStructureHandle jarg1_);
  public final static native void delete_RelinkableBlackVolTermStructureHandle(long jarg1);
  public final static native double LocalVolTermStructure_localVol__SWIG_0(long jarg1, LocalVolTermStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double LocalVolTermStructure_localVol__SWIG_1(long jarg1, LocalVolTermStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double LocalVolTermStructure_localVol__SWIG_2(long jarg1, LocalVolTermStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double LocalVolTermStructure_localVol__SWIG_3(long jarg1, LocalVolTermStructure jarg1_, double jarg2, double jarg3);
  public final static native void delete_LocalVolTermStructure(long jarg1);
  public final static native long new_LocalVolTermStructureHandle__SWIG_0(long jarg1, LocalVolTermStructure jarg1_);
  public final static native long new_LocalVolTermStructureHandle__SWIG_1();
  public final static native long LocalVolTermStructureHandle___deref__(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native long LocalVolTermStructureHandle_currentLink(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native boolean LocalVolTermStructureHandle_empty(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native long LocalVolTermStructureHandle_asObservable(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native void delete_LocalVolTermStructureHandle(long jarg1);
  public final static native double LocalVolTermStructureHandle_localVol__SWIG_0(long jarg1, LocalVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double LocalVolTermStructureHandle_localVol__SWIG_1(long jarg1, LocalVolTermStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double LocalVolTermStructureHandle_localVol__SWIG_2(long jarg1, LocalVolTermStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double LocalVolTermStructureHandle_localVol__SWIG_3(long jarg1, LocalVolTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double LocalVolTermStructureHandle_minStrike(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native double LocalVolTermStructureHandle_maxStrike(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native long LocalVolTermStructureHandle_dayCounter(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native double LocalVolTermStructureHandle_timeFromReference(long jarg1, LocalVolTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long LocalVolTermStructureHandle_calendar(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native long LocalVolTermStructureHandle_referenceDate(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native long LocalVolTermStructureHandle_maxDate(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native double LocalVolTermStructureHandle_maxTime(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native void LocalVolTermStructureHandle_enableExtrapolation(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native void LocalVolTermStructureHandle_disableExtrapolation(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native boolean LocalVolTermStructureHandle_allowsExtrapolation(long jarg1, LocalVolTermStructureHandle jarg1_);
  public final static native long new_RelinkableLocalVolTermStructureHandle__SWIG_0(long jarg1, LocalVolTermStructure jarg1_);
  public final static native long new_RelinkableLocalVolTermStructureHandle__SWIG_1();
  public final static native void RelinkableLocalVolTermStructureHandle_linkTo(long jarg1, RelinkableLocalVolTermStructureHandle jarg1_, long jarg2, LocalVolTermStructure jarg2_);
  public final static native void RelinkableLocalVolTermStructureHandle_reset(long jarg1, RelinkableLocalVolTermStructureHandle jarg1_);
  public final static native void delete_RelinkableLocalVolTermStructureHandle(long jarg1);
  public final static native double OptionletVolatilityStructure_volatility__SWIG_0(long jarg1, OptionletVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructure_volatility__SWIG_1(long jarg1, OptionletVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double OptionletVolatilityStructure_volatility__SWIG_2(long jarg1, OptionletVolatilityStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructure_volatility__SWIG_3(long jarg1, OptionletVolatilityStructure jarg1_, double jarg2, double jarg3);
  public final static native double OptionletVolatilityStructure_blackVariance__SWIG_0(long jarg1, OptionletVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructure_blackVariance__SWIG_1(long jarg1, OptionletVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double OptionletVolatilityStructure_blackVariance__SWIG_2(long jarg1, OptionletVolatilityStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructure_blackVariance__SWIG_3(long jarg1, OptionletVolatilityStructure jarg1_, double jarg2, double jarg3);
  public final static native void delete_OptionletVolatilityStructure(long jarg1);
  public final static native long new_OptionletVolatilityStructureHandle__SWIG_0(long jarg1, OptionletVolatilityStructure jarg1_);
  public final static native long new_OptionletVolatilityStructureHandle__SWIG_1();
  public final static native long OptionletVolatilityStructureHandle___deref__(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long OptionletVolatilityStructureHandle_currentLink(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native boolean OptionletVolatilityStructureHandle_empty(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long OptionletVolatilityStructureHandle_asObservable(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native void delete_OptionletVolatilityStructureHandle(long jarg1);
  public final static native double OptionletVolatilityStructureHandle_volatility__SWIG_0(long jarg1, OptionletVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructureHandle_volatility__SWIG_1(long jarg1, OptionletVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double OptionletVolatilityStructureHandle_volatility__SWIG_2(long jarg1, OptionletVolatilityStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructureHandle_volatility__SWIG_3(long jarg1, OptionletVolatilityStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double OptionletVolatilityStructureHandle_blackVariance__SWIG_0(long jarg1, OptionletVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructureHandle_blackVariance__SWIG_1(long jarg1, OptionletVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double OptionletVolatilityStructureHandle_blackVariance__SWIG_2(long jarg1, OptionletVolatilityStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double OptionletVolatilityStructureHandle_blackVariance__SWIG_3(long jarg1, OptionletVolatilityStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double OptionletVolatilityStructureHandle_minStrike(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native double OptionletVolatilityStructureHandle_maxStrike(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long OptionletVolatilityStructureHandle_dayCounter(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native double OptionletVolatilityStructureHandle_timeFromReference(long jarg1, OptionletVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long OptionletVolatilityStructureHandle_calendar(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long OptionletVolatilityStructureHandle_referenceDate(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long OptionletVolatilityStructureHandle_maxDate(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native double OptionletVolatilityStructureHandle_maxTime(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native void OptionletVolatilityStructureHandle_enableExtrapolation(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native void OptionletVolatilityStructureHandle_disableExtrapolation(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native boolean OptionletVolatilityStructureHandle_allowsExtrapolation(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long new_RelinkableOptionletVolatilityStructureHandle__SWIG_0(long jarg1, OptionletVolatilityStructure jarg1_);
  public final static native long new_RelinkableOptionletVolatilityStructureHandle__SWIG_1();
  public final static native void RelinkableOptionletVolatilityStructureHandle_linkTo(long jarg1, RelinkableOptionletVolatilityStructureHandle jarg1_, long jarg2, OptionletVolatilityStructure jarg2_);
  public final static native void RelinkableOptionletVolatilityStructureHandle_reset(long jarg1, RelinkableOptionletVolatilityStructureHandle jarg1_);
  public final static native void delete_RelinkableOptionletVolatilityStructureHandle(long jarg1);
  public final static native long YoYOptionletVolatilitySurface_observationLag(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native double YoYOptionletVolatilitySurface_frequency(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native boolean YoYOptionletVolatilitySurface_indexIsInterpolated(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native long YoYOptionletVolatilitySurface_baseDate(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native double YoYOptionletVolatilitySurface_timeFromBase__SWIG_0(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double YoYOptionletVolatilitySurface_timeFromBase__SWIG_1(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_);
  public final static native double YoYOptionletVolatilitySurface_minStrike(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native double YoYOptionletVolatilitySurface_maxStrike(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native double YoYOptionletVolatilitySurface_baseLevel(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native double YoYOptionletVolatilitySurface_volatility__SWIG_0(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurface_volatility__SWIG_1(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurface_volatility__SWIG_2(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYOptionletVolatilitySurface_volatility__SWIG_3(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurface_volatility__SWIG_4(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurface_volatility__SWIG_5(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double YoYOptionletVolatilitySurface_totalVariance__SWIG_0(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurface_totalVariance__SWIG_1(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurface_totalVariance__SWIG_2(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYOptionletVolatilitySurface_totalVariance__SWIG_3(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurface_totalVariance__SWIG_4(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurface_totalVariance__SWIG_5(long jarg1, YoYOptionletVolatilitySurface jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native void delete_YoYOptionletVolatilitySurface(long jarg1);
  public final static native long new_YoYOptionletVolatilitySurfaceHandle__SWIG_0(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native long new_YoYOptionletVolatilitySurfaceHandle__SWIG_1();
  public final static native long YoYOptionletVolatilitySurfaceHandle___deref__(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native long YoYOptionletVolatilitySurfaceHandle_currentLink(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native boolean YoYOptionletVolatilitySurfaceHandle_empty(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native long YoYOptionletVolatilitySurfaceHandle_asObservable(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native void delete_YoYOptionletVolatilitySurfaceHandle(long jarg1);
  public final static native long YoYOptionletVolatilitySurfaceHandle_observationLag(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_frequency(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native boolean YoYOptionletVolatilitySurfaceHandle_indexIsInterpolated(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native long YoYOptionletVolatilitySurfaceHandle_baseDate(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_timeFromBase__SWIG_0(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_timeFromBase__SWIG_1(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_minStrike(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_maxStrike(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_baseLevel(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_0(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_1(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_2(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_3(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_4(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_5(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_0(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_1(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_2(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_3(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_, boolean jarg5);
  public final static native double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_4(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Period jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_5(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native long YoYOptionletVolatilitySurfaceHandle_dayCounter(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_timeFromReference(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long YoYOptionletVolatilitySurfaceHandle_calendar(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native long YoYOptionletVolatilitySurfaceHandle_referenceDate(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native long YoYOptionletVolatilitySurfaceHandle_maxDate(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native double YoYOptionletVolatilitySurfaceHandle_maxTime(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native void YoYOptionletVolatilitySurfaceHandle_enableExtrapolation(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native void YoYOptionletVolatilitySurfaceHandle_disableExtrapolation(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native boolean YoYOptionletVolatilitySurfaceHandle_allowsExtrapolation(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native long new_RelinkableYoYOptionletVolatilitySurfaceHandle__SWIG_0(long jarg1, YoYOptionletVolatilitySurface jarg1_);
  public final static native long new_RelinkableYoYOptionletVolatilitySurfaceHandle__SWIG_1();
  public final static native void RelinkableYoYOptionletVolatilitySurfaceHandle_linkTo(long jarg1, RelinkableYoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, YoYOptionletVolatilitySurface jarg2_);
  public final static native void RelinkableYoYOptionletVolatilitySurfaceHandle_reset(long jarg1, RelinkableYoYOptionletVolatilitySurfaceHandle jarg1_);
  public final static native void delete_RelinkableYoYOptionletVolatilitySurfaceHandle(long jarg1);
  public final static native double SmileSection_minStrike(long jarg1, SmileSection jarg1_);
  public final static native double SmileSection_maxStrike(long jarg1, SmileSection jarg1_);
  public final static native double SmileSection_atmLevel(long jarg1, SmileSection jarg1_);
  public final static native double SmileSection_variance(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native double SmileSection_volatility__SWIG_0(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native long SmileSection_exerciseDate(long jarg1, SmileSection jarg1_);
  public final static native int SmileSection_volatilityType(long jarg1, SmileSection jarg1_);
  public final static native double SmileSection_shift(long jarg1, SmileSection jarg1_);
  public final static native long SmileSection_referenceDate(long jarg1, SmileSection jarg1_);
  public final static native double SmileSection_exerciseTime(long jarg1, SmileSection jarg1_);
  public final static native long SmileSection_dayCounter(long jarg1, SmileSection jarg1_);
  public final static native double SmileSection_optionPrice__SWIG_0(long jarg1, SmileSection jarg1_, double jarg2, int jarg3, double jarg4);
  public final static native double SmileSection_optionPrice__SWIG_1(long jarg1, SmileSection jarg1_, double jarg2, int jarg3);
  public final static native double SmileSection_optionPrice__SWIG_2(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native double SmileSection_digitalOptionPrice__SWIG_0(long jarg1, SmileSection jarg1_, double jarg2, int jarg3, double jarg4, double jarg5);
  public final static native double SmileSection_digitalOptionPrice__SWIG_1(long jarg1, SmileSection jarg1_, double jarg2, int jarg3, double jarg4);
  public final static native double SmileSection_digitalOptionPrice__SWIG_2(long jarg1, SmileSection jarg1_, double jarg2, int jarg3);
  public final static native double SmileSection_digitalOptionPrice__SWIG_3(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native double SmileSection_vega__SWIG_0(long jarg1, SmileSection jarg1_, double jarg2, double jarg3);
  public final static native double SmileSection_vega__SWIG_1(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native double SmileSection_density__SWIG_0(long jarg1, SmileSection jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double SmileSection_density__SWIG_1(long jarg1, SmileSection jarg1_, double jarg2, double jarg3);
  public final static native double SmileSection_density__SWIG_2(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native double SmileSection_volatility__SWIG_1(long jarg1, SmileSection jarg1_, double jarg2, int jarg3, double jarg4);
  public final static native double SmileSection_volatility__SWIG_2(long jarg1, SmileSection jarg1_, double jarg2, int jarg3);
  public final static native void delete_SmileSection(long jarg1);
  public final static native long new_SmileSectionVector__SWIG_0();
  public final static native long new_SmileSectionVector__SWIG_1(long jarg1, SmileSectionVector jarg1_);
  public final static native long SmileSectionVector_capacity(long jarg1, SmileSectionVector jarg1_);
  public final static native void SmileSectionVector_reserve(long jarg1, SmileSectionVector jarg1_, long jarg2);
  public final static native boolean SmileSectionVector_isEmpty(long jarg1, SmileSectionVector jarg1_);
  public final static native void SmileSectionVector_clear(long jarg1, SmileSectionVector jarg1_);
  public final static native long new_SmileSectionVector__SWIG_2(int jarg1, long jarg2, SmileSection jarg2_);
  public final static native int SmileSectionVector_doSize(long jarg1, SmileSectionVector jarg1_);
  public final static native void SmileSectionVector_doAdd__SWIG_0(long jarg1, SmileSectionVector jarg1_, long jarg2, SmileSection jarg2_);
  public final static native void SmileSectionVector_doAdd__SWIG_1(long jarg1, SmileSectionVector jarg1_, int jarg2, long jarg3, SmileSection jarg3_);
  public final static native long SmileSectionVector_doRemove(long jarg1, SmileSectionVector jarg1_, int jarg2);
  public final static native long SmileSectionVector_doGet(long jarg1, SmileSectionVector jarg1_, int jarg2);
  public final static native long SmileSectionVector_doSet(long jarg1, SmileSectionVector jarg1_, int jarg2, long jarg3, SmileSection jarg3_);
  public final static native void SmileSectionVector_doRemoveRange(long jarg1, SmileSectionVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_SmileSectionVector(long jarg1);
  public final static native double SwaptionVolatilityStructure_volatility__SWIG_0(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructure_volatility__SWIG_1(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4);
  public final static native double SwaptionVolatilityStructure_volatility__SWIG_2(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructure_volatility__SWIG_3(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double SwaptionVolatilityStructure_blackVariance__SWIG_0(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructure_blackVariance__SWIG_1(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4);
  public final static native double SwaptionVolatilityStructure_blackVariance__SWIG_2(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructure_blackVariance__SWIG_3(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long SwaptionVolatilityStructure_optionDateFromTenor(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_0(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_1(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_2(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_3(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_4(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_5(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, long jarg3, Period jarg3_);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_6(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, double jarg3, boolean jarg4);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_7(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_8(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_9(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_10(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double SwaptionVolatilityStructure_shift__SWIG_11(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_0(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_1(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_2(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_3(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_4(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_5(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_6(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, double jarg3, boolean jarg4);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_7(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_8(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_9(long jarg1, SwaptionVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_10(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native long SwaptionVolatilityStructure_smileSection__SWIG_11(long jarg1, SwaptionVolatilityStructure jarg1_, double jarg2, double jarg3);
  public final static native void delete_SwaptionVolatilityStructure(long jarg1);
  public final static native long new_SwaptionVolatilityStructureHandle__SWIG_0(long jarg1, SwaptionVolatilityStructure jarg1_);
  public final static native long new_SwaptionVolatilityStructureHandle__SWIG_1();
  public final static native long SwaptionVolatilityStructureHandle___deref__(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native long SwaptionVolatilityStructureHandle_currentLink(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native boolean SwaptionVolatilityStructureHandle_empty(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native long SwaptionVolatilityStructureHandle_asObservable(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native void delete_SwaptionVolatilityStructureHandle(long jarg1);
  public final static native double SwaptionVolatilityStructureHandle_volatility__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructureHandle_volatility__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4);
  public final static native double SwaptionVolatilityStructureHandle_volatility__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructureHandle_volatility__SWIG_3(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double SwaptionVolatilityStructureHandle_blackVariance__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructureHandle_blackVariance__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, double jarg4);
  public final static native double SwaptionVolatilityStructureHandle_blackVariance__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, boolean jarg5);
  public final static native double SwaptionVolatilityStructureHandle_blackVariance__SWIG_3(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long SwaptionVolatilityStructureHandle_optionDateFromTenor(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_3(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_4(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_5(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, long jarg3, Period jarg3_);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_6(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, double jarg3, boolean jarg4);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_7(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_8(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_9(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_10(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double SwaptionVolatilityStructureHandle_shift__SWIG_11(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_3(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_4(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_5(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_6(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, double jarg3, boolean jarg4);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_7(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_8(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_9(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_10(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native long SwaptionVolatilityStructureHandle_smileSection__SWIG_11(long jarg1, SwaptionVolatilityStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double SwaptionVolatilityStructureHandle_minStrike(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native double SwaptionVolatilityStructureHandle_maxStrike(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native long SwaptionVolatilityStructureHandle_dayCounter(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native double SwaptionVolatilityStructureHandle_timeFromReference(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long SwaptionVolatilityStructureHandle_calendar(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native long SwaptionVolatilityStructureHandle_referenceDate(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native long SwaptionVolatilityStructureHandle_maxDate(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native double SwaptionVolatilityStructureHandle_maxTime(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native void SwaptionVolatilityStructureHandle_enableExtrapolation(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native void SwaptionVolatilityStructureHandle_disableExtrapolation(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native boolean SwaptionVolatilityStructureHandle_allowsExtrapolation(long jarg1, SwaptionVolatilityStructureHandle jarg1_);
  public final static native long new_RelinkableSwaptionVolatilityStructureHandle__SWIG_0(long jarg1, SwaptionVolatilityStructure jarg1_);
  public final static native long new_RelinkableSwaptionVolatilityStructureHandle__SWIG_1();
  public final static native void RelinkableSwaptionVolatilityStructureHandle_linkTo(long jarg1, RelinkableSwaptionVolatilityStructureHandle jarg1_, long jarg2, SwaptionVolatilityStructure jarg2_);
  public final static native void RelinkableSwaptionVolatilityStructureHandle_reset(long jarg1, RelinkableSwaptionVolatilityStructureHandle jarg1_);
  public final static native void delete_RelinkableSwaptionVolatilityStructureHandle(long jarg1);
  public final static native long new_BlackConstantVol__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, double jarg3, long jarg4, DayCounter jarg4_);
  public final static native long new_BlackConstantVol__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_BlackConstantVol__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, DayCounter jarg4_);
  public final static native long new_BlackConstantVol__SWIG_3(long jarg1, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native void delete_BlackConstantVol(long jarg1);
  public final static native long new_BlackVarianceCurve__SWIG_0(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, boolean jarg5);
  public final static native long new_BlackVarianceCurve__SWIG_1(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native void delete_BlackVarianceCurve(long jarg1);
  public final static native long new_BlackVarianceSurface__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_, int jarg7, int jarg8, String jarg9);
  public final static native long new_BlackVarianceSurface__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_, int jarg7, int jarg8);
  public final static native long new_BlackVarianceSurface__SWIG_2(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_BlackVarianceSurface__SWIG_3(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_);
  public final static native void BlackVarianceSurface_setInterpolation__SWIG_0(long jarg1, BlackVarianceSurface jarg1_, String jarg2);
  public final static native void BlackVarianceSurface_setInterpolation__SWIG_1(long jarg1, BlackVarianceSurface jarg1_);
  public final static native void delete_BlackVarianceSurface(long jarg1);
  public final static native long new_ConstantOptionletVolatility__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantOptionletVolatility__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantOptionletVolatility__SWIG_2(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_ConstantOptionletVolatility__SWIG_3(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantOptionletVolatility__SWIG_4(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantOptionletVolatility__SWIG_5(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_ConstantOptionletVolatility__SWIG_6(long jarg1, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantOptionletVolatility__SWIG_7(long jarg1, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantOptionletVolatility__SWIG_8(long jarg1, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_ConstantOptionletVolatility__SWIG_9(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantOptionletVolatility__SWIG_10(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantOptionletVolatility__SWIG_11(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void delete_ConstantOptionletVolatility(long jarg1);
  public final static native long new_ConstantSwaptionVolatility__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantSwaptionVolatility__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantSwaptionVolatility__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_ConstantSwaptionVolatility__SWIG_3(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantSwaptionVolatility__SWIG_4(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantSwaptionVolatility__SWIG_5(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_ConstantSwaptionVolatility__SWIG_6(long jarg1, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantSwaptionVolatility__SWIG_7(long jarg1, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantSwaptionVolatility__SWIG_8(long jarg1, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_ConstantSwaptionVolatility__SWIG_9(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_ConstantSwaptionVolatility__SWIG_10(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_ConstantSwaptionVolatility__SWIG_11(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native void delete_ConstantSwaptionVolatility(long jarg1);
  public final static native long SwaptionVolatilityDiscrete_optionTenors(long jarg1, SwaptionVolatilityDiscrete jarg1_);
  public final static native long SwaptionVolatilityDiscrete_optionDates(long jarg1, SwaptionVolatilityDiscrete jarg1_);
  public final static native long SwaptionVolatilityDiscrete_optionTimes(long jarg1, SwaptionVolatilityDiscrete jarg1_);
  public final static native long SwaptionVolatilityDiscrete_swapTenors(long jarg1, SwaptionVolatilityDiscrete jarg1_);
  public final static native long SwaptionVolatilityDiscrete_swapLengths(long jarg1, SwaptionVolatilityDiscrete jarg1_);
  public final static native long SwaptionVolatilityDiscrete_optionDateFromTime(long jarg1, SwaptionVolatilityDiscrete jarg1_, double jarg2);
  public final static native void delete_SwaptionVolatilityDiscrete(long jarg1);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DateVector jarg4_, long jarg5, PeriodVector jarg5_, long jarg6, Matrix jarg6_, long jarg7, DayCounter jarg7_, boolean jarg8, int jarg9, long jarg10, Matrix jarg10_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DateVector jarg4_, long jarg5, PeriodVector jarg5_, long jarg6, Matrix jarg6_, long jarg7, DayCounter jarg7_, boolean jarg8, int jarg9);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_2(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DateVector jarg4_, long jarg5, PeriodVector jarg5_, long jarg6, Matrix jarg6_, long jarg7, DayCounter jarg7_, boolean jarg8);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_3(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DateVector jarg4_, long jarg5, PeriodVector jarg5_, long jarg6, Matrix jarg6_, long jarg7, DayCounter jarg7_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_4(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, DayCounter jarg6_, boolean jarg7, int jarg8, long jarg9, DoubleVectorVector jarg9_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_5(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, DayCounter jarg6_, boolean jarg7, int jarg8);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_6(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, DayCounter jarg6_, boolean jarg7);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_7(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_8(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_, boolean jarg7, int jarg8, long jarg9, Matrix jarg9_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_9(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_, boolean jarg7, int jarg8);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_10(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_, boolean jarg7);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_11(long jarg1, Calendar jarg1_, int jarg2, long jarg3, PeriodVector jarg3_, long jarg4, PeriodVector jarg4_, long jarg5, Matrix jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_12(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, boolean jarg6, int jarg7, long jarg8, Matrix jarg8_);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_13(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, boolean jarg6, int jarg7);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_14(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, boolean jarg6);
  public final static native long new_SwaptionVolatilityMatrix__SWIG_15(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long SwaptionVolatilityMatrix_locate__SWIG_0(long jarg1, SwaptionVolatilityMatrix jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native long SwaptionVolatilityMatrix_locate__SWIG_1(long jarg1, SwaptionVolatilityMatrix jarg1_, double jarg2, double jarg3);
  public final static native int SwaptionVolatilityMatrix_volatilityType(long jarg1, SwaptionVolatilityMatrix jarg1_);
  public final static native void delete_SwaptionVolatilityMatrix(long jarg1);
  public final static native long new_SabrSmileSection__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_, double jarg6, int jarg7);
  public final static native long new_SabrSmileSection__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_, double jarg6);
  public final static native long new_SabrSmileSection__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_SabrSmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, Date jarg4_);
  public final static native long new_SabrSmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_SabrSmileSection__SWIG_5(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, double jarg4, int jarg5);
  public final static native long new_SabrSmileSection__SWIG_6(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native long new_SabrSmileSection__SWIG_7(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native double SabrSmileSection_alpha(long jarg1, SabrSmileSection jarg1_);
  public final static native double SabrSmileSection_beta(long jarg1, SabrSmileSection jarg1_);
  public final static native double SabrSmileSection_nu(long jarg1, SabrSmileSection jarg1_);
  public final static native double SabrSmileSection_rho(long jarg1, SabrSmileSection jarg1_);
  public final static native void delete_SabrSmileSection(long jarg1);
  public final static native long new_SviSmileSection__SWIG_0(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_SviSmileSection__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_SviSmileSection__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_SviSmileSection(long jarg1);
  public final static native long new_SviInterpolatedSmileSection__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_SviInterpolatedSmileSection__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_SviInterpolatedSmileSection__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_SviInterpolatedSmileSection__SWIG_3(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_SviInterpolatedSmileSection__SWIG_4(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_SviInterpolatedSmileSection__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_SviInterpolatedSmileSection__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_SviInterpolatedSmileSection__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_SviInterpolatedSmileSection__SWIG_8(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_SviInterpolatedSmileSection__SWIG_9(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native double SviInterpolatedSmileSection_a(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native double SviInterpolatedSmileSection_b(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native double SviInterpolatedSmileSection_sigma(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native double SviInterpolatedSmileSection_rho(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native double SviInterpolatedSmileSection_m(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native double SviInterpolatedSmileSection_rmsError(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native double SviInterpolatedSmileSection_maxError(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native int SviInterpolatedSmileSection_endCriteria(long jarg1, SviInterpolatedSmileSection jarg1_);
  public final static native void delete_SviInterpolatedSmileSection(long jarg1);
  public final static native double SwaptionVolatilityCube_atmStrike(long jarg1, SwaptionVolatilityCube jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native void delete_SwaptionVolatilityCube(long jarg1);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13, long jarg14, OptimizationMethod jarg14_, double jarg15, boolean jarg16, long jarg17, boolean jarg18, double jarg19);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13, long jarg14, OptimizationMethod jarg14_, double jarg15, boolean jarg16, long jarg17, boolean jarg18);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13, long jarg14, OptimizationMethod jarg14_, double jarg15, boolean jarg16, long jarg17);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_3(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13, long jarg14, OptimizationMethod jarg14_, double jarg15, boolean jarg16);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_4(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13, long jarg14, OptimizationMethod jarg14_, double jarg15);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_5(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13, long jarg14, OptimizationMethod jarg14_);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_6(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_, double jarg13);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_7(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11, long jarg12, EndCriteria jarg12_);
  public final static native long new_SabrSwaptionVolatilityCube__SWIG_8(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8, long jarg9, QuoteHandleVectorVector jarg9_, long jarg10, BoolVector jarg10_, boolean jarg11);
  public final static native long SabrSwaptionVolatilityCube_sparseSabrParameters(long jarg1, SabrSwaptionVolatilityCube jarg1_);
  public final static native long SabrSwaptionVolatilityCube_denseSabrParameters(long jarg1, SabrSwaptionVolatilityCube jarg1_);
  public final static native long SabrSwaptionVolatilityCube_marketVolCube(long jarg1, SabrSwaptionVolatilityCube jarg1_);
  public final static native long SabrSwaptionVolatilityCube_volCubeAtmCalibrated(long jarg1, SabrSwaptionVolatilityCube jarg1_);
  public final static native long SabrSwaptionVolatilityCube_smileSection__SWIG_0(long jarg1, SabrSwaptionVolatilityCube jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native long SabrSwaptionVolatilityCube_smileSection__SWIG_1(long jarg1, SabrSwaptionVolatilityCube jarg1_, double jarg2, double jarg3);
  public final static native long SabrSwaptionVolatilityCube_smileSection__SWIG_2(long jarg1, SabrSwaptionVolatilityCube jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native long SabrSwaptionVolatilityCube_smileSection__SWIG_3(long jarg1, SabrSwaptionVolatilityCube jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_);
  public final static native void delete_SabrSwaptionVolatilityCube(long jarg1);
  public final static native long new_InterpolatedSwaptionVolatilityCube(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, PeriodVector jarg2_, long jarg3, PeriodVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, QuoteHandleVectorVector jarg5_, long jarg6, SwapIndex jarg6_, long jarg7, SwapIndex jarg7_, boolean jarg8);
  public final static native void delete_InterpolatedSwaptionVolatilityCube(long jarg1);
  public final static native long new_ConstantYoYOptionletVolatility__SWIG_0(double jarg1, long jarg2, long jarg3, Calendar jarg3_, int jarg4, long jarg5, DayCounter jarg5_, long jarg6, Period jarg6_, int jarg7, boolean jarg8, double jarg9, double jarg10);
  public final static native long new_ConstantYoYOptionletVolatility__SWIG_1(double jarg1, long jarg2, long jarg3, Calendar jarg3_, int jarg4, long jarg5, DayCounter jarg5_, long jarg6, Period jarg6_, int jarg7, boolean jarg8, double jarg9);
  public final static native long new_ConstantYoYOptionletVolatility__SWIG_2(double jarg1, long jarg2, long jarg3, Calendar jarg3_, int jarg4, long jarg5, DayCounter jarg5_, long jarg6, Period jarg6_, int jarg7, boolean jarg8);
  public final static native void delete_ConstantYoYOptionletVolatility(long jarg1);
  public final static native long new_FlatSmileSection__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_, long jarg4, Date jarg4_, double jarg5, int jarg6, double jarg7);
  public final static native long new_FlatSmileSection__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_, long jarg4, Date jarg4_, double jarg5, int jarg6);
  public final static native long new_FlatSmileSection__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_, long jarg4, Date jarg4_, double jarg5);
  public final static native long new_FlatSmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_, long jarg4, Date jarg4_);
  public final static native long new_FlatSmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_);
  public final static native long new_FlatSmileSection__SWIG_5(double jarg1, double jarg2, long jarg3, DayCounter jarg3_, double jarg4, int jarg5, double jarg6);
  public final static native long new_FlatSmileSection__SWIG_6(double jarg1, double jarg2, long jarg3, DayCounter jarg3_, double jarg4, int jarg5);
  public final static native long new_FlatSmileSection__SWIG_7(double jarg1, double jarg2, long jarg3, DayCounter jarg3_, double jarg4);
  public final static native long new_FlatSmileSection__SWIG_8(double jarg1, double jarg2, long jarg3, DayCounter jarg3_);
  public final static native void delete_FlatSmileSection(long jarg1);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_0(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Linear jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_1(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Linear jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_2(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Linear jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_3(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Linear jarg5_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_4(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_5(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Linear jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_6(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Linear jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_7(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Linear jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_8(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Linear jarg5_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_9(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_, long jarg7, Date jarg7_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_, long jarg7, Date jarg7_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Linear jarg6_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_20(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_LinearInterpolatedSmileSection__SWIG_21(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native void delete_LinearInterpolatedSmileSection(long jarg1);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_0(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Cubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_1(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Cubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_2(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Cubic jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_3(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, Cubic jarg5_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_4(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_5(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Cubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_6(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Cubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_7(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Cubic jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_8(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, Cubic jarg5_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_9(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_, long jarg7, Date jarg7_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_, long jarg7, Date jarg7_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Cubic jarg6_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_20(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_CubicInterpolatedSmileSection__SWIG_21(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native void delete_CubicInterpolatedSmileSection(long jarg1);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_0(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, MonotonicCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_1(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, MonotonicCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_2(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, MonotonicCubic jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_3(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, MonotonicCubic jarg5_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_4(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_5(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, MonotonicCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_6(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, MonotonicCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_7(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, MonotonicCubic jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_8(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, MonotonicCubic jarg5_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_9(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_, long jarg7, Date jarg7_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_, long jarg7, Date jarg7_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, MonotonicCubic jarg6_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_20(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_MonotonicCubicInterpolatedSmileSection__SWIG_21(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native void delete_MonotonicCubicInterpolatedSmileSection(long jarg1);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_0(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, SplineCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_1(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, SplineCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_2(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, SplineCubic jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_3(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, SplineCubic jarg5_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_4(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_5(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, SplineCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_6(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, SplineCubic jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_7(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, SplineCubic jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_8(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, SplineCubic jarg5_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_9(double jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, Date jarg7_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, Date jarg7_, int jarg8, double jarg9);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, Date jarg7_, int jarg8);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, Date jarg7_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, SplineCubic jarg6_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_20(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, long jarg5, DayCounter jarg5_);
  public final static native long new_SplineCubicInterpolatedSmileSection__SWIG_21(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native void delete_SplineCubicInterpolatedSmileSection(long jarg1);
  public final static native long new_KahaleSmileSection__SWIG_0(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3, boolean jarg4, boolean jarg5, long jarg6, DoubleVector jarg6_, double jarg7, int jarg8, int jarg9);
  public final static native long new_KahaleSmileSection__SWIG_1(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3, boolean jarg4, boolean jarg5, long jarg6, DoubleVector jarg6_, double jarg7, int jarg8);
  public final static native long new_KahaleSmileSection__SWIG_2(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3, boolean jarg4, boolean jarg5, long jarg6, DoubleVector jarg6_, double jarg7);
  public final static native long new_KahaleSmileSection__SWIG_3(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3, boolean jarg4, boolean jarg5, long jarg6, DoubleVector jarg6_);
  public final static native long new_KahaleSmileSection__SWIG_4(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_KahaleSmileSection__SWIG_5(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3, boolean jarg4);
  public final static native long new_KahaleSmileSection__SWIG_6(long jarg1, SmileSection jarg1_, double jarg2, boolean jarg3);
  public final static native long new_KahaleSmileSection__SWIG_7(long jarg1, SmileSection jarg1_, double jarg2);
  public final static native long new_KahaleSmileSection__SWIG_8(long jarg1, SmileSection jarg1_);
  public final static native void delete_KahaleSmileSection(long jarg1);
  public final static native long new_ZabrShortMaturityLognormal();
  public final static native void delete_ZabrShortMaturityLognormal(long jarg1);
  public final static native long new_ZabrShortMaturityNormal();
  public final static native void delete_ZabrShortMaturityNormal(long jarg1);
  public final static native long new_ZabrLocalVolatility();
  public final static native void delete_ZabrLocalVolatility(long jarg1);
  public final static native long new_ZabrFullFd();
  public final static native void delete_ZabrFullFd(long jarg1);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_0(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_1(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_2(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_, long jarg6);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_ZabrShortMaturityLognormalSmileSection__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_ZabrShortMaturityLognormalSmileSection(long jarg1);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_0(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_1(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_2(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_, long jarg6);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_ZabrShortMaturityNormalSmileSection__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_ZabrShortMaturityNormalSmileSection(long jarg1);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_0(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_1(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_2(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_, long jarg6);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_ZabrLocalVolatilitySmileSection__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_ZabrLocalVolatilitySmileSection(long jarg1);
  public final static native long new_ZabrFullFdSmileSection__SWIG_0(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5);
  public final static native long new_ZabrFullFdSmileSection__SWIG_1(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_);
  public final static native long new_ZabrFullFdSmileSection__SWIG_2(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_ZabrFullFdSmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_, long jarg6);
  public final static native long new_ZabrFullFdSmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long new_ZabrFullFdSmileSection__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_ZabrFullFdSmileSection__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_ZabrFullFdSmileSection(long jarg1);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_3(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_4(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_5(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_6(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_7(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_8(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_9(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native double ZabrShortMaturityLognormalInterpolatedSmileSection_alpha(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityLognormalInterpolatedSmileSection_beta(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityLognormalInterpolatedSmileSection_nu(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityLognormalInterpolatedSmileSection_rho(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityLognormalInterpolatedSmileSection_rmsError(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityLognormalInterpolatedSmileSection_maxError(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native int ZabrShortMaturityLognormalInterpolatedSmileSection_endCriteria(long jarg1, ZabrShortMaturityLognormalInterpolatedSmileSection jarg1_);
  public final static native void delete_ZabrShortMaturityLognormalInterpolatedSmileSection(long jarg1);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_3(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_4(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_5(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_6(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_7(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_8(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_9(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native double ZabrShortMaturityNormalInterpolatedSmileSection_alpha(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityNormalInterpolatedSmileSection_beta(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityNormalInterpolatedSmileSection_nu(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityNormalInterpolatedSmileSection_rho(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityNormalInterpolatedSmileSection_rmsError(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native double ZabrShortMaturityNormalInterpolatedSmileSection_maxError(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native int ZabrShortMaturityNormalInterpolatedSmileSection_endCriteria(long jarg1, ZabrShortMaturityNormalInterpolatedSmileSection jarg1_);
  public final static native void delete_ZabrShortMaturityNormalInterpolatedSmileSection(long jarg1);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_3(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_4(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_5(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_6(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_7(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_8(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_9(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native double ZabrLocalVolatilityInterpolatedSmileSection_alpha(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native double ZabrLocalVolatilityInterpolatedSmileSection_beta(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native double ZabrLocalVolatilityInterpolatedSmileSection_nu(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native double ZabrLocalVolatilityInterpolatedSmileSection_rho(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native double ZabrLocalVolatilityInterpolatedSmileSection_rmsError(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native double ZabrLocalVolatilityInterpolatedSmileSection_maxError(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native int ZabrLocalVolatilityInterpolatedSmileSection_endCriteria(long jarg1, ZabrLocalVolatilityInterpolatedSmileSection jarg1_);
  public final static native void delete_ZabrLocalVolatilityInterpolatedSmileSection(long jarg1);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_3(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_4(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_5(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_6(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_7(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_8(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_9(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_, long jarg20, DayCounter jarg20_);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_, long jarg19, OptimizationMethod jarg19_);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17, long jarg18, EndCriteria jarg18_);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16, boolean jarg17);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, boolean jarg16);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_18(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, boolean jarg12);
  public final static native long new_ZabrFullFdInterpolatedSmileSection__SWIG_19(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native double ZabrFullFdInterpolatedSmileSection_alpha(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native double ZabrFullFdInterpolatedSmileSection_beta(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native double ZabrFullFdInterpolatedSmileSection_nu(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native double ZabrFullFdInterpolatedSmileSection_rho(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native double ZabrFullFdInterpolatedSmileSection_rmsError(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native double ZabrFullFdInterpolatedSmileSection_maxError(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native int ZabrFullFdInterpolatedSmileSection_endCriteria(long jarg1, ZabrFullFdInterpolatedSmileSection jarg1_);
  public final static native void delete_ZabrFullFdInterpolatedSmileSection(long jarg1);
  public final static native long new_NoArbSabrSmileSection__SWIG_0(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, double jarg4, int jarg5);
  public final static native long new_NoArbSabrSmileSection__SWIG_1(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_, double jarg4);
  public final static native long new_NoArbSabrSmileSection__SWIG_2(double jarg1, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_NoArbSabrSmileSection__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, double jarg5, int jarg6);
  public final static native long new_NoArbSabrSmileSection__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_, double jarg5);
  public final static native long new_NoArbSabrSmileSection__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_NoArbSabrSmileSection__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_NoArbSabrSmileSection(long jarg1);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_0(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, long jarg16, EndCriteria jarg16_, long jarg17, OptimizationMethod jarg17_, long jarg18, DayCounter jarg18_);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, long jarg16, EndCriteria jarg16_, long jarg17, OptimizationMethod jarg17_);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_2(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, long jarg16, EndCriteria jarg16_);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_3(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_4(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_5(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_6(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_7(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_8(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DoubleVector jarg3_, boolean jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_9(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, long jarg16, EndCriteria jarg16_, long jarg17, OptimizationMethod jarg17_, long jarg18, DayCounter jarg18_);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_10(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, long jarg16, EndCriteria jarg16_, long jarg17, OptimizationMethod jarg17_);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_11(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15, long jarg16, EndCriteria jarg16_);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_12(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14, boolean jarg15);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_13(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_14(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12, boolean jarg13);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_15(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11, boolean jarg12);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_16(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, boolean jarg11);
  public final static native long new_NoArbSabrInterpolatedSmileSection__SWIG_17(long jarg1, Date jarg1_, double jarg2, long jarg3, DoubleVector jarg3_, boolean jarg4, double jarg5, long jarg6, DoubleVector jarg6_, double jarg7, double jarg8, double jarg9, double jarg10);
  public final static native double NoArbSabrInterpolatedSmileSection_alpha(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native double NoArbSabrInterpolatedSmileSection_beta(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native double NoArbSabrInterpolatedSmileSection_nu(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native double NoArbSabrInterpolatedSmileSection_rho(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native double NoArbSabrInterpolatedSmileSection_rmsError(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native double NoArbSabrInterpolatedSmileSection_maxError(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native int NoArbSabrInterpolatedSmileSection_endCriteria(long jarg1, NoArbSabrInterpolatedSmileSection jarg1_);
  public final static native void delete_NoArbSabrInterpolatedSmileSection(long jarg1);
  public final static native double sabrVolatility__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, int jarg8);
  public final static native double sabrVolatility__SWIG_1(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native double shiftedSabrVolatility__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, int jarg9);
  public final static native double shiftedSabrVolatility__SWIG_1(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native double sabrFlochKennedyVolatility(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native long new_CalibrationErrorTuple(double jarg1, double jarg2, double jarg3);
  public final static native double CalibrationErrorTuple_first(long jarg1, CalibrationErrorTuple jarg1_);
  public final static native double CalibrationErrorTuple_second(long jarg1, CalibrationErrorTuple jarg1_);
  public final static native double CalibrationErrorTuple_third(long jarg1, CalibrationErrorTuple jarg1_);
  public final static native void delete_CalibrationErrorTuple(long jarg1);
  public final static native int AndreasenHugeVolatilityInterpl_Call_get();
  public final static native int AndreasenHugeVolatilityInterpl_Put_get();
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_0(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5, int jarg6, long jarg7, double jarg8, double jarg9, long jarg10, OptimizationMethod jarg10_, long jarg11, EndCriteria jarg11_);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_1(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5, int jarg6, long jarg7, double jarg8, double jarg9, long jarg10, OptimizationMethod jarg10_);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_2(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5, int jarg6, long jarg7, double jarg8, double jarg9);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_3(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5, int jarg6, long jarg7, double jarg8);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_4(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5, int jarg6, long jarg7);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_5(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5, int jarg6);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_6(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_, int jarg5);
  public final static native long new_AndreasenHugeVolatilityInterpl__SWIG_7(long jarg1, CalibrationSet jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native long AndreasenHugeVolatilityInterpl_maxDate(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native double AndreasenHugeVolatilityInterpl_minStrike(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native double AndreasenHugeVolatilityInterpl_maxStrike(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native double AndreasenHugeVolatilityInterpl_fwd(long jarg1, AndreasenHugeVolatilityInterpl jarg1_, double jarg2);
  public final static native long AndreasenHugeVolatilityInterpl_riskFreeRate(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native long AndreasenHugeVolatilityInterpl_calibrationError(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native double AndreasenHugeVolatilityInterpl_optionPrice(long jarg1, AndreasenHugeVolatilityInterpl jarg1_, double jarg2, double jarg3, int jarg4);
  public final static native double AndreasenHugeVolatilityInterpl_localVol(long jarg1, AndreasenHugeVolatilityInterpl jarg1_, double jarg2, double jarg3);
  public final static native void delete_AndreasenHugeVolatilityInterpl(long jarg1);
  public final static native long new_AndreasenHugeVolatilityAdapter__SWIG_0(long jarg1, AndreasenHugeVolatilityInterpl jarg1_, double jarg2);
  public final static native long new_AndreasenHugeVolatilityAdapter__SWIG_1(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native void delete_AndreasenHugeVolatilityAdapter(long jarg1);
  public final static native long new_AndreasenHugeLocalVolAdapter(long jarg1, AndreasenHugeVolatilityInterpl jarg1_);
  public final static native void delete_AndreasenHugeLocalVolAdapter(long jarg1);
  public final static native long new_HestonBlackVolSurface__SWIG_0(long jarg1, HestonModelHandle jarg1_, int jarg2, long jarg3, AnalyticHestonEngine_Integration jarg3_);
  public final static native long new_HestonBlackVolSurface__SWIG_1(long jarg1, HestonModelHandle jarg1_, int jarg2);
  public final static native long new_HestonBlackVolSurface__SWIG_2(long jarg1, HestonModelHandle jarg1_);
  public final static native void delete_HestonBlackVolSurface(long jarg1);
  public final static native long new_CmsMarket(long jarg1, PeriodVector jarg1_, long jarg2, SwapIndexVector jarg2_, long jarg3, IborIndex jarg3_, long jarg4, QuoteHandleVectorVector jarg4_, long jarg5, CmsCouponPricerVector jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native void CmsMarket_reprice(long jarg1, CmsMarket jarg1_, long jarg2, SwaptionVolatilityStructureHandle jarg2_, double jarg3);
  public final static native long CmsMarket_swapTenors(long jarg1, CmsMarket jarg1_);
  public final static native long CmsMarket_swapLengths(long jarg1, CmsMarket jarg1_);
  public final static native long CmsMarket_impliedCmsSpreads(long jarg1, CmsMarket jarg1_);
  public final static native long CmsMarket_spreadErrors(long jarg1, CmsMarket jarg1_);
  public final static native long CmsMarket_browse(long jarg1, CmsMarket jarg1_);
  public final static native double CmsMarket_weightedSpreadError(long jarg1, CmsMarket jarg1_, long jarg2, Matrix jarg2_);
  public final static native double CmsMarket_weightedSpotNpvError(long jarg1, CmsMarket jarg1_, long jarg2, Matrix jarg2_);
  public final static native double CmsMarket_weightedFwdNpvError(long jarg1, CmsMarket jarg1_, long jarg2, Matrix jarg2_);
  public final static native long CmsMarket_weightedSpreadErrors(long jarg1, CmsMarket jarg1_, long jarg2, Matrix jarg2_);
  public final static native long CmsMarket_weightedSpotNpvErrors(long jarg1, CmsMarket jarg1_, long jarg2, Matrix jarg2_);
  public final static native long CmsMarket_weightedFwdNpvErrors(long jarg1, CmsMarket jarg1_, long jarg2, Matrix jarg2_);
  public final static native void delete_CmsMarket(long jarg1);
  public final static native long new_CmsMarketCalibration(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, CmsMarket jarg2_, long jarg3, Matrix jarg3_, int jarg4);
  public final static native long CmsMarketCalibration_compute__SWIG_0(long jarg1, CmsMarketCalibration jarg1_, long jarg2, EndCriteria jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, Array jarg4_, boolean jarg5);
  public final static native long CmsMarketCalibration_compute__SWIG_1(long jarg1, CmsMarketCalibration jarg1_, long jarg2, EndCriteria jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, Matrix jarg4_, boolean jarg5, double jarg6);
  public final static native long CmsMarketCalibration_compute__SWIG_2(long jarg1, CmsMarketCalibration jarg1_, long jarg2, EndCriteria jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, Matrix jarg4_, boolean jarg5);
  public final static native long CmsMarketCalibration_computeParametric__SWIG_0(long jarg1, CmsMarketCalibration jarg1_, long jarg2, EndCriteria jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, Matrix jarg4_, boolean jarg5, double jarg6);
  public final static native long CmsMarketCalibration_computeParametric__SWIG_1(long jarg1, CmsMarketCalibration jarg1_, long jarg2, EndCriteria jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, Matrix jarg4_, boolean jarg5);
  public final static native double CmsMarketCalibration_error(long jarg1, CmsMarketCalibration jarg1_);
  public final static native int CmsMarketCalibration_endCriteria(long jarg1, CmsMarketCalibration jarg1_);
  public final static native void delete_CmsMarketCalibration(long jarg1);
  public final static native double CashFlow_amount(long jarg1, CashFlow jarg1_);
  public final static native long CashFlow_date(long jarg1, CashFlow jarg1_);
  public final static native boolean CashFlow_hasOccurred__SWIG_0(long jarg1, CashFlow jarg1_, long jarg2, Date jarg2_);
  public final static native boolean CashFlow_hasOccurred__SWIG_1(long jarg1, CashFlow jarg1_);
  public final static native void delete_CashFlow(long jarg1);
  public final static native long new_Leg__SWIG_0();
  public final static native long new_Leg__SWIG_1(long jarg1, Leg jarg1_);
  public final static native long Leg_capacity(long jarg1, Leg jarg1_);
  public final static native void Leg_reserve(long jarg1, Leg jarg1_, long jarg2);
  public final static native boolean Leg_isEmpty(long jarg1, Leg jarg1_);
  public final static native void Leg_clear(long jarg1, Leg jarg1_);
  public final static native long new_Leg__SWIG_2(int jarg1, long jarg2, CashFlow jarg2_);
  public final static native int Leg_doSize(long jarg1, Leg jarg1_);
  public final static native void Leg_doAdd__SWIG_0(long jarg1, Leg jarg1_, long jarg2, CashFlow jarg2_);
  public final static native void Leg_doAdd__SWIG_1(long jarg1, Leg jarg1_, int jarg2, long jarg3, CashFlow jarg3_);
  public final static native long Leg_doRemove(long jarg1, Leg jarg1_, int jarg2);
  public final static native long Leg_doGet(long jarg1, Leg jarg1_, int jarg2);
  public final static native long Leg_doSet(long jarg1, Leg jarg1_, int jarg2, long jarg3, CashFlow jarg3_);
  public final static native void Leg_doRemoveRange(long jarg1, Leg jarg1_, int jarg2, int jarg3);
  public final static native void delete_Leg(long jarg1);
  public final static native long new_LegVector__SWIG_0();
  public final static native long new_LegVector__SWIG_1(long jarg1, LegVector jarg1_);
  public final static native long LegVector_capacity(long jarg1, LegVector jarg1_);
  public final static native void LegVector_reserve(long jarg1, LegVector jarg1_, long jarg2);
  public final static native boolean LegVector_isEmpty(long jarg1, LegVector jarg1_);
  public final static native void LegVector_clear(long jarg1, LegVector jarg1_);
  public final static native long new_LegVector__SWIG_2(int jarg1, long jarg2, Leg jarg2_);
  public final static native int LegVector_doSize(long jarg1, LegVector jarg1_);
  public final static native void LegVector_doAdd__SWIG_0(long jarg1, LegVector jarg1_, long jarg2, Leg jarg2_);
  public final static native void LegVector_doAdd__SWIG_1(long jarg1, LegVector jarg1_, int jarg2, long jarg3, Leg jarg3_);
  public final static native long LegVector_doRemove(long jarg1, LegVector jarg1_, int jarg2);
  public final static native long LegVector_doGet(long jarg1, LegVector jarg1_, int jarg2);
  public final static native long LegVector_doSet(long jarg1, LegVector jarg1_, int jarg2, long jarg3, Leg jarg3_);
  public final static native void LegVector_doRemoveRange(long jarg1, LegVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_LegVector(long jarg1);
  public final static native long new_SimpleCashFlow(double jarg1, long jarg2, Date jarg2_);
  public final static native void delete_SimpleCashFlow(long jarg1);
  public final static native long new_Redemption(double jarg1, long jarg2, Date jarg2_);
  public final static native void delete_Redemption(long jarg1);
  public final static native long new_AmortizingPayment(double jarg1, long jarg2, Date jarg2_);
  public final static native void delete_AmortizingPayment(long jarg1);
  public final static native long new_IndexedCashFlow__SWIG_0(double jarg1, long jarg2, Index jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, boolean jarg6);
  public final static native long new_IndexedCashFlow__SWIG_1(double jarg1, long jarg2, Index jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double IndexedCashFlow_notional(long jarg1, IndexedCashFlow jarg1_);
  public final static native long IndexedCashFlow_baseDate(long jarg1, IndexedCashFlow jarg1_);
  public final static native long IndexedCashFlow_fixingDate(long jarg1, IndexedCashFlow jarg1_);
  public final static native double IndexedCashFlow_baseFixing(long jarg1, IndexedCashFlow jarg1_);
  public final static native double IndexedCashFlow_indexFixing(long jarg1, IndexedCashFlow jarg1_);
  public final static native long IndexedCashFlow_index(long jarg1, IndexedCashFlow jarg1_);
  public final static native boolean IndexedCashFlow_growthOnly(long jarg1, IndexedCashFlow jarg1_);
  public final static native void delete_IndexedCashFlow(long jarg1);
  public final static native long as_indexed_cashflow(long jarg1, CashFlow jarg1_);
  public final static native double Coupon_nominal(long jarg1, Coupon jarg1_);
  public final static native long Coupon_accrualStartDate(long jarg1, Coupon jarg1_);
  public final static native long Coupon_accrualEndDate(long jarg1, Coupon jarg1_);
  public final static native long Coupon_referencePeriodStart(long jarg1, Coupon jarg1_);
  public final static native long Coupon_referencePeriodEnd(long jarg1, Coupon jarg1_);
  public final static native long Coupon_exCouponDate(long jarg1, Coupon jarg1_);
  public final static native double Coupon_rate(long jarg1, Coupon jarg1_);
  public final static native double Coupon_accrualPeriod(long jarg1, Coupon jarg1_);
  public final static native int Coupon_accrualDays(long jarg1, Coupon jarg1_);
  public final static native long Coupon_dayCounter(long jarg1, Coupon jarg1_);
  public final static native double Coupon_accruedAmount(long jarg1, Coupon jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_Coupon(long jarg1);
  public final static native long as_coupon(long jarg1, CashFlow jarg1_);
  public final static native long new_FixedRateCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, double jarg3, long jarg4, DayCounter jarg4_, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_, long jarg8, Date jarg8_, long jarg9, Date jarg9_);
  public final static native long new_FixedRateCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, double jarg3, long jarg4, DayCounter jarg4_, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native long new_FixedRateCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, double jarg3, long jarg4, DayCounter jarg4_, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, Date jarg7_);
  public final static native long new_FixedRateCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, double jarg3, long jarg4, DayCounter jarg4_, long jarg5, Date jarg5_, long jarg6, Date jarg6_);
  public final static native long FixedRateCoupon_interestRate(long jarg1, FixedRateCoupon jarg1_);
  public final static native void delete_FixedRateCoupon(long jarg1);
  public final static native long as_fixed_rate_coupon(long jarg1, CashFlow jarg1_);
  public final static native double FloatingRateCouponPricer_swapletPrice(long jarg1, FloatingRateCouponPricer jarg1_);
  public final static native double FloatingRateCouponPricer_swapletRate(long jarg1, FloatingRateCouponPricer jarg1_);
  public final static native double FloatingRateCouponPricer_capletPrice(long jarg1, FloatingRateCouponPricer jarg1_, double jarg2);
  public final static native double FloatingRateCouponPricer_capletRate(long jarg1, FloatingRateCouponPricer jarg1_, double jarg2);
  public final static native double FloatingRateCouponPricer_floorletPrice(long jarg1, FloatingRateCouponPricer jarg1_, double jarg2);
  public final static native double FloatingRateCouponPricer_floorletRate(long jarg1, FloatingRateCouponPricer jarg1_, double jarg2);
  public final static native void delete_FloatingRateCouponPricer(long jarg1);
  public final static native void setCouponPricer__SWIG_0(long jarg1, Leg jarg1_, long jarg2, FloatingRateCouponPricer jarg2_);
  public final static native long FloatingRateCoupon_fixingDate(long jarg1, FloatingRateCoupon jarg1_);
  public final static native int FloatingRateCoupon_fixingDays(long jarg1, FloatingRateCoupon jarg1_);
  public final static native boolean FloatingRateCoupon_isInArrears(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double FloatingRateCoupon_gearing(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double FloatingRateCoupon_spread(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double FloatingRateCoupon_indexFixing(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double FloatingRateCoupon_adjustedFixing(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double FloatingRateCoupon_convexityAdjustment(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double FloatingRateCoupon_price(long jarg1, FloatingRateCoupon jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long FloatingRateCoupon_index(long jarg1, FloatingRateCoupon jarg1_);
  public final static native void FloatingRateCoupon_setPricer(long jarg1, FloatingRateCoupon jarg1_, long jarg2, FloatingRateCouponPricer jarg2_);
  public final static native void delete_FloatingRateCoupon(long jarg1);
  public final static native long as_floating_rate_coupon(long jarg1, CashFlow jarg1_);
  public final static native long new_RateAveraging();
  public final static native void delete_RateAveraging(long jarg1);
  public final static native long new_OvernightIndexedCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_, long jarg10, DayCounter jarg10_, boolean jarg11, int jarg12);
  public final static native long new_OvernightIndexedCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_, long jarg10, DayCounter jarg10_, boolean jarg11);
  public final static native long new_OvernightIndexedCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_, long jarg10, DayCounter jarg10_);
  public final static native long new_OvernightIndexedCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_);
  public final static native long new_OvernightIndexedCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6, double jarg7, long jarg8, Date jarg8_);
  public final static native long new_OvernightIndexedCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6, double jarg7);
  public final static native long new_OvernightIndexedCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_, double jarg6);
  public final static native long new_OvernightIndexedCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, OvernightIndex jarg5_);
  public final static native long OvernightIndexedCoupon_fixingDates(long jarg1, OvernightIndexedCoupon jarg1_);
  public final static native long OvernightIndexedCoupon_dt(long jarg1, OvernightIndexedCoupon jarg1_);
  public final static native long OvernightIndexedCoupon_indexFixings(long jarg1, OvernightIndexedCoupon jarg1_);
  public final static native long OvernightIndexedCoupon_valueDates(long jarg1, OvernightIndexedCoupon jarg1_);
  public final static native void delete_OvernightIndexedCoupon(long jarg1);
  public final static native long as_overnight_indexed_coupon(long jarg1, CashFlow jarg1_);
  public final static native long new_CappedFlooredCoupon__SWIG_0(long jarg1, FloatingRateCoupon jarg1_, double jarg2, double jarg3);
  public final static native long new_CappedFlooredCoupon__SWIG_1(long jarg1, FloatingRateCoupon jarg1_, double jarg2);
  public final static native long new_CappedFlooredCoupon__SWIG_2(long jarg1, FloatingRateCoupon jarg1_);
  public final static native double CappedFlooredCoupon_cap(long jarg1, CappedFlooredCoupon jarg1_);
  public final static native double CappedFlooredCoupon_floor(long jarg1, CappedFlooredCoupon jarg1_);
  public final static native double CappedFlooredCoupon_effectiveCap(long jarg1, CappedFlooredCoupon jarg1_);
  public final static native double CappedFlooredCoupon_effectiveFloor(long jarg1, CappedFlooredCoupon jarg1_);
  public final static native boolean CappedFlooredCoupon_isCapped(long jarg1, CappedFlooredCoupon jarg1_);
  public final static native boolean CappedFlooredCoupon_isFloored(long jarg1, CappedFlooredCoupon jarg1_);
  public final static native void CappedFlooredCoupon_setPricer(long jarg1, CappedFlooredCoupon jarg1_, long jarg2, FloatingRateCouponPricer jarg2_);
  public final static native void delete_CappedFlooredCoupon(long jarg1);
  public final static native long new_IborCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_IborCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12);
  public final static native long new_IborCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_);
  public final static native long new_IborCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_);
  public final static native long new_IborCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_);
  public final static native long new_IborCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_IborCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7);
  public final static native long new_IborCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_);
  public final static native void IborCoupon_createAtParCoupons();
  public final static native void IborCoupon_createIndexedCoupons();
  public final static native boolean IborCoupon_usingAtParCoupons();
  public final static native void delete_IborCoupon(long jarg1);
  public final static native long new_CappedFlooredIborCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14, long jarg15, Date jarg15_);
  public final static native long new_CappedFlooredIborCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14);
  public final static native long new_CappedFlooredIborCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_);
  public final static native long new_CappedFlooredIborCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_);
  public final static native long new_CappedFlooredIborCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_);
  public final static native long new_CappedFlooredIborCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10);
  public final static native long new_CappedFlooredIborCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9);
  public final static native long new_CappedFlooredIborCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_CappedFlooredIborCoupon__SWIG_8(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, double jarg7);
  public final static native long new_CappedFlooredIborCoupon__SWIG_9(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_);
  public final static native void delete_CappedFlooredIborCoupon(long jarg1);
  public final static native long new_SubPeriodsCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, DayCounter jarg12_, long jarg13, Date jarg13_);
  public final static native long new_SubPeriodsCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, DayCounter jarg12_);
  public final static native long new_SubPeriodsCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_);
  public final static native long new_SubPeriodsCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9, long jarg10, Date jarg10_);
  public final static native long new_SubPeriodsCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8, double jarg9);
  public final static native long new_SubPeriodsCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_SubPeriodsCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_, double jarg7);
  public final static native long new_SubPeriodsCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, IborIndex jarg6_);
  public final static native long SubPeriodsCoupon_fixingDates(long jarg1, SubPeriodsCoupon jarg1_);
  public final static native long SubPeriodsCoupon_dt(long jarg1, SubPeriodsCoupon jarg1_);
  public final static native long SubPeriodsCoupon_valueDates(long jarg1, SubPeriodsCoupon jarg1_);
  public final static native double SubPeriodsCoupon_rateSpread(long jarg1, SubPeriodsCoupon jarg1_);
  public final static native void delete_SubPeriodsCoupon(long jarg1);
  public final static native long as_sub_periods_coupon(long jarg1, CashFlow jarg1_);
  public final static native long IborCouponPricer_capletVolatility(long jarg1, IborCouponPricer jarg1_);
  public final static native void IborCouponPricer_setCapletVolatility__SWIG_0(long jarg1, IborCouponPricer jarg1_, long jarg2, OptionletVolatilityStructureHandle jarg2_);
  public final static native void IborCouponPricer_setCapletVolatility__SWIG_1(long jarg1, IborCouponPricer jarg1_);
  public final static native void delete_IborCouponPricer(long jarg1);
  public final static native long new_BlackIborCouponPricer__SWIG_0(long jarg1, OptionletVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, OptionalBool jarg4_);
  public final static native long new_BlackIborCouponPricer__SWIG_1(long jarg1, OptionletVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native long new_BlackIborCouponPricer__SWIG_2(long jarg1, OptionletVolatilityStructureHandle jarg1_, int jarg2);
  public final static native long new_BlackIborCouponPricer__SWIG_3(long jarg1, OptionletVolatilityStructureHandle jarg1_);
  public final static native long new_BlackIborCouponPricer__SWIG_4();
  public final static native void delete_BlackIborCouponPricer(long jarg1);
  public final static native void delete_SubPeriodsPricer(long jarg1);
  public final static native long new_CompoundingRatePricer();
  public final static native void delete_CompoundingRatePricer(long jarg1);
  public final static native long new_AveragingRatePricer();
  public final static native void delete_AveragingRatePricer(long jarg1);
  public final static native long new_CmsCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_CmsCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12);
  public final static native long new_CmsCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_);
  public final static native long new_CmsCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_);
  public final static native long new_CmsCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_);
  public final static native long new_CmsCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_CmsCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_, double jarg7);
  public final static native long new_CmsCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, SwapIndex jarg6_);
  public final static native void delete_CmsCoupon(long jarg1);
  public final static native long new_CmsSpreadCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_CmsSpreadCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12);
  public final static native long new_CmsSpreadCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_, long jarg11, DayCounter jarg11_);
  public final static native long new_CmsSpreadCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Date jarg10_);
  public final static native long new_CmsSpreadCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, long jarg9, Date jarg9_);
  public final static native long new_CmsSpreadCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_CmsSpreadCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7);
  public final static native long new_CmsSpreadCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_);
  public final static native void delete_CmsSpreadCoupon(long jarg1);
  public final static native long CmsCouponPricer_swaptionVolatility(long jarg1, CmsCouponPricer jarg1_);
  public final static native void CmsCouponPricer_setSwaptionVolatility__SWIG_0(long jarg1, CmsCouponPricer jarg1_, long jarg2, SwaptionVolatilityStructureHandle jarg2_);
  public final static native void CmsCouponPricer_setSwaptionVolatility__SWIG_1(long jarg1, CmsCouponPricer jarg1_);
  public final static native void delete_CmsCouponPricer(long jarg1);
  public final static native long new_CmsCouponPricerVector__SWIG_0();
  public final static native long new_CmsCouponPricerVector__SWIG_1(long jarg1, CmsCouponPricerVector jarg1_);
  public final static native long CmsCouponPricerVector_capacity(long jarg1, CmsCouponPricerVector jarg1_);
  public final static native void CmsCouponPricerVector_reserve(long jarg1, CmsCouponPricerVector jarg1_, long jarg2);
  public final static native boolean CmsCouponPricerVector_isEmpty(long jarg1, CmsCouponPricerVector jarg1_);
  public final static native void CmsCouponPricerVector_clear(long jarg1, CmsCouponPricerVector jarg1_);
  public final static native long new_CmsCouponPricerVector__SWIG_2(int jarg1, long jarg2, CmsCouponPricer jarg2_);
  public final static native int CmsCouponPricerVector_doSize(long jarg1, CmsCouponPricerVector jarg1_);
  public final static native void CmsCouponPricerVector_doAdd__SWIG_0(long jarg1, CmsCouponPricerVector jarg1_, long jarg2, CmsCouponPricer jarg2_);
  public final static native void CmsCouponPricerVector_doAdd__SWIG_1(long jarg1, CmsCouponPricerVector jarg1_, int jarg2, long jarg3, CmsCouponPricer jarg3_);
  public final static native long CmsCouponPricerVector_doRemove(long jarg1, CmsCouponPricerVector jarg1_, int jarg2);
  public final static native long CmsCouponPricerVector_doGet(long jarg1, CmsCouponPricerVector jarg1_, int jarg2);
  public final static native long CmsCouponPricerVector_doSet(long jarg1, CmsCouponPricerVector jarg1_, int jarg2, long jarg3, CmsCouponPricer jarg3_);
  public final static native void CmsCouponPricerVector_doRemoveRange(long jarg1, CmsCouponPricerVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_CmsCouponPricerVector(long jarg1);
  public final static native void delete_GFunctionFactory(long jarg1);
  public final static native long new_AnalyticHaganPricer(long jarg1, SwaptionVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_AnalyticHaganPricer(long jarg1);
  public final static native long new_NumericHaganPricer__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6);
  public final static native long new_NumericHaganPricer__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5);
  public final static native long new_NumericHaganPricer__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_, double jarg4);
  public final static native long new_NumericHaganPricer__SWIG_3(long jarg1, SwaptionVolatilityStructureHandle jarg1_, int jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_NumericHaganPricer(long jarg1);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14, long jarg15, Date jarg15_);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8, double jarg9);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_8(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_, double jarg7);
  public final static native long new_CappedFlooredCmsCoupon__SWIG_9(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapIndex jarg6_);
  public final static native void delete_CappedFlooredCmsCoupon(long jarg1);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14, long jarg15, Date jarg15_);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, DayCounter jarg13_);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10, long jarg11, Date jarg11_);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9, double jarg10);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8, double jarg9);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_7(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7, double jarg8);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_8(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_, double jarg7);
  public final static native long new_CappedFlooredCmsSpreadCoupon__SWIG_9(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, SwapSpreadIndex jarg6_);
  public final static native void delete_CappedFlooredCmsSpreadCoupon(long jarg1);
  public final static native long new_LinearTsrPricer__SWIG_0(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, LinearTsrPricerSettings jarg4_);
  public final static native long new_LinearTsrPricer__SWIG_1(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_LinearTsrPricer__SWIG_2(long jarg1, SwaptionVolatilityStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native void delete_LinearTsrPricer(long jarg1);
  public final static native long new_LinearTsrPricerSettings();
  public final static native long LinearTsrPricerSettings_withRateBound__SWIG_0(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2, double jarg3);
  public final static native long LinearTsrPricerSettings_withRateBound__SWIG_1(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2);
  public final static native long LinearTsrPricerSettings_withRateBound__SWIG_2(long jarg1, LinearTsrPricerSettings jarg1_);
  public final static native long LinearTsrPricerSettings_withVegaRatio__SWIG_0(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2);
  public final static native long LinearTsrPricerSettings_withVegaRatio__SWIG_1(long jarg1, LinearTsrPricerSettings jarg1_);
  public final static native long LinearTsrPricerSettings_withVegaRatio__SWIG_2(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long LinearTsrPricerSettings_withPriceThreshold__SWIG_0(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2);
  public final static native long LinearTsrPricerSettings_withPriceThreshold__SWIG_1(long jarg1, LinearTsrPricerSettings jarg1_);
  public final static native long LinearTsrPricerSettings_withPriceThreshold__SWIG_2(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long LinearTsrPricerSettings_withBSStdDevs__SWIG_0(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2);
  public final static native long LinearTsrPricerSettings_withBSStdDevs__SWIG_1(long jarg1, LinearTsrPricerSettings jarg1_);
  public final static native long LinearTsrPricerSettings_withBSStdDevs__SWIG_2(long jarg1, LinearTsrPricerSettings jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void delete_LinearTsrPricerSettings(long jarg1);
  public final static native long CmsSpreadCouponPricer_correlation(long jarg1, CmsSpreadCouponPricer jarg1_);
  public final static native void CmsSpreadCouponPricer_setCorrelation__SWIG_0(long jarg1, CmsSpreadCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native void CmsSpreadCouponPricer_setCorrelation__SWIG_1(long jarg1, CmsSpreadCouponPricer jarg1_);
  public final static native void delete_CmsSpreadCouponPricer(long jarg1);
  public final static native long new_LognormalCmsSpreadPricer__SWIG_0(long jarg1, CmsCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, long jarg5, double jarg6, double jarg7);
  public final static native long new_LognormalCmsSpreadPricer__SWIG_1(long jarg1, CmsCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, long jarg5, double jarg6);
  public final static native long new_LognormalCmsSpreadPricer__SWIG_2(long jarg1, CmsCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, long jarg5);
  public final static native long new_LognormalCmsSpreadPricer__SWIG_3(long jarg1, CmsCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4);
  public final static native long new_LognormalCmsSpreadPricer__SWIG_4(long jarg1, CmsCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_LognormalCmsSpreadPricer__SWIG_5(long jarg1, CmsCouponPricer jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native double LognormalCmsSpreadPricer_swapletPrice(long jarg1, LognormalCmsSpreadPricer jarg1_);
  public final static native double LognormalCmsSpreadPricer_swapletRate(long jarg1, LognormalCmsSpreadPricer jarg1_);
  public final static native double LognormalCmsSpreadPricer_capletPrice(long jarg1, LognormalCmsSpreadPricer jarg1_, double jarg2);
  public final static native double LognormalCmsSpreadPricer_capletRate(long jarg1, LognormalCmsSpreadPricer jarg1_, double jarg2);
  public final static native double LognormalCmsSpreadPricer_floorletPrice(long jarg1, LognormalCmsSpreadPricer jarg1_, double jarg2);
  public final static native double LognormalCmsSpreadPricer_floorletRate(long jarg1, LognormalCmsSpreadPricer jarg1_, double jarg2);
  public final static native void delete_LognormalCmsSpreadPricer(long jarg1);
  public final static native void delete_EquityCashFlowPricer(long jarg1);
  public final static native void setCouponPricer__SWIG_1(long jarg1, Leg jarg1_, long jarg2, EquityCashFlowPricer jarg2_);
  public final static native long new_EquityCashFlow__SWIG_0(double jarg1, long jarg2, EquityIndex jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, boolean jarg6);
  public final static native long new_EquityCashFlow__SWIG_1(double jarg1, long jarg2, EquityIndex jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native void EquityCashFlow_setPricer(long jarg1, EquityCashFlow jarg1_, long jarg2, EquityCashFlowPricer jarg2_);
  public final static native void delete_EquityCashFlow(long jarg1);
  public final static native long new_EquityQuantoCashFlowPricer(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, BlackVolTermStructureHandle jarg2_, long jarg3, BlackVolTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native void delete_EquityQuantoCashFlowPricer(long jarg1);
  public final static native long FixedRateLeg__SWIG_0(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_, int jarg9, boolean jarg10, long jarg11, Calendar jarg11_, int jarg12, int jarg13, int jarg14);
  public final static native long FixedRateLeg__SWIG_1(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_, int jarg9, boolean jarg10, long jarg11, Calendar jarg11_, int jarg12, int jarg13);
  public final static native long FixedRateLeg__SWIG_2(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_, int jarg9, boolean jarg10, long jarg11, Calendar jarg11_, int jarg12);
  public final static native long FixedRateLeg__SWIG_3(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_, int jarg9, boolean jarg10, long jarg11, Calendar jarg11_);
  public final static native long FixedRateLeg__SWIG_4(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_, int jarg9, boolean jarg10);
  public final static native long FixedRateLeg__SWIG_5(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_, int jarg9);
  public final static native long FixedRateLeg__SWIG_6(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_, long jarg8, Calendar jarg8_);
  public final static native long FixedRateLeg__SWIG_7(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Period jarg7_);
  public final static native long FixedRateLeg__SWIG_8(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5, long jarg6, DayCounter jarg6_);
  public final static native long FixedRateLeg__SWIG_9(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_, int jarg5);
  public final static native long FixedRateLeg__SWIG_10(long jarg1, Schedule jarg1_, long jarg2, DayCounter jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, DoubleVector jarg4_);
  public final static native long IborLeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, long jarg16, Calendar jarg16_, int jarg17, long jarg18, OptionalBool jarg18_);
  public final static native long IborLeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, long jarg16, Calendar jarg16_, int jarg17);
  public final static native long IborLeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, long jarg16, Calendar jarg16_);
  public final static native long IborLeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15);
  public final static native long IborLeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14);
  public final static native long IborLeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_);
  public final static native long IborLeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_);
  public final static native long IborLeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11);
  public final static native long IborLeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long IborLeg__SWIG_9(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long IborLeg__SWIG_10(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_);
  public final static native long IborLeg__SWIG_11(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native long IborLeg__SWIG_12(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_);
  public final static native long IborLeg__SWIG_13(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long IborLeg__SWIG_14(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long IborLeg__SWIG_15(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_);
  public final static native long OvernightLeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DoubleVector jarg7_, boolean jarg8, int jarg9, long jarg10, Calendar jarg10_, int jarg11);
  public final static native long OvernightLeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DoubleVector jarg7_, boolean jarg8, int jarg9, long jarg10, Calendar jarg10_);
  public final static native long OvernightLeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DoubleVector jarg7_, boolean jarg8, int jarg9);
  public final static native long OvernightLeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DoubleVector jarg7_, boolean jarg8);
  public final static native long OvernightLeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native long OvernightLeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, DoubleVector jarg6_);
  public final static native long OvernightLeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long OvernightLeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long OvernightLeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, OvernightIndex jarg3_);
  public final static native long CmsLeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15);
  public final static native long CmsLeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14);
  public final static native long CmsLeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_);
  public final static native long CmsLeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11, long jarg12, Period jarg12_);
  public final static native long CmsLeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11);
  public final static native long CmsLeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long CmsLeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long CmsLeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_);
  public final static native long CmsLeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native long CmsLeg__SWIG_9(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_);
  public final static native long CmsLeg__SWIG_10(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long CmsLeg__SWIG_11(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long CmsLeg__SWIG_12(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_);
  public final static native long CmsZeroLeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_, int jarg13, boolean jarg14);
  public final static native long CmsZeroLeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_, int jarg13);
  public final static native long CmsZeroLeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_);
  public final static native long CmsZeroLeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, Period jarg11_);
  public final static native long CmsZeroLeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long CmsZeroLeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long CmsZeroLeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_);
  public final static native long CmsZeroLeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native long CmsZeroLeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_);
  public final static native long CmsZeroLeg__SWIG_9(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long CmsZeroLeg__SWIG_10(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long CmsZeroLeg__SWIG_11(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapIndex jarg3_);
  public final static native long CmsSpreadLeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, boolean jarg11);
  public final static native long CmsSpreadLeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long CmsSpreadLeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long CmsSpreadLeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, DoubleVector jarg8_);
  public final static native long CmsSpreadLeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native long CmsSpreadLeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, UnsignedIntVector jarg6_);
  public final static native long CmsSpreadLeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long CmsSpreadLeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long CmsSpreadLeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, SwapSpreadIndex jarg3_);
  public final static native long SubPeriodsLeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, int jarg16);
  public final static native long SubPeriodsLeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15);
  public final static native long SubPeriodsLeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14);
  public final static native long SubPeriodsLeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_);
  public final static native long SubPeriodsLeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_);
  public final static native long SubPeriodsLeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native long SubPeriodsLeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long SubPeriodsLeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long SubPeriodsLeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7, long jarg8, UnsignedIntVector jarg8_);
  public final static native long SubPeriodsLeg__SWIG_9(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_, int jarg7);
  public final static native long SubPeriodsLeg__SWIG_10(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5, long jarg6, Calendar jarg6_);
  public final static native long SubPeriodsLeg__SWIG_11(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long SubPeriodsLeg__SWIG_12(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long SubPeriodsLeg__SWIG_13(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, IborIndex jarg3_);
  public final static native long new_Duration();
  public final static native void delete_Duration(long jarg1);
  public final static native long CashFlows_startDate(long jarg1, Leg jarg1_);
  public final static native long CashFlows_maturityDate(long jarg1, Leg jarg1_);
  public final static native long CashFlows_previousCashFlowDate__SWIG_0(long jarg1, Leg jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long CashFlows_previousCashFlowDate__SWIG_1(long jarg1, Leg jarg1_, boolean jarg2);
  public final static native long CashFlows_nextCashFlowDate__SWIG_0(long jarg1, Leg jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long CashFlows_nextCashFlowDate__SWIG_1(long jarg1, Leg jarg1_, boolean jarg2);
  public final static native double CashFlows_previousCashFlowAmount__SWIG_0(long jarg1, Leg jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native double CashFlows_previousCashFlowAmount__SWIG_1(long jarg1, Leg jarg1_, boolean jarg2);
  public final static native double CashFlows_nextCashFlowAmount__SWIG_0(long jarg1, Leg jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native double CashFlows_nextCashFlowAmount__SWIG_1(long jarg1, Leg jarg1_, boolean jarg2);
  public final static native long CashFlows_previousCashFlow__SWIG_0(long jarg1, Leg jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long CashFlows_previousCashFlow__SWIG_1(long jarg1, Leg jarg1_, boolean jarg2);
  public final static native long CashFlows_nextCashFlow__SWIG_0(long jarg1, Leg jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long CashFlows_nextCashFlow__SWIG_1(long jarg1, Leg jarg1_, boolean jarg2);
  public final static native double CashFlows_npv__SWIG_0(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_);
  public final static native double CashFlows_npv__SWIG_1(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_);
  public final static native double CashFlows_npv__SWIG_2(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7);
  public final static native double CashFlows_npv__SWIG_3(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_npv__SWIG_4(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_npv__SWIG_5(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3);
  public final static native double CashFlows_npv__SWIG_6(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_npv__SWIG_7(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_npv__SWIG_8(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3);
  public final static native double CashFlows_npv__SWIG_9(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native double CashFlows_npv__SWIG_10(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_);
  public final static native double CashFlows_npv__SWIG_11(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native double CashFlows_bps__SWIG_0(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_bps__SWIG_1(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_bps__SWIG_2(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3);
  public final static native double CashFlows_bps__SWIG_3(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_bps__SWIG_4(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_bps__SWIG_5(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3);
  public final static native double CashFlows_bps__SWIG_6(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_bps__SWIG_7(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_bps__SWIG_8(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3);
  public final static native double CashFlows_bps__SWIG_9(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native double CashFlows_bps__SWIG_10(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_);
  public final static native double CashFlows_bps__SWIG_11(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native long CashFlows_npvbps__SWIG_0(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native long CashFlows_npvbps__SWIG_1(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native long CashFlows_npvbps__SWIG_2(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3);
  public final static native long CashFlows_npvbps__SWIG_3(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native long CashFlows_npvbps__SWIG_4(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native long CashFlows_npvbps__SWIG_5(long jarg1, Leg jarg1_, long jarg2, YieldTermStructureHandle jarg2_, boolean jarg3);
  public final static native double CashFlows_atmRate__SWIG_0(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6);
  public final static native double CashFlows_atmRate__SWIG_1(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_atmRate__SWIG_2(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_atmRate__SWIG_3(long jarg1, Leg jarg1_, long jarg2, YieldTermStructure jarg2_, boolean jarg3);
  public final static native double CashFlows_yield__SWIG_0(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_, double jarg9, long jarg10, double jarg11);
  public final static native double CashFlows_yield__SWIG_1(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_, double jarg9, long jarg10);
  public final static native double CashFlows_yield__SWIG_2(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_, double jarg9);
  public final static native double CashFlows_yield__SWIG_3(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native double CashFlows_yield__SWIG_4(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_);
  public final static native double CashFlows_yield__SWIG_5(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native double CashFlows_duration__SWIG_0(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, int jarg3, boolean jarg4, long jarg5, Date jarg5_);
  public final static native double CashFlows_duration__SWIG_1(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, int jarg3, boolean jarg4);
  public final static native double CashFlows_duration__SWIG_2(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_);
  public final static native double CashFlows_duration__SWIG_3(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_);
  public final static native double CashFlows_duration__SWIG_4(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, int jarg6, boolean jarg7);
  public final static native double CashFlows_convexity__SWIG_0(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_convexity__SWIG_1(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_convexity__SWIG_2(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3);
  public final static native double CashFlows_convexity__SWIG_3(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native double CashFlows_convexity__SWIG_4(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_);
  public final static native double CashFlows_convexity__SWIG_5(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native double CashFlows_basisPointValue__SWIG_0(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native double CashFlows_basisPointValue__SWIG_1(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3, long jarg4, Date jarg4_);
  public final static native double CashFlows_basisPointValue__SWIG_2(long jarg1, Leg jarg1_, long jarg2, InterestRate jarg2_, boolean jarg3);
  public final static native double CashFlows_basisPointValue__SWIG_3(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_, long jarg8, Date jarg8_);
  public final static native double CashFlows_basisPointValue__SWIG_4(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6, long jarg7, Date jarg7_);
  public final static native double CashFlows_basisPointValue__SWIG_5(long jarg1, Leg jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, boolean jarg6);
  public final static native double CashFlows_zSpread__SWIG_0(long jarg1, Leg jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_, double jarg10, long jarg11, double jarg12);
  public final static native double CashFlows_zSpread__SWIG_1(long jarg1, Leg jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_, double jarg10, long jarg11);
  public final static native double CashFlows_zSpread__SWIG_2(long jarg1, Leg jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_, double jarg10);
  public final static native double CashFlows_zSpread__SWIG_3(long jarg1, Leg jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_, long jarg9, Date jarg9_);
  public final static native double CashFlows_zSpread__SWIG_4(long jarg1, Leg jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7, long jarg8, Date jarg8_);
  public final static native double CashFlows_zSpread__SWIG_5(long jarg1, Leg jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, boolean jarg7);
  public final static native void delete_CashFlows(long jarg1);
  public final static native void delete_Dividend(long jarg1);
  public final static native long new_FixedDividend(double jarg1, long jarg2, Date jarg2_);
  public final static native void delete_FixedDividend(long jarg1);
  public final static native long new_FractionalDividend(double jarg1, long jarg2, Date jarg2_);
  public final static native void delete_FractionalDividend(long jarg1);
  public final static native long new_DividendSchedule__SWIG_0();
  public final static native long new_DividendSchedule__SWIG_1(long jarg1, DividendSchedule jarg1_);
  public final static native long DividendSchedule_capacity(long jarg1, DividendSchedule jarg1_);
  public final static native void DividendSchedule_reserve(long jarg1, DividendSchedule jarg1_, long jarg2);
  public final static native boolean DividendSchedule_isEmpty(long jarg1, DividendSchedule jarg1_);
  public final static native void DividendSchedule_clear(long jarg1, DividendSchedule jarg1_);
  public final static native long new_DividendSchedule__SWIG_2(int jarg1, long jarg2, Dividend jarg2_);
  public final static native int DividendSchedule_doSize(long jarg1, DividendSchedule jarg1_);
  public final static native void DividendSchedule_doAdd__SWIG_0(long jarg1, DividendSchedule jarg1_, long jarg2, Dividend jarg2_);
  public final static native void DividendSchedule_doAdd__SWIG_1(long jarg1, DividendSchedule jarg1_, int jarg2, long jarg3, Dividend jarg3_);
  public final static native long DividendSchedule_doRemove(long jarg1, DividendSchedule jarg1_, int jarg2);
  public final static native long DividendSchedule_doGet(long jarg1, DividendSchedule jarg1_, int jarg2);
  public final static native long DividendSchedule_doSet(long jarg1, DividendSchedule jarg1_, int jarg2, long jarg3, Dividend jarg3_);
  public final static native void DividendSchedule_doRemoveRange(long jarg1, DividendSchedule jarg1_, int jarg2, int jarg3);
  public final static native void delete_DividendSchedule(long jarg1);
  public final static native long new_Exercise(int jarg1);
  public final static native int Exercise_type(long jarg1, Exercise jarg1_);
  public final static native long Exercise_date(long jarg1, Exercise jarg1_, long jarg2);
  public final static native long Exercise_dateAt(long jarg1, Exercise jarg1_, long jarg2);
  public final static native long Exercise_dates(long jarg1, Exercise jarg1_);
  public final static native long Exercise_lastDate(long jarg1, Exercise jarg1_);
  public final static native int Exercise_exerciseType(long jarg1, Exercise jarg1_);
  public final static native void delete_Exercise(long jarg1);
  public final static native long new_EuropeanExercise(long jarg1, Date jarg1_);
  public final static native void delete_EuropeanExercise(long jarg1);
  public final static native long new_AmericanExercise__SWIG_0(long jarg1, Date jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native long new_AmericanExercise__SWIG_1(long jarg1, Date jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_AmericanExercise(long jarg1);
  public final static native long new_BermudanExercise__SWIG_0(long jarg1, DateVector jarg1_, boolean jarg2);
  public final static native long new_BermudanExercise__SWIG_1(long jarg1, DateVector jarg1_);
  public final static native void delete_BermudanExercise(long jarg1);
  public final static native long new_RebatedExercise__SWIG_0(long jarg1, Exercise jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5);
  public final static native long new_RebatedExercise__SWIG_1(long jarg1, Exercise jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, long jarg4, Calendar jarg4_);
  public final static native long new_RebatedExercise__SWIG_2(long jarg1, Exercise jarg1_, long jarg2, DoubleVector jarg2_, long jarg3);
  public final static native long new_RebatedExercise__SWIG_3(long jarg1, Exercise jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_RebatedExercise(long jarg1);
  public final static native long new_SwingExercise(long jarg1, DateVector jarg1_);
  public final static native void delete_SwingExercise(long jarg1);
  public final static native long new_TimeGrid__SWIG_0();
  public final static native long new_TimeGrid__SWIG_1(double jarg1, long jarg2);
  public final static native long new_TimeGrid__SWIG_2(long jarg1, DoubleVector jarg1_);
  public final static native long new_TimeGrid__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2);
  public final static native long TimeGrid_getSize(long jarg1, TimeGrid jarg1_);
  public final static native double TimeGrid_elementAt(long jarg1, TimeGrid jarg1_, long jarg2);
  public final static native double TimeGrid_dt(long jarg1, TimeGrid jarg1_, long jarg2);
  public final static native void delete_TimeGrid(long jarg1);
  public final static native long StochasticProcess_size(long jarg1, StochasticProcess jarg1_);
  public final static native long StochasticProcess_factors(long jarg1, StochasticProcess jarg1_);
  public final static native long StochasticProcess_initialValues(long jarg1, StochasticProcess jarg1_);
  public final static native long StochasticProcess_drift(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, Array jarg3_);
  public final static native long StochasticProcess_diffusion(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, Array jarg3_);
  public final static native long StochasticProcess_expectation(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, Array jarg3_, double jarg4);
  public final static native long StochasticProcess_stdDeviation(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, Array jarg3_, double jarg4);
  public final static native long StochasticProcess_covariance(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, Array jarg3_, double jarg4);
  public final static native long StochasticProcess_evolve(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, Array jarg3_, double jarg4, long jarg5, Array jarg5_);
  public final static native void delete_StochasticProcess(long jarg1);
  public final static native long new_StochasticProcessVector__SWIG_0();
  public final static native long new_StochasticProcessVector__SWIG_1(long jarg1, StochasticProcessVector jarg1_);
  public final static native long StochasticProcessVector_capacity(long jarg1, StochasticProcessVector jarg1_);
  public final static native void StochasticProcessVector_reserve(long jarg1, StochasticProcessVector jarg1_, long jarg2);
  public final static native boolean StochasticProcessVector_isEmpty(long jarg1, StochasticProcessVector jarg1_);
  public final static native void StochasticProcessVector_clear(long jarg1, StochasticProcessVector jarg1_);
  public final static native long new_StochasticProcessVector__SWIG_2(int jarg1, long jarg2, StochasticProcess jarg2_);
  public final static native int StochasticProcessVector_doSize(long jarg1, StochasticProcessVector jarg1_);
  public final static native void StochasticProcessVector_doAdd__SWIG_0(long jarg1, StochasticProcessVector jarg1_, long jarg2, StochasticProcess jarg2_);
  public final static native void StochasticProcessVector_doAdd__SWIG_1(long jarg1, StochasticProcessVector jarg1_, int jarg2, long jarg3, StochasticProcess jarg3_);
  public final static native long StochasticProcessVector_doRemove(long jarg1, StochasticProcessVector jarg1_, int jarg2);
  public final static native long StochasticProcessVector_doGet(long jarg1, StochasticProcessVector jarg1_, int jarg2);
  public final static native long StochasticProcessVector_doSet(long jarg1, StochasticProcessVector jarg1_, int jarg2, long jarg3, StochasticProcess jarg3_);
  public final static native void StochasticProcessVector_doRemoveRange(long jarg1, StochasticProcessVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_StochasticProcessVector(long jarg1);
  public final static native double StochasticProcess1D_x0(long jarg1, StochasticProcess1D jarg1_);
  public final static native double StochasticProcess1D_drift(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3);
  public final static native double StochasticProcess1D_diffusion(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3);
  public final static native double StochasticProcess1D_expectation(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double StochasticProcess1D_stdDeviation(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double StochasticProcess1D_variance(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double StochasticProcess1D_evolve(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double StochasticProcess1D_apply(long jarg1, StochasticProcess1D jarg1_, double jarg2, double jarg3);
  public final static native void delete_StochasticProcess1D(long jarg1);
  public final static native long new_StochasticProcess1DVector__SWIG_0();
  public final static native long new_StochasticProcess1DVector__SWIG_1(long jarg1, StochasticProcess1DVector jarg1_);
  public final static native long StochasticProcess1DVector_capacity(long jarg1, StochasticProcess1DVector jarg1_);
  public final static native void StochasticProcess1DVector_reserve(long jarg1, StochasticProcess1DVector jarg1_, long jarg2);
  public final static native boolean StochasticProcess1DVector_isEmpty(long jarg1, StochasticProcess1DVector jarg1_);
  public final static native void StochasticProcess1DVector_clear(long jarg1, StochasticProcess1DVector jarg1_);
  public final static native long new_StochasticProcess1DVector__SWIG_2(int jarg1, long jarg2, StochasticProcess1D jarg2_);
  public final static native int StochasticProcess1DVector_doSize(long jarg1, StochasticProcess1DVector jarg1_);
  public final static native void StochasticProcess1DVector_doAdd__SWIG_0(long jarg1, StochasticProcess1DVector jarg1_, long jarg2, StochasticProcess1D jarg2_);
  public final static native void StochasticProcess1DVector_doAdd__SWIG_1(long jarg1, StochasticProcess1DVector jarg1_, int jarg2, long jarg3, StochasticProcess1D jarg3_);
  public final static native long StochasticProcess1DVector_doRemove(long jarg1, StochasticProcess1DVector jarg1_, int jarg2);
  public final static native long StochasticProcess1DVector_doGet(long jarg1, StochasticProcess1DVector jarg1_, int jarg2);
  public final static native long StochasticProcess1DVector_doSet(long jarg1, StochasticProcess1DVector jarg1_, int jarg2, long jarg3, StochasticProcess1D jarg3_);
  public final static native void StochasticProcess1DVector_doRemoveRange(long jarg1, StochasticProcess1DVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_StochasticProcess1DVector(long jarg1);
  public final static native long new_GeneralizedBlackScholesProcess__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, BlackVolTermStructureHandle jarg4_);
  public final static native long new_GeneralizedBlackScholesProcess__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, BlackVolTermStructureHandle jarg4_, long jarg5, LocalVolTermStructureHandle jarg5_);
  public final static native long GeneralizedBlackScholesProcess_stateVariable(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long GeneralizedBlackScholesProcess_dividendYield(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long GeneralizedBlackScholesProcess_riskFreeRate(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long GeneralizedBlackScholesProcess_blackVolatility(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long GeneralizedBlackScholesProcess_localVolatility(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_GeneralizedBlackScholesProcess(long jarg1);
  public final static native long new_BlackScholesProcess(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, BlackVolTermStructureHandle jarg3_);
  public final static native void delete_BlackScholesProcess(long jarg1);
  public final static native long new_BlackScholesMertonProcess(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, BlackVolTermStructureHandle jarg4_);
  public final static native void delete_BlackScholesMertonProcess(long jarg1);
  public final static native long new_BlackProcess(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, BlackVolTermStructureHandle jarg3_);
  public final static native void delete_BlackProcess(long jarg1);
  public final static native long new_GarmanKohlagenProcess(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, BlackVolTermStructureHandle jarg4_);
  public final static native void delete_GarmanKohlagenProcess(long jarg1);
  public final static native long new_Merton76Process(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, BlackVolTermStructureHandle jarg4_, long jarg5, QuoteHandle jarg5_, long jarg6, QuoteHandle jarg6_, long jarg7, QuoteHandle jarg7_);
  public final static native void delete_Merton76Process(long jarg1);
  public final static native long new_StochasticProcessArray(long jarg1, StochasticProcess1DVector jarg1_, long jarg2, Matrix jarg2_);
  public final static native void delete_StochasticProcessArray(long jarg1);
  public final static native long new_GeometricBrownianMotionProcess(double jarg1, double jarg2, double jarg3);
  public final static native void delete_GeometricBrownianMotionProcess(long jarg1);
  public final static native long new_VarianceGammaProcess(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, double jarg6);
  public final static native void delete_VarianceGammaProcess(long jarg1);
  public final static native long new_HestonProcess__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, int jarg9);
  public final static native long new_HestonProcess__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native long HestonProcess_s0(long jarg1, HestonProcess jarg1_);
  public final static native long HestonProcess_dividendYield(long jarg1, HestonProcess jarg1_);
  public final static native long HestonProcess_riskFreeRate(long jarg1, HestonProcess jarg1_);
  public final static native void delete_HestonProcess(long jarg1);
  public final static native long new_BatesProcess(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);
  public final static native void delete_BatesProcess(long jarg1);
  public final static native long new_HullWhiteProcess(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native void delete_HullWhiteProcess(long jarg1);
  public final static native long new_HullWhiteForwardProcess(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double HullWhiteForwardProcess_alpha(long jarg1, HullWhiteForwardProcess jarg1_, double jarg2);
  public final static native double HullWhiteForwardProcess_M_T(long jarg1, HullWhiteForwardProcess jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double HullWhiteForwardProcess_B(long jarg1, HullWhiteForwardProcess jarg1_, double jarg2, double jarg3);
  public final static native void HullWhiteForwardProcess_setForwardMeasureTime(long jarg1, HullWhiteForwardProcess jarg1_, double jarg2);
  public final static native void delete_HullWhiteForwardProcess(long jarg1);
  public final static native long new_G2Process(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void delete_G2Process(long jarg1);
  public final static native long new_G2ForwardProcess(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void G2ForwardProcess_setForwardMeasureTime(long jarg1, G2ForwardProcess jarg1_, double jarg2);
  public final static native void delete_G2ForwardProcess(long jarg1);
  public final static native long new_GsrProcess__SWIG_0(long jarg1, Array jarg1_, long jarg2, Array jarg2_, long jarg3, Array jarg3_, double jarg4);
  public final static native long new_GsrProcess__SWIG_1(long jarg1, Array jarg1_, long jarg2, Array jarg2_, long jarg3, Array jarg3_);
  public final static native double GsrProcess_sigma(long jarg1, GsrProcess jarg1_, double jarg2);
  public final static native double GsrProcess_reversion(long jarg1, GsrProcess jarg1_, double jarg2);
  public final static native double GsrProcess_y(long jarg1, GsrProcess jarg1_, double jarg2);
  public final static native double GsrProcess_G(long jarg1, GsrProcess jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void GsrProcess_setForwardMeasureTime(long jarg1, GsrProcess jarg1_, double jarg2);
  public final static native void delete_GsrProcess(long jarg1);
  public final static native long as_gsr_process(long jarg1, StochasticProcess jarg1_);
  public final static native long new_OrnsteinUhlenbeckProcess__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native long new_OrnsteinUhlenbeckProcess__SWIG_1(double jarg1, double jarg2, double jarg3);
  public final static native long new_OrnsteinUhlenbeckProcess__SWIG_2(double jarg1, double jarg2);
  public final static native double OrnsteinUhlenbeckProcess_speed(long jarg1, OrnsteinUhlenbeckProcess jarg1_);
  public final static native double OrnsteinUhlenbeckProcess_volatility(long jarg1, OrnsteinUhlenbeckProcess jarg1_);
  public final static native double OrnsteinUhlenbeckProcess_level(long jarg1, OrnsteinUhlenbeckProcess jarg1_);
  public final static native void delete_OrnsteinUhlenbeckProcess(long jarg1);
  public final static native long new_ExtendedOrnsteinUhlenbeckProcess__SWIG_0(double jarg1, double jarg2, double jarg3, long jarg4, int jarg5, double jarg6);
  public final static native long new_ExtendedOrnsteinUhlenbeckProcess__SWIG_1(double jarg1, double jarg2, double jarg3, long jarg4, int jarg5);
  public final static native long new_ExtendedOrnsteinUhlenbeckProcess__SWIG_2(double jarg1, double jarg2, double jarg3, long jarg4);
  public final static native long new_ExtendedOrnsteinUhlenbeckProcess__SWIG_3(double jarg1, double jarg2, double jarg3, long jarg4, UnaryFunctionDelegate jarg4_, double jarg5);
  public final static native long new_ExtendedOrnsteinUhlenbeckProcess__SWIG_4(double jarg1, double jarg2, double jarg3, long jarg4, UnaryFunctionDelegate jarg4_);
  public final static native void delete_ExtendedOrnsteinUhlenbeckProcess(long jarg1);
  public final static native long new_ExtOUWithJumpsProcess(long jarg1, ExtendedOrnsteinUhlenbeckProcess jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void delete_ExtOUWithJumpsProcess(long jarg1);
  public final static native long new_KlugeExtOUProcess(double jarg1, long jarg2, ExtOUWithJumpsProcess jarg2_, long jarg3, ExtendedOrnsteinUhlenbeckProcess jarg3_);
  public final static native void delete_KlugeExtOUProcess(long jarg1);
  public final static native long new_GJRGARCHProcess__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, double jarg10, int jarg11);
  public final static native long new_GJRGARCHProcess__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, double jarg10);
  public final static native long new_GJRGARCHProcess__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9);
  public final static native long GJRGARCHProcess_s0(long jarg1, GJRGARCHProcess jarg1_);
  public final static native long GJRGARCHProcess_dividendYield(long jarg1, GJRGARCHProcess jarg1_);
  public final static native long GJRGARCHProcess_riskFreeRate(long jarg1, GJRGARCHProcess jarg1_);
  public final static native void delete_GJRGARCHProcess(long jarg1);
  public final static native void LazyObject_recalculate(long jarg1, LazyObject jarg1_);
  public final static native void LazyObject_freeze(long jarg1, LazyObject jarg1_);
  public final static native void LazyObject_unfreeze(long jarg1, LazyObject jarg1_);
  public final static native void LazyObject_forwardFirstNotificationOnly();
  public final static native void LazyObject_alwaysForwardNotifications();
  public final static native boolean LazyObject_forwardsAllNotifications();
  public final static native void delete_LazyObject(long jarg1);
  public final static native void delete_PricingEngine(long jarg1);
  public final static native double Instrument_NPV(long jarg1, Instrument jarg1_);
  public final static native double Instrument_errorEstimate(long jarg1, Instrument jarg1_);
  public final static native boolean Instrument_isExpired(long jarg1, Instrument jarg1_);
  public final static native void Instrument_setPricingEngine(long jarg1, Instrument jarg1_, long jarg2, PricingEngine jarg2_);
  public final static native void delete_Instrument(long jarg1);
  public final static native long new_InstrumentVector__SWIG_0();
  public final static native long new_InstrumentVector__SWIG_1(long jarg1, InstrumentVector jarg1_);
  public final static native long InstrumentVector_capacity(long jarg1, InstrumentVector jarg1_);
  public final static native void InstrumentVector_reserve(long jarg1, InstrumentVector jarg1_, long jarg2);
  public final static native boolean InstrumentVector_isEmpty(long jarg1, InstrumentVector jarg1_);
  public final static native void InstrumentVector_clear(long jarg1, InstrumentVector jarg1_);
  public final static native long new_InstrumentVector__SWIG_2(int jarg1, long jarg2, Instrument jarg2_);
  public final static native int InstrumentVector_doSize(long jarg1, InstrumentVector jarg1_);
  public final static native void InstrumentVector_doAdd__SWIG_0(long jarg1, InstrumentVector jarg1_, long jarg2, Instrument jarg2_);
  public final static native void InstrumentVector_doAdd__SWIG_1(long jarg1, InstrumentVector jarg1_, int jarg2, long jarg3, Instrument jarg3_);
  public final static native long InstrumentVector_doRemove(long jarg1, InstrumentVector jarg1_, int jarg2);
  public final static native long InstrumentVector_doGet(long jarg1, InstrumentVector jarg1_, int jarg2);
  public final static native long InstrumentVector_doSet(long jarg1, InstrumentVector jarg1_, int jarg2, long jarg3, Instrument jarg3_);
  public final static native void InstrumentVector_doRemoveRange(long jarg1, InstrumentVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_InstrumentVector(long jarg1);
  public final static native long new_Stock(long jarg1, QuoteHandle jarg1_);
  public final static native void delete_Stock(long jarg1);
  public final static native long new_CompositeInstrument();
  public final static native void CompositeInstrument_add__SWIG_0(long jarg1, CompositeInstrument jarg1_, long jarg2, Instrument jarg2_, double jarg3);
  public final static native void CompositeInstrument_add__SWIG_1(long jarg1, CompositeInstrument jarg1_, long jarg2, Instrument jarg2_);
  public final static native void CompositeInstrument_subtract__SWIG_0(long jarg1, CompositeInstrument jarg1_, long jarg2, Instrument jarg2_, double jarg3);
  public final static native void CompositeInstrument_subtract__SWIG_1(long jarg1, CompositeInstrument jarg1_, long jarg2, Instrument jarg2_);
  public final static native void delete_CompositeInstrument(long jarg1);
  public final static native double CalibrationHelper_calibrationError(long jarg1, CalibrationHelper jarg1_);
  public final static native void delete_CalibrationHelper(long jarg1);
  public final static native long new_CalibrationHelperVector__SWIG_0();
  public final static native long new_CalibrationHelperVector__SWIG_1(long jarg1, CalibrationHelperVector jarg1_);
  public final static native long CalibrationHelperVector_capacity(long jarg1, CalibrationHelperVector jarg1_);
  public final static native void CalibrationHelperVector_reserve(long jarg1, CalibrationHelperVector jarg1_, long jarg2);
  public final static native boolean CalibrationHelperVector_isEmpty(long jarg1, CalibrationHelperVector jarg1_);
  public final static native void CalibrationHelperVector_clear(long jarg1, CalibrationHelperVector jarg1_);
  public final static native long new_CalibrationHelperVector__SWIG_2(int jarg1, long jarg2, CalibrationHelper jarg2_);
  public final static native int CalibrationHelperVector_doSize(long jarg1, CalibrationHelperVector jarg1_);
  public final static native void CalibrationHelperVector_doAdd__SWIG_0(long jarg1, CalibrationHelperVector jarg1_, long jarg2, CalibrationHelper jarg2_);
  public final static native void CalibrationHelperVector_doAdd__SWIG_1(long jarg1, CalibrationHelperVector jarg1_, int jarg2, long jarg3, CalibrationHelper jarg3_);
  public final static native long CalibrationHelperVector_doRemove(long jarg1, CalibrationHelperVector jarg1_, int jarg2);
  public final static native long CalibrationHelperVector_doGet(long jarg1, CalibrationHelperVector jarg1_, int jarg2);
  public final static native long CalibrationHelperVector_doSet(long jarg1, CalibrationHelperVector jarg1_, int jarg2, long jarg3, CalibrationHelper jarg3_);
  public final static native void CalibrationHelperVector_doRemoveRange(long jarg1, CalibrationHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_CalibrationHelperVector(long jarg1);
  public final static native long CalibratedModel_params(long jarg1, CalibratedModel jarg1_);
  public final static native void CalibratedModel_calibrate__SWIG_0(long jarg1, CalibratedModel jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void CalibratedModel_calibrate__SWIG_1(long jarg1, CalibratedModel jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void CalibratedModel_calibrate__SWIG_2(long jarg1, CalibratedModel jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void CalibratedModel_calibrate__SWIG_3(long jarg1, CalibratedModel jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native void CalibratedModel_setParams(long jarg1, CalibratedModel jarg1_, long jarg2, Array jarg2_);
  public final static native double CalibratedModel_value(long jarg1, CalibratedModel jarg1_, long jarg2, Array jarg2_, long jarg3, CalibrationHelperVector jarg3_);
  public final static native long CalibratedModel_constraint(long jarg1, CalibratedModel jarg1_);
  public final static native int CalibratedModel_endCriteria(long jarg1, CalibratedModel jarg1_);
  public final static native long CalibratedModel_problemValues(long jarg1, CalibratedModel jarg1_);
  public final static native int CalibratedModel_functionEvaluation(long jarg1, CalibratedModel jarg1_);
  public final static native void delete_CalibratedModel(long jarg1);
  public final static native long TermStructureConsistentModel_termStructure(long jarg1, TermStructureConsistentModel jarg1_);
  public final static native void delete_TermStructureConsistentModel(long jarg1);
  public final static native long new_CalibratedModelHandle__SWIG_0(long jarg1, CalibratedModel jarg1_);
  public final static native long new_CalibratedModelHandle__SWIG_1();
  public final static native long CalibratedModelHandle___deref__(long jarg1, CalibratedModelHandle jarg1_);
  public final static native long CalibratedModelHandle_currentLink(long jarg1, CalibratedModelHandle jarg1_);
  public final static native boolean CalibratedModelHandle_empty(long jarg1, CalibratedModelHandle jarg1_);
  public final static native long CalibratedModelHandle_asObservable(long jarg1, CalibratedModelHandle jarg1_);
  public final static native void delete_CalibratedModelHandle(long jarg1);
  public final static native long CalibratedModelHandle_params(long jarg1, CalibratedModelHandle jarg1_);
  public final static native void CalibratedModelHandle_calibrate__SWIG_0(long jarg1, CalibratedModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void CalibratedModelHandle_calibrate__SWIG_1(long jarg1, CalibratedModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void CalibratedModelHandle_calibrate__SWIG_2(long jarg1, CalibratedModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void CalibratedModelHandle_calibrate__SWIG_3(long jarg1, CalibratedModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native void CalibratedModelHandle_setParams(long jarg1, CalibratedModelHandle jarg1_, long jarg2, Array jarg2_);
  public final static native double CalibratedModelHandle_value(long jarg1, CalibratedModelHandle jarg1_, long jarg2, Array jarg2_, long jarg3, CalibrationHelperVector jarg3_);
  public final static native long CalibratedModelHandle_constraint(long jarg1, CalibratedModelHandle jarg1_);
  public final static native int CalibratedModelHandle_endCriteria(long jarg1, CalibratedModelHandle jarg1_);
  public final static native long CalibratedModelHandle_problemValues(long jarg1, CalibratedModelHandle jarg1_);
  public final static native int CalibratedModelHandle_functionEvaluation(long jarg1, CalibratedModelHandle jarg1_);
  public final static native long new_RelinkableCalibratedModelHandle__SWIG_0(long jarg1, CalibratedModel jarg1_);
  public final static native long new_RelinkableCalibratedModelHandle__SWIG_1();
  public final static native void RelinkableCalibratedModelHandle_linkTo(long jarg1, RelinkableCalibratedModelHandle jarg1_, long jarg2, CalibratedModel jarg2_);
  public final static native void RelinkableCalibratedModelHandle_reset(long jarg1, RelinkableCalibratedModelHandle jarg1_);
  public final static native void delete_RelinkableCalibratedModelHandle(long jarg1);
  public final static native long new_Parameter();
  public final static native long Parameter_params(long jarg1, Parameter jarg1_);
  public final static native void Parameter_setParam(long jarg1, Parameter jarg1_, long jarg2, double jarg3);
  public final static native boolean Parameter_testParams(long jarg1, Parameter jarg1_, long jarg2, Array jarg2_);
  public final static native long Parameter_size(long jarg1, Parameter jarg1_);
  public final static native double Parameter_getValue(long jarg1, Parameter jarg1_, double jarg2);
  public final static native long Parameter_constraint(long jarg1, Parameter jarg1_);
  public final static native void delete_Parameter(long jarg1);
  public final static native long new_ConstantParameter__SWIG_0(long jarg1, Constraint jarg1_);
  public final static native long new_ConstantParameter__SWIG_1(double jarg1, long jarg2, Constraint jarg2_);
  public final static native void delete_ConstantParameter(long jarg1);
  public final static native long new_NullParameter();
  public final static native void delete_NullParameter(long jarg1);
  public final static native long new_PiecewiseConstantParameter__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Constraint jarg2_);
  public final static native long new_PiecewiseConstantParameter__SWIG_1(long jarg1, DoubleVector jarg1_);
  public final static native void delete_PiecewiseConstantParameter(long jarg1);
  public final static native double Payoff_getValue(long jarg1, Payoff jarg1_, double jarg2);
  public final static native void delete_Payoff(long jarg1);
  public final static native int Option_Put_get();
  public final static native int Option_Call_get();
  public final static native long Option_payoff(long jarg1, Option jarg1_);
  public final static native long Option_exercise(long jarg1, Option jarg1_);
  public final static native void delete_Option(long jarg1);
  public final static native int TypePayoff_optionType(long jarg1, TypePayoff jarg1_);
  public final static native void delete_TypePayoff(long jarg1);
  public final static native long new_FloatingTypePayoff(int jarg1);
  public final static native double FloatingTypePayoff_getValue__SWIG_0(long jarg1, FloatingTypePayoff jarg1_, double jarg2, double jarg3);
  public final static native double FloatingTypePayoff_getValue__SWIG_1(long jarg1, FloatingTypePayoff jarg1_, double jarg2);
  public final static native void delete_FloatingTypePayoff(long jarg1);
  public final static native double StrikedTypePayoff_strike(long jarg1, StrikedTypePayoff jarg1_);
  public final static native void delete_StrikedTypePayoff(long jarg1);
  public final static native long new_DeltaVolQuote__SWIG_0(double jarg1, long jarg2, QuoteHandle jarg2_, double jarg3, int jarg4);
  public final static native long new_DeltaVolQuote__SWIG_1(long jarg1, QuoteHandle jarg1_, int jarg2, double jarg3, int jarg4);
  public final static native double DeltaVolQuote_delta(long jarg1, DeltaVolQuote jarg1_);
  public final static native double DeltaVolQuote_maturity(long jarg1, DeltaVolQuote jarg1_);
  public final static native int DeltaVolQuote_atmType(long jarg1, DeltaVolQuote jarg1_);
  public final static native int DeltaVolQuote_deltaType(long jarg1, DeltaVolQuote jarg1_);
  public final static native void delete_DeltaVolQuote(long jarg1);
  public final static native long new_DeltaVolQuoteHandle__SWIG_0(long jarg1, DeltaVolQuote jarg1_);
  public final static native long new_DeltaVolQuoteHandle__SWIG_1();
  public final static native long DeltaVolQuoteHandle___deref__(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native long DeltaVolQuoteHandle_currentLink(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native boolean DeltaVolQuoteHandle_empty(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native long DeltaVolQuoteHandle_asObservable(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native void delete_DeltaVolQuoteHandle(long jarg1);
  public final static native double DeltaVolQuoteHandle_delta(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native double DeltaVolQuoteHandle_maturity(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native int DeltaVolQuoteHandle_atmType(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native int DeltaVolQuoteHandle_deltaType(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native double DeltaVolQuoteHandle_value(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native boolean DeltaVolQuoteHandle_isValid(long jarg1, DeltaVolQuoteHandle jarg1_);
  public final static native long new_RelinkableDeltaVolQuoteHandle__SWIG_0(long jarg1, DeltaVolQuote jarg1_);
  public final static native long new_RelinkableDeltaVolQuoteHandle__SWIG_1();
  public final static native void RelinkableDeltaVolQuoteHandle_linkTo(long jarg1, RelinkableDeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuote jarg2_);
  public final static native void RelinkableDeltaVolQuoteHandle_reset(long jarg1, RelinkableDeltaVolQuoteHandle jarg1_);
  public final static native void delete_RelinkableDeltaVolQuoteHandle(long jarg1);
  public final static native double OneAssetOption_delta(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_deltaForward(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_elasticity(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_gamma(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_theta(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_thetaPerDay(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_vega(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_rho(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_dividendRho(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_strikeSensitivity(long jarg1, OneAssetOption jarg1_);
  public final static native double OneAssetOption_itmCashProbability(long jarg1, OneAssetOption jarg1_);
  public final static native void delete_OneAssetOption(long jarg1);
  public final static native long new_VanillaOption(long jarg1, StrikedTypePayoff jarg1_, long jarg2, Exercise jarg2_);
  public final static native double VanillaOption_impliedVolatility__SWIG_0(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5, double jarg6, double jarg7);
  public final static native double VanillaOption_impliedVolatility__SWIG_1(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5, double jarg6);
  public final static native double VanillaOption_impliedVolatility__SWIG_2(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5);
  public final static native double VanillaOption_impliedVolatility__SWIG_3(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4);
  public final static native double VanillaOption_impliedVolatility__SWIG_4(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_);
  public final static native double VanillaOption_impliedVolatility__SWIG_5(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5, long jarg6, double jarg7, double jarg8);
  public final static native double VanillaOption_impliedVolatility__SWIG_6(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5, long jarg6, double jarg7);
  public final static native double VanillaOption_impliedVolatility__SWIG_7(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5, long jarg6);
  public final static native double VanillaOption_impliedVolatility__SWIG_8(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5);
  public final static native double VanillaOption_impliedVolatility__SWIG_9(long jarg1, VanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long VanillaOption_priceCurve(long jarg1, VanillaOption jarg1_);
  public final static native void delete_VanillaOption(long jarg1);
  public final static native long new_CalibrationPair__SWIG_0();
  public final static native long new_CalibrationPair__SWIG_1(long jarg1, VanillaOption jarg1_, long jarg2, Quote jarg2_);
  public final static native long new_CalibrationPair__SWIG_2(long jarg1, CalibrationPair jarg1_);
  public final static native void CalibrationPair_first_set(long jarg1, CalibrationPair jarg1_, long jarg2, VanillaOption jarg2_);
  public final static native long CalibrationPair_first_get(long jarg1, CalibrationPair jarg1_);
  public final static native void CalibrationPair_second_set(long jarg1, CalibrationPair jarg1_, long jarg2, Quote jarg2_);
  public final static native long CalibrationPair_second_get(long jarg1, CalibrationPair jarg1_);
  public final static native void delete_CalibrationPair(long jarg1);
  public final static native long new_CalibrationSet__SWIG_0();
  public final static native long new_CalibrationSet__SWIG_1(long jarg1, CalibrationSet jarg1_);
  public final static native long CalibrationSet_capacity(long jarg1, CalibrationSet jarg1_);
  public final static native void CalibrationSet_reserve(long jarg1, CalibrationSet jarg1_, long jarg2);
  public final static native boolean CalibrationSet_isEmpty(long jarg1, CalibrationSet jarg1_);
  public final static native void CalibrationSet_clear(long jarg1, CalibrationSet jarg1_);
  public final static native long new_CalibrationSet__SWIG_2(int jarg1, long jarg2, CalibrationPair jarg2_);
  public final static native int CalibrationSet_doSize(long jarg1, CalibrationSet jarg1_);
  public final static native void CalibrationSet_doAdd__SWIG_0(long jarg1, CalibrationSet jarg1_, long jarg2, CalibrationPair jarg2_);
  public final static native void CalibrationSet_doAdd__SWIG_1(long jarg1, CalibrationSet jarg1_, int jarg2, long jarg3, CalibrationPair jarg3_);
  public final static native long CalibrationSet_doRemove(long jarg1, CalibrationSet jarg1_, int jarg2);
  public final static native long CalibrationSet_doGet(long jarg1, CalibrationSet jarg1_, int jarg2);
  public final static native long CalibrationSet_doSet(long jarg1, CalibrationSet jarg1_, int jarg2, long jarg3, CalibrationPair jarg3_);
  public final static native void CalibrationSet_doRemoveRange(long jarg1, CalibrationSet jarg1_, int jarg2, int jarg3);
  public final static native void delete_CalibrationSet(long jarg1);
  public final static native long new_EuropeanOption(long jarg1, StrikedTypePayoff jarg1_, long jarg2, Exercise jarg2_);
  public final static native void delete_EuropeanOption(long jarg1);
  public final static native long new_ForwardVanillaOption(double jarg1, long jarg2, Date jarg2_, long jarg3, StrikedTypePayoff jarg3_, long jarg4, Exercise jarg4_);
  public final static native void delete_ForwardVanillaOption(long jarg1);
  public final static native long new_QuantoVanillaOption(long jarg1, StrikedTypePayoff jarg1_, long jarg2, Exercise jarg2_);
  public final static native double QuantoVanillaOption_qvega(long jarg1, QuantoVanillaOption jarg1_);
  public final static native double QuantoVanillaOption_qrho(long jarg1, QuantoVanillaOption jarg1_);
  public final static native double QuantoVanillaOption_qlambda(long jarg1, QuantoVanillaOption jarg1_);
  public final static native void delete_QuantoVanillaOption(long jarg1);
  public final static native long new_QuantoForwardVanillaOption(double jarg1, long jarg2, Date jarg2_, long jarg3, StrikedTypePayoff jarg3_, long jarg4, Exercise jarg4_);
  public final static native void delete_QuantoForwardVanillaOption(long jarg1);
  public final static native double MultiAssetOption_delta(long jarg1, MultiAssetOption jarg1_);
  public final static native double MultiAssetOption_gamma(long jarg1, MultiAssetOption jarg1_);
  public final static native double MultiAssetOption_theta(long jarg1, MultiAssetOption jarg1_);
  public final static native double MultiAssetOption_vega(long jarg1, MultiAssetOption jarg1_);
  public final static native double MultiAssetOption_rho(long jarg1, MultiAssetOption jarg1_);
  public final static native double MultiAssetOption_dividendRho(long jarg1, MultiAssetOption jarg1_);
  public final static native void delete_MultiAssetOption(long jarg1);
  public final static native long new_AnalyticEuropeanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long new_AnalyticEuropeanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_AnalyticEuropeanEngine(long jarg1);
  public final static native long new_HestonModel(long jarg1, HestonProcess jarg1_);
  public final static native double HestonModel_theta(long jarg1, HestonModel jarg1_);
  public final static native double HestonModel_kappa(long jarg1, HestonModel jarg1_);
  public final static native double HestonModel_sigma(long jarg1, HestonModel jarg1_);
  public final static native double HestonModel_rho(long jarg1, HestonModel jarg1_);
  public final static native double HestonModel_v0(long jarg1, HestonModel jarg1_);
  public final static native void delete_HestonModel(long jarg1);
  public final static native long new_HestonModelHandle__SWIG_0(long jarg1, HestonModel jarg1_);
  public final static native long new_HestonModelHandle__SWIG_1();
  public final static native long HestonModelHandle___deref__(long jarg1, HestonModelHandle jarg1_);
  public final static native long HestonModelHandle_currentLink(long jarg1, HestonModelHandle jarg1_);
  public final static native boolean HestonModelHandle_empty(long jarg1, HestonModelHandle jarg1_);
  public final static native long HestonModelHandle_asObservable(long jarg1, HestonModelHandle jarg1_);
  public final static native void delete_HestonModelHandle(long jarg1);
  public final static native double HestonModelHandle_theta(long jarg1, HestonModelHandle jarg1_);
  public final static native double HestonModelHandle_kappa(long jarg1, HestonModelHandle jarg1_);
  public final static native double HestonModelHandle_sigma(long jarg1, HestonModelHandle jarg1_);
  public final static native double HestonModelHandle_rho(long jarg1, HestonModelHandle jarg1_);
  public final static native double HestonModelHandle_v0(long jarg1, HestonModelHandle jarg1_);
  public final static native long HestonModelHandle_params(long jarg1, HestonModelHandle jarg1_);
  public final static native void HestonModelHandle_calibrate__SWIG_0(long jarg1, HestonModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void HestonModelHandle_calibrate__SWIG_1(long jarg1, HestonModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void HestonModelHandle_calibrate__SWIG_2(long jarg1, HestonModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void HestonModelHandle_calibrate__SWIG_3(long jarg1, HestonModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native void HestonModelHandle_setParams(long jarg1, HestonModelHandle jarg1_, long jarg2, Array jarg2_);
  public final static native double HestonModelHandle_value(long jarg1, HestonModelHandle jarg1_, long jarg2, Array jarg2_, long jarg3, CalibrationHelperVector jarg3_);
  public final static native long HestonModelHandle_constraint(long jarg1, HestonModelHandle jarg1_);
  public final static native int HestonModelHandle_endCriteria(long jarg1, HestonModelHandle jarg1_);
  public final static native long HestonModelHandle_problemValues(long jarg1, HestonModelHandle jarg1_);
  public final static native int HestonModelHandle_functionEvaluation(long jarg1, HestonModelHandle jarg1_);
  public final static native long new_PiecewiseTimeDependentHestonModel(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, QuoteHandle jarg3_, double jarg4, long jarg5, Parameter jarg5_, long jarg6, Parameter jarg6_, long jarg7, Parameter jarg7_, long jarg8, Parameter jarg8_, long jarg9, TimeGrid jarg9_);
  public final static native double PiecewiseTimeDependentHestonModel_theta(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, double jarg2);
  public final static native double PiecewiseTimeDependentHestonModel_kappa(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, double jarg2);
  public final static native double PiecewiseTimeDependentHestonModel_sigma(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, double jarg2);
  public final static native double PiecewiseTimeDependentHestonModel_rho(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, double jarg2);
  public final static native double PiecewiseTimeDependentHestonModel_v0(long jarg1, PiecewiseTimeDependentHestonModel jarg1_);
  public final static native double PiecewiseTimeDependentHestonModel_s0(long jarg1, PiecewiseTimeDependentHestonModel jarg1_);
  public final static native long PiecewiseTimeDependentHestonModel_timeGrid(long jarg1, PiecewiseTimeDependentHestonModel jarg1_);
  public final static native long PiecewiseTimeDependentHestonModel_dividendYield(long jarg1, PiecewiseTimeDependentHestonModel jarg1_);
  public final static native long PiecewiseTimeDependentHestonModel_riskFreeRate(long jarg1, PiecewiseTimeDependentHestonModel jarg1_);
  public final static native void delete_PiecewiseTimeDependentHestonModel(long jarg1);
  public final static native long new_AnalyticHestonEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2);
  public final static native long new_AnalyticHestonEngine__SWIG_1(long jarg1, HestonModel jarg1_);
  public final static native long new_AnalyticHestonEngine__SWIG_2(long jarg1, HestonModel jarg1_, double jarg2, long jarg3);
  public final static native long new_AnalyticHestonEngine__SWIG_3(long jarg1, HestonModel jarg1_, int jarg2, long jarg3, AnalyticHestonEngine_Integration jarg3_, double jarg4);
  public final static native long new_AnalyticHestonEngine__SWIG_4(long jarg1, HestonModel jarg1_, int jarg2, long jarg3, AnalyticHestonEngine_Integration jarg3_);
  public final static native long AnalyticHestonEngine_numberOfEvaluations(long jarg1, AnalyticHestonEngine jarg1_);
  public final static native long AnalyticHestonEngine_chF(long jarg1, AnalyticHestonEngine jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void delete_AnalyticHestonEngine(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_gaussLaguerre__SWIG_0(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_gaussLaguerre__SWIG_1();
  public final static native long AnalyticHestonEngine_Integration_gaussLegendre__SWIG_0(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_gaussLegendre__SWIG_1();
  public final static native long AnalyticHestonEngine_Integration_gaussChebyshev__SWIG_0(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_gaussChebyshev__SWIG_1();
  public final static native long AnalyticHestonEngine_Integration_gaussChebyshev2nd__SWIG_0(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_gaussChebyshev2nd__SWIG_1();
  public final static native long AnalyticHestonEngine_Integration_gaussLobatto__SWIG_0(double jarg1, double jarg2, long jarg3, boolean jarg4);
  public final static native long AnalyticHestonEngine_Integration_gaussLobatto__SWIG_1(double jarg1, double jarg2, long jarg3);
  public final static native long AnalyticHestonEngine_Integration_gaussLobatto__SWIG_2(double jarg1, double jarg2);
  public final static native long AnalyticHestonEngine_Integration_gaussKronrod__SWIG_0(double jarg1, long jarg2);
  public final static native long AnalyticHestonEngine_Integration_gaussKronrod__SWIG_1(double jarg1);
  public final static native long AnalyticHestonEngine_Integration_simpson__SWIG_0(double jarg1, long jarg2);
  public final static native long AnalyticHestonEngine_Integration_simpson__SWIG_1(double jarg1);
  public final static native long AnalyticHestonEngine_Integration_trapezoid__SWIG_0(double jarg1, long jarg2);
  public final static native long AnalyticHestonEngine_Integration_trapezoid__SWIG_1(double jarg1);
  public final static native long AnalyticHestonEngine_Integration_discreteSimpson__SWIG_0(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_discreteSimpson__SWIG_1();
  public final static native long AnalyticHestonEngine_Integration_discreteTrapezoid__SWIG_0(long jarg1);
  public final static native long AnalyticHestonEngine_Integration_discreteTrapezoid__SWIG_1();
  public final static native long AnalyticHestonEngine_Integration_expSinh__SWIG_0(double jarg1);
  public final static native long AnalyticHestonEngine_Integration_expSinh__SWIG_1();
  public final static native double AnalyticHestonEngine_Integration_andersenPiterbargIntegrationLimit(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native long AnalyticHestonEngine_Integration_numberOfEvaluations(long jarg1, AnalyticHestonEngine_Integration jarg1_);
  public final static native boolean AnalyticHestonEngine_Integration_isAdaptiveIntegration(long jarg1, AnalyticHestonEngine_Integration jarg1_);
  public final static native void delete_AnalyticHestonEngine_Integration(long jarg1);
  public final static native long new_AnalyticHestonEngine_OptimalAlpha(double jarg1, long jarg2, AnalyticHestonEngine jarg2_);
  public final static native double AnalyticHestonEngine_OptimalAlpha_getValue(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2);
  public final static native long AnalyticHestonEngine_OptimalAlpha_alphaGreaterZero(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2);
  public final static native long AnalyticHestonEngine_OptimalAlpha_alphaSmallerMinusOne(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2);
  public final static native long AnalyticHestonEngine_OptimalAlpha_numberOfEvaluations(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_);
  public final static native double AnalyticHestonEngine_OptimalAlpha_M(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2);
  public final static native double AnalyticHestonEngine_OptimalAlpha_k(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2, int jarg3);
  public final static native double AnalyticHestonEngine_OptimalAlpha_alphaMin(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2);
  public final static native double AnalyticHestonEngine_OptimalAlpha_alphaMax(long jarg1, AnalyticHestonEngine_OptimalAlpha jarg1_, double jarg2);
  public final static native void delete_AnalyticHestonEngine_OptimalAlpha(long jarg1);
  public final static native long new_COSHestonEngine__SWIG_0(long jarg1, HestonModel jarg1_, double jarg2, long jarg3);
  public final static native long new_COSHestonEngine__SWIG_1(long jarg1, HestonModel jarg1_, double jarg2);
  public final static native long new_COSHestonEngine__SWIG_2(long jarg1, HestonModel jarg1_);
  public final static native void delete_COSHestonEngine(long jarg1);
  public final static native long new_ExponentialFittingHestonEngine__SWIG_0(long jarg1, HestonModel jarg1_, int jarg2, double jarg3, double jarg4);
  public final static native long new_ExponentialFittingHestonEngine__SWIG_1(long jarg1, HestonModel jarg1_, int jarg2, double jarg3);
  public final static native long new_ExponentialFittingHestonEngine__SWIG_2(long jarg1, HestonModel jarg1_, int jarg2);
  public final static native long new_ExponentialFittingHestonEngine__SWIG_3(long jarg1, HestonModel jarg1_);
  public final static native void delete_ExponentialFittingHestonEngine(long jarg1);
  public final static native long new_AnalyticPTDHestonEngine__SWIG_0(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, double jarg2, long jarg3);
  public final static native long new_AnalyticPTDHestonEngine__SWIG_1(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, long jarg2);
  public final static native long new_AnalyticPTDHestonEngine__SWIG_2(long jarg1, PiecewiseTimeDependentHestonModel jarg1_);
  public final static native long new_AnalyticPTDHestonEngine__SWIG_3(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, int jarg2, long jarg3, AnalyticHestonEngine_Integration jarg3_, double jarg4);
  public final static native long new_AnalyticPTDHestonEngine__SWIG_4(long jarg1, PiecewiseTimeDependentHestonModel jarg1_, int jarg2, long jarg3, AnalyticHestonEngine_Integration jarg3_);
  public final static native void delete_AnalyticPTDHestonEngine(long jarg1);
  public final static native long new_BatesModel(long jarg1, BatesProcess jarg1_);
  public final static native double BatesModel_nu(long jarg1, BatesModel jarg1_);
  public final static native double BatesModel_delta(long jarg1, BatesModel jarg1_);
  public final static native double BatesModel_lambda(long jarg1, BatesModel jarg1_);
  public final static native void delete_BatesModel(long jarg1);
  public final static native long new_BatesEngine__SWIG_0(long jarg1, BatesModel jarg1_, long jarg2);
  public final static native long new_BatesEngine__SWIG_1(long jarg1, BatesModel jarg1_);
  public final static native long new_BatesEngine__SWIG_2(long jarg1, BatesModel jarg1_, double jarg2, long jarg3);
  public final static native void delete_BatesEngine(long jarg1);
  public final static native long new_IntegralEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_IntegralEngine(long jarg1);
  public final static native long new_BinomialCRRVanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialCRRVanillaEngine(long jarg1);
  public final static native long new_BinomialJRVanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialJRVanillaEngine(long jarg1);
  public final static native long new_BinomialEQPVanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialEQPVanillaEngine(long jarg1);
  public final static native long new_BinomialTrigeorgisVanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialTrigeorgisVanillaEngine(long jarg1);
  public final static native long new_BinomialTianVanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialTianVanillaEngine(long jarg1);
  public final static native long new_BinomialLRVanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialLRVanillaEngine(long jarg1);
  public final static native long new_BinomialJ4VanillaEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialJ4VanillaEngine(long jarg1);
  public final static native long new_LsmBasisSystem();
  public final static native void delete_LsmBasisSystem(long jarg1);
  public final static native long new_MCPREuropeanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPREuropeanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPREuropeanEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPREuropeanEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPREuropeanEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPREuropeanEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPREuropeanEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPREuropeanEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCPREuropeanEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPREuropeanEngine(long jarg1);
  public final static native long new_MCLDEuropeanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDEuropeanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDEuropeanEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDEuropeanEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDEuropeanEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDEuropeanEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDEuropeanEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDEuropeanEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCLDEuropeanEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDEuropeanEngine(long jarg1);
  public final static native long new_MCPRAmericanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, long jarg13, OptionalBool jarg13_, long jarg14);
  public final static native long new_MCPRAmericanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, long jarg13, OptionalBool jarg13_);
  public final static native long new_MCPRAmericanEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12);
  public final static native long new_MCPRAmericanEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11);
  public final static native long new_MCPRAmericanEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10);
  public final static native long new_MCPRAmericanEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPRAmericanEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPRAmericanEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPRAmericanEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPRAmericanEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPRAmericanEngine__SWIG_10(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPRAmericanEngine__SWIG_11(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPRAmericanEngine__SWIG_12(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCPRAmericanEngine__SWIG_13(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRAmericanEngine(long jarg1);
  public final static native long new_MCLDAmericanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, long jarg13, OptionalBool jarg13_, long jarg14);
  public final static native long new_MCLDAmericanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, long jarg13, OptionalBool jarg13_);
  public final static native long new_MCLDAmericanEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12);
  public final static native long new_MCLDAmericanEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11);
  public final static native long new_MCLDAmericanEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10);
  public final static native long new_MCLDAmericanEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDAmericanEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDAmericanEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDAmericanEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDAmericanEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDAmericanEngine__SWIG_10(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDAmericanEngine__SWIG_11(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDAmericanEngine__SWIG_12(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCLDAmericanEngine__SWIG_13(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDAmericanEngine(long jarg1);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, int jarg2);
  public final static native long new_MCPREuropeanHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCPREuropeanHestonEngine(long jarg1);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, int jarg2);
  public final static native long new_MCLDEuropeanHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCLDEuropeanHestonEngine(long jarg1);
  public final static native long new_MCPRDigitalEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPRDigitalEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPRDigitalEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPRDigitalEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPRDigitalEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPRDigitalEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPRDigitalEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPRDigitalEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCPRDigitalEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRDigitalEngine(long jarg1);
  public final static native long new_MCLDDigitalEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDDigitalEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDDigitalEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDDigitalEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDDigitalEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDDigitalEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDDigitalEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDDigitalEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCLDDigitalEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDDigitalEngine(long jarg1);
  public final static native long new_BaroneAdesiWhaleyApproximationEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_BaroneAdesiWhaleyApproximationEngine(long jarg1);
  public final static native long new_BjerksundStenslandApproximationEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_BjerksundStenslandApproximationEngine(long jarg1);
  public final static native long new_JuQuadraticApproximationEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_JuQuadraticApproximationEngine(long jarg1);
  public final static native long new_AnalyticDigitalAmericanEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticDigitalAmericanEngine(long jarg1);
  public final static native long new_AnalyticDigitalAmericanKOEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticDigitalAmericanKOEngine(long jarg1);
  public final static native long new_DividendVanillaOption(long jarg1, StrikedTypePayoff jarg1_, long jarg2, Exercise jarg2_, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_);
  public final static native double DividendVanillaOption_impliedVolatility__SWIG_0(long jarg1, DividendVanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5, double jarg6, double jarg7);
  public final static native double DividendVanillaOption_impliedVolatility__SWIG_1(long jarg1, DividendVanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5, double jarg6);
  public final static native double DividendVanillaOption_impliedVolatility__SWIG_2(long jarg1, DividendVanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5);
  public final static native double DividendVanillaOption_impliedVolatility__SWIG_3(long jarg1, DividendVanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4);
  public final static native double DividendVanillaOption_impliedVolatility__SWIG_4(long jarg1, DividendVanillaOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_);
  public final static native void delete_DividendVanillaOption(long jarg1);
  public final static native long new_AnalyticDividendEuropeanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long new_AnalyticDividendEuropeanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_AnalyticDividendEuropeanEngine(long jarg1);
  public final static native long new_QdPlusAmericanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, int jarg3, double jarg4, long jarg5);
  public final static native long new_QdPlusAmericanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, int jarg3, double jarg4);
  public final static native long new_QdPlusAmericanEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, int jarg3);
  public final static native long new_QdPlusAmericanEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native long new_QdPlusAmericanEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_QdPlusAmericanEngine(long jarg1);
  public final static native void delete_QdFpIterationScheme(long jarg1);
  public final static native long new_QdFpLegendreScheme(long jarg1, long jarg2, long jarg3, long jarg4);
  public final static native void delete_QdFpLegendreScheme(long jarg1);
  public final static native long new_QdFpLegendreTanhSinhScheme(long jarg1, long jarg2, long jarg3, double jarg4);
  public final static native void delete_QdFpLegendreTanhSinhScheme(long jarg1);
  public final static native long new_QdFpTanhSinhIterationScheme(long jarg1, long jarg2, double jarg3);
  public final static native void delete_QdFpTanhSinhIterationScheme(long jarg1);
  public final static native long new_QdFpAmericanEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, QdFpIterationScheme jarg2_, int jarg3);
  public final static native long new_QdFpAmericanEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, QdFpIterationScheme jarg2_);
  public final static native long new_QdFpAmericanEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long QdFpAmericanEngine_fastScheme();
  public final static native long QdFpAmericanEngine_accurateScheme();
  public final static native long QdFpAmericanEngine_highPrecisionScheme();
  public final static native void delete_QdFpAmericanEngine(long jarg1);
  public final static native long new_FdmSchemeDesc(int jarg1, double jarg2, double jarg3);
  public final static native int FdmSchemeDesc_type_get(long jarg1, FdmSchemeDesc jarg1_);
  public final static native double FdmSchemeDesc_theta_get(long jarg1, FdmSchemeDesc jarg1_);
  public final static native double FdmSchemeDesc_mu_get(long jarg1, FdmSchemeDesc jarg1_);
  public final static native long FdmSchemeDesc_Douglas();
  public final static native long FdmSchemeDesc_CrankNicolson();
  public final static native long FdmSchemeDesc_ImplicitEuler();
  public final static native long FdmSchemeDesc_ExplicitEuler();
  public final static native long FdmSchemeDesc_CraigSneyd();
  public final static native long FdmSchemeDesc_ModifiedCraigSneyd();
  public final static native long FdmSchemeDesc_Hundsdorfer();
  public final static native long FdmSchemeDesc_ModifiedHundsdorfer();
  public final static native long FdmSchemeDesc_MethodOfLines__SWIG_0(double jarg1, double jarg2);
  public final static native long FdmSchemeDesc_MethodOfLines__SWIG_1(double jarg1);
  public final static native long FdmSchemeDesc_MethodOfLines__SWIG_2();
  public final static native long FdmSchemeDesc_TrBDF2();
  public final static native void delete_FdmSchemeDesc(long jarg1);
  public final static native long new_FdmQuantoHelper(long jarg1, YieldTermStructure jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, BlackVolTermStructure jarg3_, double jarg4, double jarg5);
  public final static native void delete_FdmQuantoHelper(long jarg1);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6, double jarg7, int jarg8);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6, double jarg7);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7, double jarg8, int jarg9);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7, double jarg8);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_10(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_11(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_12(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_13(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_14(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_15(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, FdmQuantoHelper jarg2_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_16(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7, double jarg8, int jarg9);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_17(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7, double jarg8);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_18(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_19(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_20(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_21(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_22(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_23(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_24(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, boolean jarg8, double jarg9, int jarg10);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_25(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, boolean jarg8, double jarg9);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_26(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, boolean jarg8);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_27(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_28(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_29(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_30(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4);
  public final static native long new_FdBlackScholesVanillaEngine__SWIG_31(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_);
  public final static native void delete_FdBlackScholesVanillaEngine(long jarg1);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdBlackScholesShoutEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_FdBlackScholesShoutEngine(long jarg1);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_0(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4, long jarg5, double jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_1(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4, long jarg5, double jarg6);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_2(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_3(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_4(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_5(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_6(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, DividendSchedule jarg3_, long jarg4, long jarg5, long jarg6, double jarg7, long jarg8, FdmSchemeDesc jarg8_);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_7(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, DividendSchedule jarg3_, long jarg4, long jarg5, long jarg6, double jarg7);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_8(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, DividendSchedule jarg3_, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_9(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, DividendSchedule jarg3_, long jarg4, long jarg5);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_10(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, DividendSchedule jarg3_, long jarg4);
  public final static native long new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_11(long jarg1, OrnsteinUhlenbeckProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, DividendSchedule jarg3_);
  public final static native void delete_FdOrnsteinUhlenbeckVanillaEngine(long jarg1);
  public final static native long new_FdBatesVanillaEngine__SWIG_0(long jarg1, BatesModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdBatesVanillaEngine__SWIG_1(long jarg1, BatesModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBatesVanillaEngine__SWIG_2(long jarg1, BatesModel jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdBatesVanillaEngine__SWIG_3(long jarg1, BatesModel jarg1_, long jarg2, long jarg3);
  public final static native long new_FdBatesVanillaEngine__SWIG_4(long jarg1, BatesModel jarg1_, long jarg2);
  public final static native long new_FdBatesVanillaEngine__SWIG_5(long jarg1, BatesModel jarg1_);
  public final static native long new_FdBatesVanillaEngine__SWIG_6(long jarg1, BatesModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdBatesVanillaEngine__SWIG_7(long jarg1, BatesModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdBatesVanillaEngine__SWIG_8(long jarg1, BatesModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBatesVanillaEngine__SWIG_9(long jarg1, BatesModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdBatesVanillaEngine__SWIG_10(long jarg1, BatesModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdBatesVanillaEngine__SWIG_11(long jarg1, BatesModel jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_FdBatesVanillaEngine(long jarg1);
  public final static native long new_FdHestonVanillaEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_, double jarg8);
  public final static native long new_FdHestonVanillaEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_);
  public final static native long new_FdHestonVanillaEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdHestonVanillaEngine__SWIG_3(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonVanillaEngine__SWIG_4(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdHestonVanillaEngine__SWIG_5(long jarg1, HestonModel jarg1_, long jarg2, long jarg3);
  public final static native long new_FdHestonVanillaEngine__SWIG_6(long jarg1, HestonModel jarg1_, long jarg2);
  public final static native long new_FdHestonVanillaEngine__SWIG_7(long jarg1, HestonModel jarg1_);
  public final static native long new_FdHestonVanillaEngine__SWIG_8(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_, double jarg9);
  public final static native long new_FdHestonVanillaEngine__SWIG_9(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_);
  public final static native long new_FdHestonVanillaEngine__SWIG_10(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdHestonVanillaEngine__SWIG_11(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonVanillaEngine__SWIG_12(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonVanillaEngine__SWIG_13(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3, long jarg4);
  public final static native long new_FdHestonVanillaEngine__SWIG_14(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_, long jarg3);
  public final static native long new_FdHestonVanillaEngine__SWIG_15(long jarg1, HestonModel jarg1_, long jarg2, FdmQuantoHelper jarg2_);
  public final static native long new_FdHestonVanillaEngine__SWIG_16(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_, double jarg9);
  public final static native long new_FdHestonVanillaEngine__SWIG_17(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_);
  public final static native long new_FdHestonVanillaEngine__SWIG_18(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdHestonVanillaEngine__SWIG_19(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonVanillaEngine__SWIG_20(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonVanillaEngine__SWIG_21(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdHestonVanillaEngine__SWIG_22(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdHestonVanillaEngine__SWIG_23(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native long new_FdHestonVanillaEngine__SWIG_24(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, FdmSchemeDesc jarg8_, long jarg9, LocalVolTermStructure jarg9_, double jarg10);
  public final static native long new_FdHestonVanillaEngine__SWIG_25(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, FdmSchemeDesc jarg8_, long jarg9, LocalVolTermStructure jarg9_);
  public final static native long new_FdHestonVanillaEngine__SWIG_26(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, FdmSchemeDesc jarg8_);
  public final static native long new_FdHestonVanillaEngine__SWIG_27(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6, long jarg7);
  public final static native long new_FdHestonVanillaEngine__SWIG_28(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonVanillaEngine__SWIG_29(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, long jarg5);
  public final static native long new_FdHestonVanillaEngine__SWIG_30(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4);
  public final static native long new_FdHestonVanillaEngine__SWIG_31(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, FdmQuantoHelper jarg3_);
  public final static native void delete_FdHestonVanillaEngine(long jarg1);
  public final static native long new_AnalyticCEVEngine(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native void delete_AnalyticCEVEngine(long jarg1);
  public final static native long new_FdCEVVanillaEngine__SWIG_0(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, long jarg5, long jarg6, long jarg7, double jarg8, double jarg9, long jarg10, FdmSchemeDesc jarg10_);
  public final static native long new_FdCEVVanillaEngine__SWIG_1(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, long jarg5, long jarg6, long jarg7, double jarg8, double jarg9);
  public final static native long new_FdCEVVanillaEngine__SWIG_2(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, long jarg5, long jarg6, long jarg7, double jarg8);
  public final static native long new_FdCEVVanillaEngine__SWIG_3(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, long jarg5, long jarg6, long jarg7);
  public final static native long new_FdCEVVanillaEngine__SWIG_4(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, long jarg5, long jarg6);
  public final static native long new_FdCEVVanillaEngine__SWIG_5(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, long jarg5);
  public final static native long new_FdCEVVanillaEngine__SWIG_6(double jarg1, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native void delete_FdCEVVanillaEngine(long jarg1);
  public final static native long new_FdSabrVanillaEngine__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, long jarg8, long jarg9, long jarg10, double jarg11, double jarg12, long jarg13, FdmSchemeDesc jarg13_);
  public final static native long new_FdSabrVanillaEngine__SWIG_1(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, long jarg8, long jarg9, long jarg10, double jarg11, double jarg12);
  public final static native long new_FdSabrVanillaEngine__SWIG_2(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, long jarg8, long jarg9, long jarg10, double jarg11);
  public final static native long new_FdSabrVanillaEngine__SWIG_3(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, long jarg8, long jarg9, long jarg10);
  public final static native long new_FdSabrVanillaEngine__SWIG_4(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, long jarg8, long jarg9);
  public final static native long new_FdSabrVanillaEngine__SWIG_5(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, long jarg8);
  public final static native long new_FdSabrVanillaEngine__SWIG_6(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_, long jarg7);
  public final static native long new_FdSabrVanillaEngine__SWIG_7(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native void delete_FdSabrVanillaEngine(long jarg1);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, boolean jarg9, long jarg10, FdmSchemeDesc jarg10_);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, boolean jarg9);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_3(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_4(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_5(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_6(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_7(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_8(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5, long jarg6, long jarg7, long jarg8, long jarg9, boolean jarg10, long jarg11, FdmSchemeDesc jarg11_);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_9(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5, long jarg6, long jarg7, long jarg8, long jarg9, boolean jarg10);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_10(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5, long jarg6, long jarg7, long jarg8, long jarg9);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_11(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5, long jarg6, long jarg7, long jarg8);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_12(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5, long jarg6, long jarg7);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_13(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_14(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4, long jarg5);
  public final static native long new_FdHestonHullWhiteVanillaEngine__SWIG_15(long jarg1, HestonModel jarg1_, long jarg2, HullWhiteProcess jarg2_, long jarg3, DividendSchedule jarg3_, double jarg4);
  public final static native void delete_FdHestonHullWhiteVanillaEngine(long jarg1);
  public final static native long new_AnalyticHestonHullWhiteEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, long jarg3);
  public final static native long new_AnalyticHestonHullWhiteEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2);
  public final static native long new_AnalyticHestonHullWhiteEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, double jarg3, long jarg4);
  public final static native void delete_AnalyticHestonHullWhiteEngine(long jarg1);
  public final static native long new_AnalyticH1HWEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, double jarg3, long jarg4);
  public final static native long new_AnalyticH1HWEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2, double jarg3);
  public final static native long new_AnalyticH1HWEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, double jarg3, double jarg4, long jarg5);
  public final static native void delete_AnalyticH1HWEngine(long jarg1);
  public final static native long new_ForwardEuropeanEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_ForwardEuropeanEngine(long jarg1);
  public final static native long new_QuantoEuropeanEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, BlackVolTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native void delete_QuantoEuropeanEngine(long jarg1);
  public final static native long new_QuantoForwardEuropeanEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, BlackVolTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native void delete_QuantoForwardEuropeanEngine(long jarg1);
  public final static native long new_AnalyticHestonForwardEuropeanEngine__SWIG_0(long jarg1, HestonProcess jarg1_, long jarg2);
  public final static native long new_AnalyticHestonForwardEuropeanEngine__SWIG_1(long jarg1, HestonProcess jarg1_);
  public final static native void delete_AnalyticHestonForwardEuropeanEngine(long jarg1);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCPRForwardEuropeanBSEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRForwardEuropeanBSEngine(long jarg1);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCLDForwardEuropeanBSEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDForwardEuropeanBSEngine(long jarg1);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8, boolean jarg9);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_, int jarg2);
  public final static native long new_MCPRForwardEuropeanHestonEngine__SWIG_8(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCPRForwardEuropeanHestonEngine(long jarg1);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8, boolean jarg9);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_, int jarg2);
  public final static native long new_MCLDForwardEuropeanHestonEngine__SWIG_8(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCLDForwardEuropeanHestonEngine(long jarg1);
  public final static native long new_BlackCalculator__SWIG_0(long jarg1, StrikedTypePayoff jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long new_BlackCalculator__SWIG_1(long jarg1, StrikedTypePayoff jarg1_, double jarg2, double jarg3);
  public final static native double BlackCalculator_value(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_deltaForward(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_delta(long jarg1, BlackCalculator jarg1_, double jarg2);
  public final static native double BlackCalculator_elasticityForward(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_elasticity(long jarg1, BlackCalculator jarg1_, double jarg2);
  public final static native double BlackCalculator_gammaForward(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_gamma(long jarg1, BlackCalculator jarg1_, double jarg2);
  public final static native double BlackCalculator_theta(long jarg1, BlackCalculator jarg1_, double jarg2, double jarg3);
  public final static native double BlackCalculator_thetaPerDay(long jarg1, BlackCalculator jarg1_, double jarg2, double jarg3);
  public final static native double BlackCalculator_vega(long jarg1, BlackCalculator jarg1_, double jarg2);
  public final static native double BlackCalculator_rho(long jarg1, BlackCalculator jarg1_, double jarg2);
  public final static native double BlackCalculator_dividendRho(long jarg1, BlackCalculator jarg1_, double jarg2);
  public final static native double BlackCalculator_itmCashProbability(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_itmAssetProbability(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_strikeSensitivity(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_strikeGamma(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_alpha(long jarg1, BlackCalculator jarg1_);
  public final static native double BlackCalculator_beta(long jarg1, BlackCalculator jarg1_);
  public final static native void delete_BlackCalculator(long jarg1);
  public final static native long new_VarianceGammaEngine(long jarg1, VarianceGammaProcess jarg1_);
  public final static native void delete_VarianceGammaEngine(long jarg1);
  public final static native long new_FFTVarianceGammaEngine__SWIG_0(long jarg1, VarianceGammaProcess jarg1_, double jarg2);
  public final static native long new_FFTVarianceGammaEngine__SWIG_1(long jarg1, VarianceGammaProcess jarg1_);
  public final static native void FFTVarianceGammaEngine_precalculate(long jarg1, FFTVarianceGammaEngine jarg1_, long jarg2, InstrumentVector jarg2_);
  public final static native void delete_FFTVarianceGammaEngine(long jarg1);
  public final static native long new_GJRGARCHModel(long jarg1, GJRGARCHProcess jarg1_);
  public final static native double GJRGARCHModel_omega(long jarg1, GJRGARCHModel jarg1_);
  public final static native double GJRGARCHModel_alpha(long jarg1, GJRGARCHModel jarg1_);
  public final static native double GJRGARCHModel_beta(long jarg1, GJRGARCHModel jarg1_);
  public final static native double GJRGARCHModel_gamma(long jarg1, GJRGARCHModel jarg1_);
  public final static native double GJRGARCHModel_lambda(long jarg1, GJRGARCHModel jarg1_);
  public final static native double GJRGARCHModel_v0(long jarg1, GJRGARCHModel jarg1_);
  public final static native void delete_GJRGARCHModel(long jarg1);
  public final static native long new_AnalyticGJRGARCHEngine(long jarg1, GJRGARCHModel jarg1_);
  public final static native void delete_AnalyticGJRGARCHEngine(long jarg1);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_0(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_1(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_2(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_3(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_4(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_5(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_6(long jarg1, GJRGARCHProcess jarg1_, int jarg2);
  public final static native long new_MCPREuropeanGJRGARCHEngine__SWIG_7(long jarg1, GJRGARCHProcess jarg1_);
  public final static native void delete_MCPREuropeanGJRGARCHEngine(long jarg1);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_0(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_1(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_2(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_3(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_4(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_5(long jarg1, GJRGARCHProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_6(long jarg1, GJRGARCHProcess jarg1_, int jarg2);
  public final static native long new_MCLDEuropeanGJRGARCHEngine__SWIG_7(long jarg1, GJRGARCHProcess jarg1_);
  public final static native void delete_MCLDEuropeanGJRGARCHEngine(long jarg1);
  public final static native long new_MargrabeOption(int jarg1, int jarg2, long jarg3, Exercise jarg3_);
  public final static native double MargrabeOption_delta1(long jarg1, MargrabeOption jarg1_);
  public final static native double MargrabeOption_delta2(long jarg1, MargrabeOption jarg1_);
  public final static native double MargrabeOption_gamma1(long jarg1, MargrabeOption jarg1_);
  public final static native double MargrabeOption_gamma2(long jarg1, MargrabeOption jarg1_);
  public final static native void delete_MargrabeOption(long jarg1);
  public final static native long new_AnalyticEuropeanMargrabeEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3);
  public final static native void delete_AnalyticEuropeanMargrabeEngine(long jarg1);
  public final static native long new_AnalyticAmericanMargrabeEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3);
  public final static native void delete_AnalyticAmericanMargrabeEngine(long jarg1);
  public final static native long new_CompoundOption(long jarg1, StrikedTypePayoff jarg1_, long jarg2, Exercise jarg2_, long jarg3, StrikedTypePayoff jarg3_, long jarg4, Exercise jarg4_);
  public final static native void delete_CompoundOption(long jarg1);
  public final static native long new_AnalyticCompoundOptionEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticCompoundOptionEngine(long jarg1);
  public final static native long new_SimpleChooserOption(long jarg1, Date jarg1_, double jarg2, long jarg3, Exercise jarg3_);
  public final static native void delete_SimpleChooserOption(long jarg1);
  public final static native long new_AnalyticSimpleChooserEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticSimpleChooserEngine(long jarg1);
  public final static native long new_ComplexChooserOption(long jarg1, Date jarg1_, double jarg2, double jarg3, long jarg4, Exercise jarg4_, long jarg5, Exercise jarg5_);
  public final static native void delete_ComplexChooserOption(long jarg1);
  public final static native long new_AnalyticComplexChooserEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticComplexChooserEngine(long jarg1);
  public final static native long new_Average();
  public final static native void delete_Average(long jarg1);
  public final static native long new_ContinuousAveragingAsianOption(int jarg1, long jarg2, StrikedTypePayoff jarg2_, long jarg3, Exercise jarg3_);
  public final static native void delete_ContinuousAveragingAsianOption(long jarg1);
  public final static native long new_DiscreteAveragingAsianOption__SWIG_0(int jarg1, double jarg2, long jarg3, long jarg4, DateVector jarg4_, long jarg5, StrikedTypePayoff jarg5_, long jarg6, Exercise jarg6_);
  public final static native long new_DiscreteAveragingAsianOption__SWIG_1(int jarg1, long jarg2, DateVector jarg2_, long jarg3, StrikedTypePayoff jarg3_, long jarg4, Exercise jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long new_DiscreteAveragingAsianOption__SWIG_2(int jarg1, long jarg2, DateVector jarg2_, long jarg3, StrikedTypePayoff jarg3_, long jarg4, Exercise jarg4_);
  public final static native long DiscreteAveragingAsianOption_timeGrid(long jarg1, DiscreteAveragingAsianOption jarg1_);
  public final static native void delete_DiscreteAveragingAsianOption(long jarg1);
  public final static native long new_AnalyticContinuousGeometricAveragePriceAsianEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticContinuousGeometricAveragePriceAsianEngine(long jarg1);
  public final static native long new_AnalyticContinuousGeometricAveragePriceAsianHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, long jarg2, double jarg3);
  public final static native long new_AnalyticContinuousGeometricAveragePriceAsianHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, long jarg2);
  public final static native long new_AnalyticContinuousGeometricAveragePriceAsianHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_);
  public final static native void delete_AnalyticContinuousGeometricAveragePriceAsianHestonEngine(long jarg1);
  public final static native long new_AnalyticDiscreteGeometricAveragePriceAsianEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticDiscreteGeometricAveragePriceAsianEngine(long jarg1);
  public final static native long new_AnalyticDiscreteGeometricAveragePriceAsianHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, double jarg2);
  public final static native long new_AnalyticDiscreteGeometricAveragePriceAsianHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_);
  public final static native void delete_AnalyticDiscreteGeometricAveragePriceAsianHestonEngine(long jarg1);
  public final static native long new_AnalyticDiscreteGeometricAverageStrikeAsianEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticDiscreteGeometricAverageStrikeAsianEngine(long jarg1);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCPRDiscreteArithmeticAPEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRDiscreteArithmeticAPEngine(long jarg1);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7, int jarg8);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5, double jarg6, int jarg7);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5, double jarg6);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4, int jarg5);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, boolean jarg4);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCLDDiscreteArithmeticAPEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDDiscreteArithmeticAPEngine(long jarg1);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7, int jarg8, boolean jarg9);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7, int jarg8);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_, boolean jarg2);
  public final static native long new_MCPRDiscreteArithmeticAPHestonEngine__SWIG_8(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCPRDiscreteArithmeticAPHestonEngine(long jarg1);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7, int jarg8, boolean jarg9);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7, int jarg8);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_, boolean jarg2);
  public final static native long new_MCLDDiscreteArithmeticAPHestonEngine__SWIG_8(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCLDDiscreteArithmeticAPHestonEngine(long jarg1);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCPRDiscreteArithmeticASEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRDiscreteArithmeticASEngine(long jarg1);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCLDDiscreteArithmeticASEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDDiscreteArithmeticASEngine(long jarg1);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCPRDiscreteGeometricAPEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRDiscreteGeometricAPEngine(long jarg1);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCLDDiscreteGeometricAPEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDDiscreteGeometricAPEngine(long jarg1);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7, int jarg8);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, boolean jarg2);
  public final static native long new_MCPRDiscreteGeometricAPHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCPRDiscreteGeometricAPHestonEngine(long jarg1);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_0(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7, int jarg8);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_1(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6, int jarg7);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_2(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5, int jarg6);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_3(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4, int jarg5);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_4(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3, double jarg4);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_5(long jarg1, HestonProcess jarg1_, boolean jarg2, int jarg3);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_6(long jarg1, HestonProcess jarg1_, boolean jarg2);
  public final static native long new_MCLDDiscreteGeometricAPHestonEngine__SWIG_7(long jarg1, HestonProcess jarg1_);
  public final static native void delete_MCLDDiscreteGeometricAPHestonEngine(long jarg1);
  public final static native long new_ContinuousArithmeticAsianLevyEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, Date jarg3_);
  public final static native void delete_ContinuousArithmeticAsianLevyEngine(long jarg1);
  public final static native long new_FdBlackScholesAsianEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native void delete_FdBlackScholesAsianEngine(long jarg1);
  public final static native long new_TurnbullWakemanAsianEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_TurnbullWakemanAsianEngine(long jarg1);
  public final static native long new_Barrier();
  public final static native void delete_Barrier(long jarg1);
  public final static native long new_BarrierOption(int jarg1, double jarg2, double jarg3, long jarg4, StrikedTypePayoff jarg4_, long jarg5, Exercise jarg5_);
  public final static native double BarrierOption_impliedVolatility__SWIG_0(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5, double jarg6, double jarg7);
  public final static native double BarrierOption_impliedVolatility__SWIG_1(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5, double jarg6);
  public final static native double BarrierOption_impliedVolatility__SWIG_2(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, long jarg5);
  public final static native double BarrierOption_impliedVolatility__SWIG_3(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4);
  public final static native double BarrierOption_impliedVolatility__SWIG_4(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_);
  public final static native double BarrierOption_impliedVolatility__SWIG_5(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5, long jarg6, double jarg7, double jarg8);
  public final static native double BarrierOption_impliedVolatility__SWIG_6(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5, long jarg6, double jarg7);
  public final static native double BarrierOption_impliedVolatility__SWIG_7(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5, long jarg6);
  public final static native double BarrierOption_impliedVolatility__SWIG_8(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_, double jarg5);
  public final static native double BarrierOption_impliedVolatility__SWIG_9(long jarg1, BarrierOption jarg1_, double jarg2, long jarg3, GeneralizedBlackScholesProcess jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native void delete_BarrierOption(long jarg1);
  public final static native long new_QuantoBarrierOption(int jarg1, double jarg2, double jarg3, long jarg4, StrikedTypePayoff jarg4_, long jarg5, Exercise jarg5_);
  public final static native void delete_QuantoBarrierOption(long jarg1);
  public final static native long new_PartialBarrier();
  public final static native void delete_PartialBarrier(long jarg1);
  public final static native long new_PartialTimeBarrierOption(int jarg1, int jarg2, double jarg3, double jarg4, long jarg5, Date jarg5_, long jarg6, StrikedTypePayoff jarg6_, long jarg7, Exercise jarg7_);
  public final static native void delete_PartialTimeBarrierOption(long jarg1);
  public final static native long new_AnalyticPartialTimeBarrierOptionEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticPartialTimeBarrierOptionEngine(long jarg1);
  public final static native long new_DividendBarrierOption(int jarg1, double jarg2, double jarg3, long jarg4, StrikedTypePayoff jarg4_, long jarg5, Exercise jarg5_, long jarg6, DateVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native void delete_DividendBarrierOption(long jarg1);
  public final static native long new_AnalyticBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticBarrierEngine(long jarg1);
  public final static native long new_MCPRBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, boolean jarg9, int jarg10);
  public final static native long new_MCPRBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, boolean jarg9);
  public final static native long new_MCPRBarrierEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPRBarrierEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPRBarrierEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPRBarrierEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPRBarrierEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPRBarrierEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPRBarrierEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCPRBarrierEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRBarrierEngine(long jarg1);
  public final static native long new_MCLDBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, boolean jarg9, int jarg10);
  public final static native long new_MCLDBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, boolean jarg9);
  public final static native long new_MCLDBarrierEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDBarrierEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDBarrierEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDBarrierEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDBarrierEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDBarrierEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDBarrierEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_MCLDBarrierEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDBarrierEngine(long jarg1);
  public final static native long new_QuantoBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, BlackVolTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native void delete_QuantoBarrierEngine(long jarg1);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6, double jarg7);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7, double jarg8);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_10(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_11(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_12(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdBlackScholesBarrierEngine__SWIG_13(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_FdBlackScholesBarrierEngine(long jarg1);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6, double jarg7);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, FdmSchemeDesc jarg5_);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7, double jarg8);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_8(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, boolean jarg7);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_9(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_10(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_11(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_12(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdBlackScholesRebateEngine__SWIG_13(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_FdBlackScholesRebateEngine(long jarg1);
  public final static native long new_FdHestonBarrierEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_, double jarg8);
  public final static native long new_FdHestonBarrierEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_);
  public final static native long new_FdHestonBarrierEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdHestonBarrierEngine__SWIG_3(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonBarrierEngine__SWIG_4(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdHestonBarrierEngine__SWIG_5(long jarg1, HestonModel jarg1_, long jarg2, long jarg3);
  public final static native long new_FdHestonBarrierEngine__SWIG_6(long jarg1, HestonModel jarg1_, long jarg2);
  public final static native long new_FdHestonBarrierEngine__SWIG_7(long jarg1, HestonModel jarg1_);
  public final static native long new_FdHestonBarrierEngine__SWIG_8(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_, double jarg9);
  public final static native long new_FdHestonBarrierEngine__SWIG_9(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_);
  public final static native long new_FdHestonBarrierEngine__SWIG_10(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdHestonBarrierEngine__SWIG_11(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonBarrierEngine__SWIG_12(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonBarrierEngine__SWIG_13(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdHestonBarrierEngine__SWIG_14(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdHestonBarrierEngine__SWIG_15(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_FdHestonBarrierEngine(long jarg1);
  public final static native long new_FdHestonRebateEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_, double jarg8);
  public final static native long new_FdHestonRebateEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_);
  public final static native long new_FdHestonRebateEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdHestonRebateEngine__SWIG_3(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonRebateEngine__SWIG_4(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdHestonRebateEngine__SWIG_5(long jarg1, HestonModel jarg1_, long jarg2, long jarg3);
  public final static native long new_FdHestonRebateEngine__SWIG_6(long jarg1, HestonModel jarg1_, long jarg2);
  public final static native long new_FdHestonRebateEngine__SWIG_7(long jarg1, HestonModel jarg1_);
  public final static native long new_FdHestonRebateEngine__SWIG_8(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_, double jarg9);
  public final static native long new_FdHestonRebateEngine__SWIG_9(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_, long jarg8, LocalVolTermStructure jarg8_);
  public final static native long new_FdHestonRebateEngine__SWIG_10(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdHestonRebateEngine__SWIG_11(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_FdHestonRebateEngine__SWIG_12(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonRebateEngine__SWIG_13(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3, long jarg4);
  public final static native long new_FdHestonRebateEngine__SWIG_14(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_, long jarg3);
  public final static native long new_FdHestonRebateEngine__SWIG_15(long jarg1, HestonModel jarg1_, long jarg2, DividendSchedule jarg2_);
  public final static native void delete_FdHestonRebateEngine(long jarg1);
  public final static native long new_AnalyticBinaryBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticBinaryBarrierEngine(long jarg1);
  public final static native long new_BinomialCRRBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialCRRBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialCRRBarrierEngine(long jarg1);
  public final static native long new_BinomialJRBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialJRBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialJRBarrierEngine(long jarg1);
  public final static native long new_BinomialEQPBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialEQPBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialEQPBarrierEngine(long jarg1);
  public final static native long new_BinomialTrigeorgisBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialTrigeorgisBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialTrigeorgisBarrierEngine(long jarg1);
  public final static native long new_BinomialTianBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialTianBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialTianBarrierEngine(long jarg1);
  public final static native long new_BinomialLRBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialLRBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialLRBarrierEngine(long jarg1);
  public final static native long new_BinomialJ4BarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_BinomialJ4BarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialJ4BarrierEngine(long jarg1);
  public final static native long new_VannaVolgaBarrierEngine__SWIG_0(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7, double jarg8);
  public final static native long new_VannaVolgaBarrierEngine__SWIG_1(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7);
  public final static native long new_VannaVolgaBarrierEngine__SWIG_2(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native void delete_VannaVolgaBarrierEngine(long jarg1);
  public final static native long new_DoubleBarrier();
  public final static native void delete_DoubleBarrier(long jarg1);
  public final static native long new_DoubleBarrierOption(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, StrikedTypePayoff jarg5_, long jarg6, Exercise jarg6_);
  public final static native void delete_DoubleBarrierOption(long jarg1);
  public final static native long new_QuantoDoubleBarrierOption(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, StrikedTypePayoff jarg5_, long jarg6, Exercise jarg6_);
  public final static native double QuantoDoubleBarrierOption_qvega(long jarg1, QuantoDoubleBarrierOption jarg1_);
  public final static native double QuantoDoubleBarrierOption_qrho(long jarg1, QuantoDoubleBarrierOption jarg1_);
  public final static native double QuantoDoubleBarrierOption_qlambda(long jarg1, QuantoDoubleBarrierOption jarg1_);
  public final static native void delete_QuantoDoubleBarrierOption(long jarg1);
  public final static native long new_AnalyticDoubleBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_AnalyticDoubleBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticDoubleBarrierEngine(long jarg1);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_0(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_, double jarg8);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_1(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_, long jarg7, LocalVolTermStructure jarg7_);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_2(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_3(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_4(long jarg1, HestonModel jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_5(long jarg1, HestonModel jarg1_, long jarg2, long jarg3);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_6(long jarg1, HestonModel jarg1_, long jarg2);
  public final static native long new_FdHestonDoubleBarrierEngine__SWIG_7(long jarg1, HestonModel jarg1_);
  public final static native void delete_FdHestonDoubleBarrierEngine(long jarg1);
  public final static native long new_SuoWangDoubleBarrierEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, int jarg2);
  public final static native long new_SuoWangDoubleBarrierEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_SuoWangDoubleBarrierEngine(long jarg1);
  public final static native long new_VannaVolgaIKDoubleBarrierEngine__SWIG_0(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7, double jarg8, int jarg9);
  public final static native long new_VannaVolgaIKDoubleBarrierEngine__SWIG_1(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7, double jarg8);
  public final static native long new_VannaVolgaIKDoubleBarrierEngine__SWIG_2(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7);
  public final static native long new_VannaVolgaIKDoubleBarrierEngine__SWIG_3(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native void delete_VannaVolgaIKDoubleBarrierEngine(long jarg1);
  public final static native long new_VannaVolgaWODoubleBarrierEngine__SWIG_0(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7, double jarg8, int jarg9);
  public final static native long new_VannaVolgaWODoubleBarrierEngine__SWIG_1(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7, double jarg8);
  public final static native long new_VannaVolgaWODoubleBarrierEngine__SWIG_2(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, boolean jarg7);
  public final static native long new_VannaVolgaWODoubleBarrierEngine__SWIG_3(long jarg1, DeltaVolQuoteHandle jarg1_, long jarg2, DeltaVolQuoteHandle jarg2_, long jarg3, DeltaVolQuoteHandle jarg3_, long jarg4, QuoteHandle jarg4_, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native void delete_VannaVolgaWODoubleBarrierEngine(long jarg1);
  public final static native long new_AnalyticDoubleBarrierBinaryEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticDoubleBarrierBinaryEngine(long jarg1);
  public final static native long new_BinomialCRRDoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialCRRDoubleBarrierEngine(long jarg1);
  public final static native long new_BinomialJRDoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialJRDoubleBarrierEngine(long jarg1);
  public final static native long new_BinomialEQPDoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialEQPDoubleBarrierEngine(long jarg1);
  public final static native long new_BinomialTrigeorgisDoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialTrigeorgisDoubleBarrierEngine(long jarg1);
  public final static native long new_BinomialTianDoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialTianDoubleBarrierEngine(long jarg1);
  public final static native long new_BinomialLRDoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialLRDoubleBarrierEngine(long jarg1);
  public final static native long new_BinomialJ4DoubleBarrierEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native void delete_BinomialJ4DoubleBarrierEngine(long jarg1);
  public final static native long new_PlainVanillaPayoff(int jarg1, double jarg2);
  public final static native void delete_PlainVanillaPayoff(long jarg1);
  public final static native long as_plain_vanilla_payoff(long jarg1, Payoff jarg1_);
  public final static native long new_PercentageStrikePayoff(int jarg1, double jarg2);
  public final static native void delete_PercentageStrikePayoff(long jarg1);
  public final static native long new_CashOrNothingPayoff(int jarg1, double jarg2, double jarg3);
  public final static native void delete_CashOrNothingPayoff(long jarg1);
  public final static native long new_AssetOrNothingPayoff(int jarg1, double jarg2);
  public final static native void delete_AssetOrNothingPayoff(long jarg1);
  public final static native long new_SuperSharePayoff(int jarg1, double jarg2, double jarg3);
  public final static native void delete_SuperSharePayoff(long jarg1);
  public final static native long new_GapPayoff(int jarg1, double jarg2, double jarg3);
  public final static native void delete_GapPayoff(long jarg1);
  public final static native long new_VanillaForwardPayoff(int jarg1, double jarg2);
  public final static native void delete_VanillaForwardPayoff(long jarg1);
  public final static native void delete_BasketPayoff(long jarg1);
  public final static native long new_MinBasketPayoff(long jarg1, Payoff jarg1_);
  public final static native void delete_MinBasketPayoff(long jarg1);
  public final static native long new_MaxBasketPayoff(long jarg1, Payoff jarg1_);
  public final static native void delete_MaxBasketPayoff(long jarg1);
  public final static native long new_AverageBasketPayoff__SWIG_0(long jarg1, Payoff jarg1_, long jarg2, Array jarg2_);
  public final static native long new_AverageBasketPayoff__SWIG_1(long jarg1, Payoff jarg1_, long jarg2);
  public final static native void delete_AverageBasketPayoff(long jarg1);
  public final static native long new_SpreadBasketPayoff(long jarg1, Payoff jarg1_);
  public final static native void delete_SpreadBasketPayoff(long jarg1);
  public final static native long new_BasketOption(long jarg1, BasketPayoff jarg1_, long jarg2, Exercise jarg2_);
  public final static native void delete_BasketOption(long jarg1);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_7(long jarg1, StochasticProcessArray jarg1_, int jarg2);
  public final static native long new_MCPREuropeanBasketEngine__SWIG_8(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCPREuropeanBasketEngine(long jarg1);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_7(long jarg1, StochasticProcessArray jarg1_, int jarg2);
  public final static native long new_MCLDEuropeanBasketEngine__SWIG_8(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCLDEuropeanBasketEngine(long jarg1);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, long jarg10, long jarg11, int jarg12);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, long jarg10, long jarg11);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, long jarg10);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_7(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_8(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_9(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_10(long jarg1, StochasticProcessArray jarg1_, int jarg2);
  public final static native long new_MCPRAmericanBasketEngine__SWIG_11(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCPRAmericanBasketEngine(long jarg1);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, long jarg10, long jarg11, int jarg12);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, long jarg10, long jarg11);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9, long jarg10);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_7(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_8(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3, boolean jarg4);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_9(long jarg1, StochasticProcessArray jarg1_, int jarg2, int jarg3);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_10(long jarg1, StochasticProcessArray jarg1_, int jarg2);
  public final static native long new_MCLDAmericanBasketEngine__SWIG_11(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCLDAmericanBasketEngine(long jarg1);
  public final static native long new_StulzEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3);
  public final static native void delete_StulzEngine(long jarg1);
  public final static native long new_KirkEngine(long jarg1, BlackProcess jarg1_, long jarg2, BlackProcess jarg2_, double jarg3);
  public final static native void delete_KirkEngine(long jarg1);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, FdmSchemeDesc jarg8_, boolean jarg9, double jarg10);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, FdmSchemeDesc jarg8_, boolean jarg9);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7, long jarg8, FdmSchemeDesc jarg8_);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6, long jarg7);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, long jarg5, long jarg6);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, long jarg5);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4);
  public final static native long new_Fd2dBlackScholesVanillaEngine__SWIG_7(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3);
  public final static native void delete_Fd2dBlackScholesVanillaEngine(long jarg1);
  public final static native long new_EverestOption(double jarg1, double jarg2, long jarg3, Exercise jarg3_);
  public final static native void delete_EverestOption(long jarg1);
  public final static native long new_MCPREverestEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCPREverestEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCPREverestEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCPREverestEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCPREverestEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCPREverestEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4);
  public final static native long new_MCPREverestEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3);
  public final static native long new_MCPREverestEngine__SWIG_7(long jarg1, StochasticProcessArray jarg1_, long jarg2);
  public final static native long new_MCPREverestEngine__SWIG_8(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCPREverestEngine(long jarg1);
  public final static native long new_MCLDEverestEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8, int jarg9);
  public final static native long new_MCLDEverestEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7, int jarg8);
  public final static native long new_MCLDEverestEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6, double jarg7);
  public final static native long new_MCLDEverestEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5, int jarg6);
  public final static native long new_MCLDEverestEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_MCLDEverestEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3, boolean jarg4);
  public final static native long new_MCLDEverestEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_, long jarg2, long jarg3);
  public final static native long new_MCLDEverestEngine__SWIG_7(long jarg1, StochasticProcessArray jarg1_, long jarg2);
  public final static native long new_MCLDEverestEngine__SWIG_8(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCLDEverestEngine(long jarg1);
  public final static native long new_HimalayaOption(long jarg1, DateVector jarg1_, double jarg2);
  public final static native void delete_HimalayaOption(long jarg1);
  public final static native long new_MCPRHimalayaEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCPRHimalayaEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCPRHimalayaEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCPRHimalayaEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCPRHimalayaEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCPRHimalayaEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, boolean jarg2);
  public final static native long new_MCPRHimalayaEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCPRHimalayaEngine(long jarg1);
  public final static native long new_MCLDHimalayaEngine__SWIG_0(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCLDHimalayaEngine__SWIG_1(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCLDHimalayaEngine__SWIG_2(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCLDHimalayaEngine__SWIG_3(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCLDHimalayaEngine__SWIG_4(long jarg1, StochasticProcessArray jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCLDHimalayaEngine__SWIG_5(long jarg1, StochasticProcessArray jarg1_, boolean jarg2);
  public final static native long new_MCLDHimalayaEngine__SWIG_6(long jarg1, StochasticProcessArray jarg1_);
  public final static native void delete_MCLDHimalayaEngine(long jarg1);
  public final static native double blackFormula__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native double blackFormula__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double blackFormula__SWIG_2(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaImpliedStdDev__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9);
  public final static native double blackFormulaImpliedStdDev__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native double blackFormulaImpliedStdDev__SWIG_2(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native double blackFormulaImpliedStdDev__SWIG_3(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native double blackFormulaImpliedStdDev__SWIG_4(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double blackFormulaImpliedStdDev__SWIG_5(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, long jarg10);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_2(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_3(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_4(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_5(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_6(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_7(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_8(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_9(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_10(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_11(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_12(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaImpliedStdDevLiRS__SWIG_13(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3);
  public final static native double blackFormulaCashItmProbability__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double blackFormulaCashItmProbability__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaCashItmProbability__SWIG_2(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaCashItmProbability__SWIG_3(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3);
  public final static native double blackFormulaAssetItmProbability__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double blackFormulaAssetItmProbability__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaAssetItmProbability__SWIG_2(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double blackFormulaAssetItmProbability__SWIG_3(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3);
  public final static native double bachelierBlackFormula__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double bachelierBlackFormula__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double bachelierBlackFormulaImpliedVol__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native double bachelierBlackFormulaImpliedVol__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double bachelierBlackFormulaAssetItmProbability__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double bachelierBlackFormulaAssetItmProbability__SWIG_1(long jarg1, PlainVanillaPayoff jarg1_, double jarg2, double jarg3);
  public final static native long new_BlackDeltaCalculator(int jarg1, int jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native double BlackDeltaCalculator_deltaFromStrike(long jarg1, BlackDeltaCalculator jarg1_, double jarg2);
  public final static native double BlackDeltaCalculator_strikeFromDelta(long jarg1, BlackDeltaCalculator jarg1_, double jarg2);
  public final static native double BlackDeltaCalculator_atmStrike(long jarg1, BlackDeltaCalculator jarg1_, int jarg2);
  public final static native void delete_BlackDeltaCalculator(long jarg1);
  public final static native long new_TimeBasket__SWIG_0();
  public final static native long new_TimeBasket__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long TimeBasket_size(long jarg1, TimeBasket jarg1_);
  public final static native long TimeBasket_rebin(long jarg1, TimeBasket jarg1_, long jarg2, DateVector jarg2_);
  public final static native void delete_TimeBasket(long jarg1);
  public final static native int Swap_Receiver_get();
  public final static native int Swap_Payer_get();
  public final static native long new_Swap__SWIG_0(long jarg1, Leg jarg1_, long jarg2, Leg jarg2_);
  public final static native long new_Swap__SWIG_1(long jarg1, LegVector jarg1_, long jarg2, BoolVector jarg2_);
  public final static native long Swap_numberOfLegs(long jarg1, Swap jarg1_);
  public final static native long Swap_startDate(long jarg1, Swap jarg1_);
  public final static native long Swap_maturityDate(long jarg1, Swap jarg1_);
  public final static native long Swap_leg(long jarg1, Swap jarg1_, long jarg2);
  public final static native double Swap_legNPV(long jarg1, Swap jarg1_, long jarg2);
  public final static native double Swap_legBPS(long jarg1, Swap jarg1_, long jarg2);
  public final static native double Swap_startDiscounts(long jarg1, Swap jarg1_, long jarg2);
  public final static native double Swap_endDiscounts(long jarg1, Swap jarg1_, long jarg2);
  public final static native double Swap_npvDateDiscount(long jarg1, Swap jarg1_);
  public final static native boolean Swap_payer(long jarg1, Swap jarg1_, long jarg2);
  public final static native void delete_Swap(long jarg1);
  public final static native void simplifyNotificationGraph__SWIG_0(long jarg1, Swap jarg1_, boolean jarg2);
  public final static native void simplifyNotificationGraph__SWIG_1(long jarg1, Swap jarg1_);
  public final static native long new_VanillaSwap__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, long jarg7, IborIndex jarg7_, double jarg8, long jarg9, DayCounter jarg9_, long jarg10, OptionalBool jarg10_);
  public final static native long new_VanillaSwap__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, long jarg7, IborIndex jarg7_, double jarg8, long jarg9, DayCounter jarg9_);
  public final static native int VanillaSwap_type(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_fairRate(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_fairSpread(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_fixedLegBPS(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_floatingLegBPS(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_fixedLegNPV(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_floatingLegNPV(long jarg1, VanillaSwap jarg1_);
  public final static native long VanillaSwap_fixedLeg(long jarg1, VanillaSwap jarg1_);
  public final static native long VanillaSwap_floatingLeg(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_nominal(long jarg1, VanillaSwap jarg1_);
  public final static native long VanillaSwap_fixedSchedule(long jarg1, VanillaSwap jarg1_);
  public final static native long VanillaSwap_floatingSchedule(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_fixedRate(long jarg1, VanillaSwap jarg1_);
  public final static native double VanillaSwap_spread(long jarg1, VanillaSwap jarg1_);
  public final static native long VanillaSwap_floatingDayCount(long jarg1, VanillaSwap jarg1_);
  public final static native long VanillaSwap_fixedDayCount(long jarg1, VanillaSwap jarg1_);
  public final static native void delete_VanillaSwap(long jarg1);
  public final static native long MakeVanillaSwap_receiveFixed__SWIG_0(long jarg1, MakeVanillaSwap jarg1_, boolean jarg2);
  public final static native long MakeVanillaSwap_receiveFixed__SWIG_1(long jarg1, MakeVanillaSwap jarg1_);
  public final static native long MakeVanillaSwap_withType(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withNominal(long jarg1, MakeVanillaSwap jarg1_, double jarg2);
  public final static native long MakeVanillaSwap_withSettlementDays(long jarg1, MakeVanillaSwap jarg1_, long jarg2);
  public final static native long MakeVanillaSwap_withEffectiveDate(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeVanillaSwap_withTerminationDate(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeVanillaSwap_withRule(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFixedLegTenor(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Period jarg2_);
  public final static native long MakeVanillaSwap_withFixedLegCalendar(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Calendar jarg2_);
  public final static native long MakeVanillaSwap_withFixedLegConvention(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFixedLegTerminationDateConvention(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFixedLegRule(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFixedLegEndOfMonth__SWIG_0(long jarg1, MakeVanillaSwap jarg1_, boolean jarg2);
  public final static native long MakeVanillaSwap_withFixedLegEndOfMonth__SWIG_1(long jarg1, MakeVanillaSwap jarg1_);
  public final static native long MakeVanillaSwap_withFixedLegFirstDate(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeVanillaSwap_withFixedLegNextToLastDate(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeVanillaSwap_withFixedLegDayCount(long jarg1, MakeVanillaSwap jarg1_, long jarg2, DayCounter jarg2_);
  public final static native long MakeVanillaSwap_withFloatingLegTenor(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Period jarg2_);
  public final static native long MakeVanillaSwap_withFloatingLegCalendar(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Calendar jarg2_);
  public final static native long MakeVanillaSwap_withFloatingLegConvention(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFloatingLegTerminationDateConvention(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFloatingLegRule(long jarg1, MakeVanillaSwap jarg1_, int jarg2);
  public final static native long MakeVanillaSwap_withFloatingLegEndOfMonth__SWIG_0(long jarg1, MakeVanillaSwap jarg1_, boolean jarg2);
  public final static native long MakeVanillaSwap_withFloatingLegEndOfMonth__SWIG_1(long jarg1, MakeVanillaSwap jarg1_);
  public final static native long MakeVanillaSwap_withFloatingLegFirstDate(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeVanillaSwap_withFloatingLegNextToLastDate(long jarg1, MakeVanillaSwap jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeVanillaSwap_withFloatingLegDayCount(long jarg1, MakeVanillaSwap jarg1_, long jarg2, DayCounter jarg2_);
  public final static native long MakeVanillaSwap_withFloatingLegSpread(long jarg1, MakeVanillaSwap jarg1_, double jarg2);
  public final static native long MakeVanillaSwap_withDiscountingTermStructure(long jarg1, MakeVanillaSwap jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long MakeVanillaSwap_withPricingEngine(long jarg1, MakeVanillaSwap jarg1_, long jarg2, PricingEngine jarg2_);
  public final static native long MakeVanillaSwap_withIndexedCoupons__SWIG_0(long jarg1, MakeVanillaSwap jarg1_, boolean jarg2);
  public final static native long MakeVanillaSwap_withIndexedCoupons__SWIG_1(long jarg1, MakeVanillaSwap jarg1_);
  public final static native long MakeVanillaSwap_withAtParCoupons__SWIG_0(long jarg1, MakeVanillaSwap jarg1_, boolean jarg2);
  public final static native long MakeVanillaSwap_withAtParCoupons__SWIG_1(long jarg1, MakeVanillaSwap jarg1_);
  public final static native long new_MakeVanillaSwap(long jarg1, Period jarg1_, long jarg2, IborIndex jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native long MakeVanillaSwap_makeVanillaSwap(long jarg1, MakeVanillaSwap jarg1_);
  public final static native void delete_MakeVanillaSwap(long jarg1);
  public final static native long new_NonstandardSwap__SWIG_0(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, IborIndex jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, boolean jarg13, int jarg14);
  public final static native long new_NonstandardSwap__SWIG_1(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, IborIndex jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, boolean jarg13);
  public final static native long new_NonstandardSwap__SWIG_2(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, IborIndex jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12);
  public final static native long new_NonstandardSwap__SWIG_3(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, IborIndex jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DayCounter jarg11_);
  public final static native int NonstandardSwap_type(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_fixedNominal(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_floatingNominal(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_fixedSchedule(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_fixedRate(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_fixedDayCount(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_floatingSchedule(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_iborIndex(long jarg1, NonstandardSwap jarg1_);
  public final static native double NonstandardSwap_spread(long jarg1, NonstandardSwap jarg1_);
  public final static native double NonstandardSwap_gearing(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_spreads(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_gearings(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_floatingDayCount(long jarg1, NonstandardSwap jarg1_);
  public final static native int NonstandardSwap_paymentConvention(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_fixedLeg(long jarg1, NonstandardSwap jarg1_);
  public final static native long NonstandardSwap_floatingLeg(long jarg1, NonstandardSwap jarg1_);
  public final static native void delete_NonstandardSwap(long jarg1);
  public final static native long new_DiscountingSwapEngine__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, boolean jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_);
  public final static native long new_DiscountingSwapEngine__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, boolean jarg2, long jarg3, Date jarg3_);
  public final static native long new_DiscountingSwapEngine__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, boolean jarg2);
  public final static native long new_DiscountingSwapEngine__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native long new_DiscountingSwapEngine__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long new_DiscountingSwapEngine__SWIG_5(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native void delete_DiscountingSwapEngine(long jarg1);
  public final static native long new_AssetSwap__SWIG_0(boolean jarg1, long jarg2, double jarg3, long jarg4, IborIndex jarg4_, double jarg5, long jarg6, Schedule jarg6_, long jarg7, DayCounter jarg7_, boolean jarg8);
  public final static native long new_AssetSwap__SWIG_1(boolean jarg1, long jarg2, double jarg3, long jarg4, IborIndex jarg4_, double jarg5, long jarg6, Schedule jarg6_, long jarg7, DayCounter jarg7_);
  public final static native long new_AssetSwap__SWIG_2(boolean jarg1, long jarg2, double jarg3, long jarg4, IborIndex jarg4_, double jarg5, long jarg6, Schedule jarg6_);
  public final static native long new_AssetSwap__SWIG_3(boolean jarg1, long jarg2, double jarg3, long jarg4, IborIndex jarg4_, double jarg5);
  public final static native double AssetSwap_fairCleanPrice(long jarg1, AssetSwap jarg1_);
  public final static native double AssetSwap_fairSpread(long jarg1, AssetSwap jarg1_);
  public final static native void delete_AssetSwap(long jarg1);
  public final static native long new_FloatFloatSwap__SWIG_0(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_, long jarg16, DoubleVector jarg16_, long jarg17, DoubleVector jarg17_, long jarg18, DoubleVector jarg18_, long jarg19, DoubleVector jarg19_, int jarg20, int jarg21);
  public final static native long new_FloatFloatSwap__SWIG_1(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_, long jarg16, DoubleVector jarg16_, long jarg17, DoubleVector jarg17_, long jarg18, DoubleVector jarg18_, long jarg19, DoubleVector jarg19_, int jarg20);
  public final static native long new_FloatFloatSwap__SWIG_2(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_, long jarg16, DoubleVector jarg16_, long jarg17, DoubleVector jarg17_, long jarg18, DoubleVector jarg18_, long jarg19, DoubleVector jarg19_);
  public final static native long new_FloatFloatSwap__SWIG_3(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_, long jarg16, DoubleVector jarg16_, long jarg17, DoubleVector jarg17_, long jarg18, DoubleVector jarg18_);
  public final static native long new_FloatFloatSwap__SWIG_4(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_, long jarg16, DoubleVector jarg16_, long jarg17, DoubleVector jarg17_);
  public final static native long new_FloatFloatSwap__SWIG_5(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_, long jarg16, DoubleVector jarg16_);
  public final static native long new_FloatFloatSwap__SWIG_6(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_, long jarg15, DoubleVector jarg15_);
  public final static native long new_FloatFloatSwap__SWIG_7(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_, long jarg14, DoubleVector jarg14_);
  public final static native long new_FloatFloatSwap__SWIG_8(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, long jarg13, DoubleVector jarg13_);
  public final static native long new_FloatFloatSwap__SWIG_9(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_);
  public final static native long new_FloatFloatSwap__SWIG_10(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10, boolean jarg11);
  public final static native long new_FloatFloatSwap__SWIG_11(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_, boolean jarg10);
  public final static native long new_FloatFloatSwap__SWIG_12(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Schedule jarg4_, long jarg5, InterestRateIndex jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, long jarg8, InterestRateIndex jarg8_, long jarg9, DayCounter jarg9_);
  public final static native void delete_FloatFloatSwap(long jarg1);
  public final static native long new_OvernightIndexedSwap__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, boolean jarg11, int jarg12);
  public final static native long new_OvernightIndexedSwap__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, boolean jarg11);
  public final static native long new_OvernightIndexedSwap__SWIG_2(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_);
  public final static native long new_OvernightIndexedSwap__SWIG_3(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9);
  public final static native long new_OvernightIndexedSwap__SWIG_4(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8);
  public final static native long new_OvernightIndexedSwap__SWIG_5(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7);
  public final static native long new_OvernightIndexedSwap__SWIG_6(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_);
  public final static native long new_OvernightIndexedSwap__SWIG_7(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, boolean jarg11, int jarg12);
  public final static native long new_OvernightIndexedSwap__SWIG_8(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, boolean jarg11);
  public final static native long new_OvernightIndexedSwap__SWIG_9(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_);
  public final static native long new_OvernightIndexedSwap__SWIG_10(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8, int jarg9);
  public final static native long new_OvernightIndexedSwap__SWIG_11(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7, int jarg8);
  public final static native long new_OvernightIndexedSwap__SWIG_12(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, double jarg7);
  public final static native long new_OvernightIndexedSwap__SWIG_13(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_);
  public final static native long new_OvernightIndexedSwap__SWIG_14(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_, double jarg9, int jarg10, int jarg11, long jarg12, Calendar jarg12_, boolean jarg13, int jarg14);
  public final static native long new_OvernightIndexedSwap__SWIG_15(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_, double jarg9, int jarg10, int jarg11, long jarg12, Calendar jarg12_, boolean jarg13);
  public final static native long new_OvernightIndexedSwap__SWIG_16(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_, double jarg9, int jarg10, int jarg11, long jarg12, Calendar jarg12_);
  public final static native long new_OvernightIndexedSwap__SWIG_17(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_, double jarg9, int jarg10, int jarg11);
  public final static native long new_OvernightIndexedSwap__SWIG_18(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_, double jarg9, int jarg10);
  public final static native long new_OvernightIndexedSwap__SWIG_19(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_, double jarg9);
  public final static native long new_OvernightIndexedSwap__SWIG_20(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, Schedule jarg7_, long jarg8, OvernightIndex jarg8_);
  public final static native double OvernightIndexedSwap_fixedLegBPS(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_fixedLegNPV(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_fairRate(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_overnightLegBPS(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_overnightLegNPV(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_fairSpread(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native int OvernightIndexedSwap_type(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_nominal(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native long OvernightIndexedSwap_nominals(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native int OvernightIndexedSwap_paymentFrequency(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_fixedRate(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native long OvernightIndexedSwap_fixedDayCount(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native long OvernightIndexedSwap_overnightIndex(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native double OvernightIndexedSwap_spread(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native long OvernightIndexedSwap_fixedLeg(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native long OvernightIndexedSwap_overnightLeg(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native int OvernightIndexedSwap_averagingMethod(long jarg1, OvernightIndexedSwap jarg1_);
  public final static native void delete_OvernightIndexedSwap(long jarg1);
  public final static native long new_MakeOIS__SWIG_0(long jarg1, Period jarg1_, long jarg2, OvernightIndex jarg2_, double jarg3, long jarg4, Period jarg4_);
  public final static native long new_MakeOIS__SWIG_1(long jarg1, Period jarg1_, long jarg2, OvernightIndex jarg2_, double jarg3);
  public final static native long new_MakeOIS__SWIG_2(long jarg1, Period jarg1_, long jarg2, OvernightIndex jarg2_);
  public final static native long MakeOIS_makeOIS(long jarg1, MakeOIS jarg1_);
  public final static native long MakeOIS_receiveFixed__SWIG_0(long jarg1, MakeOIS jarg1_, boolean jarg2);
  public final static native long MakeOIS_receiveFixed__SWIG_1(long jarg1, MakeOIS jarg1_);
  public final static native long MakeOIS_withType(long jarg1, MakeOIS jarg1_, int jarg2);
  public final static native long MakeOIS_withNominal(long jarg1, MakeOIS jarg1_, double jarg2);
  public final static native long MakeOIS_withSettlementDays(long jarg1, MakeOIS jarg1_, long jarg2);
  public final static native long MakeOIS_withEffectiveDate(long jarg1, MakeOIS jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeOIS_withTerminationDate(long jarg1, MakeOIS jarg1_, long jarg2, Date jarg2_);
  public final static native long MakeOIS_withRule(long jarg1, MakeOIS jarg1_, int jarg2);
  public final static native long MakeOIS_withPaymentFrequency(long jarg1, MakeOIS jarg1_, int jarg2);
  public final static native long MakeOIS_withPaymentAdjustment(long jarg1, MakeOIS jarg1_, int jarg2);
  public final static native long MakeOIS_withPaymentLag(long jarg1, MakeOIS jarg1_, int jarg2);
  public final static native long MakeOIS_withPaymentCalendar(long jarg1, MakeOIS jarg1_, long jarg2, Calendar jarg2_);
  public final static native long MakeOIS_withEndOfMonth__SWIG_0(long jarg1, MakeOIS jarg1_, boolean jarg2);
  public final static native long MakeOIS_withEndOfMonth__SWIG_1(long jarg1, MakeOIS jarg1_);
  public final static native long MakeOIS_withFixedLegDayCount(long jarg1, MakeOIS jarg1_, long jarg2, DayCounter jarg2_);
  public final static native long MakeOIS_withOvernightLegSpread(long jarg1, MakeOIS jarg1_, double jarg2);
  public final static native long MakeOIS_withDiscountingTermStructure(long jarg1, MakeOIS jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long MakeOIS_withTelescopicValueDates(long jarg1, MakeOIS jarg1_, boolean jarg2);
  public final static native long MakeOIS_withAveragingMethod(long jarg1, MakeOIS jarg1_, int jarg2);
  public final static native long MakeOIS_withPricingEngine(long jarg1, MakeOIS jarg1_, long jarg2, PricingEngine jarg2_);
  public final static native void delete_MakeOIS(long jarg1);
  public final static native long new_OvernightIndexedSwapIndex__SWIG_0(String jarg1, long jarg2, Period jarg2_, long jarg3, long jarg4, Currency jarg4_, long jarg5, OvernightIndex jarg5_, boolean jarg6, int jarg7);
  public final static native long new_OvernightIndexedSwapIndex__SWIG_1(String jarg1, long jarg2, Period jarg2_, long jarg3, long jarg4, Currency jarg4_, long jarg5, OvernightIndex jarg5_, boolean jarg6);
  public final static native long new_OvernightIndexedSwapIndex__SWIG_2(String jarg1, long jarg2, Period jarg2_, long jarg3, long jarg4, Currency jarg4_, long jarg5, OvernightIndex jarg5_);
  public final static native long OvernightIndexedSwapIndex_overnightIndex(long jarg1, OvernightIndexedSwapIndex jarg1_);
  public final static native long OvernightIndexedSwapIndex_underlyingSwap(long jarg1, OvernightIndexedSwapIndex jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_OvernightIndexedSwapIndex(long jarg1);
  public final static native long as_overnight_swap_index(long jarg1, InterestRateIndex jarg1_);
  public final static native long new_ZeroCouponSwap__SWIG_0(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, IborIndex jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9);
  public final static native long new_ZeroCouponSwap__SWIG_1(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, IborIndex jarg6_, long jarg7, Calendar jarg7_, int jarg8);
  public final static native long new_ZeroCouponSwap__SWIG_2(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, IborIndex jarg6_, long jarg7, Calendar jarg7_);
  public final static native long new_ZeroCouponSwap__SWIG_3(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, Calendar jarg8_, int jarg9, long jarg10);
  public final static native long new_ZeroCouponSwap__SWIG_4(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, Calendar jarg8_, int jarg9);
  public final static native long new_ZeroCouponSwap__SWIG_5(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, Calendar jarg8_);
  public final static native int ZeroCouponSwap_type(long jarg1, ZeroCouponSwap jarg1_);
  public final static native double ZeroCouponSwap_baseNominal(long jarg1, ZeroCouponSwap jarg1_);
  public final static native long ZeroCouponSwap_iborIndex(long jarg1, ZeroCouponSwap jarg1_);
  public final static native long ZeroCouponSwap_fixedLeg(long jarg1, ZeroCouponSwap jarg1_);
  public final static native long ZeroCouponSwap_floatingLeg(long jarg1, ZeroCouponSwap jarg1_);
  public final static native double ZeroCouponSwap_fixedPayment(long jarg1, ZeroCouponSwap jarg1_);
  public final static native double ZeroCouponSwap_fixedLegNPV(long jarg1, ZeroCouponSwap jarg1_);
  public final static native double ZeroCouponSwap_floatingLegNPV(long jarg1, ZeroCouponSwap jarg1_);
  public final static native double ZeroCouponSwap_fairFixedPayment(long jarg1, ZeroCouponSwap jarg1_);
  public final static native double ZeroCouponSwap_fairFixedRate(long jarg1, ZeroCouponSwap jarg1_, long jarg2, DayCounter jarg2_);
  public final static native void delete_ZeroCouponSwap(long jarg1);
  public final static native long new_EquityTotalReturnSwap__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, IborIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8, long jarg9, Calendar jarg9_, int jarg10, long jarg11);
  public final static native long new_EquityTotalReturnSwap__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, IborIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8, long jarg9, Calendar jarg9_, int jarg10);
  public final static native long new_EquityTotalReturnSwap__SWIG_2(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, IborIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8, long jarg9, Calendar jarg9_);
  public final static native long new_EquityTotalReturnSwap__SWIG_3(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, IborIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8);
  public final static native long new_EquityTotalReturnSwap__SWIG_4(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, IborIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7);
  public final static native long new_EquityTotalReturnSwap__SWIG_5(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, OvernightIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8, long jarg9, Calendar jarg9_, int jarg10, long jarg11);
  public final static native long new_EquityTotalReturnSwap__SWIG_6(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, OvernightIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8, long jarg9, Calendar jarg9_, int jarg10);
  public final static native long new_EquityTotalReturnSwap__SWIG_7(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, OvernightIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8, long jarg9, Calendar jarg9_);
  public final static native long new_EquityTotalReturnSwap__SWIG_8(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, OvernightIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7, double jarg8);
  public final static native long new_EquityTotalReturnSwap__SWIG_9(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, EquityIndex jarg4_, long jarg5, OvernightIndex jarg5_, long jarg6, DayCounter jarg6_, double jarg7);
  public final static native int EquityTotalReturnSwap_type(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native double EquityTotalReturnSwap_nominal(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_equityIndex(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_interestRateIndex(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_schedule(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_dayCounter(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native double EquityTotalReturnSwap_margin(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native double EquityTotalReturnSwap_gearing(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_paymentCalendar(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native int EquityTotalReturnSwap_paymentConvention(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_paymentDelay(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_equityLeg(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native long EquityTotalReturnSwap_interestRateLeg(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native double EquityTotalReturnSwap_equityLegNPV(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native double EquityTotalReturnSwap_interestRateLegNPV(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native double EquityTotalReturnSwap_fairMargin(long jarg1, EquityTotalReturnSwap jarg1_);
  public final static native void delete_EquityTotalReturnSwap(long jarg1);
  public final static native long new_ArithmeticAverageOIS__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8, double jarg9, double jarg10, boolean jarg11);
  public final static native long new_ArithmeticAverageOIS__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8, double jarg9, double jarg10);
  public final static native long new_ArithmeticAverageOIS__SWIG_2(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8, double jarg9);
  public final static native long new_ArithmeticAverageOIS__SWIG_3(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8);
  public final static native long new_ArithmeticAverageOIS__SWIG_4(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_);
  public final static native long new_ArithmeticAverageOIS__SWIG_5(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8, double jarg9, double jarg10, boolean jarg11);
  public final static native long new_ArithmeticAverageOIS__SWIG_6(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8, double jarg9, double jarg10);
  public final static native long new_ArithmeticAverageOIS__SWIG_7(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8, double jarg9);
  public final static native long new_ArithmeticAverageOIS__SWIG_8(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_, double jarg8);
  public final static native long new_ArithmeticAverageOIS__SWIG_9(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, OvernightIndex jarg6_, long jarg7, Schedule jarg7_);
  public final static native int ArithmeticAverageOIS_type(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_nominal(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native long ArithmeticAverageOIS_nominals(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native int ArithmeticAverageOIS_fixedLegPaymentFrequency(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native int ArithmeticAverageOIS_overnightLegPaymentFrequency(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_fixedRate(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native long ArithmeticAverageOIS_fixedDayCount(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native long ArithmeticAverageOIS_overnightIndex(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_spread(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native long ArithmeticAverageOIS_fixedLeg(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native long ArithmeticAverageOIS_overnightLeg(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_fixedLegBPS(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_fixedLegNPV(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_fairRate(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_overnightLegBPS(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_overnightLegNPV(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native double ArithmeticAverageOIS_fairSpread(long jarg1, ArithmeticAverageOIS jarg1_);
  public final static native void delete_ArithmeticAverageOIS(long jarg1);
  public final static native double Seasonality_correctZeroRate(long jarg1, Seasonality jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, InflationTermStructure jarg4_);
  public final static native double Seasonality_correctYoYRate(long jarg1, Seasonality jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, InflationTermStructure jarg4_);
  public final static native boolean Seasonality_isConsistent(long jarg1, Seasonality jarg1_, long jarg2, InflationTermStructure jarg2_);
  public final static native void delete_Seasonality(long jarg1);
  public final static native long new_MultiplicativePriceSeasonality(long jarg1, Date jarg1_, int jarg2, long jarg3, DoubleVector jarg3_);
  public final static native void delete_MultiplicativePriceSeasonality(long jarg1);
  public final static native long new_KerkhofSeasonality(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_KerkhofSeasonality(long jarg1);
  public final static native long InflationTermStructure_observationLag(long jarg1, InflationTermStructure jarg1_);
  public final static native int InflationTermStructure_frequency(long jarg1, InflationTermStructure jarg1_);
  public final static native double InflationTermStructure_baseRate(long jarg1, InflationTermStructure jarg1_);
  public final static native long InflationTermStructure_baseDate(long jarg1, InflationTermStructure jarg1_);
  public final static native void InflationTermStructure_setSeasonality__SWIG_0(long jarg1, InflationTermStructure jarg1_, long jarg2, Seasonality jarg2_);
  public final static native void InflationTermStructure_setSeasonality__SWIG_1(long jarg1, InflationTermStructure jarg1_);
  public final static native long InflationTermStructure_seasonality(long jarg1, InflationTermStructure jarg1_);
  public final static native boolean InflationTermStructure_hasSeasonality(long jarg1, InflationTermStructure jarg1_);
  public final static native void delete_InflationTermStructure(long jarg1);
  public final static native double YoYInflationTermStructure_yoyRate__SWIG_0(long jarg1, YoYInflationTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4, boolean jarg5);
  public final static native double YoYInflationTermStructure_yoyRate__SWIG_1(long jarg1, YoYInflationTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double YoYInflationTermStructure_yoyRate__SWIG_2(long jarg1, YoYInflationTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double YoYInflationTermStructure_yoyRate__SWIG_3(long jarg1, YoYInflationTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double YoYInflationTermStructure_yoyRate__SWIG_4(long jarg1, YoYInflationTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double YoYInflationTermStructure_yoyRate__SWIG_5(long jarg1, YoYInflationTermStructure jarg1_, double jarg2);
  public final static native boolean YoYInflationTermStructure_indexIsInterpolated(long jarg1, YoYInflationTermStructure jarg1_);
  public final static native void delete_YoYInflationTermStructure(long jarg1);
  public final static native long new_YoYInflationTermStructureHandle__SWIG_0(long jarg1, YoYInflationTermStructure jarg1_);
  public final static native long new_YoYInflationTermStructureHandle__SWIG_1();
  public final static native long YoYInflationTermStructureHandle___deref__(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_currentLink(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native boolean YoYInflationTermStructureHandle_empty(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_asObservable(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native void delete_YoYInflationTermStructureHandle(long jarg1);
  public final static native double YoYInflationTermStructureHandle_yoyRate__SWIG_0(long jarg1, YoYInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4, boolean jarg5);
  public final static native double YoYInflationTermStructureHandle_yoyRate__SWIG_1(long jarg1, YoYInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double YoYInflationTermStructureHandle_yoyRate__SWIG_2(long jarg1, YoYInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double YoYInflationTermStructureHandle_yoyRate__SWIG_3(long jarg1, YoYInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double YoYInflationTermStructureHandle_yoyRate__SWIG_4(long jarg1, YoYInflationTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double YoYInflationTermStructureHandle_yoyRate__SWIG_5(long jarg1, YoYInflationTermStructureHandle jarg1_, double jarg2);
  public final static native boolean YoYInflationTermStructureHandle_indexIsInterpolated(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_observationLag(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native int YoYInflationTermStructureHandle_frequency(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native double YoYInflationTermStructureHandle_baseRate(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_baseDate(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native void YoYInflationTermStructureHandle_setSeasonality__SWIG_0(long jarg1, YoYInflationTermStructureHandle jarg1_, long jarg2, Seasonality jarg2_);
  public final static native void YoYInflationTermStructureHandle_setSeasonality__SWIG_1(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_seasonality(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native boolean YoYInflationTermStructureHandle_hasSeasonality(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_dayCounter(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native double YoYInflationTermStructureHandle_timeFromReference(long jarg1, YoYInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long YoYInflationTermStructureHandle_calendar(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_referenceDate(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long YoYInflationTermStructureHandle_maxDate(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native double YoYInflationTermStructureHandle_maxTime(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native void YoYInflationTermStructureHandle_enableExtrapolation(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native void YoYInflationTermStructureHandle_disableExtrapolation(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native boolean YoYInflationTermStructureHandle_allowsExtrapolation(long jarg1, YoYInflationTermStructureHandle jarg1_);
  public final static native long new_RelinkableYoYInflationTermStructureHandle__SWIG_0(long jarg1, YoYInflationTermStructure jarg1_);
  public final static native long new_RelinkableYoYInflationTermStructureHandle__SWIG_1();
  public final static native void RelinkableYoYInflationTermStructureHandle_linkTo(long jarg1, RelinkableYoYInflationTermStructureHandle jarg1_, long jarg2, YoYInflationTermStructure jarg2_);
  public final static native void RelinkableYoYInflationTermStructureHandle_reset(long jarg1, RelinkableYoYInflationTermStructureHandle jarg1_);
  public final static native void delete_RelinkableYoYInflationTermStructureHandle(long jarg1);
  public final static native double ZeroInflationTermStructure_zeroRate__SWIG_0(long jarg1, ZeroInflationTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4, boolean jarg5);
  public final static native double ZeroInflationTermStructure_zeroRate__SWIG_1(long jarg1, ZeroInflationTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double ZeroInflationTermStructure_zeroRate__SWIG_2(long jarg1, ZeroInflationTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double ZeroInflationTermStructure_zeroRate__SWIG_3(long jarg1, ZeroInflationTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double ZeroInflationTermStructure_zeroRate__SWIG_4(long jarg1, ZeroInflationTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double ZeroInflationTermStructure_zeroRate__SWIG_5(long jarg1, ZeroInflationTermStructure jarg1_, double jarg2);
  public final static native void delete_ZeroInflationTermStructure(long jarg1);
  public final static native long new_ZeroInflationTermStructureHandle__SWIG_0(long jarg1, ZeroInflationTermStructure jarg1_);
  public final static native long new_ZeroInflationTermStructureHandle__SWIG_1();
  public final static native long ZeroInflationTermStructureHandle___deref__(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_currentLink(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native boolean ZeroInflationTermStructureHandle_empty(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_asObservable(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native void delete_ZeroInflationTermStructureHandle(long jarg1);
  public final static native double ZeroInflationTermStructureHandle_zeroRate__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4, boolean jarg5);
  public final static native double ZeroInflationTermStructureHandle_zeroRate__SWIG_1(long jarg1, ZeroInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double ZeroInflationTermStructureHandle_zeroRate__SWIG_2(long jarg1, ZeroInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double ZeroInflationTermStructureHandle_zeroRate__SWIG_3(long jarg1, ZeroInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double ZeroInflationTermStructureHandle_zeroRate__SWIG_4(long jarg1, ZeroInflationTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double ZeroInflationTermStructureHandle_zeroRate__SWIG_5(long jarg1, ZeroInflationTermStructureHandle jarg1_, double jarg2);
  public final static native long ZeroInflationTermStructureHandle_observationLag(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native int ZeroInflationTermStructureHandle_frequency(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native double ZeroInflationTermStructureHandle_baseRate(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_baseDate(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native void ZeroInflationTermStructureHandle_setSeasonality__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_, long jarg2, Seasonality jarg2_);
  public final static native void ZeroInflationTermStructureHandle_setSeasonality__SWIG_1(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_seasonality(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native boolean ZeroInflationTermStructureHandle_hasSeasonality(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_dayCounter(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native double ZeroInflationTermStructureHandle_timeFromReference(long jarg1, ZeroInflationTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long ZeroInflationTermStructureHandle_calendar(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_referenceDate(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long ZeroInflationTermStructureHandle_maxDate(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native double ZeroInflationTermStructureHandle_maxTime(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native void ZeroInflationTermStructureHandle_enableExtrapolation(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native void ZeroInflationTermStructureHandle_disableExtrapolation(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native boolean ZeroInflationTermStructureHandle_allowsExtrapolation(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_RelinkableZeroInflationTermStructureHandle__SWIG_0(long jarg1, ZeroInflationTermStructure jarg1_);
  public final static native long new_RelinkableZeroInflationTermStructureHandle__SWIG_1();
  public final static native void RelinkableZeroInflationTermStructureHandle_linkTo(long jarg1, RelinkableZeroInflationTermStructureHandle jarg1_, long jarg2, ZeroInflationTermStructure jarg2_);
  public final static native void RelinkableZeroInflationTermStructureHandle_reset(long jarg1, RelinkableZeroInflationTermStructureHandle jarg1_);
  public final static native void delete_RelinkableZeroInflationTermStructureHandle(long jarg1);
  public final static native String Region_name(long jarg1, Region jarg1_);
  public final static native String Region_code(long jarg1, Region jarg1_);
  public final static native void delete_Region(long jarg1);
  public final static native long new_CustomRegion(String jarg1, String jarg2);
  public final static native void delete_CustomRegion(long jarg1);
  public final static native String InflationIndex_familyName(long jarg1, InflationIndex jarg1_);
  public final static native long InflationIndex_region(long jarg1, InflationIndex jarg1_);
  public final static native boolean InflationIndex_revised(long jarg1, InflationIndex jarg1_);
  public final static native boolean InflationIndex_interpolated(long jarg1, InflationIndex jarg1_);
  public final static native int InflationIndex_frequency(long jarg1, InflationIndex jarg1_);
  public final static native long InflationIndex_availabilityLag(long jarg1, InflationIndex jarg1_);
  public final static native long InflationIndex_currency(long jarg1, InflationIndex jarg1_);
  public final static native void delete_InflationIndex(long jarg1);
  public final static native long new_ZeroInflationIndex__SWIG_0(String jarg1, long jarg2, Region jarg2_, boolean jarg3, int jarg4, long jarg5, Period jarg5_, long jarg6, Currency jarg6_, long jarg7, ZeroInflationTermStructureHandle jarg7_);
  public final static native long new_ZeroInflationIndex__SWIG_1(String jarg1, long jarg2, Region jarg2_, boolean jarg3, int jarg4, long jarg5, Period jarg5_, long jarg6, Currency jarg6_);
  public final static native long new_ZeroInflationIndex__SWIG_2(String jarg1, long jarg2, Region jarg2_, boolean jarg3, boolean jarg4, int jarg5, long jarg6, Period jarg6_, long jarg7, Currency jarg7_, long jarg8, ZeroInflationTermStructureHandle jarg8_);
  public final static native long new_ZeroInflationIndex__SWIG_3(String jarg1, long jarg2, Region jarg2_, boolean jarg3, boolean jarg4, int jarg5, long jarg6, Period jarg6_, long jarg7, Currency jarg7_);
  public final static native long ZeroInflationIndex_zeroInflationTermStructure(long jarg1, ZeroInflationIndex jarg1_);
  public final static native long ZeroInflationIndex_clone(long jarg1, ZeroInflationIndex jarg1_, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native void delete_ZeroInflationIndex(long jarg1);
  public final static native long as_zero_inflation_index(long jarg1, Index jarg1_);
  public final static native long new_YoYInflationIndex__SWIG_0(long jarg1, ZeroInflationIndex jarg1_, boolean jarg2, long jarg3, YoYInflationTermStructureHandle jarg3_);
  public final static native long new_YoYInflationIndex__SWIG_1(long jarg1, ZeroInflationIndex jarg1_, boolean jarg2);
  public final static native long new_YoYInflationIndex__SWIG_2(String jarg1, long jarg2, Region jarg2_, boolean jarg3, boolean jarg4, int jarg5, long jarg6, Period jarg6_, long jarg7, Currency jarg7_, long jarg8, YoYInflationTermStructureHandle jarg8_);
  public final static native long new_YoYInflationIndex__SWIG_3(String jarg1, long jarg2, Region jarg2_, boolean jarg3, boolean jarg4, int jarg5, long jarg6, Period jarg6_, long jarg7, Currency jarg7_);
  public final static native long new_YoYInflationIndex__SWIG_4(String jarg1, long jarg2, Region jarg2_, boolean jarg3, boolean jarg4, boolean jarg5, int jarg6, long jarg7, Period jarg7_, long jarg8, Currency jarg8_, long jarg9, YoYInflationTermStructureHandle jarg9_);
  public final static native long new_YoYInflationIndex__SWIG_5(String jarg1, long jarg2, Region jarg2_, boolean jarg3, boolean jarg4, boolean jarg5, int jarg6, long jarg7, Period jarg7_, long jarg8, Currency jarg8_);
  public final static native boolean YoYInflationIndex_ratio(long jarg1, YoYInflationIndex jarg1_);
  public final static native long YoYInflationIndex_underlyingIndex(long jarg1, YoYInflationIndex jarg1_);
  public final static native long YoYInflationIndex_yoyInflationTermStructure(long jarg1, YoYInflationIndex jarg1_);
  public final static native long YoYInflationIndex_clone(long jarg1, YoYInflationIndex jarg1_, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native void delete_YoYInflationIndex(long jarg1);
  public final static native long new_EUHICP__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_EUHICP__SWIG_1();
  public final static native long new_EUHICP__SWIG_2(boolean jarg1, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native long new_EUHICP__SWIG_3(boolean jarg1);
  public final static native void delete_EUHICP(long jarg1);
  public final static native long new_EUHICPXT__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_EUHICPXT__SWIG_1();
  public final static native long new_EUHICPXT__SWIG_2(boolean jarg1, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native long new_EUHICPXT__SWIG_3(boolean jarg1);
  public final static native void delete_EUHICPXT(long jarg1);
  public final static native long new_FRHICP__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_FRHICP__SWIG_1();
  public final static native long new_FRHICP__SWIG_2(boolean jarg1, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native long new_FRHICP__SWIG_3(boolean jarg1);
  public final static native void delete_FRHICP(long jarg1);
  public final static native long new_UKRPI__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_UKRPI__SWIG_1();
  public final static native long new_UKRPI__SWIG_2(boolean jarg1, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native long new_UKRPI__SWIG_3(boolean jarg1);
  public final static native void delete_UKRPI(long jarg1);
  public final static native long new_USCPI__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_USCPI__SWIG_1();
  public final static native long new_USCPI__SWIG_2(boolean jarg1, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native long new_USCPI__SWIG_3(boolean jarg1);
  public final static native void delete_USCPI(long jarg1);
  public final static native long new_ZACPI__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_ZACPI__SWIG_1();
  public final static native long new_ZACPI__SWIG_2(boolean jarg1, long jarg2, ZeroInflationTermStructureHandle jarg2_);
  public final static native long new_ZACPI__SWIG_3(boolean jarg1);
  public final static native void delete_ZACPI(long jarg1);
  public final static native long new_UKHICP__SWIG_0(long jarg1, ZeroInflationTermStructureHandle jarg1_);
  public final static native long new_UKHICP__SWIG_1();
  public final static native void delete_UKHICP(long jarg1);
  public final static native long new_YYEUHICP__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYEUHICP__SWIG_1(boolean jarg1);
  public final static native void delete_YYEUHICP(long jarg1);
  public final static native long new_YYEUHICPXT__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYEUHICPXT__SWIG_1(boolean jarg1);
  public final static native void delete_YYEUHICPXT(long jarg1);
  public final static native long new_YYEUHICPr__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYEUHICPr__SWIG_1(boolean jarg1);
  public final static native void delete_YYEUHICPr(long jarg1);
  public final static native long new_YYFRHICP__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYFRHICP__SWIG_1(boolean jarg1);
  public final static native void delete_YYFRHICP(long jarg1);
  public final static native long new_YYFRHICPr__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYFRHICPr__SWIG_1(boolean jarg1);
  public final static native void delete_YYFRHICPr(long jarg1);
  public final static native long new_YYUKRPI__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYUKRPI__SWIG_1(boolean jarg1);
  public final static native void delete_YYUKRPI(long jarg1);
  public final static native long new_YYUKRPIr__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYUKRPIr__SWIG_1(boolean jarg1);
  public final static native void delete_YYUKRPIr(long jarg1);
  public final static native long new_YYUSCPI__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYUSCPI__SWIG_1(boolean jarg1);
  public final static native void delete_YYUSCPI(long jarg1);
  public final static native long new_YYUSCPIr__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYUSCPIr__SWIG_1(boolean jarg1);
  public final static native void delete_YYUSCPIr(long jarg1);
  public final static native long new_YYZACPI__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYZACPI__SWIG_1(boolean jarg1);
  public final static native void delete_YYZACPI(long jarg1);
  public final static native long new_YYZACPIr__SWIG_0(boolean jarg1, long jarg2, YoYInflationTermStructureHandle jarg2_);
  public final static native long new_YYZACPIr__SWIG_1(boolean jarg1);
  public final static native void delete_YYZACPIr(long jarg1);
  public final static native long new_AUCPI__SWIG_0(int jarg1, boolean jarg2, long jarg3, ZeroInflationTermStructureHandle jarg3_);
  public final static native long new_AUCPI__SWIG_1(int jarg1, boolean jarg2);
  public final static native long new_AUCPI__SWIG_2(int jarg1, boolean jarg2, boolean jarg3, long jarg4, ZeroInflationTermStructureHandle jarg4_);
  public final static native long new_AUCPI__SWIG_3(int jarg1, boolean jarg2, boolean jarg3);
  public final static native void delete_AUCPI(long jarg1);
  public final static native double CPI_laggedFixing(long jarg1, ZeroInflationIndex jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, int jarg4);
  public final static native long new_CPI();
  public final static native void delete_CPI(long jarg1);
  public final static native long InflationCoupon_fixingDate(long jarg1, InflationCoupon jarg1_);
  public final static native int InflationCoupon_fixingDays(long jarg1, InflationCoupon jarg1_);
  public final static native long InflationCoupon_observationLag(long jarg1, InflationCoupon jarg1_);
  public final static native double InflationCoupon_indexFixing(long jarg1, InflationCoupon jarg1_);
  public final static native long InflationCoupon_index(long jarg1, InflationCoupon jarg1_);
  public final static native void delete_InflationCoupon(long jarg1);
  public final static native long as_inflation_coupon(long jarg1, CashFlow jarg1_);
  public final static native long new_CPICouponPricer();
  public final static native void delete_CPICouponPricer(long jarg1);
  public final static native long new_CPICoupon__SWIG_0(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, Date jarg13_);
  public final static native long new_CPICoupon__SWIG_1(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_);
  public final static native long new_CPICoupon__SWIG_2(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, Date jarg11_);
  public final static native long new_CPICoupon__SWIG_3(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10);
  public final static native long new_CPICoupon__SWIG_4(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_, long jarg13, Date jarg13_);
  public final static native long new_CPICoupon__SWIG_5(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_);
  public final static native long new_CPICoupon__SWIG_6(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, Date jarg11_);
  public final static native long new_CPICoupon__SWIG_7(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10);
  public final static native long new_CPICoupon__SWIG_8(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, long jarg12, Date jarg12_, long jarg13, Date jarg13_, long jarg14, Date jarg14_);
  public final static native long new_CPICoupon__SWIG_9(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, long jarg12, Date jarg12_, long jarg13, Date jarg13_);
  public final static native long new_CPICoupon__SWIG_10(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, long jarg12, Date jarg12_);
  public final static native long new_CPICoupon__SWIG_11(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11);
  public final static native long new_CPICoupon__SWIG_12(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11, long jarg12, Date jarg12_, long jarg13, Date jarg13_, long jarg14, Date jarg14_);
  public final static native long new_CPICoupon__SWIG_13(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11, long jarg12, Date jarg12_, long jarg13, Date jarg13_);
  public final static native long new_CPICoupon__SWIG_14(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11, long jarg12, Date jarg12_);
  public final static native long new_CPICoupon__SWIG_15(double jarg1, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11);
  public final static native long new_CPICoupon__SWIG_16(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11, long jarg12, Date jarg12_, long jarg13, Date jarg13_, long jarg14, Date jarg14_);
  public final static native long new_CPICoupon__SWIG_17(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11, long jarg12, Date jarg12_, long jarg13, Date jarg13_);
  public final static native long new_CPICoupon__SWIG_18(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11, long jarg12, Date jarg12_);
  public final static native long new_CPICoupon__SWIG_19(long jarg1, Date jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, ZeroInflationIndex jarg6_, long jarg7, Period jarg7_, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, double jarg11);
  public final static native long new_CPICoupon__SWIG_20(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, double jarg12, long jarg13, Date jarg13_, long jarg14, Date jarg14_, long jarg15, Date jarg15_);
  public final static native long new_CPICoupon__SWIG_21(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, double jarg12, long jarg13, Date jarg13_, long jarg14, Date jarg14_);
  public final static native long new_CPICoupon__SWIG_22(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, double jarg12, long jarg13, Date jarg13_);
  public final static native long new_CPICoupon__SWIG_23(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Date jarg6_, long jarg7, ZeroInflationIndex jarg7_, long jarg8, Period jarg8_, int jarg9, long jarg10, DayCounter jarg10_, double jarg11, double jarg12);
  public final static native double CPICoupon_fixedRate(long jarg1, CPICoupon jarg1_);
  public final static native double CPICoupon_spread(long jarg1, CPICoupon jarg1_);
  public final static native double CPICoupon_adjustedIndexGrowth(long jarg1, CPICoupon jarg1_);
  public final static native double CPICoupon_indexFixing(long jarg1, CPICoupon jarg1_);
  public final static native double CPICoupon_indexRatio(long jarg1, CPICoupon jarg1_, long jarg2, Date jarg2_);
  public final static native double CPICoupon_baseCPI(long jarg1, CPICoupon jarg1_);
  public final static native long CPICoupon_baseDate(long jarg1, CPICoupon jarg1_);
  public final static native int CPICoupon_observationInterpolation(long jarg1, CPICoupon jarg1_);
  public final static native long CPICoupon_cpiIndex(long jarg1, CPICoupon jarg1_);
  public final static native void CPICoupon_setPricer(long jarg1, CPICoupon jarg1_, long jarg2, CPICouponPricer jarg2_);
  public final static native void delete_CPICoupon(long jarg1);
  public final static native long as_cpi_coupon(long jarg1, CashFlow jarg1_);
  public final static native long new_CPICashFlow__SWIG_0(double jarg1, long jarg2, ZeroInflationIndex jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Period jarg6_, int jarg7, long jarg8, Date jarg8_, boolean jarg9);
  public final static native long new_CPICashFlow__SWIG_1(double jarg1, long jarg2, ZeroInflationIndex jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, Date jarg5_, long jarg6, Period jarg6_, int jarg7, long jarg8, Date jarg8_);
  public final static native int CPICashFlow_interpolation(long jarg1, CPICashFlow jarg1_);
  public final static native int CPICashFlow_frequency(long jarg1, CPICashFlow jarg1_);
  public final static native void delete_CPICashFlow(long jarg1);
  public final static native long as_cpi_cashflow(long jarg1, CashFlow jarg1_);
  public final static native long CPILeg__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, long jarg16, Calendar jarg16_, boolean jarg17, int jarg18);
  public final static native long CPILeg__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, long jarg16, Calendar jarg16_, boolean jarg17);
  public final static native long CPILeg__SWIG_2(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15, long jarg16, Calendar jarg16_);
  public final static native long CPILeg__SWIG_3(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15);
  public final static native long CPILeg__SWIG_4(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14);
  public final static native long CPILeg__SWIG_5(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_);
  public final static native long CPILeg__SWIG_6(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, Period jarg12_);
  public final static native long CPILeg__SWIG_7(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native long CPILeg__SWIG_8(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long CPILeg__SWIG_9(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long CPILeg__SWIG_10(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, DoubleVector jarg8_);
  public final static native long CPILeg__SWIG_11(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long CPILeg__SWIG_12(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long CPILeg__SWIG_13(long jarg1, DoubleVector jarg1_, long jarg2, Schedule jarg2_, long jarg3, ZeroInflationIndex jarg3_, double jarg4, long jarg5, Period jarg5_);
  public final static native long new_ZeroInflationCashFlow__SWIG_0(double jarg1, long jarg2, ZeroInflationIndex jarg2_, int jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, Period jarg6_, long jarg7, Date jarg7_, boolean jarg8);
  public final static native long new_ZeroInflationCashFlow__SWIG_1(double jarg1, long jarg2, ZeroInflationIndex jarg2_, int jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, Period jarg6_, long jarg7, Date jarg7_);
  public final static native double ZeroInflationCashFlow_notional(long jarg1, ZeroInflationCashFlow jarg1_);
  public final static native long ZeroInflationCashFlow_baseDate(long jarg1, ZeroInflationCashFlow jarg1_);
  public final static native long ZeroInflationCashFlow_fixingDate(long jarg1, ZeroInflationCashFlow jarg1_);
  public final static native boolean ZeroInflationCashFlow_growthOnly(long jarg1, ZeroInflationCashFlow jarg1_);
  public final static native int ZeroInflationCashFlow_observationInterpolation(long jarg1, ZeroInflationCashFlow jarg1_);
  public final static native long ZeroInflationCashFlow_zeroInflationIndex(long jarg1, ZeroInflationCashFlow jarg1_);
  public final static native void delete_ZeroInflationCashFlow(long jarg1);
  public final static native long as_zero_inflation_cash_flow(long jarg1, CashFlow jarg1_);
  public final static native long ZeroHelper_quote(long jarg1, ZeroHelper jarg1_);
  public final static native long ZeroHelper_latestDate(long jarg1, ZeroHelper jarg1_);
  public final static native long ZeroHelper_earliestDate(long jarg1, ZeroHelper jarg1_);
  public final static native long ZeroHelper_maturityDate(long jarg1, ZeroHelper jarg1_);
  public final static native long ZeroHelper_latestRelevantDate(long jarg1, ZeroHelper jarg1_);
  public final static native long ZeroHelper_pillarDate(long jarg1, ZeroHelper jarg1_);
  public final static native double ZeroHelper_impliedQuote(long jarg1, ZeroHelper jarg1_);
  public final static native double ZeroHelper_quoteError(long jarg1, ZeroHelper jarg1_);
  public final static native void delete_ZeroHelper(long jarg1);
  public final static native long YoYHelper_quote(long jarg1, YoYHelper jarg1_);
  public final static native long YoYHelper_latestDate(long jarg1, YoYHelper jarg1_);
  public final static native long YoYHelper_earliestDate(long jarg1, YoYHelper jarg1_);
  public final static native long YoYHelper_maturityDate(long jarg1, YoYHelper jarg1_);
  public final static native long YoYHelper_latestRelevantDate(long jarg1, YoYHelper jarg1_);
  public final static native long YoYHelper_pillarDate(long jarg1, YoYHelper jarg1_);
  public final static native double YoYHelper_impliedQuote(long jarg1, YoYHelper jarg1_);
  public final static native double YoYHelper_quoteError(long jarg1, YoYHelper jarg1_);
  public final static native void delete_YoYHelper(long jarg1);
  public final static native long YoYOptionHelper_quote(long jarg1, YoYOptionHelper jarg1_);
  public final static native long YoYOptionHelper_latestDate(long jarg1, YoYOptionHelper jarg1_);
  public final static native long YoYOptionHelper_earliestDate(long jarg1, YoYOptionHelper jarg1_);
  public final static native long YoYOptionHelper_maturityDate(long jarg1, YoYOptionHelper jarg1_);
  public final static native long YoYOptionHelper_latestRelevantDate(long jarg1, YoYOptionHelper jarg1_);
  public final static native long YoYOptionHelper_pillarDate(long jarg1, YoYOptionHelper jarg1_);
  public final static native double YoYOptionHelper_impliedQuote(long jarg1, YoYOptionHelper jarg1_);
  public final static native double YoYOptionHelper_quoteError(long jarg1, YoYOptionHelper jarg1_);
  public final static native void delete_YoYOptionHelper(long jarg1);
  public final static native long new_ZeroHelperVector__SWIG_0();
  public final static native long new_ZeroHelperVector__SWIG_1(long jarg1, ZeroHelperVector jarg1_);
  public final static native long ZeroHelperVector_capacity(long jarg1, ZeroHelperVector jarg1_);
  public final static native void ZeroHelperVector_reserve(long jarg1, ZeroHelperVector jarg1_, long jarg2);
  public final static native boolean ZeroHelperVector_isEmpty(long jarg1, ZeroHelperVector jarg1_);
  public final static native void ZeroHelperVector_clear(long jarg1, ZeroHelperVector jarg1_);
  public final static native long new_ZeroHelperVector__SWIG_2(int jarg1, long jarg2, ZeroHelper jarg2_);
  public final static native int ZeroHelperVector_doSize(long jarg1, ZeroHelperVector jarg1_);
  public final static native void ZeroHelperVector_doAdd__SWIG_0(long jarg1, ZeroHelperVector jarg1_, long jarg2, ZeroHelper jarg2_);
  public final static native void ZeroHelperVector_doAdd__SWIG_1(long jarg1, ZeroHelperVector jarg1_, int jarg2, long jarg3, ZeroHelper jarg3_);
  public final static native long ZeroHelperVector_doRemove(long jarg1, ZeroHelperVector jarg1_, int jarg2);
  public final static native long ZeroHelperVector_doGet(long jarg1, ZeroHelperVector jarg1_, int jarg2);
  public final static native long ZeroHelperVector_doSet(long jarg1, ZeroHelperVector jarg1_, int jarg2, long jarg3, ZeroHelper jarg3_);
  public final static native void ZeroHelperVector_doRemoveRange(long jarg1, ZeroHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_ZeroHelperVector(long jarg1);
  public final static native long new_YoYHelperVector__SWIG_0();
  public final static native long new_YoYHelperVector__SWIG_1(long jarg1, YoYHelperVector jarg1_);
  public final static native long YoYHelperVector_capacity(long jarg1, YoYHelperVector jarg1_);
  public final static native void YoYHelperVector_reserve(long jarg1, YoYHelperVector jarg1_, long jarg2);
  public final static native boolean YoYHelperVector_isEmpty(long jarg1, YoYHelperVector jarg1_);
  public final static native void YoYHelperVector_clear(long jarg1, YoYHelperVector jarg1_);
  public final static native long new_YoYHelperVector__SWIG_2(int jarg1, long jarg2, YoYHelper jarg2_);
  public final static native int YoYHelperVector_doSize(long jarg1, YoYHelperVector jarg1_);
  public final static native void YoYHelperVector_doAdd__SWIG_0(long jarg1, YoYHelperVector jarg1_, long jarg2, YoYHelper jarg2_);
  public final static native void YoYHelperVector_doAdd__SWIG_1(long jarg1, YoYHelperVector jarg1_, int jarg2, long jarg3, YoYHelper jarg3_);
  public final static native long YoYHelperVector_doRemove(long jarg1, YoYHelperVector jarg1_, int jarg2);
  public final static native long YoYHelperVector_doGet(long jarg1, YoYHelperVector jarg1_, int jarg2);
  public final static native long YoYHelperVector_doSet(long jarg1, YoYHelperVector jarg1_, int jarg2, long jarg3, YoYHelper jarg3_);
  public final static native void YoYHelperVector_doRemoveRange(long jarg1, YoYHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_YoYHelperVector(long jarg1);
  public final static native long new_YoYOptionHelperVector__SWIG_0();
  public final static native long new_YoYOptionHelperVector__SWIG_1(long jarg1, YoYOptionHelperVector jarg1_);
  public final static native long YoYOptionHelperVector_capacity(long jarg1, YoYOptionHelperVector jarg1_);
  public final static native void YoYOptionHelperVector_reserve(long jarg1, YoYOptionHelperVector jarg1_, long jarg2);
  public final static native boolean YoYOptionHelperVector_isEmpty(long jarg1, YoYOptionHelperVector jarg1_);
  public final static native void YoYOptionHelperVector_clear(long jarg1, YoYOptionHelperVector jarg1_);
  public final static native long new_YoYOptionHelperVector__SWIG_2(int jarg1, long jarg2, YoYOptionHelper jarg2_);
  public final static native int YoYOptionHelperVector_doSize(long jarg1, YoYOptionHelperVector jarg1_);
  public final static native void YoYOptionHelperVector_doAdd__SWIG_0(long jarg1, YoYOptionHelperVector jarg1_, long jarg2, YoYOptionHelper jarg2_);
  public final static native void YoYOptionHelperVector_doAdd__SWIG_1(long jarg1, YoYOptionHelperVector jarg1_, int jarg2, long jarg3, YoYOptionHelper jarg3_);
  public final static native long YoYOptionHelperVector_doRemove(long jarg1, YoYOptionHelperVector jarg1_, int jarg2);
  public final static native long YoYOptionHelperVector_doGet(long jarg1, YoYOptionHelperVector jarg1_, int jarg2);
  public final static native long YoYOptionHelperVector_doSet(long jarg1, YoYOptionHelperVector jarg1_, int jarg2, long jarg3, YoYOptionHelper jarg3_);
  public final static native void YoYOptionHelperVector_doRemoveRange(long jarg1, YoYOptionHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_YoYOptionHelperVector(long jarg1);
  public final static native long new_ZeroCouponInflationSwapHelper(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Date jarg3_, long jarg4, Calendar jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, ZeroInflationIndex jarg7_, int jarg8, long jarg9, YieldTermStructureHandle jarg9_);
  public final static native void delete_ZeroCouponInflationSwapHelper(long jarg1);
  public final static native long new_YearOnYearInflationSwapHelper(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Date jarg3_, long jarg4, Calendar jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, YoYInflationIndex jarg7_, long jarg8, YieldTermStructureHandle jarg8_);
  public final static native void delete_YearOnYearInflationSwapHelper(long jarg1);
  public final static native long new_PiecewiseZeroInflation__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, double jarg6, long jarg7, ZeroHelperVector jarg7_, double jarg8, long jarg9, Linear jarg9_);
  public final static native long new_PiecewiseZeroInflation__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, double jarg6, long jarg7, ZeroHelperVector jarg7_, double jarg8);
  public final static native long new_PiecewiseZeroInflation__SWIG_2(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, double jarg6, long jarg7, ZeroHelperVector jarg7_);
  public final static native long PiecewiseZeroInflation_dates(long jarg1, PiecewiseZeroInflation jarg1_);
  public final static native long PiecewiseZeroInflation_times(long jarg1, PiecewiseZeroInflation jarg1_);
  public final static native long PiecewiseZeroInflation_nodes(long jarg1, PiecewiseZeroInflation jarg1_);
  public final static native void delete_PiecewiseZeroInflation(long jarg1);
  public final static native long new_PiecewiseYoYInflation__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, boolean jarg6, double jarg7, long jarg8, YoYHelperVector jarg8_, double jarg9, long jarg10, Linear jarg10_);
  public final static native long new_PiecewiseYoYInflation__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, boolean jarg6, double jarg7, long jarg8, YoYHelperVector jarg8_, double jarg9);
  public final static native long new_PiecewiseYoYInflation__SWIG_2(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, boolean jarg6, double jarg7, long jarg8, YoYHelperVector jarg8_);
  public final static native long PiecewiseYoYInflation_dates(long jarg1, PiecewiseYoYInflation jarg1_);
  public final static native long PiecewiseYoYInflation_times(long jarg1, PiecewiseYoYInflation jarg1_);
  public final static native long PiecewiseYoYInflation_nodes(long jarg1, PiecewiseYoYInflation jarg1_);
  public final static native void delete_PiecewiseYoYInflation(long jarg1);
  public final static native long new_DatePair__SWIG_0();
  public final static native long new_DatePair__SWIG_1(long jarg1, Date jarg1_, long jarg2, Date jarg2_);
  public final static native long new_DatePair__SWIG_2(long jarg1, DatePair jarg1_);
  public final static native void DatePair_first_set(long jarg1, DatePair jarg1_, long jarg2, Date jarg2_);
  public final static native long DatePair_first_get(long jarg1, DatePair jarg1_);
  public final static native void DatePair_second_set(long jarg1, DatePair jarg1_, long jarg2, Date jarg2_);
  public final static native long DatePair_second_get(long jarg1, DatePair jarg1_);
  public final static native void delete_DatePair(long jarg1);
  public final static native long inflationPeriod(long jarg1, Date jarg1_, int jarg2);
  public final static native double inflationYearFraction(int jarg1, boolean jarg2, long jarg3, DayCounter jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native long inflationBaseDate(long jarg1, Date jarg1_, long jarg2, Period jarg2_, int jarg3, boolean jarg4);
  public final static native void delete_YoYInflationCouponPricer(long jarg1);
  public final static native void setCouponPricer__SWIG_2(long jarg1, Leg jarg1_, long jarg2, YoYInflationCouponPricer jarg2_);
  public final static native long new_YoYInflationCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10, long jarg11, Date jarg11_, long jarg12, Date jarg12_);
  public final static native long new_YoYInflationCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10, long jarg11, Date jarg11_);
  public final static native long new_YoYInflationCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10);
  public final static native long new_YoYInflationCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9);
  public final static native long new_YoYInflationCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_);
  public final static native double YoYInflationCoupon_gearing(long jarg1, YoYInflationCoupon jarg1_);
  public final static native double YoYInflationCoupon_spread(long jarg1, YoYInflationCoupon jarg1_);
  public final static native double YoYInflationCoupon_adjustedFixing(long jarg1, YoYInflationCoupon jarg1_);
  public final static native long YoYInflationCoupon_yoyIndex(long jarg1, YoYInflationCoupon jarg1_);
  public final static native void delete_YoYInflationCoupon(long jarg1);
  public final static native long as_yoy_inflation_coupon(long jarg1, CashFlow jarg1_);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10, double jarg11, double jarg12, long jarg13, Date jarg13_, long jarg14, Date jarg14_);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_1(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10, double jarg11, double jarg12, long jarg13, Date jarg13_);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_2(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10, double jarg11, double jarg12);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_3(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10, double jarg11);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_4(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9, double jarg10);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_5(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_, double jarg9);
  public final static native long new_CappedFlooredYoYInflationCoupon__SWIG_6(long jarg1, Date jarg1_, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, YoYInflationIndex jarg6_, long jarg7, Period jarg7_, long jarg8, DayCounter jarg8_);
  public final static native double CappedFlooredYoYInflationCoupon_rate(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native double CappedFlooredYoYInflationCoupon_cap(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native double CappedFlooredYoYInflationCoupon_floor(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native double CappedFlooredYoYInflationCoupon_effectiveCap(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native double CappedFlooredYoYInflationCoupon_effectiveFloor(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native double CappedFlooredYoYInflationCoupon_underlyingRate(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native boolean CappedFlooredYoYInflationCoupon_isCapped(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native boolean CappedFlooredYoYInflationCoupon_isFloored(long jarg1, CappedFlooredYoYInflationCoupon jarg1_);
  public final static native void delete_CappedFlooredYoYInflationCoupon(long jarg1);
  public final static native long as_capped_floored_yoy_inflation_coupon(long jarg1, CashFlow jarg1_);
  public final static native long yoyInflationLeg__SWIG_0(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, long jarg12, DoubleVector jarg12_);
  public final static native long yoyInflationLeg__SWIG_1(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native long yoyInflationLeg__SWIG_2(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long yoyInflationLeg__SWIG_3(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8, long jarg9, DoubleVector jarg9_);
  public final static native long yoyInflationLeg__SWIG_4(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, long jarg8);
  public final static native long yoyInflationLeg__SWIG_5(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long yoyInflationLeg__SWIG_6(long jarg1, Schedule jarg1_, long jarg2, Calendar jarg2_, long jarg3, YoYInflationIndex jarg3_, long jarg4, Period jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_BlackYoYInflationCouponPricer(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_BlackYoYInflationCouponPricer(long jarg1);
  public final static native long new_UnitDisplacedBlackYoYInflationCouponPricer(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_UnitDisplacedBlackYoYInflationCouponPricer(long jarg1);
  public final static native long new_BachelierYoYInflationCouponPricer(long jarg1, YoYOptionletVolatilitySurfaceHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_BachelierYoYInflationCouponPricer(long jarg1);
  public final static native long new_ZeroCouponInflationSwap__SWIG_0(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Calendar jarg5_, int jarg6, long jarg7, DayCounter jarg7_, double jarg8, long jarg9, ZeroInflationIndex jarg9_, long jarg10, Period jarg10_, int jarg11, boolean jarg12, long jarg13, Calendar jarg13_, int jarg14);
  public final static native long new_ZeroCouponInflationSwap__SWIG_1(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Calendar jarg5_, int jarg6, long jarg7, DayCounter jarg7_, double jarg8, long jarg9, ZeroInflationIndex jarg9_, long jarg10, Period jarg10_, int jarg11, boolean jarg12, long jarg13, Calendar jarg13_);
  public final static native long new_ZeroCouponInflationSwap__SWIG_2(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Calendar jarg5_, int jarg6, long jarg7, DayCounter jarg7_, double jarg8, long jarg9, ZeroInflationIndex jarg9_, long jarg10, Period jarg10_, int jarg11, boolean jarg12);
  public final static native long new_ZeroCouponInflationSwap__SWIG_3(int jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Calendar jarg5_, int jarg6, long jarg7, DayCounter jarg7_, double jarg8, long jarg9, ZeroInflationIndex jarg9_, long jarg10, Period jarg10_, int jarg11);
  public final static native double ZeroCouponInflationSwap_fairRate(long jarg1, ZeroCouponInflationSwap jarg1_);
  public final static native double ZeroCouponInflationSwap_fixedLegNPV(long jarg1, ZeroCouponInflationSwap jarg1_);
  public final static native double ZeroCouponInflationSwap_inflationLegNPV(long jarg1, ZeroCouponInflationSwap jarg1_);
  public final static native long ZeroCouponInflationSwap_fixedLeg(long jarg1, ZeroCouponInflationSwap jarg1_);
  public final static native long ZeroCouponInflationSwap_inflationLeg(long jarg1, ZeroCouponInflationSwap jarg1_);
  public final static native int ZeroCouponInflationSwap_type(long jarg1, ZeroCouponInflationSwap jarg1_);
  public final static native void delete_ZeroCouponInflationSwap(long jarg1);
  public final static native long new_YearOnYearInflationSwap__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, long jarg7, YoYInflationIndex jarg7_, long jarg8, Period jarg8_, double jarg9, long jarg10, DayCounter jarg10_, long jarg11, Calendar jarg11_, int jarg12);
  public final static native long new_YearOnYearInflationSwap__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, long jarg7, YoYInflationIndex jarg7_, long jarg8, Period jarg8_, double jarg9, long jarg10, DayCounter jarg10_, long jarg11, Calendar jarg11_);
  public final static native double YearOnYearInflationSwap_fairRate(long jarg1, YearOnYearInflationSwap jarg1_);
  public final static native double YearOnYearInflationSwap_fixedLegNPV(long jarg1, YearOnYearInflationSwap jarg1_);
  public final static native double YearOnYearInflationSwap_yoyLegNPV(long jarg1, YearOnYearInflationSwap jarg1_);
  public final static native double YearOnYearInflationSwap_fairSpread(long jarg1, YearOnYearInflationSwap jarg1_);
  public final static native long YearOnYearInflationSwap_fixedLeg(long jarg1, YearOnYearInflationSwap jarg1_);
  public final static native long YearOnYearInflationSwap_yoyLeg(long jarg1, YearOnYearInflationSwap jarg1_);
  public final static native void delete_YearOnYearInflationSwap(long jarg1);
  public final static native long new_CPISwap__SWIG_0(int jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, int jarg7, long jarg8, long jarg9, IborIndex jarg9_, double jarg10, double jarg11, long jarg12, DayCounter jarg12_, long jarg13, Schedule jarg13_, int jarg14, long jarg15, Period jarg15_, long jarg16, ZeroInflationIndex jarg16_, int jarg17, double jarg18);
  public final static native long new_CPISwap__SWIG_1(int jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, int jarg7, long jarg8, long jarg9, IborIndex jarg9_, double jarg10, double jarg11, long jarg12, DayCounter jarg12_, long jarg13, Schedule jarg13_, int jarg14, long jarg15, Period jarg15_, long jarg16, ZeroInflationIndex jarg16_, int jarg17);
  public final static native long new_CPISwap__SWIG_2(int jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, DayCounter jarg5_, long jarg6, Schedule jarg6_, int jarg7, long jarg8, long jarg9, IborIndex jarg9_, double jarg10, double jarg11, long jarg12, DayCounter jarg12_, long jarg13, Schedule jarg13_, int jarg14, long jarg15, Period jarg15_, long jarg16, ZeroInflationIndex jarg16_);
  public final static native double CPISwap_fairRate(long jarg1, CPISwap jarg1_);
  public final static native double CPISwap_floatLegNPV(long jarg1, CPISwap jarg1_);
  public final static native double CPISwap_fairSpread(long jarg1, CPISwap jarg1_);
  public final static native double CPISwap_fixedLegNPV(long jarg1, CPISwap jarg1_);
  public final static native long CPISwap_cpiLeg(long jarg1, CPISwap jarg1_);
  public final static native long CPISwap_floatLeg(long jarg1, CPISwap jarg1_);
  public final static native void delete_CPISwap(long jarg1);
  public final static native long new_YoYInflationCapFloor(int jarg1, long jarg2, Leg jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native double YoYInflationCapFloor_impliedVolatility__SWIG_0(long jarg1, YoYInflationCapFloor jarg1_, double jarg2, long jarg3, YoYInflationTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8);
  public final static native double YoYInflationCapFloor_impliedVolatility__SWIG_1(long jarg1, YoYInflationCapFloor jarg1_, double jarg2, long jarg3, YoYInflationTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7);
  public final static native double YoYInflationCapFloor_impliedVolatility__SWIG_2(long jarg1, YoYInflationCapFloor jarg1_, double jarg2, long jarg3, YoYInflationTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6);
  public final static native double YoYInflationCapFloor_impliedVolatility__SWIG_3(long jarg1, YoYInflationCapFloor jarg1_, double jarg2, long jarg3, YoYInflationTermStructureHandle jarg3_, double jarg4, double jarg5);
  public final static native double YoYInflationCapFloor_impliedVolatility__SWIG_4(long jarg1, YoYInflationCapFloor jarg1_, double jarg2, long jarg3, YoYInflationTermStructureHandle jarg3_, double jarg4);
  public final static native long YoYInflationCapFloor_optionletPrices(long jarg1, YoYInflationCapFloor jarg1_);
  public final static native void delete_YoYInflationCapFloor(long jarg1);
  public final static native long new_YoYInflationCap(long jarg1, Leg jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_YoYInflationCap(long jarg1);
  public final static native long new_YoYInflationFloor(long jarg1, Leg jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_YoYInflationFloor(long jarg1);
  public final static native long new_YoYInflationCollar(long jarg1, Leg jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void delete_YoYInflationCollar(long jarg1);
  public final static native long new_ZeroInflationCurve__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, long jarg6, DateVector jarg6_, long jarg7, DoubleVector jarg7_, long jarg8, Linear jarg8_);
  public final static native long new_ZeroInflationCurve__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, long jarg6, DateVector jarg6_, long jarg7, DoubleVector jarg7_);
  public final static native long ZeroInflationCurve_dates(long jarg1, ZeroInflationCurve jarg1_);
  public final static native long ZeroInflationCurve_times(long jarg1, ZeroInflationCurve jarg1_);
  public final static native long ZeroInflationCurve_data(long jarg1, ZeroInflationCurve jarg1_);
  public final static native long ZeroInflationCurve_rates(long jarg1, ZeroInflationCurve jarg1_);
  public final static native long ZeroInflationCurve_nodes(long jarg1, ZeroInflationCurve jarg1_);
  public final static native void delete_ZeroInflationCurve(long jarg1);
  public final static native long new_YoYInflationCurve__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, boolean jarg6, long jarg7, DateVector jarg7_, long jarg8, DoubleVector jarg8_, long jarg9, Linear jarg9_);
  public final static native long new_YoYInflationCurve__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Period jarg4_, int jarg5, boolean jarg6, long jarg7, DateVector jarg7_, long jarg8, DoubleVector jarg8_);
  public final static native long YoYInflationCurve_dates(long jarg1, YoYInflationCurve jarg1_);
  public final static native long YoYInflationCurve_times(long jarg1, YoYInflationCurve jarg1_);
  public final static native long YoYInflationCurve_data(long jarg1, YoYInflationCurve jarg1_);
  public final static native long YoYInflationCurve_rates(long jarg1, YoYInflationCurve jarg1_);
  public final static native long YoYInflationCurve_nodes(long jarg1, YoYInflationCurve jarg1_);
  public final static native void delete_YoYInflationCurve(long jarg1);
  public final static native long YoYCapFloorTermPriceSurface_atmYoYSwapTimeRates(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_atmYoYSwapDateRates(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_YoYTS(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_yoyIndex(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native int YoYCapFloorTermPriceSurface_businessDayConvention(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_fixingDays(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native double YoYCapFloorTermPriceSurface_price__SWIG_0(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYCapFloorTermPriceSurface_capPrice__SWIG_0(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYCapFloorTermPriceSurface_floorPrice__SWIG_0(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_0(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_1(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_0(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_1(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_2(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Date jarg2_);
  public final static native double YoYCapFloorTermPriceSurface_price__SWIG_1(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double YoYCapFloorTermPriceSurface_capPrice__SWIG_1(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double YoYCapFloorTermPriceSurface_floorPrice__SWIG_1(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_2(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_, boolean jarg3);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_3(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_3(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_, boolean jarg4);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_4(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_, long jarg3, Period jarg3_);
  public final static native double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_5(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_);
  public final static native long YoYCapFloorTermPriceSurface_strikes(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_capStrikes(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_floorStrikes(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_maturities(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native double YoYCapFloorTermPriceSurface_minStrike(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native double YoYCapFloorTermPriceSurface_maxStrike(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_minMaturity(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_maxMaturity(long jarg1, YoYCapFloorTermPriceSurface jarg1_);
  public final static native long YoYCapFloorTermPriceSurface_yoyOptionDateFromTenor(long jarg1, YoYCapFloorTermPriceSurface jarg1_, long jarg2, Period jarg2_);
  public final static native void delete_YoYCapFloorTermPriceSurface(long jarg1);
  public final static native long new_YoYInflationCapFloorTermPriceSurface__SWIG_0(long jarg1, long jarg2, Period jarg2_, long jarg3, YoYInflationIndex jarg3_, double jarg4, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, PeriodVector jarg11_, long jarg12, Matrix jarg12_, long jarg13, Matrix jarg13_, long jarg14, Bicubic jarg14_, long jarg15, Cubic jarg15_);
  public final static native long new_YoYInflationCapFloorTermPriceSurface__SWIG_1(long jarg1, long jarg2, Period jarg2_, long jarg3, YoYInflationIndex jarg3_, double jarg4, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, PeriodVector jarg11_, long jarg12, Matrix jarg12_, long jarg13, Matrix jarg13_, long jarg14, Bicubic jarg14_);
  public final static native long new_YoYInflationCapFloorTermPriceSurface__SWIG_2(long jarg1, long jarg2, Period jarg2_, long jarg3, YoYInflationIndex jarg3_, double jarg4, long jarg5, YieldTermStructureHandle jarg5_, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, PeriodVector jarg11_, long jarg12, Matrix jarg12_, long jarg13, Matrix jarg13_);
  public final static native void delete_YoYInflationCapFloorTermPriceSurface(long jarg1);
  public final static native long new_YoYInflationBlackCapFloorEngine(long jarg1, YoYInflationIndex jarg1_, long jarg2, YoYOptionletVolatilitySurfaceHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_YoYInflationBlackCapFloorEngine(long jarg1);
  public final static native long new_YoYInflationUnitDisplacedBlackCapFloorEngine(long jarg1, YoYInflationIndex jarg1_, long jarg2, YoYOptionletVolatilitySurfaceHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_YoYInflationUnitDisplacedBlackCapFloorEngine(long jarg1);
  public final static native long new_YoYInflationBachelierCapFloorEngine(long jarg1, YoYInflationIndex jarg1_, long jarg2, YoYOptionletVolatilitySurfaceHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_YoYInflationBachelierCapFloorEngine(long jarg1);
  public final static native long new_YoYOptionletHelper(long jarg1, QuoteHandle jarg1_, double jarg2, int jarg3, long jarg4, Period jarg4_, long jarg5, DayCounter jarg5_, long jarg6, Calendar jarg6_, long jarg7, long jarg8, YoYInflationIndex jarg8_, double jarg9, long jarg10, long jarg11, PricingEngine jarg11_);
  public final static native void delete_YoYOptionletHelper(long jarg1);
  public final static native void YoYOptionletStripper_initialize(long jarg1, YoYOptionletStripper jarg1_, long jarg2, YoYCapFloorTermPriceSurface jarg2_, long jarg3, PricingEngine jarg3_, double jarg4);
  public final static native double YoYOptionletStripper_maxStrike(long jarg1, YoYOptionletStripper jarg1_);
  public final static native long YoYOptionletStripper_strikes(long jarg1, YoYOptionletStripper jarg1_);
  public final static native long YoYOptionletStripper_slice(long jarg1, YoYOptionletStripper jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_YoYOptionletStripper(long jarg1);
  public final static native long new_InterpolatedYoYInflationOptionletStripper();
  public final static native void delete_InterpolatedYoYInflationOptionletStripper(long jarg1);
  public final static native long new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DayCounter jarg4_, long jarg5, Period jarg5_, int jarg6, boolean jarg7, long jarg8, DateVector jarg8_, long jarg9, DoubleVector jarg9_, double jarg10, double jarg11, long jarg12, Linear jarg12_);
  public final static native long new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DayCounter jarg4_, long jarg5, Period jarg5_, int jarg6, boolean jarg7, long jarg8, DateVector jarg8_, long jarg9, DoubleVector jarg9_, double jarg10, double jarg11);
  public final static native void delete_InterpolatedYoYInflationOptionletVolatilityCurve(long jarg1);
  public final static native long new_KInterpolatedYoYInflationOptionletVolatilitySurface__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DayCounter jarg4_, long jarg5, Period jarg5_, long jarg6, YoYCapFloorTermPriceSurface jarg6_, long jarg7, PricingEngine jarg7_, long jarg8, YoYOptionletStripper jarg8_, double jarg9, long jarg10, Linear jarg10_);
  public final static native long new_KInterpolatedYoYInflationOptionletVolatilitySurface__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, DayCounter jarg4_, long jarg5, Period jarg5_, long jarg6, YoYCapFloorTermPriceSurface jarg6_, long jarg7, PricingEngine jarg7_, long jarg8, YoYOptionletStripper jarg8_, double jarg9);
  public final static native long KInterpolatedYoYInflationOptionletVolatilitySurface_Dslice(long jarg1, KInterpolatedYoYInflationOptionletVolatilitySurface jarg1_, long jarg2, Date jarg2_);
  public final static native void delete_KInterpolatedYoYInflationOptionletVolatilitySurface(long jarg1);
  public final static native void delete_ShortRateModel(long jarg1);
  public final static native long new_ShortRateModelHandle__SWIG_0(long jarg1, ShortRateModel jarg1_);
  public final static native long new_ShortRateModelHandle__SWIG_1();
  public final static native long ShortRateModelHandle___deref__(long jarg1, ShortRateModelHandle jarg1_);
  public final static native long ShortRateModelHandle_currentLink(long jarg1, ShortRateModelHandle jarg1_);
  public final static native boolean ShortRateModelHandle_empty(long jarg1, ShortRateModelHandle jarg1_);
  public final static native long ShortRateModelHandle_asObservable(long jarg1, ShortRateModelHandle jarg1_);
  public final static native void delete_ShortRateModelHandle(long jarg1);
  public final static native long ShortRateModelHandle_params(long jarg1, ShortRateModelHandle jarg1_);
  public final static native void ShortRateModelHandle_calibrate__SWIG_0(long jarg1, ShortRateModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void ShortRateModelHandle_calibrate__SWIG_1(long jarg1, ShortRateModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void ShortRateModelHandle_calibrate__SWIG_2(long jarg1, ShortRateModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void ShortRateModelHandle_calibrate__SWIG_3(long jarg1, ShortRateModelHandle jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native void ShortRateModelHandle_setParams(long jarg1, ShortRateModelHandle jarg1_, long jarg2, Array jarg2_);
  public final static native double ShortRateModelHandle_value(long jarg1, ShortRateModelHandle jarg1_, long jarg2, Array jarg2_, long jarg3, CalibrationHelperVector jarg3_);
  public final static native long ShortRateModelHandle_constraint(long jarg1, ShortRateModelHandle jarg1_);
  public final static native int ShortRateModelHandle_endCriteria(long jarg1, ShortRateModelHandle jarg1_);
  public final static native long ShortRateModelHandle_problemValues(long jarg1, ShortRateModelHandle jarg1_);
  public final static native int ShortRateModelHandle_functionEvaluation(long jarg1, ShortRateModelHandle jarg1_);
  public final static native long new_RelinkableShortRateModelHandle__SWIG_0(long jarg1, ShortRateModel jarg1_);
  public final static native long new_RelinkableShortRateModelHandle__SWIG_1();
  public final static native void RelinkableShortRateModelHandle_linkTo(long jarg1, RelinkableShortRateModelHandle jarg1_, long jarg2, ShortRateModel jarg2_);
  public final static native void RelinkableShortRateModelHandle_reset(long jarg1, RelinkableShortRateModelHandle jarg1_);
  public final static native void delete_RelinkableShortRateModelHandle(long jarg1);
  public final static native double OneFactorAffineModel_discountBond__SWIG_0(long jarg1, OneFactorAffineModel jarg1_, double jarg2, double jarg3, long jarg4, Array jarg4_);
  public final static native double OneFactorAffineModel_discountBond__SWIG_1(long jarg1, OneFactorAffineModel jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double OneFactorAffineModel_discount(long jarg1, OneFactorAffineModel jarg1_, double jarg2);
  public final static native void delete_OneFactorAffineModel(long jarg1);
  public final static native long new_Vasicek__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native long new_Vasicek__SWIG_1(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native long new_Vasicek__SWIG_2(double jarg1, double jarg2, double jarg3);
  public final static native long new_Vasicek__SWIG_3(double jarg1, double jarg2);
  public final static native long new_Vasicek__SWIG_4(double jarg1);
  public final static native long new_Vasicek__SWIG_5();
  public final static native void delete_Vasicek(long jarg1);
  public final static native long new_HullWhite__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native long new_HullWhite__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, double jarg2);
  public final static native long new_HullWhite__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native double HullWhite_convexityBias(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native long HullWhite_termStructure(long jarg1, HullWhite jarg1_);
  public final static native void delete_HullWhite(long jarg1);
  public final static native long new_BlackKarasinski__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native long new_BlackKarasinski__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, double jarg2);
  public final static native long new_BlackKarasinski__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long BlackKarasinski_termStructure(long jarg1, BlackKarasinski jarg1_);
  public final static native void delete_BlackKarasinski(long jarg1);
  public final static native long new_CoxIngersollRoss__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native long new_CoxIngersollRoss__SWIG_1(double jarg1, double jarg2, double jarg3);
  public final static native long new_CoxIngersollRoss__SWIG_2(double jarg1, double jarg2);
  public final static native long new_CoxIngersollRoss__SWIG_3(double jarg1);
  public final static native long new_CoxIngersollRoss__SWIG_4();
  public final static native double CoxIngersollRoss_discount(long jarg1, CoxIngersollRoss jarg1_, double jarg2);
  public final static native void delete_CoxIngersollRoss(long jarg1);
  public final static native long new_ExtendedCoxIngersollRoss__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native long new_ExtendedCoxIngersollRoss__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long new_ExtendedCoxIngersollRoss__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native long new_ExtendedCoxIngersollRoss__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, double jarg2);
  public final static native long new_ExtendedCoxIngersollRoss__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native double ExtendedCoxIngersollRoss_discount(long jarg1, ExtendedCoxIngersollRoss jarg1_, double jarg2);
  public final static native void delete_ExtendedCoxIngersollRoss(long jarg1);
  public final static native long new_G2__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_G2__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native long new_G2__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long new_G2__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native long new_G2__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, double jarg2);
  public final static native long new_G2__SWIG_5(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native long G2_termStructure(long jarg1, G2 jarg1_);
  public final static native void delete_G2(long jarg1);
  public final static native long new_JamshidianSwaptionEngine__SWIG_0(long jarg1, OneFactorAffineModel jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_JamshidianSwaptionEngine__SWIG_1(long jarg1, OneFactorAffineModel jarg1_);
  public final static native void delete_JamshidianSwaptionEngine(long jarg1);
  public final static native long new_TreeSwaptionEngine__SWIG_0(long jarg1, ShortRateModel jarg1_, long jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeSwaptionEngine__SWIG_1(long jarg1, ShortRateModel jarg1_, long jarg2);
  public final static native long new_TreeSwaptionEngine__SWIG_2(long jarg1, ShortRateModel jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeSwaptionEngine__SWIG_3(long jarg1, ShortRateModel jarg1_, long jarg2, TimeGrid jarg2_);
  public final static native long new_TreeSwaptionEngine__SWIG_4(long jarg1, ShortRateModelHandle jarg1_, long jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeSwaptionEngine__SWIG_5(long jarg1, ShortRateModelHandle jarg1_, long jarg2);
  public final static native void delete_TreeSwaptionEngine(long jarg1);
  public final static native long new_AnalyticCapFloorEngine__SWIG_0(long jarg1, OneFactorAffineModel jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native long new_AnalyticCapFloorEngine__SWIG_1(long jarg1, OneFactorAffineModel jarg1_);
  public final static native void delete_AnalyticCapFloorEngine(long jarg1);
  public final static native long new_TreeCapFloorEngine__SWIG_0(long jarg1, ShortRateModel jarg1_, long jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeCapFloorEngine__SWIG_1(long jarg1, ShortRateModel jarg1_, long jarg2);
  public final static native long new_TreeCapFloorEngine__SWIG_2(long jarg1, ShortRateModel jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeCapFloorEngine__SWIG_3(long jarg1, ShortRateModel jarg1_, long jarg2, TimeGrid jarg2_);
  public final static native void delete_TreeCapFloorEngine(long jarg1);
  public final static native long new_G2SwaptionEngine(long jarg1, G2 jarg1_, double jarg2, long jarg3);
  public final static native void delete_G2SwaptionEngine(long jarg1);
  public final static native long new_FdG2SwaptionEngine__SWIG_0(long jarg1, G2 jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, double jarg6, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdG2SwaptionEngine__SWIG_1(long jarg1, G2 jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, double jarg6);
  public final static native long new_FdG2SwaptionEngine__SWIG_2(long jarg1, G2 jarg1_, long jarg2, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdG2SwaptionEngine__SWIG_3(long jarg1, G2 jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdG2SwaptionEngine__SWIG_4(long jarg1, G2 jarg1_, long jarg2, long jarg3);
  public final static native long new_FdG2SwaptionEngine__SWIG_5(long jarg1, G2 jarg1_, long jarg2);
  public final static native long new_FdG2SwaptionEngine__SWIG_6(long jarg1, G2 jarg1_);
  public final static native void delete_FdG2SwaptionEngine(long jarg1);
  public final static native long new_FdHullWhiteSwaptionEngine__SWIG_0(long jarg1, HullWhite jarg1_, long jarg2, long jarg3, long jarg4, double jarg5, long jarg6, FdmSchemeDesc jarg6_);
  public final static native long new_FdHullWhiteSwaptionEngine__SWIG_1(long jarg1, HullWhite jarg1_, long jarg2, long jarg3, long jarg4, double jarg5);
  public final static native long new_FdHullWhiteSwaptionEngine__SWIG_2(long jarg1, HullWhite jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native long new_FdHullWhiteSwaptionEngine__SWIG_3(long jarg1, HullWhite jarg1_, long jarg2, long jarg3);
  public final static native long new_FdHullWhiteSwaptionEngine__SWIG_4(long jarg1, HullWhite jarg1_, long jarg2);
  public final static native long new_FdHullWhiteSwaptionEngine__SWIG_5(long jarg1, HullWhite jarg1_);
  public final static native void delete_FdHullWhiteSwaptionEngine(long jarg1);
  public final static native long new_AnalyticBSMHullWhiteEngine(double jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, long jarg3, HullWhite jarg3_);
  public final static native void delete_AnalyticBSMHullWhiteEngine(long jarg1);
  public final static native long new_BondPrice(double jarg1, int jarg2);
  public final static native double BondPrice_amount(long jarg1, BondPrice jarg1_);
  public final static native int BondPrice_type(long jarg1, BondPrice jarg1_);
  public final static native void delete_BondPrice(long jarg1);
  public final static native long new_Bond__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_, long jarg6, Leg jarg6_);
  public final static native long new_Bond__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_, long jarg5, Date jarg5_);
  public final static native long new_Bond__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_);
  public final static native long new_Bond__SWIG_3(long jarg1, long jarg2, Calendar jarg2_, long jarg3, Date jarg3_, long jarg4, Leg jarg4_);
  public final static native long new_Bond__SWIG_4(long jarg1, long jarg2, Calendar jarg2_, long jarg3, Date jarg3_);
  public final static native long new_Bond__SWIG_5(long jarg1, long jarg2, Calendar jarg2_);
  public final static native double Bond_nextCouponRate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double Bond_nextCouponRate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double Bond_previousCouponRate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double Bond_previousCouponRate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native long Bond_settlementDays(long jarg1, Bond jarg1_);
  public final static native long Bond_settlementDate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native long Bond_settlementDate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native long Bond_startDate(long jarg1, Bond jarg1_);
  public final static native long Bond_maturityDate(long jarg1, Bond jarg1_);
  public final static native long Bond_issueDate(long jarg1, Bond jarg1_);
  public final static native long Bond_cashflows(long jarg1, Bond jarg1_);
  public final static native long Bond_redemptions(long jarg1, Bond jarg1_);
  public final static native long Bond_redemption(long jarg1, Bond jarg1_);
  public final static native long Bond_calendar(long jarg1, Bond jarg1_);
  public final static native long Bond_notionals(long jarg1, Bond jarg1_);
  public final static native double Bond_notional__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double Bond_notional__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double Bond_cleanPrice__SWIG_0(long jarg1, Bond jarg1_);
  public final static native double Bond_cleanPrice__SWIG_1(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double Bond_cleanPrice__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double Bond_dirtyPrice__SWIG_0(long jarg1, Bond jarg1_);
  public final static native double Bond_dirtyPrice__SWIG_1(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double Bond_dirtyPrice__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double Bond_yield__SWIG_0(long jarg1, Bond jarg1_, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, double jarg5, long jarg6);
  public final static native double Bond_yield__SWIG_1(long jarg1, Bond jarg1_, long jarg2, DayCounter jarg2_, int jarg3, int jarg4, double jarg5);
  public final static native double Bond_yield__SWIG_2(long jarg1, Bond jarg1_, long jarg2, DayCounter jarg2_, int jarg3, int jarg4);
  public final static native double Bond_yield__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_, double jarg7, long jarg8);
  public final static native double Bond_yield__SWIG_4(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_, double jarg7);
  public final static native double Bond_yield__SWIG_5(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double Bond_yield__SWIG_6(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double Bond_accruedAmount__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double Bond_accruedAmount__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double Bond_settlementValue__SWIG_0(long jarg1, Bond jarg1_);
  public final static native double Bond_settlementValue__SWIG_1(long jarg1, Bond jarg1_, double jarg2);
  public final static native void delete_Bond(long jarg1);
  public final static native void simplifyNotificationGraph__SWIG_2(long jarg1, Bond jarg1_, boolean jarg2);
  public final static native void simplifyNotificationGraph__SWIG_3(long jarg1, Bond jarg1_);
  public final static native double cleanPriceFromZSpread__SWIG_0(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double cleanPriceFromZSpread__SWIG_1(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long sinkingSchedule(long jarg1, Date jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_);
  public final static native long sinkingNotionals(long jarg1, Period jarg1_, int jarg2, double jarg3, double jarg4);
  public final static native long new_ZeroCouponBond__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_, int jarg5, double jarg6, long jarg7, Date jarg7_);
  public final static native long new_ZeroCouponBond__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_, int jarg5, double jarg6);
  public final static native long new_ZeroCouponBond__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_, int jarg5);
  public final static native long new_ZeroCouponBond__SWIG_3(long jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, Date jarg4_);
  public final static native void delete_ZeroCouponBond(long jarg1);
  public final static native long new_FixedRateBond__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Calendar jarg9_, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_, int jarg12, boolean jarg13);
  public final static native long new_FixedRateBond__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Calendar jarg9_, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_, int jarg12);
  public final static native long new_FixedRateBond__SWIG_2(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Calendar jarg9_, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_);
  public final static native long new_FixedRateBond__SWIG_3(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Calendar jarg9_, long jarg10, Period jarg10_);
  public final static native long new_FixedRateBond__SWIG_4(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, Calendar jarg9_);
  public final static native long new_FixedRateBond__SWIG_5(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_);
  public final static native long new_FixedRateBond__SWIG_6(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_FixedRateBond__SWIG_7(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_FixedRateBond__SWIG_8(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_);
  public final static native int FixedRateBond_frequency(long jarg1, FixedRateBond jarg1_);
  public final static native long FixedRateBond_dayCounter(long jarg1, FixedRateBond jarg1_);
  public final static native void delete_FixedRateBond(long jarg1);
  public final static native long new_AmortizingFixedRateBond__SWIG_0(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_, long jarg8, Period jarg8_, long jarg9, Calendar jarg9_, int jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_, int jarg13);
  public final static native long new_AmortizingFixedRateBond__SWIG_1(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_, long jarg8, Period jarg8_, long jarg9, Calendar jarg9_, int jarg10, boolean jarg11, long jarg12, DoubleVector jarg12_);
  public final static native long new_AmortizingFixedRateBond__SWIG_2(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_, long jarg8, Period jarg8_, long jarg9, Calendar jarg9_, int jarg10, boolean jarg11);
  public final static native long new_AmortizingFixedRateBond__SWIG_3(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_, long jarg8, Period jarg8_, long jarg9, Calendar jarg9_, int jarg10);
  public final static native long new_AmortizingFixedRateBond__SWIG_4(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_, long jarg8, Period jarg8_, long jarg9, Calendar jarg9_);
  public final static native long new_AmortizingFixedRateBond__SWIG_5(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_, long jarg8, Period jarg8_);
  public final static native long new_AmortizingFixedRateBond__SWIG_6(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, Date jarg7_);
  public final static native long new_AmortizingFixedRateBond__SWIG_7(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_AmortizingFixedRateBond__SWIG_8(int jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_);
  public final static native int AmortizingFixedRateBond_frequency(long jarg1, AmortizingFixedRateBond jarg1_);
  public final static native long AmortizingFixedRateBond_dayCounter(long jarg1, AmortizingFixedRateBond jarg1_);
  public final static native void delete_AmortizingFixedRateBond(long jarg1);
  public final static native long new_AmortizingFloatingRateBond__SWIG_0(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_, int jarg16, boolean jarg17, long jarg18, DoubleVector jarg18_, int jarg19);
  public final static native long new_AmortizingFloatingRateBond__SWIG_1(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_, int jarg16, boolean jarg17, long jarg18, DoubleVector jarg18_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_2(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_, int jarg16, boolean jarg17);
  public final static native long new_AmortizingFloatingRateBond__SWIG_3(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_, int jarg16);
  public final static native long new_AmortizingFloatingRateBond__SWIG_4(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_5(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14, Period jarg14_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_6(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_7(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12);
  public final static native long new_AmortizingFloatingRateBond__SWIG_8(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_9(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_10(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_11(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_);
  public final static native long new_AmortizingFloatingRateBond__SWIG_12(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7);
  public final static native long new_AmortizingFloatingRateBond__SWIG_13(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_AmortizingFloatingRateBond__SWIG_14(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void delete_AmortizingFloatingRateBond(long jarg1);
  public final static native long new_FloatingRateBond__SWIG_0(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13, long jarg14, Date jarg14_, long jarg15, Period jarg15_, long jarg16, Calendar jarg16_, int jarg17, boolean jarg18);
  public final static native long new_FloatingRateBond__SWIG_1(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13, long jarg14, Date jarg14_, long jarg15, Period jarg15_, long jarg16, Calendar jarg16_, int jarg17);
  public final static native long new_FloatingRateBond__SWIG_2(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13, long jarg14, Date jarg14_, long jarg15, Period jarg15_, long jarg16, Calendar jarg16_);
  public final static native long new_FloatingRateBond__SWIG_3(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13, long jarg14, Date jarg14_, long jarg15, Period jarg15_);
  public final static native long new_FloatingRateBond__SWIG_4(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13, long jarg14, Date jarg14_);
  public final static native long new_FloatingRateBond__SWIG_5(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13);
  public final static native long new_FloatingRateBond__SWIG_6(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12);
  public final static native long new_FloatingRateBond__SWIG_7(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native long new_FloatingRateBond__SWIG_8(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long new_FloatingRateBond__SWIG_9(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long new_FloatingRateBond__SWIG_10(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_);
  public final static native long new_FloatingRateBond__SWIG_11(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7);
  public final static native long new_FloatingRateBond__SWIG_12(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_FloatingRateBond__SWIG_13(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, IborIndex jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void delete_FloatingRateBond(long jarg1);
  public final static native long new_CmsRateBond__SWIG_0(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13, long jarg14, Date jarg14_);
  public final static native long new_CmsRateBond__SWIG_1(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, double jarg13);
  public final static native long new_CmsRateBond__SWIG_2(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12);
  public final static native long new_CmsRateBond__SWIG_3(long jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native void delete_CmsRateBond(long jarg1);
  public final static native long new_AmortizingCmsRateBond__SWIG_0(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_AmortizingCmsRateBond__SWIG_1(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_, boolean jarg12);
  public final static native long new_AmortizingCmsRateBond__SWIG_2(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_, long jarg11, DoubleVector jarg11_);
  public final static native long new_AmortizingCmsRateBond__SWIG_3(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native long new_AmortizingCmsRateBond__SWIG_4(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DoubleVector jarg9_);
  public final static native long new_AmortizingCmsRateBond__SWIG_5(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7, long jarg8, DoubleVector jarg8_);
  public final static native long new_AmortizingCmsRateBond__SWIG_6(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6, long jarg7);
  public final static native long new_AmortizingCmsRateBond__SWIG_7(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_AmortizingCmsRateBond__SWIG_8(long jarg1, long jarg2, DoubleVector jarg2_, long jarg3, Schedule jarg3_, long jarg4, SwapIndex jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void delete_AmortizingCmsRateBond(long jarg1);
  public final static native long new_DiscountingBondEngine(long jarg1, YieldTermStructureHandle jarg1_);
  public final static native void delete_DiscountingBondEngine(long jarg1);
  public final static native long new_Callability(long jarg1, BondPrice jarg1_, int jarg2, long jarg3, Date jarg3_);
  public final static native long Callability_price(long jarg1, Callability jarg1_);
  public final static native int Callability_type(long jarg1, Callability jarg1_);
  public final static native long Callability_date(long jarg1, Callability jarg1_);
  public final static native void delete_Callability(long jarg1);
  public final static native long new_SoftCallability(long jarg1, BondPrice jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native void delete_SoftCallability(long jarg1);
  public final static native long new_CallabilitySchedule__SWIG_0();
  public final static native long new_CallabilitySchedule__SWIG_1(long jarg1, CallabilitySchedule jarg1_);
  public final static native long CallabilitySchedule_capacity(long jarg1, CallabilitySchedule jarg1_);
  public final static native void CallabilitySchedule_reserve(long jarg1, CallabilitySchedule jarg1_, long jarg2);
  public final static native boolean CallabilitySchedule_isEmpty(long jarg1, CallabilitySchedule jarg1_);
  public final static native void CallabilitySchedule_clear(long jarg1, CallabilitySchedule jarg1_);
  public final static native long new_CallabilitySchedule__SWIG_2(int jarg1, long jarg2, Callability jarg2_);
  public final static native int CallabilitySchedule_doSize(long jarg1, CallabilitySchedule jarg1_);
  public final static native void CallabilitySchedule_doAdd__SWIG_0(long jarg1, CallabilitySchedule jarg1_, long jarg2, Callability jarg2_);
  public final static native void CallabilitySchedule_doAdd__SWIG_1(long jarg1, CallabilitySchedule jarg1_, int jarg2, long jarg3, Callability jarg3_);
  public final static native long CallabilitySchedule_doRemove(long jarg1, CallabilitySchedule jarg1_, int jarg2);
  public final static native long CallabilitySchedule_doGet(long jarg1, CallabilitySchedule jarg1_, int jarg2);
  public final static native long CallabilitySchedule_doSet(long jarg1, CallabilitySchedule jarg1_, int jarg2, long jarg3, Callability jarg3_);
  public final static native void CallabilitySchedule_doRemoveRange(long jarg1, CallabilitySchedule jarg1_, int jarg2, int jarg3);
  public final static native void delete_CallabilitySchedule(long jarg1);
  public final static native long CallableBond_callability(long jarg1, CallableBond jarg1_);
  public final static native double CallableBond_impliedVolatility(long jarg1, CallableBond jarg1_, long jarg2, BondPrice jarg2_, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, long jarg5, double jarg6, double jarg7);
  public final static native double CallableBond_OAS__SWIG_0(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, double jarg10);
  public final static native double CallableBond_OAS__SWIG_1(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9);
  public final static native double CallableBond_OAS__SWIG_2(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double CallableBond_OAS__SWIG_3(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double CallableBond_OAS__SWIG_4(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double CallableBond_cleanPriceOAS__SWIG_0(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double CallableBond_cleanPriceOAS__SWIG_1(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double CallableBond_effectiveDuration__SWIG_0(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, double jarg7);
  public final static native double CallableBond_effectiveDuration__SWIG_1(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double CallableBond_effectiveConvexity__SWIG_0(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, double jarg7);
  public final static native double CallableBond_effectiveConvexity__SWIG_1(long jarg1, CallableBond jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native void delete_CallableBond(long jarg1);
  public final static native long new_CallableFixedRateBond__SWIG_0(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, CallabilitySchedule jarg9_, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_, int jarg12, boolean jarg13);
  public final static native long new_CallableFixedRateBond__SWIG_1(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, CallabilitySchedule jarg9_, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_, int jarg12);
  public final static native long new_CallableFixedRateBond__SWIG_2(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, CallabilitySchedule jarg9_, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_);
  public final static native long new_CallableFixedRateBond__SWIG_3(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, CallabilitySchedule jarg9_, long jarg10, Period jarg10_);
  public final static native long new_CallableFixedRateBond__SWIG_4(int jarg1, double jarg2, long jarg3, Schedule jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, CallabilitySchedule jarg9_);
  public final static native void delete_CallableFixedRateBond(long jarg1);
  public final static native long new_CallableZeroCouponBond__SWIG_0(int jarg1, double jarg2, long jarg3, Calendar jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_, long jarg9, CallabilitySchedule jarg9_);
  public final static native long new_CallableZeroCouponBond__SWIG_1(int jarg1, double jarg2, long jarg3, Calendar jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7, long jarg8, Date jarg8_);
  public final static native long new_CallableZeroCouponBond__SWIG_2(int jarg1, double jarg2, long jarg3, Calendar jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_, int jarg6, double jarg7);
  public final static native long new_CallableZeroCouponBond__SWIG_3(int jarg1, double jarg2, long jarg3, Calendar jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_CallableZeroCouponBond__SWIG_4(int jarg1, double jarg2, long jarg3, Calendar jarg3_, long jarg4, Date jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void delete_CallableZeroCouponBond(long jarg1);
  public final static native long new_TreeCallableFixedRateBondEngine__SWIG_0(long jarg1, ShortRateModel jarg1_, long jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeCallableFixedRateBondEngine__SWIG_1(long jarg1, ShortRateModel jarg1_, long jarg2);
  public final static native long new_TreeCallableFixedRateBondEngine__SWIG_2(long jarg1, ShortRateModel jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native long new_TreeCallableFixedRateBondEngine__SWIG_3(long jarg1, ShortRateModel jarg1_, long jarg2, TimeGrid jarg2_);
  public final static native void delete_TreeCallableFixedRateBondEngine(long jarg1);
  public final static native long new_BlackCallableFixedRateBondEngine(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_BlackCallableFixedRateBondEngine(long jarg1);
  public final static native long new_CPIBond__SWIG_0(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11, long jarg12, Date jarg12_, long jarg13, Calendar jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_, int jarg16, boolean jarg17);
  public final static native long new_CPIBond__SWIG_1(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11, long jarg12, Date jarg12_, long jarg13, Calendar jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_, int jarg16);
  public final static native long new_CPIBond__SWIG_2(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11, long jarg12, Date jarg12_, long jarg13, Calendar jarg13_, long jarg14, Period jarg14_, long jarg15, Calendar jarg15_);
  public final static native long new_CPIBond__SWIG_3(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11, long jarg12, Date jarg12_, long jarg13, Calendar jarg13_, long jarg14, Period jarg14_);
  public final static native long new_CPIBond__SWIG_4(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11, long jarg12, Date jarg12_, long jarg13, Calendar jarg13_);
  public final static native long new_CPIBond__SWIG_5(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11, long jarg12, Date jarg12_);
  public final static native long new_CPIBond__SWIG_6(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_, int jarg11);
  public final static native long new_CPIBond__SWIG_7(long jarg1, double jarg2, boolean jarg3, double jarg4, long jarg5, Period jarg5_, long jarg6, ZeroInflationIndex jarg6_, int jarg7, long jarg8, Schedule jarg8_, long jarg9, DoubleVector jarg9_, long jarg10, DayCounter jarg10_);
  public final static native void delete_CPIBond(long jarg1);
  public final static native long BondFunctions_startDate(long jarg1, Bond jarg1_);
  public final static native long BondFunctions_maturityDate(long jarg1, Bond jarg1_);
  public final static native boolean BondFunctions_isTradable__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native boolean BondFunctions_isTradable__SWIG_1(long jarg1, Bond jarg1_);
  public final static native long BondFunctions_previousCashFlowDate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native long BondFunctions_previousCashFlowDate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native long BondFunctions_nextCashFlowDate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native long BondFunctions_nextCashFlowDate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_previousCashFlowAmount__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_previousCashFlowAmount__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_nextCashFlowAmount__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_nextCashFlowAmount__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_previousCouponRate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_previousCouponRate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_nextCouponRate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_nextCouponRate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native long BondFunctions_accrualStartDate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native long BondFunctions_accrualStartDate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native long BondFunctions_accrualEndDate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native long BondFunctions_accrualEndDate__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_accrualPeriod__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_accrualPeriod__SWIG_1(long jarg1, Bond jarg1_);
  public final static native int BondFunctions_accrualDays__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native int BondFunctions_accrualDays__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_accruedPeriod__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_accruedPeriod__SWIG_1(long jarg1, Bond jarg1_);
  public final static native int BondFunctions_accruedDays__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native int BondFunctions_accruedDays__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_accruedAmount__SWIG_0(long jarg1, Bond jarg1_, long jarg2, Date jarg2_);
  public final static native double BondFunctions_accruedAmount__SWIG_1(long jarg1, Bond jarg1_);
  public final static native double BondFunctions_cleanPrice__SWIG_0(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_cleanPrice__SWIG_1(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native double BondFunctions_bps__SWIG_0(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_bps__SWIG_1(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native double BondFunctions_atmRate__SWIG_0(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double BondFunctions_atmRate__SWIG_1(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_atmRate__SWIG_2(long jarg1, Bond jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native double BondFunctions_cleanPrice__SWIG_2(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_cleanPrice__SWIG_3(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_);
  public final static native double BondFunctions_cleanPrice__SWIG_4(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double BondFunctions_cleanPrice__SWIG_5(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_bps__SWIG_2(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_bps__SWIG_3(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_);
  public final static native double BondFunctions_bps__SWIG_4(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double BondFunctions_bps__SWIG_5(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_yield__SWIG_0(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_, double jarg7, long jarg8, double jarg9);
  public final static native double BondFunctions_yield__SWIG_1(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_, double jarg7, long jarg8);
  public final static native double BondFunctions_yield__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_, double jarg7);
  public final static native double BondFunctions_yield__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double BondFunctions_yield__SWIG_4(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_duration__SWIG_0(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, int jarg3, long jarg4, Date jarg4_);
  public final static native double BondFunctions_duration__SWIG_1(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, int jarg3);
  public final static native double BondFunctions_duration__SWIG_2(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_);
  public final static native double BondFunctions_duration__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_duration__SWIG_4(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, int jarg6);
  public final static native double BondFunctions_duration__SWIG_5(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_convexity__SWIG_0(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_convexity__SWIG_1(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_);
  public final static native double BondFunctions_convexity__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double BondFunctions_convexity__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_basisPointValue__SWIG_0(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_basisPointValue__SWIG_1(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_);
  public final static native double BondFunctions_basisPointValue__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double BondFunctions_basisPointValue__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_yieldValueBasisPoint__SWIG_0(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_, long jarg3, Date jarg3_);
  public final static native double BondFunctions_yieldValueBasisPoint__SWIG_1(long jarg1, Bond jarg1_, long jarg2, InterestRate jarg2_);
  public final static native double BondFunctions_yieldValueBasisPoint__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5, long jarg6, Date jarg6_);
  public final static native double BondFunctions_yieldValueBasisPoint__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, DayCounter jarg3_, int jarg4, int jarg5);
  public final static native double BondFunctions_zSpread__SWIG_0(long jarg1, Bond jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, double jarg10);
  public final static native double BondFunctions_zSpread__SWIG_1(long jarg1, Bond jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9);
  public final static native double BondFunctions_zSpread__SWIG_2(long jarg1, Bond jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double BondFunctions_zSpread__SWIG_3(long jarg1, Bond jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_zSpread__SWIG_4(long jarg1, Bond jarg1_, double jarg2, long jarg3, YieldTermStructure jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double BondFunctions_yieldBrent__SWIG_0(long jarg1, Brent jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, double jarg9);
  public final static native double BondFunctions_yieldBrent__SWIG_1(long jarg1, Brent jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double BondFunctions_yieldBrent__SWIG_2(long jarg1, Brent jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_yieldBrent__SWIG_3(long jarg1, Brent jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double BondFunctions_yieldBisection__SWIG_0(long jarg1, Bisection jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, double jarg9);
  public final static native double BondFunctions_yieldBisection__SWIG_1(long jarg1, Bisection jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double BondFunctions_yieldBisection__SWIG_2(long jarg1, Bisection jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_yieldBisection__SWIG_3(long jarg1, Bisection jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double BondFunctions_yieldFalsePosition__SWIG_0(long jarg1, FalsePosition jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, double jarg9);
  public final static native double BondFunctions_yieldFalsePosition__SWIG_1(long jarg1, FalsePosition jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double BondFunctions_yieldFalsePosition__SWIG_2(long jarg1, FalsePosition jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_yieldFalsePosition__SWIG_3(long jarg1, FalsePosition jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double BondFunctions_yieldRidder__SWIG_0(long jarg1, Ridder jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, double jarg9);
  public final static native double BondFunctions_yieldRidder__SWIG_1(long jarg1, Ridder jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double BondFunctions_yieldRidder__SWIG_2(long jarg1, Ridder jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_yieldRidder__SWIG_3(long jarg1, Ridder jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native double BondFunctions_yieldSecant__SWIG_0(long jarg1, Secant jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8, double jarg9);
  public final static native double BondFunctions_yieldSecant__SWIG_1(long jarg1, Secant jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double BondFunctions_yieldSecant__SWIG_2(long jarg1, Secant jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6, long jarg7, Date jarg7_);
  public final static native double BondFunctions_yieldSecant__SWIG_3(long jarg1, Secant jarg1_, long jarg2, Bond jarg2_, double jarg3, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long new_BondFunctions();
  public final static native void delete_BondFunctions(long jarg1);
  public final static native void BlackCalibrationHelper_setPricingEngine(long jarg1, BlackCalibrationHelper jarg1_, long jarg2, PricingEngine jarg2_);
  public final static native double BlackCalibrationHelper_marketValue(long jarg1, BlackCalibrationHelper jarg1_);
  public final static native double BlackCalibrationHelper_modelValue(long jarg1, BlackCalibrationHelper jarg1_);
  public final static native double BlackCalibrationHelper_impliedVolatility(long jarg1, BlackCalibrationHelper jarg1_, double jarg2, double jarg3, long jarg4, double jarg5, double jarg6);
  public final static native double BlackCalibrationHelper_blackPrice(long jarg1, BlackCalibrationHelper jarg1_, double jarg2);
  public final static native long BlackCalibrationHelper_volatility(long jarg1, BlackCalibrationHelper jarg1_);
  public final static native int BlackCalibrationHelper_volatilityType(long jarg1, BlackCalibrationHelper jarg1_);
  public final static native double BlackCalibrationHelper_calibrationError(long jarg1, BlackCalibrationHelper jarg1_);
  public final static native void delete_BlackCalibrationHelper(long jarg1);
  public final static native long as_black_helper(long jarg1, CalibrationHelper jarg1_);
  public final static native long as_swaption_helper(long jarg1, BlackCalibrationHelper jarg1_);
  public final static native long new_SwaptionHelper__SWIG_0(long jarg1, Period jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11, int jarg12, double jarg13);
  public final static native long new_SwaptionHelper__SWIG_1(long jarg1, Period jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11, int jarg12);
  public final static native long new_SwaptionHelper__SWIG_2(long jarg1, Period jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11);
  public final static native long new_SwaptionHelper__SWIG_3(long jarg1, Period jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10);
  public final static native long new_SwaptionHelper__SWIG_4(long jarg1, Period jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9);
  public final static native long new_SwaptionHelper__SWIG_5(long jarg1, Period jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_);
  public final static native long new_SwaptionHelper__SWIG_6(long jarg1, Date jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11, int jarg12, double jarg13);
  public final static native long new_SwaptionHelper__SWIG_7(long jarg1, Date jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11, int jarg12);
  public final static native long new_SwaptionHelper__SWIG_8(long jarg1, Date jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11);
  public final static native long new_SwaptionHelper__SWIG_9(long jarg1, Date jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10);
  public final static native long new_SwaptionHelper__SWIG_10(long jarg1, Date jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9);
  public final static native long new_SwaptionHelper__SWIG_11(long jarg1, Date jarg1_, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_);
  public final static native long new_SwaptionHelper__SWIG_12(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11, int jarg12, double jarg13);
  public final static native long new_SwaptionHelper__SWIG_13(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11, int jarg12);
  public final static native long new_SwaptionHelper__SWIG_14(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10, double jarg11);
  public final static native long new_SwaptionHelper__SWIG_15(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9, double jarg10);
  public final static native long new_SwaptionHelper__SWIG_16(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_, int jarg9);
  public final static native long new_SwaptionHelper__SWIG_17(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, IborIndex jarg4_, long jarg5, Period jarg5_, long jarg6, DayCounter jarg6_, long jarg7, DayCounter jarg7_, long jarg8, YieldTermStructureHandle jarg8_);
  public final static native long SwaptionHelper_underlyingSwap(long jarg1, SwaptionHelper jarg1_);
  public final static native long SwaptionHelper_swaption(long jarg1, SwaptionHelper jarg1_);
  public final static native long SwaptionHelper_times(long jarg1, SwaptionHelper jarg1_);
  public final static native long SwaptionHelper_swaptionExpiryDate(long jarg1, SwaptionHelper jarg1_);
  public final static native double SwaptionHelper_swaptionStrike(long jarg1, SwaptionHelper jarg1_);
  public final static native double SwaptionHelper_swaptionNominal(long jarg1, SwaptionHelper jarg1_);
  public final static native long SwaptionHelper_swaptionMaturityDate(long jarg1, SwaptionHelper jarg1_);
  public final static native void delete_SwaptionHelper(long jarg1);
  public final static native long new_CapHelper__SWIG_0(long jarg1, Period jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, DayCounter jarg5_, boolean jarg6, long jarg7, YieldTermStructureHandle jarg7_, int jarg8, int jarg9, double jarg10);
  public final static native long new_CapHelper__SWIG_1(long jarg1, Period jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, DayCounter jarg5_, boolean jarg6, long jarg7, YieldTermStructureHandle jarg7_, int jarg8, int jarg9);
  public final static native long new_CapHelper__SWIG_2(long jarg1, Period jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, DayCounter jarg5_, boolean jarg6, long jarg7, YieldTermStructureHandle jarg7_, int jarg8);
  public final static native long new_CapHelper__SWIG_3(long jarg1, Period jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, DayCounter jarg5_, boolean jarg6, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native long CapHelper_times(long jarg1, CapHelper jarg1_);
  public final static native void delete_CapHelper(long jarg1);
  public final static native long new_HestonModelHelper__SWIG_0(long jarg1, Period jarg1_, long jarg2, Calendar jarg2_, double jarg3, double jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_, int jarg8);
  public final static native long new_HestonModelHelper__SWIG_1(long jarg1, Period jarg1_, long jarg2, Calendar jarg2_, double jarg3, double jarg4, long jarg5, QuoteHandle jarg5_, long jarg6, YieldTermStructureHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native void delete_HestonModelHelper(long jarg1);
  public final static native long new_BlackCalibrationHelperVector__SWIG_0();
  public final static native long new_BlackCalibrationHelperVector__SWIG_1(long jarg1, BlackCalibrationHelperVector jarg1_);
  public final static native long BlackCalibrationHelperVector_capacity(long jarg1, BlackCalibrationHelperVector jarg1_);
  public final static native void BlackCalibrationHelperVector_reserve(long jarg1, BlackCalibrationHelperVector jarg1_, long jarg2);
  public final static native boolean BlackCalibrationHelperVector_isEmpty(long jarg1, BlackCalibrationHelperVector jarg1_);
  public final static native void BlackCalibrationHelperVector_clear(long jarg1, BlackCalibrationHelperVector jarg1_);
  public final static native long new_BlackCalibrationHelperVector__SWIG_2(int jarg1, long jarg2, BlackCalibrationHelper jarg2_);
  public final static native int BlackCalibrationHelperVector_doSize(long jarg1, BlackCalibrationHelperVector jarg1_);
  public final static native void BlackCalibrationHelperVector_doAdd__SWIG_0(long jarg1, BlackCalibrationHelperVector jarg1_, long jarg2, BlackCalibrationHelper jarg2_);
  public final static native void BlackCalibrationHelperVector_doAdd__SWIG_1(long jarg1, BlackCalibrationHelperVector jarg1_, int jarg2, long jarg3, BlackCalibrationHelper jarg3_);
  public final static native long BlackCalibrationHelperVector_doRemove(long jarg1, BlackCalibrationHelperVector jarg1_, int jarg2);
  public final static native long BlackCalibrationHelperVector_doGet(long jarg1, BlackCalibrationHelperVector jarg1_, int jarg2);
  public final static native long BlackCalibrationHelperVector_doSet(long jarg1, BlackCalibrationHelperVector jarg1_, int jarg2, long jarg3, BlackCalibrationHelper jarg3_);
  public final static native void BlackCalibrationHelperVector_doRemoveRange(long jarg1, BlackCalibrationHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_BlackCalibrationHelperVector(long jarg1);
  public final static native double CapFloor_impliedVolatility__SWIG_0(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8, int jarg9, double jarg10);
  public final static native double CapFloor_impliedVolatility__SWIG_1(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8, int jarg9);
  public final static native double CapFloor_impliedVolatility__SWIG_2(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8);
  public final static native double CapFloor_impliedVolatility__SWIG_3(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7);
  public final static native double CapFloor_impliedVolatility__SWIG_4(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6);
  public final static native double CapFloor_impliedVolatility__SWIG_5(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5);
  public final static native double CapFloor_impliedVolatility__SWIG_6(long jarg1, CapFloor jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4);
  public final static native long CapFloor_floatingLeg(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_capRates(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_floorRates(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_startDate(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_maturityDate(long jarg1, CapFloor jarg1_);
  public final static native int CapFloor_type(long jarg1, CapFloor jarg1_);
  public final static native double CapFloor_atmRate(long jarg1, CapFloor jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native double CapFloor_vega(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_optionletsPrice(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_optionletsVega(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_optionletsDelta(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_optionletsDiscountFactor(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_optionletsAtmForward(long jarg1, CapFloor jarg1_);
  public final static native long CapFloor_optionletsStdDev(long jarg1, CapFloor jarg1_);
  public final static native void delete_CapFloor(long jarg1);
  public final static native long new_Cap(long jarg1, Leg jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_Cap(long jarg1);
  public final static native long new_Floor(long jarg1, Leg jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_Floor(long jarg1);
  public final static native long new_Collar(long jarg1, Leg jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void delete_Collar(long jarg1);
  public final static native long new_BlackCapFloorEngine__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_, double jarg4);
  public final static native long new_BlackCapFloorEngine__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_BlackCapFloorEngine__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native long new_BlackCapFloorEngine__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, OptionletVolatilityStructureHandle jarg2_, double jarg3);
  public final static native long new_BlackCapFloorEngine__SWIG_4(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, OptionletVolatilityStructureHandle jarg2_);
  public final static native void delete_BlackCapFloorEngine(long jarg1);
  public final static native long new_BachelierCapFloorEngine__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native long new_BachelierCapFloorEngine__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, OptionletVolatilityStructureHandle jarg2_);
  public final static native void delete_BachelierCapFloorEngine(long jarg1);
  public final static native long new_CliquetOption(long jarg1, PercentageStrikePayoff jarg1_, long jarg2, EuropeanExercise jarg2_, long jarg3, DateVector jarg3_);
  public final static native void delete_CliquetOption(long jarg1);
  public final static native long new_AnalyticCliquetEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticCliquetEngine(long jarg1);
  public final static native long new_AnalyticPerformanceEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticPerformanceEngine(long jarg1);
  public final static native long new_MCPRPerformanceEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCPRPerformanceEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCPRPerformanceEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCPRPerformanceEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCPRPerformanceEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCPRPerformanceEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCPRPerformanceEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCPRPerformanceEngine(long jarg1);
  public final static native long new_MCLDPerformanceEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6, int jarg7);
  public final static native long new_MCLDPerformanceEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5, int jarg6);
  public final static native long new_MCLDPerformanceEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4, double jarg5);
  public final static native long new_MCLDPerformanceEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3, int jarg4);
  public final static native long new_MCLDPerformanceEngine__SWIG_4(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2, boolean jarg3);
  public final static native long new_MCLDPerformanceEngine__SWIG_5(long jarg1, GeneralizedBlackScholesProcess jarg1_, boolean jarg2);
  public final static native long new_MCLDPerformanceEngine__SWIG_6(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_MCLDPerformanceEngine(long jarg1);
  public final static native long new_ConvertibleZeroCouponBond__SWIG_0(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_, double jarg8);
  public final static native long new_ConvertibleZeroCouponBond__SWIG_1(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, Schedule jarg7_);
  public final static native void delete_ConvertibleZeroCouponBond(long jarg1);
  public final static native long new_ConvertibleFixedCouponBond__SWIG_0(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DayCounter jarg7_, long jarg8, Schedule jarg8_, double jarg9, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_, int jarg12, boolean jarg13);
  public final static native long new_ConvertibleFixedCouponBond__SWIG_1(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DayCounter jarg7_, long jarg8, Schedule jarg8_, double jarg9, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_, int jarg12);
  public final static native long new_ConvertibleFixedCouponBond__SWIG_2(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DayCounter jarg7_, long jarg8, Schedule jarg8_, double jarg9, long jarg10, Period jarg10_, long jarg11, Calendar jarg11_);
  public final static native long new_ConvertibleFixedCouponBond__SWIG_3(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DayCounter jarg7_, long jarg8, Schedule jarg8_, double jarg9, long jarg10, Period jarg10_);
  public final static native long new_ConvertibleFixedCouponBond__SWIG_4(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DayCounter jarg7_, long jarg8, Schedule jarg8_, double jarg9);
  public final static native long new_ConvertibleFixedCouponBond__SWIG_5(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, DoubleVector jarg6_, long jarg7, DayCounter jarg7_, long jarg8, Schedule jarg8_);
  public final static native void delete_ConvertibleFixedCouponBond(long jarg1);
  public final static native long new_ConvertibleFloatingRateBond__SWIG_0(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DayCounter jarg9_, long jarg10, Schedule jarg10_, double jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14, boolean jarg15);
  public final static native long new_ConvertibleFloatingRateBond__SWIG_1(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DayCounter jarg9_, long jarg10, Schedule jarg10_, double jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_, int jarg14);
  public final static native long new_ConvertibleFloatingRateBond__SWIG_2(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DayCounter jarg9_, long jarg10, Schedule jarg10_, double jarg11, long jarg12, Period jarg12_, long jarg13, Calendar jarg13_);
  public final static native long new_ConvertibleFloatingRateBond__SWIG_3(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DayCounter jarg9_, long jarg10, Schedule jarg10_, double jarg11, long jarg12, Period jarg12_);
  public final static native long new_ConvertibleFloatingRateBond__SWIG_4(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DayCounter jarg9_, long jarg10, Schedule jarg10_, double jarg11);
  public final static native long new_ConvertibleFloatingRateBond__SWIG_5(long jarg1, Exercise jarg1_, double jarg2, long jarg3, CallabilitySchedule jarg3_, long jarg4, Date jarg4_, int jarg5, long jarg6, IborIndex jarg6_, int jarg7, long jarg8, DoubleVector jarg8_, long jarg9, DayCounter jarg9_, long jarg10, Schedule jarg10_);
  public final static native void delete_ConvertibleFloatingRateBond(long jarg1);
  public final static native long new_BinomialCRRConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialCRRConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialCRRConvertibleEngine(long jarg1);
  public final static native long new_BinomialJRConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialJRConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialJRConvertibleEngine(long jarg1);
  public final static native long new_BinomialEQPConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialEQPConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialEQPConvertibleEngine(long jarg1);
  public final static native long new_BinomialTrigeorgisConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialTrigeorgisConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialTrigeorgisConvertibleEngine(long jarg1);
  public final static native long new_BinomialTianConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialTianConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialTianConvertibleEngine(long jarg1);
  public final static native long new_BinomialLRConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialLRConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialLRConvertibleEngine(long jarg1);
  public final static native long new_BinomialJ4ConvertibleEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_, long jarg4, DividendSchedule jarg4_);
  public final static native long new_BinomialJ4ConvertibleEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_BinomialJ4ConvertibleEngine(long jarg1);
  public final static native long Forward_settlementDate(long jarg1, Forward jarg1_);
  public final static native boolean Forward_isExpired(long jarg1, Forward jarg1_);
  public final static native long Forward_calendar(long jarg1, Forward jarg1_);
  public final static native int Forward_businessDayConvention(long jarg1, Forward jarg1_);
  public final static native long Forward_dayCounter(long jarg1, Forward jarg1_);
  public final static native long Forward_discountCurve(long jarg1, Forward jarg1_);
  public final static native long Forward_incomeDiscountCurve(long jarg1, Forward jarg1_);
  public final static native double Forward_spotValue(long jarg1, Forward jarg1_);
  public final static native double Forward_spotIncome(long jarg1, Forward jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native double Forward_forwardValue(long jarg1, Forward jarg1_);
  public final static native long Forward_impliedYield(long jarg1, Forward jarg1_, double jarg2, double jarg3, long jarg4, Date jarg4_, int jarg5, long jarg6, DayCounter jarg6_);
  public final static native void delete_Forward(long jarg1);
  public final static native long new_BondForward__SWIG_0(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, long jarg5, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, Bond jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, YieldTermStructureHandle jarg11_);
  public final static native long new_BondForward__SWIG_1(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, long jarg5, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, Bond jarg9_, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native long new_BondForward__SWIG_2(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, long jarg5, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, Bond jarg9_);
  public final static native double BondForward_forwardPrice(long jarg1, BondForward jarg1_);
  public final static native double BondForward_cleanForwardPrice(long jarg1, BondForward jarg1_);
  public final static native void delete_BondForward(long jarg1);
  public final static native long new_FixedRateBondForward__SWIG_0(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, long jarg5, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, FixedRateBond jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, YieldTermStructureHandle jarg11_);
  public final static native long new_FixedRateBondForward__SWIG_1(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, long jarg5, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, FixedRateBond jarg9_, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native long new_FixedRateBondForward__SWIG_2(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, long jarg5, long jarg6, DayCounter jarg6_, long jarg7, Calendar jarg7_, int jarg8, long jarg9, FixedRateBond jarg9_);
  public final static native void delete_FixedRateBondForward(long jarg1);
  public final static native long new_Futures();
  public final static native void delete_Futures(long jarg1);
  public final static native long new_OvernightIndexFuture__SWIG_0(long jarg1, OvernightIndex jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, QuoteHandle jarg4_, int jarg5);
  public final static native long new_OvernightIndexFuture__SWIG_1(long jarg1, OvernightIndex jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_OvernightIndexFuture__SWIG_2(long jarg1, OvernightIndex jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double OvernightIndexFuture_convexityAdjustment(long jarg1, OvernightIndexFuture jarg1_);
  public final static native void delete_OvernightIndexFuture(long jarg1);
  public final static native long new_Pillar();
  public final static native void delete_Pillar(long jarg1);
  public final static native long RateHelper_quote(long jarg1, RateHelper jarg1_);
  public final static native long RateHelper_latestDate(long jarg1, RateHelper jarg1_);
  public final static native long RateHelper_earliestDate(long jarg1, RateHelper jarg1_);
  public final static native long RateHelper_maturityDate(long jarg1, RateHelper jarg1_);
  public final static native long RateHelper_latestRelevantDate(long jarg1, RateHelper jarg1_);
  public final static native long RateHelper_pillarDate(long jarg1, RateHelper jarg1_);
  public final static native double RateHelper_impliedQuote(long jarg1, RateHelper jarg1_);
  public final static native double RateHelper_quoteError(long jarg1, RateHelper jarg1_);
  public final static native void delete_RateHelper(long jarg1);
  public final static native long new_DepositRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_);
  public final static native long new_DepositRateHelper__SWIG_1(double jarg1, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_);
  public final static native long new_DepositRateHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, IborIndex jarg2_);
  public final static native long new_DepositRateHelper__SWIG_3(double jarg1, long jarg2, IborIndex jarg2_);
  public final static native void delete_DepositRateHelper(long jarg1);
  public final static native long new_FraRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, int jarg9, long jarg10, Date jarg10_, boolean jarg11);
  public final static native long new_FraRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, int jarg9, long jarg10, Date jarg10_);
  public final static native long new_FraRateHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, int jarg9);
  public final static native long new_FraRateHelper__SWIG_3(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_);
  public final static native long new_FraRateHelper__SWIG_4(double jarg1, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, int jarg9, long jarg10, Date jarg10_, boolean jarg11);
  public final static native long new_FraRateHelper__SWIG_5(double jarg1, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, int jarg9, long jarg10, Date jarg10_);
  public final static native long new_FraRateHelper__SWIG_6(double jarg1, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_, int jarg9);
  public final static native long new_FraRateHelper__SWIG_7(double jarg1, long jarg2, long jarg3, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, long jarg8, DayCounter jarg8_);
  public final static native long new_FraRateHelper__SWIG_8(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_, boolean jarg6);
  public final static native long new_FraRateHelper__SWIG_9(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_);
  public final static native long new_FraRateHelper__SWIG_10(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, IborIndex jarg3_, int jarg4);
  public final static native long new_FraRateHelper__SWIG_11(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, IborIndex jarg3_);
  public final static native long new_FraRateHelper__SWIG_12(double jarg1, long jarg2, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_, boolean jarg6);
  public final static native long new_FraRateHelper__SWIG_13(double jarg1, long jarg2, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_);
  public final static native long new_FraRateHelper__SWIG_14(double jarg1, long jarg2, long jarg3, IborIndex jarg3_, int jarg4);
  public final static native long new_FraRateHelper__SWIG_15(double jarg1, long jarg2, long jarg3, IborIndex jarg3_);
  public final static native long new_FraRateHelper__SWIG_16(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, IborIndex jarg4_, int jarg5, long jarg6, Date jarg6_, boolean jarg7);
  public final static native long new_FraRateHelper__SWIG_17(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, IborIndex jarg4_, int jarg5, long jarg6, Date jarg6_);
  public final static native long new_FraRateHelper__SWIG_18(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, IborIndex jarg4_, int jarg5);
  public final static native long new_FraRateHelper__SWIG_19(long jarg1, QuoteHandle jarg1_, long jarg2, long jarg3, long jarg4, IborIndex jarg4_);
  public final static native long new_FraRateHelper__SWIG_20(double jarg1, long jarg2, long jarg3, long jarg4, IborIndex jarg4_, int jarg5, long jarg6, Date jarg6_, boolean jarg7);
  public final static native long new_FraRateHelper__SWIG_21(double jarg1, long jarg2, long jarg3, long jarg4, IborIndex jarg4_, int jarg5, long jarg6, Date jarg6_);
  public final static native long new_FraRateHelper__SWIG_22(double jarg1, long jarg2, long jarg3, long jarg4, IborIndex jarg4_, int jarg5);
  public final static native long new_FraRateHelper__SWIG_23(double jarg1, long jarg2, long jarg3, long jarg4, IborIndex jarg4_);
  public final static native long new_FraRateHelper__SWIG_24(double jarg1, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_, boolean jarg6);
  public final static native long new_FraRateHelper__SWIG_25(double jarg1, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_);
  public final static native long new_FraRateHelper__SWIG_26(double jarg1, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_, int jarg4);
  public final static native long new_FraRateHelper__SWIG_27(double jarg1, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_);
  public final static native long new_FraRateHelper__SWIG_28(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_, boolean jarg6);
  public final static native long new_FraRateHelper__SWIG_29(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_, int jarg4, long jarg5, Date jarg5_);
  public final static native long new_FraRateHelper__SWIG_30(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_, int jarg4);
  public final static native long new_FraRateHelper__SWIG_31(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, IborIndex jarg3_);
  public final static native void delete_FraRateHelper(long jarg1);
  public final static native long new_FuturesRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_, long jarg8, QuoteHandle jarg8_, int jarg9);
  public final static native long new_FuturesRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_, long jarg8, QuoteHandle jarg8_);
  public final static native long new_FuturesRateHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_);
  public final static native long new_FuturesRateHelper__SWIG_3(double jarg1, long jarg2, Date jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_, double jarg8, int jarg9);
  public final static native long new_FuturesRateHelper__SWIG_4(double jarg1, long jarg2, Date jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_, double jarg8);
  public final static native long new_FuturesRateHelper__SWIG_5(double jarg1, long jarg2, Date jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, DayCounter jarg7_);
  public final static native long new_FuturesRateHelper__SWIG_6(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandle jarg5_, int jarg6);
  public final static native long new_FuturesRateHelper__SWIG_7(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandle jarg5_);
  public final static native long new_FuturesRateHelper__SWIG_8(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_FuturesRateHelper__SWIG_9(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, double jarg5, int jarg6);
  public final static native long new_FuturesRateHelper__SWIG_10(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, double jarg5);
  public final static native long new_FuturesRateHelper__SWIG_11(double jarg1, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_FuturesRateHelper__SWIG_12(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, IborIndex jarg3_, long jarg4, QuoteHandle jarg4_, int jarg5);
  public final static native long new_FuturesRateHelper__SWIG_13(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, IborIndex jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_FuturesRateHelper__SWIG_14(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, IborIndex jarg3_);
  public final static native long new_FuturesRateHelper__SWIG_15(double jarg1, long jarg2, Date jarg2_, long jarg3, IborIndex jarg3_, double jarg4, int jarg5);
  public final static native long new_FuturesRateHelper__SWIG_16(double jarg1, long jarg2, Date jarg2_, long jarg3, IborIndex jarg3_, double jarg4);
  public final static native long new_FuturesRateHelper__SWIG_17(double jarg1, long jarg2, Date jarg2_, long jarg3, IborIndex jarg3_);
  public final static native void delete_FuturesRateHelper(long jarg1);
  public final static native long new_SwapRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12, long jarg13, Date jarg13_, boolean jarg14, long jarg15, OptionalBool jarg15_);
  public final static native long new_SwapRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12, long jarg13, Date jarg13_, boolean jarg14);
  public final static native long new_SwapRateHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12, long jarg13, Date jarg13_);
  public final static native long new_SwapRateHelper__SWIG_3(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12);
  public final static native long new_SwapRateHelper__SWIG_4(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11);
  public final static native long new_SwapRateHelper__SWIG_5(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native long new_SwapRateHelper__SWIG_6(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_);
  public final static native long new_SwapRateHelper__SWIG_7(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_);
  public final static native long new_SwapRateHelper__SWIG_8(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_);
  public final static native long new_SwapRateHelper__SWIG_9(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12, long jarg13, Date jarg13_, boolean jarg14, long jarg15, OptionalBool jarg15_);
  public final static native long new_SwapRateHelper__SWIG_10(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12, long jarg13, Date jarg13_, boolean jarg14);
  public final static native long new_SwapRateHelper__SWIG_11(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12, long jarg13, Date jarg13_);
  public final static native long new_SwapRateHelper__SWIG_12(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11, int jarg12);
  public final static native long new_SwapRateHelper__SWIG_13(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_, long jarg11);
  public final static native long new_SwapRateHelper__SWIG_14(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native long new_SwapRateHelper__SWIG_15(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_, long jarg9, Period jarg9_);
  public final static native long new_SwapRateHelper__SWIG_16(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_, long jarg8, QuoteHandle jarg8_);
  public final static native long new_SwapRateHelper__SWIG_17(double jarg1, long jarg2, Period jarg2_, long jarg3, Calendar jarg3_, int jarg4, int jarg5, long jarg6, DayCounter jarg6_, long jarg7, IborIndex jarg7_);
  public final static native long new_SwapRateHelper__SWIG_18(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6, long jarg7, Date jarg7_, boolean jarg8, long jarg9, OptionalBool jarg9_);
  public final static native long new_SwapRateHelper__SWIG_19(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6, long jarg7, Date jarg7_, boolean jarg8);
  public final static native long new_SwapRateHelper__SWIG_20(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6, long jarg7, Date jarg7_);
  public final static native long new_SwapRateHelper__SWIG_21(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6);
  public final static native long new_SwapRateHelper__SWIG_22(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_);
  public final static native long new_SwapRateHelper__SWIG_23(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_);
  public final static native long new_SwapRateHelper__SWIG_24(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_);
  public final static native long new_SwapRateHelper__SWIG_25(long jarg1, QuoteHandle jarg1_, long jarg2, SwapIndex jarg2_);
  public final static native long new_SwapRateHelper__SWIG_26(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6, long jarg7, Date jarg7_, boolean jarg8, long jarg9, OptionalBool jarg9_);
  public final static native long new_SwapRateHelper__SWIG_27(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6, long jarg7, Date jarg7_, boolean jarg8);
  public final static native long new_SwapRateHelper__SWIG_28(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6, long jarg7, Date jarg7_);
  public final static native long new_SwapRateHelper__SWIG_29(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_, int jarg6);
  public final static native long new_SwapRateHelper__SWIG_30(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_, long jarg5, YieldTermStructureHandle jarg5_);
  public final static native long new_SwapRateHelper__SWIG_31(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, Period jarg4_);
  public final static native long new_SwapRateHelper__SWIG_32(double jarg1, long jarg2, SwapIndex jarg2_, long jarg3, QuoteHandle jarg3_);
  public final static native long new_SwapRateHelper__SWIG_33(double jarg1, long jarg2, SwapIndex jarg2_);
  public final static native double SwapRateHelper_spread(long jarg1, SwapRateHelper jarg1_);
  public final static native long SwapRateHelper_swap(long jarg1, SwapRateHelper jarg1_);
  public final static native void delete_SwapRateHelper(long jarg1);
  public final static native long new_BondHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Bond jarg2_, int jarg3);
  public final static native long new_BondHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, Bond jarg2_);
  public final static native long BondHelper_bond(long jarg1, BondHelper jarg1_);
  public final static native void delete_BondHelper(long jarg1);
  public final static native long new_FixedRateBondHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_, int jarg13, boolean jarg14, int jarg15);
  public final static native long new_FixedRateBondHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_, int jarg13, boolean jarg14);
  public final static native long new_FixedRateBondHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_, int jarg13);
  public final static native long new_FixedRateBondHelper__SWIG_3(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, long jarg12, Calendar jarg12_);
  public final static native long new_FixedRateBondHelper__SWIG_4(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_);
  public final static native long new_FixedRateBondHelper__SWIG_5(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_, long jarg10, Calendar jarg10_);
  public final static native long new_FixedRateBondHelper__SWIG_6(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8, long jarg9, Date jarg9_);
  public final static native long new_FixedRateBondHelper__SWIG_7(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7, double jarg8);
  public final static native long new_FixedRateBondHelper__SWIG_8(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_, int jarg7);
  public final static native long new_FixedRateBondHelper__SWIG_9(long jarg1, QuoteHandle jarg1_, long jarg2, double jarg3, long jarg4, Schedule jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long FixedRateBondHelper_fixedRateBond(long jarg1, FixedRateBondHelper jarg1_);
  public final static native void delete_FixedRateBondHelper(long jarg1);
  public final static native long new_OISRateHelper__SWIG_0(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12, int jarg13, long jarg14, Date jarg14_, int jarg15, long jarg16, OptionalBool jarg16_, long jarg17, OptionalFrequency jarg17_, long jarg18, Calendar jarg18_);
  public final static native long new_OISRateHelper__SWIG_1(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12, int jarg13, long jarg14, Date jarg14_, int jarg15, long jarg16, OptionalBool jarg16_, long jarg17, OptionalFrequency jarg17_);
  public final static native long new_OISRateHelper__SWIG_2(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12, int jarg13, long jarg14, Date jarg14_, int jarg15, long jarg16, OptionalBool jarg16_);
  public final static native long new_OISRateHelper__SWIG_3(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12, int jarg13, long jarg14, Date jarg14_, int jarg15);
  public final static native long new_OISRateHelper__SWIG_4(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12, int jarg13, long jarg14, Date jarg14_);
  public final static native long new_OISRateHelper__SWIG_5(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12, int jarg13);
  public final static native long new_OISRateHelper__SWIG_6(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_, double jarg12);
  public final static native long new_OISRateHelper__SWIG_7(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_, long jarg11, Period jarg11_);
  public final static native long new_OISRateHelper__SWIG_8(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, long jarg10, Calendar jarg10_);
  public final static native long new_OISRateHelper__SWIG_9(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9);
  public final static native long new_OISRateHelper__SWIG_10(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8);
  public final static native long new_OISRateHelper__SWIG_11(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7);
  public final static native long new_OISRateHelper__SWIG_12(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6);
  public final static native long new_OISRateHelper__SWIG_13(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_);
  public final static native long new_OISRateHelper__SWIG_14(long jarg1, long jarg2, Period jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_);
  public final static native long OISRateHelper_swap(long jarg1, OISRateHelper jarg1_);
  public final static native void delete_OISRateHelper(long jarg1);
  public final static native long new_DatedOISRateHelper__SWIG_0(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10, long jarg11, Calendar jarg11_, long jarg12, Period jarg12_, double jarg13, long jarg14, OptionalBool jarg14_, long jarg15, OptionalFrequency jarg15_, long jarg16, Calendar jarg16_);
  public final static native long new_DatedOISRateHelper__SWIG_1(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10, long jarg11, Calendar jarg11_, long jarg12, Period jarg12_, double jarg13, long jarg14, OptionalBool jarg14_, long jarg15, OptionalFrequency jarg15_);
  public final static native long new_DatedOISRateHelper__SWIG_2(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10, long jarg11, Calendar jarg11_, long jarg12, Period jarg12_, double jarg13, long jarg14, OptionalBool jarg14_);
  public final static native long new_DatedOISRateHelper__SWIG_3(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10, long jarg11, Calendar jarg11_, long jarg12, Period jarg12_, double jarg13);
  public final static native long new_DatedOISRateHelper__SWIG_4(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10, long jarg11, Calendar jarg11_, long jarg12, Period jarg12_);
  public final static native long new_DatedOISRateHelper__SWIG_5(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10, long jarg11, Calendar jarg11_);
  public final static native long new_DatedOISRateHelper__SWIG_6(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9, int jarg10);
  public final static native long new_DatedOISRateHelper__SWIG_7(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8, int jarg9);
  public final static native long new_DatedOISRateHelper__SWIG_8(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7, int jarg8);
  public final static native long new_DatedOISRateHelper__SWIG_9(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6, int jarg7);
  public final static native long new_DatedOISRateHelper__SWIG_10(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_, boolean jarg6);
  public final static native long new_DatedOISRateHelper__SWIG_11(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, YieldTermStructureHandle jarg5_);
  public final static native long new_DatedOISRateHelper__SWIG_12(long jarg1, Date jarg1_, long jarg2, Date jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, OvernightIndex jarg4_);
  public final static native void delete_DatedOISRateHelper(long jarg1);
  public final static native long new_FxSwapRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, Period jarg3_, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, boolean jarg8, long jarg9, YieldTermStructureHandle jarg9_, long jarg10, Calendar jarg10_);
  public final static native long new_FxSwapRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, Period jarg3_, long jarg4, long jarg5, Calendar jarg5_, int jarg6, boolean jarg7, boolean jarg8, long jarg9, YieldTermStructureHandle jarg9_);
  public final static native void delete_FxSwapRateHelper(long jarg1);
  public final static native long new_OvernightIndexFutureRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, QuoteHandle jarg5_, int jarg6);
  public final static native long new_OvernightIndexFutureRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, OvernightIndex jarg4_, long jarg5, QuoteHandle jarg5_);
  public final static native long new_OvernightIndexFutureRateHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, long jarg4, OvernightIndex jarg4_);
  public final static native void delete_OvernightIndexFutureRateHelper(long jarg1);
  public final static native long new_SofrFutureRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, int jarg2, int jarg3, int jarg4, long jarg5, QuoteHandle jarg5_);
  public final static native long new_SofrFutureRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, int jarg2, int jarg3, int jarg4);
  public final static native long new_SofrFutureRateHelper__SWIG_2(double jarg1, int jarg2, int jarg3, int jarg4, double jarg5);
  public final static native long new_SofrFutureRateHelper__SWIG_3(double jarg1, int jarg2, int jarg3, int jarg4);
  public final static native void delete_SofrFutureRateHelper(long jarg1);
  public final static native long new_ConstNotionalCrossCurrencyBasisSwapRateHelper(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, IborIndex jarg7_, long jarg8, IborIndex jarg8_, long jarg9, YieldTermStructureHandle jarg9_, boolean jarg10, boolean jarg11);
  public final static native void delete_ConstNotionalCrossCurrencyBasisSwapRateHelper(long jarg1);
  public final static native long new_MtMCrossCurrencyBasisSwapRateHelper(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, IborIndex jarg7_, long jarg8, IborIndex jarg8_, long jarg9, YieldTermStructureHandle jarg9_, boolean jarg10, boolean jarg11, boolean jarg12);
  public final static native void delete_MtMCrossCurrencyBasisSwapRateHelper(long jarg1);
  public final static native long new_IborIborBasisSwapRateHelper(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, IborIndex jarg7_, long jarg8, IborIndex jarg8_, long jarg9, YieldTermStructureHandle jarg9_, boolean jarg10);
  public final static native void delete_IborIborBasisSwapRateHelper(long jarg1);
  public final static native long new_OvernightIborBasisSwapRateHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, OvernightIndex jarg7_, long jarg8, IborIndex jarg8_, long jarg9, YieldTermStructureHandle jarg9_);
  public final static native long new_OvernightIborBasisSwapRateHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, long jarg3, long jarg4, Calendar jarg4_, int jarg5, boolean jarg6, long jarg7, OvernightIndex jarg7_, long jarg8, IborIndex jarg8_);
  public final static native void delete_OvernightIborBasisSwapRateHelper(long jarg1);
  public final static native long new_ArithmeticOISRateHelper__SWIG_0(long jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, OvernightIndex jarg5_, int jarg6, long jarg7, QuoteHandle jarg7_, double jarg8, double jarg9, boolean jarg10, long jarg11, YieldTermStructureHandle jarg11_);
  public final static native long new_ArithmeticOISRateHelper__SWIG_1(long jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, OvernightIndex jarg5_, int jarg6, long jarg7, QuoteHandle jarg7_, double jarg8, double jarg9, boolean jarg10);
  public final static native long new_ArithmeticOISRateHelper__SWIG_2(long jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, OvernightIndex jarg5_, int jarg6, long jarg7, QuoteHandle jarg7_, double jarg8, double jarg9);
  public final static native long new_ArithmeticOISRateHelper__SWIG_3(long jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, OvernightIndex jarg5_, int jarg6, long jarg7, QuoteHandle jarg7_, double jarg8);
  public final static native long new_ArithmeticOISRateHelper__SWIG_4(long jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, QuoteHandle jarg4_, long jarg5, OvernightIndex jarg5_, int jarg6, long jarg7, QuoteHandle jarg7_);
  public final static native long ArithmeticOISRateHelper_swap(long jarg1, ArithmeticOISRateHelper jarg1_);
  public final static native void delete_ArithmeticOISRateHelper(long jarg1);
  public final static native long new_RateHelperVector__SWIG_0();
  public final static native long new_RateHelperVector__SWIG_1(long jarg1, RateHelperVector jarg1_);
  public final static native long RateHelperVector_capacity(long jarg1, RateHelperVector jarg1_);
  public final static native void RateHelperVector_reserve(long jarg1, RateHelperVector jarg1_, long jarg2);
  public final static native boolean RateHelperVector_isEmpty(long jarg1, RateHelperVector jarg1_);
  public final static native void RateHelperVector_clear(long jarg1, RateHelperVector jarg1_);
  public final static native long new_RateHelperVector__SWIG_2(int jarg1, long jarg2, RateHelper jarg2_);
  public final static native int RateHelperVector_doSize(long jarg1, RateHelperVector jarg1_);
  public final static native void RateHelperVector_doAdd__SWIG_0(long jarg1, RateHelperVector jarg1_, long jarg2, RateHelper jarg2_);
  public final static native void RateHelperVector_doAdd__SWIG_1(long jarg1, RateHelperVector jarg1_, int jarg2, long jarg3, RateHelper jarg3_);
  public final static native long RateHelperVector_doRemove(long jarg1, RateHelperVector jarg1_, int jarg2);
  public final static native long RateHelperVector_doGet(long jarg1, RateHelperVector jarg1_, int jarg2);
  public final static native long RateHelperVector_doSet(long jarg1, RateHelperVector jarg1_, int jarg2, long jarg3, RateHelper jarg3_);
  public final static native void RateHelperVector_doRemoveRange(long jarg1, RateHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_RateHelperVector(long jarg1);
  public final static native long new_BondHelperVector__SWIG_0();
  public final static native long new_BondHelperVector__SWIG_1(long jarg1, BondHelperVector jarg1_);
  public final static native long BondHelperVector_capacity(long jarg1, BondHelperVector jarg1_);
  public final static native void BondHelperVector_reserve(long jarg1, BondHelperVector jarg1_, long jarg2);
  public final static native boolean BondHelperVector_isEmpty(long jarg1, BondHelperVector jarg1_);
  public final static native void BondHelperVector_clear(long jarg1, BondHelperVector jarg1_);
  public final static native long new_BondHelperVector__SWIG_2(int jarg1, long jarg2, BondHelper jarg2_);
  public final static native int BondHelperVector_doSize(long jarg1, BondHelperVector jarg1_);
  public final static native void BondHelperVector_doAdd__SWIG_0(long jarg1, BondHelperVector jarg1_, long jarg2, BondHelper jarg2_);
  public final static native void BondHelperVector_doAdd__SWIG_1(long jarg1, BondHelperVector jarg1_, int jarg2, long jarg3, BondHelper jarg3_);
  public final static native long BondHelperVector_doRemove(long jarg1, BondHelperVector jarg1_, int jarg2);
  public final static native long BondHelperVector_doGet(long jarg1, BondHelperVector jarg1_, int jarg2);
  public final static native long BondHelperVector_doSet(long jarg1, BondHelperVector jarg1_, int jarg2, long jarg3, BondHelper jarg3_);
  public final static native void BondHelperVector_doRemoveRange(long jarg1, BondHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_BondHelperVector(long jarg1);
  public final static native long as_depositratehelper(long jarg1, RateHelper jarg1_);
  public final static native long as_fraratehelper(long jarg1, RateHelper jarg1_);
  public final static native long as_swapratehelper(long jarg1, RateHelper jarg1_);
  public final static native long as_oisratehelper(long jarg1, RateHelper jarg1_);
  public final static native long as_constnotionalcrosscurrencybasisswapratehelper(long jarg1, RateHelper jarg1_);
  public final static native long as_mtmcrosscurrencybasisswapratehelper(long jarg1, RateHelper jarg1_);
  public final static native long new_Discount();
  public final static native void delete_Discount(long jarg1);
  public final static native long new_ZeroYield();
  public final static native void delete_ZeroYield(long jarg1);
  public final static native long new_ForwardRate();
  public final static native void delete_ForwardRate(long jarg1);
  public final static native long new_IterativeBootstrap__SWIG_0(double jarg1, double jarg2, double jarg3, long jarg4, double jarg5, double jarg6, boolean jarg7, long jarg8, long jarg9);
  public final static native long new_IterativeBootstrap__SWIG_1(double jarg1, double jarg2, double jarg3, long jarg4, double jarg5, double jarg6, boolean jarg7, long jarg8);
  public final static native long new_IterativeBootstrap__SWIG_2(double jarg1, double jarg2, double jarg3, long jarg4, double jarg5, double jarg6, boolean jarg7);
  public final static native long new_IterativeBootstrap__SWIG_3(double jarg1, double jarg2, double jarg3, long jarg4, double jarg5, double jarg6);
  public final static native long new_IterativeBootstrap__SWIG_4(double jarg1, double jarg2, double jarg3, long jarg4, double jarg5);
  public final static native long new_IterativeBootstrap__SWIG_5(double jarg1, double jarg2, double jarg3, long jarg4);
  public final static native long new_IterativeBootstrap__SWIG_6(double jarg1, double jarg2, double jarg3);
  public final static native long new_IterativeBootstrap__SWIG_7(double jarg1, double jarg2);
  public final static native long new_IterativeBootstrap__SWIG_8(double jarg1);
  public final static native long new_IterativeBootstrap__SWIG_9();
  public final static native void delete_IterativeBootstrap(long jarg1);
  public final static native long new_PiecewiseFlatForward__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, BackwardFlat jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseFlatForward__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, BackwardFlat jarg6_);
  public final static native long new_PiecewiseFlatForward__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseFlatForward__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseFlatForward__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseFlatForward__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, BackwardFlat jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseFlatForward__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, BackwardFlat jarg7_);
  public final static native long new_PiecewiseFlatForward__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseFlatForward__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseFlatForward__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseFlatForward__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, BackwardFlat jarg5_);
  public final static native long new_PiecewiseFlatForward__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseFlatForward__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, BackwardFlat jarg6_);
  public final static native long new_PiecewiseFlatForward__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseFlatForward_dates(long jarg1, PiecewiseFlatForward jarg1_);
  public final static native long PiecewiseFlatForward_times(long jarg1, PiecewiseFlatForward jarg1_);
  public final static native long PiecewiseFlatForward_nodes(long jarg1, PiecewiseFlatForward jarg1_);
  public final static native void PiecewiseFlatForward_recalculate(long jarg1, PiecewiseFlatForward jarg1_);
  public final static native void PiecewiseFlatForward_freeze(long jarg1, PiecewiseFlatForward jarg1_);
  public final static native void PiecewiseFlatForward_unfreeze(long jarg1, PiecewiseFlatForward jarg1_);
  public final static native void delete_PiecewiseFlatForward(long jarg1);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, LogLinear jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, LogLinear jarg6_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, LogLinear jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, LogLinear jarg7_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, LogLinear jarg5_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, LogLinear jarg6_);
  public final static native long new_PiecewiseLogLinearDiscount__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseLogLinearDiscount_dates(long jarg1, PiecewiseLogLinearDiscount jarg1_);
  public final static native long PiecewiseLogLinearDiscount_times(long jarg1, PiecewiseLogLinearDiscount jarg1_);
  public final static native long PiecewiseLogLinearDiscount_nodes(long jarg1, PiecewiseLogLinearDiscount jarg1_);
  public final static native void PiecewiseLogLinearDiscount_recalculate(long jarg1, PiecewiseLogLinearDiscount jarg1_);
  public final static native void PiecewiseLogLinearDiscount_freeze(long jarg1, PiecewiseLogLinearDiscount jarg1_);
  public final static native void PiecewiseLogLinearDiscount_unfreeze(long jarg1, PiecewiseLogLinearDiscount jarg1_);
  public final static native void delete_PiecewiseLogLinearDiscount(long jarg1);
  public final static native long new_PiecewiseLinearForward__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Linear jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseLinearForward__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Linear jarg6_);
  public final static native long new_PiecewiseLinearForward__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseLinearForward__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseLinearForward__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseLinearForward__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Linear jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseLinearForward__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Linear jarg7_);
  public final static native long new_PiecewiseLinearForward__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseLinearForward__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseLinearForward__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseLinearForward__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, Linear jarg5_);
  public final static native long new_PiecewiseLinearForward__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseLinearForward__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, Linear jarg6_);
  public final static native long new_PiecewiseLinearForward__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseLinearForward_dates(long jarg1, PiecewiseLinearForward jarg1_);
  public final static native long PiecewiseLinearForward_times(long jarg1, PiecewiseLinearForward jarg1_);
  public final static native long PiecewiseLinearForward_nodes(long jarg1, PiecewiseLinearForward jarg1_);
  public final static native void PiecewiseLinearForward_recalculate(long jarg1, PiecewiseLinearForward jarg1_);
  public final static native void PiecewiseLinearForward_freeze(long jarg1, PiecewiseLinearForward jarg1_);
  public final static native void PiecewiseLinearForward_unfreeze(long jarg1, PiecewiseLinearForward jarg1_);
  public final static native void delete_PiecewiseLinearForward(long jarg1);
  public final static native long new_PiecewiseLinearZero__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Linear jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseLinearZero__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Linear jarg6_);
  public final static native long new_PiecewiseLinearZero__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseLinearZero__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseLinearZero__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseLinearZero__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Linear jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseLinearZero__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Linear jarg7_);
  public final static native long new_PiecewiseLinearZero__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseLinearZero__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseLinearZero__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseLinearZero__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, Linear jarg5_);
  public final static native long new_PiecewiseLinearZero__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseLinearZero__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, Linear jarg6_);
  public final static native long new_PiecewiseLinearZero__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseLinearZero_dates(long jarg1, PiecewiseLinearZero jarg1_);
  public final static native long PiecewiseLinearZero_times(long jarg1, PiecewiseLinearZero jarg1_);
  public final static native long PiecewiseLinearZero_nodes(long jarg1, PiecewiseLinearZero jarg1_);
  public final static native void PiecewiseLinearZero_recalculate(long jarg1, PiecewiseLinearZero jarg1_);
  public final static native void PiecewiseLinearZero_freeze(long jarg1, PiecewiseLinearZero jarg1_);
  public final static native void PiecewiseLinearZero_unfreeze(long jarg1, PiecewiseLinearZero jarg1_);
  public final static native void delete_PiecewiseLinearZero(long jarg1);
  public final static native long new_PiecewiseCubicZero__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Cubic jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseCubicZero__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Cubic jarg6_);
  public final static native long new_PiecewiseCubicZero__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseCubicZero__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseCubicZero__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseCubicZero__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Cubic jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseCubicZero__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Cubic jarg7_);
  public final static native long new_PiecewiseCubicZero__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseCubicZero__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseCubicZero__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseCubicZero__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, Cubic jarg5_);
  public final static native long new_PiecewiseCubicZero__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseCubicZero__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, Cubic jarg6_);
  public final static native long new_PiecewiseCubicZero__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseCubicZero_dates(long jarg1, PiecewiseCubicZero jarg1_);
  public final static native long PiecewiseCubicZero_times(long jarg1, PiecewiseCubicZero jarg1_);
  public final static native long PiecewiseCubicZero_nodes(long jarg1, PiecewiseCubicZero jarg1_);
  public final static native void PiecewiseCubicZero_recalculate(long jarg1, PiecewiseCubicZero jarg1_);
  public final static native void PiecewiseCubicZero_freeze(long jarg1, PiecewiseCubicZero jarg1_);
  public final static native void PiecewiseCubicZero_unfreeze(long jarg1, PiecewiseCubicZero jarg1_);
  public final static native void delete_PiecewiseCubicZero(long jarg1);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, MonotonicLogCubic jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, MonotonicLogCubic jarg6_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, MonotonicLogCubic jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, MonotonicLogCubic jarg7_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, MonotonicLogCubic jarg5_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, MonotonicLogCubic jarg6_);
  public final static native long new_PiecewiseLogCubicDiscount__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseLogCubicDiscount_dates(long jarg1, PiecewiseLogCubicDiscount jarg1_);
  public final static native long PiecewiseLogCubicDiscount_times(long jarg1, PiecewiseLogCubicDiscount jarg1_);
  public final static native long PiecewiseLogCubicDiscount_nodes(long jarg1, PiecewiseLogCubicDiscount jarg1_);
  public final static native void PiecewiseLogCubicDiscount_recalculate(long jarg1, PiecewiseLogCubicDiscount jarg1_);
  public final static native void PiecewiseLogCubicDiscount_freeze(long jarg1, PiecewiseLogCubicDiscount jarg1_);
  public final static native void PiecewiseLogCubicDiscount_unfreeze(long jarg1, PiecewiseLogCubicDiscount jarg1_);
  public final static native void delete_PiecewiseLogCubicDiscount(long jarg1);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, SplineCubic jarg6_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, SplineCubic jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, SplineCubic jarg7_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, SplineCubic jarg5_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, SplineCubic jarg6_);
  public final static native long new_PiecewiseSplineCubicDiscount__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseSplineCubicDiscount_dates(long jarg1, PiecewiseSplineCubicDiscount jarg1_);
  public final static native long PiecewiseSplineCubicDiscount_times(long jarg1, PiecewiseSplineCubicDiscount jarg1_);
  public final static native long PiecewiseSplineCubicDiscount_nodes(long jarg1, PiecewiseSplineCubicDiscount jarg1_);
  public final static native void PiecewiseSplineCubicDiscount_recalculate(long jarg1, PiecewiseSplineCubicDiscount jarg1_);
  public final static native void PiecewiseSplineCubicDiscount_freeze(long jarg1, PiecewiseSplineCubicDiscount jarg1_);
  public final static native void PiecewiseSplineCubicDiscount_unfreeze(long jarg1, PiecewiseSplineCubicDiscount jarg1_);
  public final static native void delete_PiecewiseSplineCubicDiscount(long jarg1);
  public final static native long new_PiecewiseKrugerZero__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Kruger jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseKrugerZero__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, Kruger jarg6_);
  public final static native long new_PiecewiseKrugerZero__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseKrugerZero__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseKrugerZero__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseKrugerZero__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Kruger jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseKrugerZero__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, Kruger jarg7_);
  public final static native long new_PiecewiseKrugerZero__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseKrugerZero__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseKrugerZero__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseKrugerZero__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, Kruger jarg5_);
  public final static native long new_PiecewiseKrugerZero__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseKrugerZero__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, Kruger jarg6_);
  public final static native long new_PiecewiseKrugerZero__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseKrugerZero_dates(long jarg1, PiecewiseKrugerZero jarg1_);
  public final static native long PiecewiseKrugerZero_times(long jarg1, PiecewiseKrugerZero jarg1_);
  public final static native long PiecewiseKrugerZero_nodes(long jarg1, PiecewiseKrugerZero jarg1_);
  public final static native void PiecewiseKrugerZero_recalculate(long jarg1, PiecewiseKrugerZero jarg1_);
  public final static native void PiecewiseKrugerZero_freeze(long jarg1, PiecewiseKrugerZero jarg1_);
  public final static native void PiecewiseKrugerZero_unfreeze(long jarg1, PiecewiseKrugerZero jarg1_);
  public final static native void delete_PiecewiseKrugerZero(long jarg1);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, KrugerLog jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, KrugerLog jarg6_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, KrugerLog jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, KrugerLog jarg7_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, KrugerLog jarg5_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, KrugerLog jarg6_);
  public final static native long new_PiecewiseKrugerLogDiscount__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseKrugerLogDiscount_dates(long jarg1, PiecewiseKrugerLogDiscount jarg1_);
  public final static native long PiecewiseKrugerLogDiscount_times(long jarg1, PiecewiseKrugerLogDiscount jarg1_);
  public final static native long PiecewiseKrugerLogDiscount_nodes(long jarg1, PiecewiseKrugerLogDiscount jarg1_);
  public final static native void PiecewiseKrugerLogDiscount_recalculate(long jarg1, PiecewiseKrugerLogDiscount jarg1_);
  public final static native void PiecewiseKrugerLogDiscount_freeze(long jarg1, PiecewiseKrugerLogDiscount jarg1_);
  public final static native void PiecewiseKrugerLogDiscount_unfreeze(long jarg1, PiecewiseKrugerLogDiscount jarg1_);
  public final static native void delete_PiecewiseKrugerLogDiscount(long jarg1);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, ConvexMonotone jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, ConvexMonotone jarg6_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, ConvexMonotone jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, ConvexMonotone jarg7_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, ConvexMonotone jarg5_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, ConvexMonotone jarg6_);
  public final static native long new_PiecewiseConvexMonotoneForward__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseConvexMonotoneForward_dates(long jarg1, PiecewiseConvexMonotoneForward jarg1_);
  public final static native long PiecewiseConvexMonotoneForward_times(long jarg1, PiecewiseConvexMonotoneForward jarg1_);
  public final static native long PiecewiseConvexMonotoneForward_nodes(long jarg1, PiecewiseConvexMonotoneForward jarg1_);
  public final static native void PiecewiseConvexMonotoneForward_recalculate(long jarg1, PiecewiseConvexMonotoneForward jarg1_);
  public final static native void PiecewiseConvexMonotoneForward_freeze(long jarg1, PiecewiseConvexMonotoneForward jarg1_);
  public final static native void PiecewiseConvexMonotoneForward_unfreeze(long jarg1, PiecewiseConvexMonotoneForward jarg1_);
  public final static native void delete_PiecewiseConvexMonotoneForward(long jarg1);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, ConvexMonotone jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, ConvexMonotone jarg6_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, ConvexMonotone jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, ConvexMonotone jarg7_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, ConvexMonotone jarg5_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, ConvexMonotone jarg6_);
  public final static native long new_PiecewiseConvexMonotoneZero__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseConvexMonotoneZero_dates(long jarg1, PiecewiseConvexMonotoneZero jarg1_);
  public final static native long PiecewiseConvexMonotoneZero_times(long jarg1, PiecewiseConvexMonotoneZero jarg1_);
  public final static native long PiecewiseConvexMonotoneZero_nodes(long jarg1, PiecewiseConvexMonotoneZero jarg1_);
  public final static native void PiecewiseConvexMonotoneZero_recalculate(long jarg1, PiecewiseConvexMonotoneZero jarg1_);
  public final static native void PiecewiseConvexMonotoneZero_freeze(long jarg1, PiecewiseConvexMonotoneZero jarg1_);
  public final static native void PiecewiseConvexMonotoneZero_unfreeze(long jarg1, PiecewiseConvexMonotoneZero jarg1_);
  public final static native void delete_PiecewiseConvexMonotoneZero(long jarg1);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, SplineCubic jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, SplineCubic jarg6_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, SplineCubic jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, SplineCubic jarg7_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, SplineCubic jarg5_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, SplineCubic jarg6_);
  public final static native long new_PiecewiseNaturalCubicZero__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseNaturalCubicZero_dates(long jarg1, PiecewiseNaturalCubicZero jarg1_);
  public final static native long PiecewiseNaturalCubicZero_times(long jarg1, PiecewiseNaturalCubicZero jarg1_);
  public final static native long PiecewiseNaturalCubicZero_nodes(long jarg1, PiecewiseNaturalCubicZero jarg1_);
  public final static native void PiecewiseNaturalCubicZero_recalculate(long jarg1, PiecewiseNaturalCubicZero jarg1_);
  public final static native void PiecewiseNaturalCubicZero_freeze(long jarg1, PiecewiseNaturalCubicZero jarg1_);
  public final static native void PiecewiseNaturalCubicZero_unfreeze(long jarg1, PiecewiseNaturalCubicZero jarg1_);
  public final static native void delete_PiecewiseNaturalCubicZero(long jarg1);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, SplineLogCubic jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, SplineLogCubic jarg6_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, SplineLogCubic jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, SplineLogCubic jarg7_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, SplineLogCubic jarg5_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, SplineLogCubic jarg6_);
  public final static native long new_PiecewiseNaturalLogCubicDiscount__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseNaturalLogCubicDiscount_dates(long jarg1, PiecewiseNaturalLogCubicDiscount jarg1_);
  public final static native long PiecewiseNaturalLogCubicDiscount_times(long jarg1, PiecewiseNaturalLogCubicDiscount jarg1_);
  public final static native long PiecewiseNaturalLogCubicDiscount_nodes(long jarg1, PiecewiseNaturalLogCubicDiscount jarg1_);
  public final static native void PiecewiseNaturalLogCubicDiscount_recalculate(long jarg1, PiecewiseNaturalLogCubicDiscount jarg1_);
  public final static native void PiecewiseNaturalLogCubicDiscount_freeze(long jarg1, PiecewiseNaturalLogCubicDiscount jarg1_);
  public final static native void PiecewiseNaturalLogCubicDiscount_unfreeze(long jarg1, PiecewiseNaturalLogCubicDiscount jarg1_);
  public final static native void delete_PiecewiseNaturalLogCubicDiscount(long jarg1);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_0(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, LogMixedLinearCubic jarg6_, long jarg7, IterativeBootstrap jarg7_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_1(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, LogMixedLinearCubic jarg6_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_2(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_, long jarg5, DateVector jarg5_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_3(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_4(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, LogMixedLinearCubic jarg7_, long jarg8, IterativeBootstrap jarg8_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_6(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_, long jarg7, LogMixedLinearCubic jarg7_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_, long jarg6, DateVector jarg6_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_8(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, QuoteHandleVector jarg5_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_9(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_10(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_, long jarg5, LogMixedLinearCubic jarg5_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_11(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_12(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_, long jarg6, LogMixedLinearCubic jarg6_);
  public final static native long new_PiecewiseLogMixedLinearCubicDiscount__SWIG_13(int jarg1, long jarg2, Calendar jarg2_, long jarg3, RateHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseLogMixedLinearCubicDiscount_dates(long jarg1, PiecewiseLogMixedLinearCubicDiscount jarg1_);
  public final static native long PiecewiseLogMixedLinearCubicDiscount_times(long jarg1, PiecewiseLogMixedLinearCubicDiscount jarg1_);
  public final static native long PiecewiseLogMixedLinearCubicDiscount_nodes(long jarg1, PiecewiseLogMixedLinearCubicDiscount jarg1_);
  public final static native void PiecewiseLogMixedLinearCubicDiscount_recalculate(long jarg1, PiecewiseLogMixedLinearCubicDiscount jarg1_);
  public final static native void PiecewiseLogMixedLinearCubicDiscount_freeze(long jarg1, PiecewiseLogMixedLinearCubicDiscount jarg1_);
  public final static native void PiecewiseLogMixedLinearCubicDiscount_unfreeze(long jarg1, PiecewiseLogMixedLinearCubicDiscount jarg1_);
  public final static native void delete_PiecewiseLogMixedLinearCubicDiscount(long jarg1);
  public final static native long new_GlobalBootstrap__SWIG_0(double jarg1);
  public final static native long new_GlobalBootstrap__SWIG_1();
  public final static native long new_GlobalBootstrap__SWIG_2(long jarg1, RateHelperVector jarg1_, long jarg2, DateVector jarg2_, double jarg3);
  public final static native long new_GlobalBootstrap__SWIG_3(long jarg1, RateHelperVector jarg1_, long jarg2, DateVector jarg2_);
  public final static native void delete_GlobalBootstrap(long jarg1);
  public final static native long new_GlobalLinearSimpleZeroCurve(long jarg1, Date jarg1_, long jarg2, RateHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, GlobalBootstrap jarg4_);
  public final static native long GlobalLinearSimpleZeroCurve_dates(long jarg1, GlobalLinearSimpleZeroCurve jarg1_);
  public final static native long GlobalLinearSimpleZeroCurve_times(long jarg1, GlobalLinearSimpleZeroCurve jarg1_);
  public final static native long GlobalLinearSimpleZeroCurve_nodes(long jarg1, GlobalLinearSimpleZeroCurve jarg1_);
  public final static native void delete_GlobalLinearSimpleZeroCurve(long jarg1);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_0(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_1(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_2(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_3(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_4(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, boolean jarg4);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_5(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_6(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double DefaultProbabilityTermStructure_defaultProbability__SWIG_7(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2, double jarg3);
  public final static native double DefaultProbabilityTermStructure_survivalProbability__SWIG_0(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_survivalProbability__SWIG_1(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructure_survivalProbability__SWIG_2(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_survivalProbability__SWIG_3(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2);
  public final static native double DefaultProbabilityTermStructure_defaultDensity__SWIG_0(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_defaultDensity__SWIG_1(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructure_defaultDensity__SWIG_2(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_defaultDensity__SWIG_3(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2);
  public final static native double DefaultProbabilityTermStructure_hazardRate__SWIG_0(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_hazardRate__SWIG_1(long jarg1, DefaultProbabilityTermStructure jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructure_hazardRate__SWIG_2(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructure_hazardRate__SWIG_3(long jarg1, DefaultProbabilityTermStructure jarg1_, double jarg2);
  public final static native void delete_DefaultProbabilityTermStructure(long jarg1);
  public final static native long new_DefaultProbabilityTermStructureHandle__SWIG_0(long jarg1, DefaultProbabilityTermStructure jarg1_);
  public final static native long new_DefaultProbabilityTermStructureHandle__SWIG_1();
  public final static native long DefaultProbabilityTermStructureHandle___deref__(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native long DefaultProbabilityTermStructureHandle_currentLink(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native boolean DefaultProbabilityTermStructureHandle_empty(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native long DefaultProbabilityTermStructureHandle_asObservable(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native void delete_DefaultProbabilityTermStructureHandle(long jarg1);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_0(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_1(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_2(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_3(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_4(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, boolean jarg4);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_5(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_6(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_7(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_0(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_1(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_2(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_3(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2);
  public final static native double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_0(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_1(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_2(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_3(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2);
  public final static native double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_0(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_1(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_2(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, boolean jarg3);
  public final static native double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_3(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2);
  public final static native long DefaultProbabilityTermStructureHandle_dayCounter(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native double DefaultProbabilityTermStructureHandle_timeFromReference(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long DefaultProbabilityTermStructureHandle_calendar(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native long DefaultProbabilityTermStructureHandle_referenceDate(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native long DefaultProbabilityTermStructureHandle_maxDate(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native double DefaultProbabilityTermStructureHandle_maxTime(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native void DefaultProbabilityTermStructureHandle_enableExtrapolation(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native void DefaultProbabilityTermStructureHandle_disableExtrapolation(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native boolean DefaultProbabilityTermStructureHandle_allowsExtrapolation(long jarg1, DefaultProbabilityTermStructureHandle jarg1_);
  public final static native long new_RelinkableDefaultProbabilityTermStructureHandle__SWIG_0(long jarg1, DefaultProbabilityTermStructure jarg1_);
  public final static native long new_RelinkableDefaultProbabilityTermStructureHandle__SWIG_1();
  public final static native void RelinkableDefaultProbabilityTermStructureHandle_linkTo(long jarg1, RelinkableDefaultProbabilityTermStructureHandle jarg1_, long jarg2, DefaultProbabilityTermStructure jarg2_);
  public final static native void RelinkableDefaultProbabilityTermStructureHandle_reset(long jarg1, RelinkableDefaultProbabilityTermStructureHandle jarg1_);
  public final static native void delete_RelinkableDefaultProbabilityTermStructureHandle(long jarg1);
  public final static native long new_FlatHazardRate__SWIG_0(int jarg1, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_FlatHazardRate__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_);
  public final static native void delete_FlatHazardRate(long jarg1);
  public final static native long new_HazardRateCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, BackwardFlat jarg5_);
  public final static native long new_HazardRateCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_HazardRateCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long HazardRateCurve_dates(long jarg1, HazardRateCurve jarg1_);
  public final static native long HazardRateCurve_hazardRates(long jarg1, HazardRateCurve jarg1_);
  public final static native long HazardRateCurve_nodes(long jarg1, HazardRateCurve jarg1_);
  public final static native void delete_HazardRateCurve(long jarg1);
  public final static native long new_DefaultDensityCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Linear jarg5_);
  public final static native long new_DefaultDensityCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_DefaultDensityCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long DefaultDensityCurve_dates(long jarg1, DefaultDensityCurve jarg1_);
  public final static native long DefaultDensityCurve_defaultDensities(long jarg1, DefaultDensityCurve jarg1_);
  public final static native long DefaultDensityCurve_nodes(long jarg1, DefaultDensityCurve jarg1_);
  public final static native void delete_DefaultDensityCurve(long jarg1);
  public final static native long new_SurvivalProbabilityCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Linear jarg5_);
  public final static native long new_SurvivalProbabilityCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_SurvivalProbabilityCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long SurvivalProbabilityCurve_dates(long jarg1, SurvivalProbabilityCurve jarg1_);
  public final static native long SurvivalProbabilityCurve_survivalProbabilities(long jarg1, SurvivalProbabilityCurve jarg1_);
  public final static native long SurvivalProbabilityCurve_nodes(long jarg1, SurvivalProbabilityCurve jarg1_);
  public final static native void delete_SurvivalProbabilityCurve(long jarg1);
  public final static native long DefaultProbabilityHelper_quote(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native long DefaultProbabilityHelper_latestDate(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native long DefaultProbabilityHelper_earliestDate(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native long DefaultProbabilityHelper_maturityDate(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native long DefaultProbabilityHelper_latestRelevantDate(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native long DefaultProbabilityHelper_pillarDate(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native double DefaultProbabilityHelper_impliedQuote(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native double DefaultProbabilityHelper_quoteError(long jarg1, DefaultProbabilityHelper jarg1_);
  public final static native void delete_DefaultProbabilityHelper(long jarg1);
  public final static native long new_DefaultProbabilityHelperVector__SWIG_0();
  public final static native long new_DefaultProbabilityHelperVector__SWIG_1(long jarg1, DefaultProbabilityHelperVector jarg1_);
  public final static native long DefaultProbabilityHelperVector_capacity(long jarg1, DefaultProbabilityHelperVector jarg1_);
  public final static native void DefaultProbabilityHelperVector_reserve(long jarg1, DefaultProbabilityHelperVector jarg1_, long jarg2);
  public final static native boolean DefaultProbabilityHelperVector_isEmpty(long jarg1, DefaultProbabilityHelperVector jarg1_);
  public final static native void DefaultProbabilityHelperVector_clear(long jarg1, DefaultProbabilityHelperVector jarg1_);
  public final static native long new_DefaultProbabilityHelperVector__SWIG_2(int jarg1, long jarg2, DefaultProbabilityHelper jarg2_);
  public final static native int DefaultProbabilityHelperVector_doSize(long jarg1, DefaultProbabilityHelperVector jarg1_);
  public final static native void DefaultProbabilityHelperVector_doAdd__SWIG_0(long jarg1, DefaultProbabilityHelperVector jarg1_, long jarg2, DefaultProbabilityHelper jarg2_);
  public final static native void DefaultProbabilityHelperVector_doAdd__SWIG_1(long jarg1, DefaultProbabilityHelperVector jarg1_, int jarg2, long jarg3, DefaultProbabilityHelper jarg3_);
  public final static native long DefaultProbabilityHelperVector_doRemove(long jarg1, DefaultProbabilityHelperVector jarg1_, int jarg2);
  public final static native long DefaultProbabilityHelperVector_doGet(long jarg1, DefaultProbabilityHelperVector jarg1_, int jarg2);
  public final static native long DefaultProbabilityHelperVector_doSet(long jarg1, DefaultProbabilityHelperVector jarg1_, int jarg2, long jarg3, DefaultProbabilityHelper jarg3_);
  public final static native void DefaultProbabilityHelperVector_doRemoveRange(long jarg1, DefaultProbabilityHelperVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_DefaultProbabilityHelperVector(long jarg1);
  public final static native long new_SpreadCdsHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_, long jarg14, DayCounter jarg14_, boolean jarg15, int jarg16);
  public final static native long new_SpreadCdsHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_, long jarg14, DayCounter jarg14_, boolean jarg15);
  public final static native long new_SpreadCdsHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_, long jarg14, DayCounter jarg14_);
  public final static native long new_SpreadCdsHelper__SWIG_3(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_SpreadCdsHelper__SWIG_4(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12);
  public final static native long new_SpreadCdsHelper__SWIG_5(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11);
  public final static native long new_SpreadCdsHelper__SWIG_6(long jarg1, QuoteHandle jarg1_, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native long new_SpreadCdsHelper__SWIG_7(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_, long jarg14, DayCounter jarg14_, boolean jarg15, int jarg16);
  public final static native long new_SpreadCdsHelper__SWIG_8(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_, long jarg14, DayCounter jarg14_, boolean jarg15);
  public final static native long new_SpreadCdsHelper__SWIG_9(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_, long jarg14, DayCounter jarg14_);
  public final static native long new_SpreadCdsHelper__SWIG_10(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_SpreadCdsHelper__SWIG_11(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11, boolean jarg12);
  public final static native long new_SpreadCdsHelper__SWIG_12(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_, boolean jarg11);
  public final static native long new_SpreadCdsHelper__SWIG_13(double jarg1, long jarg2, Period jarg2_, int jarg3, long jarg4, Calendar jarg4_, int jarg5, int jarg6, int jarg7, long jarg8, DayCounter jarg8_, double jarg9, long jarg10, YieldTermStructureHandle jarg10_);
  public final static native void delete_SpreadCdsHelper(long jarg1);
  public final static native long new_UpfrontCdsHelper__SWIG_0(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_, long jarg16, DayCounter jarg16_, boolean jarg17, int jarg18);
  public final static native long new_UpfrontCdsHelper__SWIG_1(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_, long jarg16, DayCounter jarg16_, boolean jarg17);
  public final static native long new_UpfrontCdsHelper__SWIG_2(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_, long jarg16, DayCounter jarg16_);
  public final static native long new_UpfrontCdsHelper__SWIG_3(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_);
  public final static native long new_UpfrontCdsHelper__SWIG_4(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_UpfrontCdsHelper__SWIG_5(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13);
  public final static native long new_UpfrontCdsHelper__SWIG_6(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12);
  public final static native long new_UpfrontCdsHelper__SWIG_7(long jarg1, QuoteHandle jarg1_, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_);
  public final static native long new_UpfrontCdsHelper__SWIG_8(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_, long jarg16, DayCounter jarg16_, boolean jarg17, int jarg18);
  public final static native long new_UpfrontCdsHelper__SWIG_9(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_, long jarg16, DayCounter jarg16_, boolean jarg17);
  public final static native long new_UpfrontCdsHelper__SWIG_10(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_, long jarg16, DayCounter jarg16_);
  public final static native long new_UpfrontCdsHelper__SWIG_11(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14, long jarg15, Date jarg15_);
  public final static native long new_UpfrontCdsHelper__SWIG_12(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13, boolean jarg14);
  public final static native long new_UpfrontCdsHelper__SWIG_13(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12, boolean jarg13);
  public final static native long new_UpfrontCdsHelper__SWIG_14(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_, long jarg12);
  public final static native long new_UpfrontCdsHelper__SWIG_15(double jarg1, double jarg2, long jarg3, Period jarg3_, int jarg4, long jarg5, Calendar jarg5_, int jarg6, int jarg7, int jarg8, long jarg9, DayCounter jarg9_, double jarg10, long jarg11, YieldTermStructureHandle jarg11_);
  public final static native void delete_UpfrontCdsHelper(long jarg1);
  public final static native long new_HazardRate();
  public final static native void delete_HazardRate(long jarg1);
  public final static native long new_DefaultDensity();
  public final static native void delete_DefaultDensity(long jarg1);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_0(long jarg1, Date jarg1_, long jarg2, DefaultProbabilityHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, BackwardFlat jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_1(long jarg1, Date jarg1_, long jarg2, DefaultProbabilityHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, BackwardFlat jarg4_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_2(long jarg1, Date jarg1_, long jarg2, DefaultProbabilityHelperVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_3(int jarg1, long jarg2, Calendar jarg2_, long jarg3, DefaultProbabilityHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, BackwardFlat jarg5_, long jarg6, IterativeBootstrap jarg6_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_4(int jarg1, long jarg2, Calendar jarg2_, long jarg3, DefaultProbabilityHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, BackwardFlat jarg5_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_5(int jarg1, long jarg2, Calendar jarg2_, long jarg3, DefaultProbabilityHelperVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_6(long jarg1, Date jarg1_, long jarg2, DefaultProbabilityHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, IterativeBootstrap jarg4_);
  public final static native long new_PiecewiseFlatHazardRate__SWIG_7(int jarg1, long jarg2, Calendar jarg2_, long jarg3, DefaultProbabilityHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, IterativeBootstrap jarg5_);
  public final static native long PiecewiseFlatHazardRate_dates(long jarg1, PiecewiseFlatHazardRate jarg1_);
  public final static native long PiecewiseFlatHazardRate_times(long jarg1, PiecewiseFlatHazardRate jarg1_);
  public final static native long PiecewiseFlatHazardRate_nodes(long jarg1, PiecewiseFlatHazardRate jarg1_);
  public final static native void delete_PiecewiseFlatHazardRate(long jarg1);
  public final static native long new_RiskyBondEngine(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_RiskyBondEngine(long jarg1);
  public final static native long new_Protection();
  public final static native void delete_Protection(long jarg1);
  public final static native double Claim_amount(long jarg1, Claim jarg1_, long jarg2, Date jarg2_, double jarg3, double jarg4);
  public final static native void delete_Claim(long jarg1);
  public final static native long new_FaceValueClaim();
  public final static native void delete_FaceValueClaim(long jarg1);
  public final static native long new_FaceValueAccrualClaim(long jarg1, Bond jarg1_);
  public final static native void delete_FaceValueAccrualClaim(long jarg1);
  public final static native long new_CreditDefaultSwap__SWIG_0(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8, long jarg9, Date jarg9_, long jarg10, Claim jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, long jarg13, Date jarg13_, long jarg14);
  public final static native long new_CreditDefaultSwap__SWIG_1(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8, long jarg9, Date jarg9_, long jarg10, Claim jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12, long jarg13, Date jarg13_);
  public final static native long new_CreditDefaultSwap__SWIG_2(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8, long jarg9, Date jarg9_, long jarg10, Claim jarg10_, long jarg11, DayCounter jarg11_, boolean jarg12);
  public final static native long new_CreditDefaultSwap__SWIG_3(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8, long jarg9, Date jarg9_, long jarg10, Claim jarg10_, long jarg11, DayCounter jarg11_);
  public final static native long new_CreditDefaultSwap__SWIG_4(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8, long jarg9, Date jarg9_, long jarg10, Claim jarg10_);
  public final static native long new_CreditDefaultSwap__SWIG_5(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8, long jarg9, Date jarg9_);
  public final static native long new_CreditDefaultSwap__SWIG_6(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7, boolean jarg8);
  public final static native long new_CreditDefaultSwap__SWIG_7(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_, boolean jarg7);
  public final static native long new_CreditDefaultSwap__SWIG_8(int jarg1, double jarg2, double jarg3, long jarg4, Schedule jarg4_, int jarg5, long jarg6, DayCounter jarg6_);
  public final static native long new_CreditDefaultSwap__SWIG_9(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, Claim jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14, long jarg15, Date jarg15_, long jarg16);
  public final static native long new_CreditDefaultSwap__SWIG_10(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, Claim jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14, long jarg15, Date jarg15_);
  public final static native long new_CreditDefaultSwap__SWIG_11(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, Claim jarg12_, long jarg13, DayCounter jarg13_, boolean jarg14);
  public final static native long new_CreditDefaultSwap__SWIG_12(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, Claim jarg12_, long jarg13, DayCounter jarg13_);
  public final static native long new_CreditDefaultSwap__SWIG_13(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_, long jarg12, Claim jarg12_);
  public final static native long new_CreditDefaultSwap__SWIG_14(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_, long jarg11, Date jarg11_);
  public final static native long new_CreditDefaultSwap__SWIG_15(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9, long jarg10, Date jarg10_);
  public final static native long new_CreditDefaultSwap__SWIG_16(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8, boolean jarg9);
  public final static native long new_CreditDefaultSwap__SWIG_17(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_, boolean jarg8);
  public final static native long new_CreditDefaultSwap__SWIG_18(int jarg1, double jarg2, double jarg3, double jarg4, long jarg5, Schedule jarg5_, int jarg6, long jarg7, DayCounter jarg7_);
  public final static native int CreditDefaultSwap_side(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_notional(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_runningSpread(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_upfront(long jarg1, CreditDefaultSwap jarg1_);
  public final static native boolean CreditDefaultSwap_settlesAccrual(long jarg1, CreditDefaultSwap jarg1_);
  public final static native boolean CreditDefaultSwap_paysAtDefaultTime(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_coupons(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_protectionStartDate(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_protectionEndDate(long jarg1, CreditDefaultSwap jarg1_);
  public final static native boolean CreditDefaultSwap_rebatesAccrual(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_upfrontPayment(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_accrualRebate(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_tradeDate(long jarg1, CreditDefaultSwap jarg1_);
  public final static native long CreditDefaultSwap_cashSettlementDays(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_fairUpfront(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_fairSpread(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_couponLegBPS(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_upfrontBPS(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_couponLegNPV(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_defaultLegNPV(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_upfrontNPV(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_accrualRebateNPV(long jarg1, CreditDefaultSwap jarg1_);
  public final static native double CreditDefaultSwap_impliedHazardRate__SWIG_0(long jarg1, CreditDefaultSwap jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, double jarg5, double jarg6, int jarg7);
  public final static native double CreditDefaultSwap_impliedHazardRate__SWIG_1(long jarg1, CreditDefaultSwap jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, double jarg5, double jarg6);
  public final static native double CreditDefaultSwap_impliedHazardRate__SWIG_2(long jarg1, CreditDefaultSwap jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, double jarg5);
  public final static native double CreditDefaultSwap_impliedHazardRate__SWIG_3(long jarg1, CreditDefaultSwap jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native double CreditDefaultSwap_conventionalSpread__SWIG_0(long jarg1, CreditDefaultSwap jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native double CreditDefaultSwap_conventionalSpread__SWIG_1(long jarg1, CreditDefaultSwap jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native void delete_CreditDefaultSwap(long jarg1);
  public final static native long new_MidPointCdsEngine(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_MidPointCdsEngine(long jarg1);
  public final static native long new_IntegralCdsEngine__SWIG_0(long jarg1, Period jarg1_, long jarg2, DefaultProbabilityTermStructureHandle jarg2_, double jarg3, long jarg4, YieldTermStructureHandle jarg4_, boolean jarg5);
  public final static native long new_IntegralCdsEngine__SWIG_1(long jarg1, Period jarg1_, long jarg2, DefaultProbabilityTermStructureHandle jarg2_, double jarg3, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native void delete_IntegralCdsEngine(long jarg1);
  public final static native long new_IsdaCdsEngine__SWIG_0(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, boolean jarg4, int jarg5, int jarg6, int jarg7);
  public final static native long new_IsdaCdsEngine__SWIG_1(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, boolean jarg4, int jarg5, int jarg6);
  public final static native long new_IsdaCdsEngine__SWIG_2(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, boolean jarg4, int jarg5);
  public final static native long new_IsdaCdsEngine__SWIG_3(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, boolean jarg4);
  public final static native long new_IsdaCdsEngine__SWIG_4(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_);
  public final static native void delete_IsdaCdsEngine(long jarg1);
  public final static native long new_CdsOption__SWIG_0(long jarg1, CreditDefaultSwap jarg1_, long jarg2, Exercise jarg2_, boolean jarg3);
  public final static native long new_CdsOption__SWIG_1(long jarg1, CreditDefaultSwap jarg1_, long jarg2, Exercise jarg2_);
  public final static native double CdsOption_atmRate(long jarg1, CdsOption jarg1_);
  public final static native double CdsOption_riskyAnnuity(long jarg1, CdsOption jarg1_);
  public final static native double CdsOption_impliedVolatility__SWIG_0(long jarg1, CdsOption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DefaultProbabilityTermStructureHandle jarg4_, double jarg5, double jarg6, long jarg7, double jarg8, double jarg9);
  public final static native double CdsOption_impliedVolatility__SWIG_1(long jarg1, CdsOption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DefaultProbabilityTermStructureHandle jarg4_, double jarg5, double jarg6, long jarg7, double jarg8);
  public final static native double CdsOption_impliedVolatility__SWIG_2(long jarg1, CdsOption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DefaultProbabilityTermStructureHandle jarg4_, double jarg5, double jarg6, long jarg7);
  public final static native double CdsOption_impliedVolatility__SWIG_3(long jarg1, CdsOption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DefaultProbabilityTermStructureHandle jarg4_, double jarg5, double jarg6);
  public final static native double CdsOption_impliedVolatility__SWIG_4(long jarg1, CdsOption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, DefaultProbabilityTermStructureHandle jarg4_, double jarg5);
  public final static native void delete_CdsOption(long jarg1);
  public final static native long new_BlackCdsOptionEngine(long jarg1, DefaultProbabilityTermStructureHandle jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long BlackCdsOptionEngine_termStructure(long jarg1, BlackCdsOptionEngine jarg1_);
  public final static native long BlackCdsOptionEngine_volatility(long jarg1, BlackCdsOptionEngine jarg1_);
  public final static native void delete_BlackCdsOptionEngine(long jarg1);
  public final static native long new_DiscountCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, LogLinear jarg5_);
  public final static native long new_DiscountCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_DiscountCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long DiscountCurve_times(long jarg1, DiscountCurve jarg1_);
  public final static native long DiscountCurve_data(long jarg1, DiscountCurve jarg1_);
  public final static native long DiscountCurve_dates(long jarg1, DiscountCurve jarg1_);
  public final static native long DiscountCurve_discounts(long jarg1, DiscountCurve jarg1_);
  public final static native long DiscountCurve_nodes(long jarg1, DiscountCurve jarg1_);
  public final static native void delete_DiscountCurve(long jarg1);
  public final static native long new_MonotonicLogCubicDiscountCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, MonotonicLogCubic jarg5_);
  public final static native long new_MonotonicLogCubicDiscountCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_MonotonicLogCubicDiscountCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long MonotonicLogCubicDiscountCurve_times(long jarg1, MonotonicLogCubicDiscountCurve jarg1_);
  public final static native long MonotonicLogCubicDiscountCurve_data(long jarg1, MonotonicLogCubicDiscountCurve jarg1_);
  public final static native long MonotonicLogCubicDiscountCurve_dates(long jarg1, MonotonicLogCubicDiscountCurve jarg1_);
  public final static native long MonotonicLogCubicDiscountCurve_discounts(long jarg1, MonotonicLogCubicDiscountCurve jarg1_);
  public final static native long MonotonicLogCubicDiscountCurve_nodes(long jarg1, MonotonicLogCubicDiscountCurve jarg1_);
  public final static native void delete_MonotonicLogCubicDiscountCurve(long jarg1);
  public final static native long new_NaturalCubicDiscountCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, SplineCubic jarg5_);
  public final static native long new_NaturalCubicDiscountCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_NaturalCubicDiscountCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long NaturalCubicDiscountCurve_times(long jarg1, NaturalCubicDiscountCurve jarg1_);
  public final static native long NaturalCubicDiscountCurve_data(long jarg1, NaturalCubicDiscountCurve jarg1_);
  public final static native long NaturalCubicDiscountCurve_dates(long jarg1, NaturalCubicDiscountCurve jarg1_);
  public final static native long NaturalCubicDiscountCurve_discounts(long jarg1, NaturalCubicDiscountCurve jarg1_);
  public final static native long NaturalCubicDiscountCurve_nodes(long jarg1, NaturalCubicDiscountCurve jarg1_);
  public final static native void delete_NaturalCubicDiscountCurve(long jarg1);
  public final static native long new_KrugerLogDiscountCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, KrugerLog jarg5_);
  public final static native long new_KrugerLogDiscountCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_KrugerLogDiscountCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long KrugerLogDiscountCurve_times(long jarg1, KrugerLogDiscountCurve jarg1_);
  public final static native long KrugerLogDiscountCurve_data(long jarg1, KrugerLogDiscountCurve jarg1_);
  public final static native long KrugerLogDiscountCurve_dates(long jarg1, KrugerLogDiscountCurve jarg1_);
  public final static native long KrugerLogDiscountCurve_discounts(long jarg1, KrugerLogDiscountCurve jarg1_);
  public final static native long KrugerLogDiscountCurve_nodes(long jarg1, KrugerLogDiscountCurve jarg1_);
  public final static native void delete_KrugerLogDiscountCurve(long jarg1);
  public final static native long new_NaturalLogCubicDiscountCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, SplineLogCubic jarg5_);
  public final static native long new_NaturalLogCubicDiscountCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_NaturalLogCubicDiscountCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long NaturalLogCubicDiscountCurve_times(long jarg1, NaturalLogCubicDiscountCurve jarg1_);
  public final static native long NaturalLogCubicDiscountCurve_data(long jarg1, NaturalLogCubicDiscountCurve jarg1_);
  public final static native long NaturalLogCubicDiscountCurve_dates(long jarg1, NaturalLogCubicDiscountCurve jarg1_);
  public final static native long NaturalLogCubicDiscountCurve_discounts(long jarg1, NaturalLogCubicDiscountCurve jarg1_);
  public final static native long NaturalLogCubicDiscountCurve_nodes(long jarg1, NaturalLogCubicDiscountCurve jarg1_);
  public final static native void delete_NaturalLogCubicDiscountCurve(long jarg1);
  public final static native long new_LogMixedLinearCubicDiscountCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, LogMixedLinearCubic jarg5_);
  public final static native long new_LogMixedLinearCubicDiscountCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_LogMixedLinearCubicDiscountCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long LogMixedLinearCubicDiscountCurve_times(long jarg1, LogMixedLinearCubicDiscountCurve jarg1_);
  public final static native long LogMixedLinearCubicDiscountCurve_data(long jarg1, LogMixedLinearCubicDiscountCurve jarg1_);
  public final static native long LogMixedLinearCubicDiscountCurve_dates(long jarg1, LogMixedLinearCubicDiscountCurve jarg1_);
  public final static native long LogMixedLinearCubicDiscountCurve_discounts(long jarg1, LogMixedLinearCubicDiscountCurve jarg1_);
  public final static native long LogMixedLinearCubicDiscountCurve_nodes(long jarg1, LogMixedLinearCubicDiscountCurve jarg1_);
  public final static native void delete_LogMixedLinearCubicDiscountCurve(long jarg1);
  public final static native long new_NormalDistribution__SWIG_0(double jarg1, double jarg2);
  public final static native long new_NormalDistribution__SWIG_1(double jarg1);
  public final static native long new_NormalDistribution__SWIG_2();
  public final static native double NormalDistribution_getValue(long jarg1, NormalDistribution jarg1_, double jarg2);
  public final static native double NormalDistribution_derivative(long jarg1, NormalDistribution jarg1_, double jarg2);
  public final static native void delete_NormalDistribution(long jarg1);
  public final static native long new_CumulativeNormalDistribution__SWIG_0(double jarg1, double jarg2);
  public final static native long new_CumulativeNormalDistribution__SWIG_1(double jarg1);
  public final static native long new_CumulativeNormalDistribution__SWIG_2();
  public final static native double CumulativeNormalDistribution_getValue(long jarg1, CumulativeNormalDistribution jarg1_, double jarg2);
  public final static native double CumulativeNormalDistribution_derivative(long jarg1, CumulativeNormalDistribution jarg1_, double jarg2);
  public final static native void delete_CumulativeNormalDistribution(long jarg1);
  public final static native long new_InverseCumulativeNormal__SWIG_0(double jarg1, double jarg2);
  public final static native long new_InverseCumulativeNormal__SWIG_1(double jarg1);
  public final static native long new_InverseCumulativeNormal__SWIG_2();
  public final static native double InverseCumulativeNormal_getValue(long jarg1, InverseCumulativeNormal jarg1_, double jarg2);
  public final static native void delete_InverseCumulativeNormal(long jarg1);
  public final static native long new_MoroInverseCumulativeNormal__SWIG_0(double jarg1, double jarg2);
  public final static native long new_MoroInverseCumulativeNormal__SWIG_1(double jarg1);
  public final static native long new_MoroInverseCumulativeNormal__SWIG_2();
  public final static native double MoroInverseCumulativeNormal_getValue(long jarg1, MoroInverseCumulativeNormal jarg1_, double jarg2);
  public final static native void delete_MoroInverseCumulativeNormal(long jarg1);
  public final static native long new_BivariateCumulativeNormalDistribution(double jarg1);
  public final static native double BivariateCumulativeNormalDistribution_getValue(long jarg1, BivariateCumulativeNormalDistribution jarg1_, double jarg2, double jarg3);
  public final static native void delete_BivariateCumulativeNormalDistribution(long jarg1);
  public final static native long new_BinomialDistribution(double jarg1, long jarg2);
  public final static native double BinomialDistribution_getValue(long jarg1, BinomialDistribution jarg1_, long jarg2);
  public final static native void delete_BinomialDistribution(long jarg1);
  public final static native long new_CumulativeBinomialDistribution(double jarg1, long jarg2);
  public final static native double CumulativeBinomialDistribution_getValue(long jarg1, CumulativeBinomialDistribution jarg1_, long jarg2);
  public final static native void delete_CumulativeBinomialDistribution(long jarg1);
  public final static native long new_BivariateCumulativeNormalDistributionDr78(double jarg1);
  public final static native double BivariateCumulativeNormalDistributionDr78_getValue(long jarg1, BivariateCumulativeNormalDistributionDr78 jarg1_, double jarg2, double jarg3);
  public final static native void delete_BivariateCumulativeNormalDistributionDr78(long jarg1);
  public final static native long new_BivariateCumulativeNormalDistributionWe04DP(double jarg1);
  public final static native double BivariateCumulativeNormalDistributionWe04DP_getValue(long jarg1, BivariateCumulativeNormalDistributionWe04DP jarg1_, double jarg2, double jarg3);
  public final static native void delete_BivariateCumulativeNormalDistributionWe04DP(long jarg1);
  public final static native long new_CumulativeChiSquareDistribution(double jarg1);
  public final static native double CumulativeChiSquareDistribution_getValue(long jarg1, CumulativeChiSquareDistribution jarg1_, double jarg2);
  public final static native void delete_CumulativeChiSquareDistribution(long jarg1);
  public final static native long new_NonCentralCumulativeChiSquareDistribution(double jarg1, double jarg2);
  public final static native double NonCentralCumulativeChiSquareDistribution_getValue(long jarg1, NonCentralCumulativeChiSquareDistribution jarg1_, double jarg2);
  public final static native void delete_NonCentralCumulativeChiSquareDistribution(long jarg1);
  public final static native long new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_0(double jarg1, double jarg2, long jarg3, double jarg4);
  public final static native long new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_1(double jarg1, double jarg2, long jarg3);
  public final static native long new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_2(double jarg1, double jarg2);
  public final static native double InverseNonCentralCumulativeChiSquareDistribution_getValue(long jarg1, InverseNonCentralCumulativeChiSquareDistribution jarg1_, double jarg2);
  public final static native void delete_InverseNonCentralCumulativeChiSquareDistribution(long jarg1);
  public final static native long new_CumulativeGammaDistribution(double jarg1);
  public final static native double CumulativeGammaDistribution_getValue(long jarg1, CumulativeGammaDistribution jarg1_, double jarg2);
  public final static native void delete_CumulativeGammaDistribution(long jarg1);
  public final static native double GammaFunction_logValue(long jarg1, GammaFunction jarg1_, double jarg2);
  public final static native long new_GammaFunction();
  public final static native void delete_GammaFunction(long jarg1);
  public final static native long new_PoissonDistribution(double jarg1);
  public final static native double PoissonDistribution_getValue(long jarg1, PoissonDistribution jarg1_, long jarg2);
  public final static native void delete_PoissonDistribution(long jarg1);
  public final static native long new_CumulativePoissonDistribution(double jarg1);
  public final static native double CumulativePoissonDistribution_getValue(long jarg1, CumulativePoissonDistribution jarg1_, long jarg2);
  public final static native void delete_CumulativePoissonDistribution(long jarg1);
  public final static native long new_InverseCumulativePoisson(double jarg1);
  public final static native double InverseCumulativePoisson_getValue(long jarg1, InverseCumulativePoisson jarg1_, double jarg2);
  public final static native void delete_InverseCumulativePoisson(long jarg1);
  public final static native long new_StudentDistribution(int jarg1);
  public final static native double StudentDistribution_getValue(long jarg1, StudentDistribution jarg1_, double jarg2);
  public final static native void delete_StudentDistribution(long jarg1);
  public final static native long new_CumulativeStudentDistribution(int jarg1);
  public final static native double CumulativeStudentDistribution_getValue(long jarg1, CumulativeStudentDistribution jarg1_, double jarg2);
  public final static native void delete_CumulativeStudentDistribution(long jarg1);
  public final static native long new_InverseCumulativeStudent__SWIG_0(int jarg1, double jarg2, long jarg3);
  public final static native long new_InverseCumulativeStudent__SWIG_1(int jarg1, double jarg2);
  public final static native long new_InverseCumulativeStudent__SWIG_2(int jarg1);
  public final static native double InverseCumulativeStudent_getValue(long jarg1, InverseCumulativeStudent jarg1_, double jarg2);
  public final static native void delete_InverseCumulativeStudent(long jarg1);
  public final static native long new_Money__SWIG_0(long jarg1, Currency jarg1_, double jarg2);
  public final static native long new_Money__SWIG_1(double jarg1, long jarg2, Currency jarg2_);
  public final static native long Money_currency(long jarg1, Money jarg1_);
  public final static native double Money_value(long jarg1, Money jarg1_);
  public final static native long Money_rounded(long jarg1, Money jarg1_);
  public final static native long Money_add__SWIG_0(long jarg1, Money jarg1_);
  public final static native long Money_subtract__SWIG_0(long jarg1, Money jarg1_);
  public final static native long Money_add__SWIG_1(long jarg1, Money jarg1_, long jarg2, Money jarg2_);
  public final static native long Money_subtract__SWIG_1(long jarg1, Money jarg1_, long jarg2, Money jarg2_);
  public final static native long Money_multiply(long jarg1, Money jarg1_, double jarg2);
  public final static native long Money_divide__SWIG_0(long jarg1, Money jarg1_, double jarg2);
  public final static native double Money_divide__SWIG_1(long jarg1, Money jarg1_, long jarg2, Money jarg2_);
  public final static native int Money_compare(long jarg1, Money jarg1_, long jarg2, Money jarg2_);
  public final static native String Money_toString(long jarg1, Money jarg1_);
  public final static native void Money_setConversionType(int jarg1);
  public final static native void Money_setBaseCurrency(long jarg1, Currency jarg1_);
  public final static native void delete_Money(long jarg1);
  public final static native long new_ExchangeRate(long jarg1, Currency jarg1_, long jarg2, Currency jarg2_, double jarg3);
  public final static native long ExchangeRate_source(long jarg1, ExchangeRate jarg1_);
  public final static native long ExchangeRate_target(long jarg1, ExchangeRate jarg1_);
  public final static native int ExchangeRate_type(long jarg1, ExchangeRate jarg1_);
  public final static native double ExchangeRate_rate(long jarg1, ExchangeRate jarg1_);
  public final static native long ExchangeRate_exchange(long jarg1, ExchangeRate jarg1_, long jarg2, Money jarg2_);
  public final static native long ExchangeRate_chain(long jarg1, ExchangeRate jarg1_, long jarg2, ExchangeRate jarg2_);
  public final static native void delete_ExchangeRate(long jarg1);
  public final static native long ExchangeRateManager_instance();
  public final static native void ExchangeRateManager_add__SWIG_0(long jarg1, ExchangeRateManager jarg1_, long jarg2, ExchangeRate jarg2_, long jarg3, Date jarg3_, long jarg4, Date jarg4_);
  public final static native void ExchangeRateManager_add__SWIG_1(long jarg1, ExchangeRateManager jarg1_, long jarg2, ExchangeRate jarg2_, long jarg3, Date jarg3_);
  public final static native void ExchangeRateManager_add__SWIG_2(long jarg1, ExchangeRateManager jarg1_, long jarg2, ExchangeRate jarg2_);
  public final static native long ExchangeRateManager_lookup__SWIG_0(long jarg1, ExchangeRateManager jarg1_, long jarg2, Currency jarg2_, long jarg3, Currency jarg3_, long jarg4, Date jarg4_, int jarg5);
  public final static native long ExchangeRateManager_lookup__SWIG_1(long jarg1, ExchangeRateManager jarg1_, long jarg2, Currency jarg2_, long jarg3, Currency jarg3_, long jarg4, Date jarg4_);
  public final static native void ExchangeRateManager_clear(long jarg1, ExchangeRateManager jarg1_);
  public final static native void delete_ExchangeRateManager(long jarg1);
  public final static native long Settings_instance();
  public final static native long Settings_getEvaluationDate(long jarg1, Settings jarg1_);
  public final static native void Settings_setEvaluationDate(long jarg1, Settings jarg1_, long jarg2, Date jarg2_);
  public final static native void Settings_includeReferenceDateEvents(long jarg1, Settings jarg1_, boolean jarg2);
  public final static native void Settings_includeTodaysCashFlows(long jarg1, Settings jarg1_, boolean jarg2);
  public final static native void Settings_setEnforcesTodaysHistoricFixings(long jarg1, Settings jarg1_, boolean jarg2);
  public final static native boolean Settings_getEnforcesTodaysHistoricFixings(long jarg1, Settings jarg1_);
  public final static native void delete_Settings(long jarg1);
  public final static native long new_Fdm1dMesher(long jarg1);
  public final static native long Fdm1dMesher_size(long jarg1, Fdm1dMesher jarg1_);
  public final static native double Fdm1dMesher_dplus(long jarg1, Fdm1dMesher jarg1_, long jarg2);
  public final static native double Fdm1dMesher_dminus(long jarg1, Fdm1dMesher jarg1_, long jarg2);
  public final static native double Fdm1dMesher_location(long jarg1, Fdm1dMesher jarg1_, long jarg2);
  public final static native long Fdm1dMesher_locations(long jarg1, Fdm1dMesher jarg1_);
  public final static native void delete_Fdm1dMesher(long jarg1);
  public final static native long new_Fdm1dMesherVector__SWIG_0();
  public final static native long new_Fdm1dMesherVector__SWIG_1(long jarg1, Fdm1dMesherVector jarg1_);
  public final static native long Fdm1dMesherVector_capacity(long jarg1, Fdm1dMesherVector jarg1_);
  public final static native void Fdm1dMesherVector_reserve(long jarg1, Fdm1dMesherVector jarg1_, long jarg2);
  public final static native boolean Fdm1dMesherVector_isEmpty(long jarg1, Fdm1dMesherVector jarg1_);
  public final static native void Fdm1dMesherVector_clear(long jarg1, Fdm1dMesherVector jarg1_);
  public final static native long new_Fdm1dMesherVector__SWIG_2(int jarg1, long jarg2, Fdm1dMesher jarg2_);
  public final static native int Fdm1dMesherVector_doSize(long jarg1, Fdm1dMesherVector jarg1_);
  public final static native void Fdm1dMesherVector_doAdd__SWIG_0(long jarg1, Fdm1dMesherVector jarg1_, long jarg2, Fdm1dMesher jarg2_);
  public final static native void Fdm1dMesherVector_doAdd__SWIG_1(long jarg1, Fdm1dMesherVector jarg1_, int jarg2, long jarg3, Fdm1dMesher jarg3_);
  public final static native long Fdm1dMesherVector_doRemove(long jarg1, Fdm1dMesherVector jarg1_, int jarg2);
  public final static native long Fdm1dMesherVector_doGet(long jarg1, Fdm1dMesherVector jarg1_, int jarg2);
  public final static native long Fdm1dMesherVector_doSet(long jarg1, Fdm1dMesherVector jarg1_, int jarg2, long jarg3, Fdm1dMesher jarg3_);
  public final static native void Fdm1dMesherVector_doRemoveRange(long jarg1, Fdm1dMesherVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_Fdm1dMesherVector(long jarg1);
  public final static native long new_FdmBlackScholesMesher__SWIG_0(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9, DoublePair jarg9_, long jarg10, DividendSchedule jarg10_, long jarg11, FdmQuantoHelper jarg11_, double jarg12);
  public final static native long new_FdmBlackScholesMesher__SWIG_1(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9, DoublePair jarg9_, long jarg10, DividendSchedule jarg10_, long jarg11, FdmQuantoHelper jarg11_);
  public final static native long new_FdmBlackScholesMesher__SWIG_2(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9, DoublePair jarg9_, long jarg10, DividendSchedule jarg10_);
  public final static native long new_FdmBlackScholesMesher__SWIG_3(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, long jarg9, DoublePair jarg9_);
  public final static native long new_FdmBlackScholesMesher__SWIG_4(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);
  public final static native long new_FdmBlackScholesMesher__SWIG_5(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native long new_FdmBlackScholesMesher__SWIG_6(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_FdmBlackScholesMesher__SWIG_7(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native long new_FdmBlackScholesMesher__SWIG_8(long jarg1, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, double jarg4);
  public final static native long FdmBlackScholesMesher_processHelper(long jarg1, QuoteHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, double jarg4);
  public final static native void delete_FdmBlackScholesMesher(long jarg1);
  public final static native long new_Concentrating1dMesherPoint(double jarg1, double jarg2, boolean jarg3);
  public final static native double Concentrating1dMesherPoint_first(long jarg1, Concentrating1dMesherPoint jarg1_);
  public final static native double Concentrating1dMesherPoint_second(long jarg1, Concentrating1dMesherPoint jarg1_);
  public final static native boolean Concentrating1dMesherPoint_third(long jarg1, Concentrating1dMesherPoint jarg1_);
  public final static native void delete_Concentrating1dMesherPoint(long jarg1);
  public final static native long new_Concentrating1dMesherPointVector__SWIG_0();
  public final static native long new_Concentrating1dMesherPointVector__SWIG_1(long jarg1, Concentrating1dMesherPointVector jarg1_);
  public final static native long Concentrating1dMesherPointVector_capacity(long jarg1, Concentrating1dMesherPointVector jarg1_);
  public final static native void Concentrating1dMesherPointVector_reserve(long jarg1, Concentrating1dMesherPointVector jarg1_, long jarg2);
  public final static native boolean Concentrating1dMesherPointVector_isEmpty(long jarg1, Concentrating1dMesherPointVector jarg1_);
  public final static native void Concentrating1dMesherPointVector_clear(long jarg1, Concentrating1dMesherPointVector jarg1_);
  public final static native long new_Concentrating1dMesherPointVector__SWIG_2(int jarg1, long jarg2, Concentrating1dMesherPoint jarg2_);
  public final static native int Concentrating1dMesherPointVector_doSize(long jarg1, Concentrating1dMesherPointVector jarg1_);
  public final static native void Concentrating1dMesherPointVector_doAdd__SWIG_0(long jarg1, Concentrating1dMesherPointVector jarg1_, long jarg2, Concentrating1dMesherPoint jarg2_);
  public final static native void Concentrating1dMesherPointVector_doAdd__SWIG_1(long jarg1, Concentrating1dMesherPointVector jarg1_, int jarg2, long jarg3, Concentrating1dMesherPoint jarg3_);
  public final static native long Concentrating1dMesherPointVector_doRemove(long jarg1, Concentrating1dMesherPointVector jarg1_, int jarg2);
  public final static native long Concentrating1dMesherPointVector_doGet(long jarg1, Concentrating1dMesherPointVector jarg1_, int jarg2);
  public final static native long Concentrating1dMesherPointVector_doSet(long jarg1, Concentrating1dMesherPointVector jarg1_, int jarg2, long jarg3, Concentrating1dMesherPoint jarg3_);
  public final static native void Concentrating1dMesherPointVector_doRemoveRange(long jarg1, Concentrating1dMesherPointVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_Concentrating1dMesherPointVector(long jarg1);
  public final static native long new_Concentrating1dMesher__SWIG_0(double jarg1, double jarg2, long jarg3, long jarg4, DoublePair jarg4_, boolean jarg5);
  public final static native long new_Concentrating1dMesher__SWIG_1(double jarg1, double jarg2, long jarg3, long jarg4, DoublePair jarg4_);
  public final static native long new_Concentrating1dMesher__SWIG_2(double jarg1, double jarg2, long jarg3);
  public final static native long new_Concentrating1dMesher__SWIG_3(double jarg1, double jarg2, long jarg3, long jarg4, Concentrating1dMesherPointVector jarg4_, double jarg5);
  public final static native long new_Concentrating1dMesher__SWIG_4(double jarg1, double jarg2, long jarg3, long jarg4, Concentrating1dMesherPointVector jarg4_);
  public final static native void delete_Concentrating1dMesher(long jarg1);
  public final static native long new_ExponentialJump1dMesher__SWIG_0(long jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native long new_ExponentialJump1dMesher__SWIG_1(long jarg1, double jarg2, double jarg3, double jarg4);
  public final static native void delete_ExponentialJump1dMesher(long jarg1);
  public final static native long new_FdmCEV1dMesher__SWIG_0(long jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, long jarg8, DoublePair jarg8_);
  public final static native long new_FdmCEV1dMesher__SWIG_1(long jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native long new_FdmCEV1dMesher__SWIG_2(long jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);
  public final static native long new_FdmCEV1dMesher__SWIG_3(long jarg1, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void delete_FdmCEV1dMesher(long jarg1);
  public final static native long new_FdmHestonVarianceMesher__SWIG_0(long jarg1, long jarg2, HestonProcess jarg2_, double jarg3, long jarg4, double jarg5);
  public final static native long new_FdmHestonVarianceMesher__SWIG_1(long jarg1, long jarg2, HestonProcess jarg2_, double jarg3, long jarg4);
  public final static native long new_FdmHestonVarianceMesher__SWIG_2(long jarg1, long jarg2, HestonProcess jarg2_, double jarg3);
  public final static native double FdmHestonVarianceMesher_volaEstimate(long jarg1, FdmHestonVarianceMesher jarg1_);
  public final static native void delete_FdmHestonVarianceMesher(long jarg1);
  public final static native long new_FdmHestonLocalVolatilityVarianceMesher__SWIG_0(long jarg1, long jarg2, HestonProcess jarg2_, long jarg3, LocalVolTermStructure jarg3_, double jarg4, long jarg5, double jarg6);
  public final static native long new_FdmHestonLocalVolatilityVarianceMesher__SWIG_1(long jarg1, long jarg2, HestonProcess jarg2_, long jarg3, LocalVolTermStructure jarg3_, double jarg4, long jarg5);
  public final static native long new_FdmHestonLocalVolatilityVarianceMesher__SWIG_2(long jarg1, long jarg2, HestonProcess jarg2_, long jarg3, LocalVolTermStructure jarg3_, double jarg4);
  public final static native double FdmHestonLocalVolatilityVarianceMesher_volaEstimate(long jarg1, FdmHestonLocalVolatilityVarianceMesher jarg1_);
  public final static native void delete_FdmHestonLocalVolatilityVarianceMesher(long jarg1);
  public final static native long new_FdmSimpleProcess1dMesher__SWIG_0(long jarg1, long jarg2, StochasticProcess1D jarg2_, double jarg3, long jarg4, double jarg5, double jarg6);
  public final static native long new_FdmSimpleProcess1dMesher__SWIG_1(long jarg1, long jarg2, StochasticProcess1D jarg2_, double jarg3, long jarg4, double jarg5);
  public final static native long new_FdmSimpleProcess1dMesher__SWIG_2(long jarg1, long jarg2, StochasticProcess1D jarg2_, double jarg3, long jarg4);
  public final static native long new_FdmSimpleProcess1dMesher__SWIG_3(long jarg1, long jarg2, StochasticProcess1D jarg2_, double jarg3);
  public final static native void delete_FdmSimpleProcess1dMesher(long jarg1);
  public final static native long new_Uniform1dMesher(double jarg1, double jarg2, long jarg3);
  public final static native void delete_Uniform1dMesher(long jarg1);
  public final static native long new_Predefined1dMesher(long jarg1, DoubleVector jarg1_);
  public final static native void delete_Predefined1dMesher(long jarg1);
  public final static native long new_Glued1dMesher(long jarg1, Fdm1dMesher jarg1_, long jarg2, Fdm1dMesher jarg2_);
  public final static native void delete_Glued1dMesher(long jarg1);
  public final static native long new_FdmLinearOpIterator__SWIG_0(long jarg1, UnsignedIntVector jarg1_);
  public final static native long new_FdmLinearOpIterator__SWIG_1(long jarg1, UnsignedIntVector jarg1_, long jarg2, UnsignedIntVector jarg2_, long jarg3);
  public final static native long FdmLinearOpIterator_coordinates(long jarg1, FdmLinearOpIterator jarg1_);
  public final static native void FdmLinearOpIterator_increment(long jarg1, FdmLinearOpIterator jarg1_);
  public final static native boolean FdmLinearOpIterator_notEqual(long jarg1, FdmLinearOpIterator jarg1_, long jarg2, FdmLinearOpIterator jarg2_);
  public final static native long FdmLinearOpIterator_index(long jarg1, FdmLinearOpIterator jarg1_);
  public final static native void delete_FdmLinearOpIterator(long jarg1);
  public final static native long new_FdmLinearOpLayout(long jarg1, UnsignedIntVector jarg1_);
  public final static native long FdmLinearOpLayout_spacing(long jarg1, FdmLinearOpLayout jarg1_);
  public final static native long FdmLinearOpLayout_dim(long jarg1, FdmLinearOpLayout jarg1_);
  public final static native long FdmLinearOpLayout_index(long jarg1, FdmLinearOpLayout jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native long FdmLinearOpLayout_begin(long jarg1, FdmLinearOpLayout jarg1_);
  public final static native long FdmLinearOpLayout_end(long jarg1, FdmLinearOpLayout jarg1_);
  public final static native long FdmLinearOpLayout_size(long jarg1, FdmLinearOpLayout jarg1_);
  public final static native long FdmLinearOpLayout_neighbourhood__SWIG_0(long jarg1, FdmLinearOpLayout jarg1_, long jarg2, FdmLinearOpIterator jarg2_, long jarg3, int jarg4);
  public final static native long FdmLinearOpLayout_neighbourhood__SWIG_1(long jarg1, FdmLinearOpLayout jarg1_, long jarg2, FdmLinearOpIterator jarg2_, long jarg3, int jarg4, long jarg5, int jarg6);
  public final static native long FdmLinearOpLayout_iter_neighbourhood(long jarg1, FdmLinearOpLayout jarg1_, long jarg2, FdmLinearOpIterator jarg2_, long jarg3, int jarg4);
  public final static native void delete_FdmLinearOpLayout(long jarg1);
  public final static native double FdmMesher_dplus(long jarg1, FdmMesher jarg1_, long jarg2, FdmLinearOpIterator jarg2_, long jarg3);
  public final static native double FdmMesher_dminus(long jarg1, FdmMesher jarg1_, long jarg2, FdmLinearOpIterator jarg2_, long jarg3);
  public final static native double FdmMesher_location(long jarg1, FdmMesher jarg1_, long jarg2, FdmLinearOpIterator jarg2_, long jarg3);
  public final static native long FdmMesher_locations(long jarg1, FdmMesher jarg1_, long jarg2);
  public final static native long FdmMesher_layout(long jarg1, FdmMesher jarg1_);
  public final static native void delete_FdmMesher(long jarg1);
  public final static native long new_FdmMesherComposite__SWIG_0(long jarg1, FdmLinearOpLayout jarg1_, long jarg2, Fdm1dMesherVector jarg2_);
  public final static native long new_FdmMesherComposite__SWIG_1(long jarg1, Fdm1dMesherVector jarg1_);
  public final static native long new_FdmMesherComposite__SWIG_2(long jarg1, Fdm1dMesher jarg1_);
  public final static native long new_FdmMesherComposite__SWIG_3(long jarg1, Fdm1dMesher jarg1_, long jarg2, Fdm1dMesher jarg2_);
  public final static native long new_FdmMesherComposite__SWIG_4(long jarg1, Fdm1dMesher jarg1_, long jarg2, Fdm1dMesher jarg2_, long jarg3, Fdm1dMesher jarg3_);
  public final static native long new_FdmMesherComposite__SWIG_5(long jarg1, Fdm1dMesher jarg1_, long jarg2, Fdm1dMesher jarg2_, long jarg3, Fdm1dMesher jarg3_, long jarg4, Fdm1dMesher jarg4_);
  public final static native long FdmMesherComposite_getFdm1dMeshers(long jarg1, FdmMesherComposite jarg1_);
  public final static native void delete_FdmMesherComposite(long jarg1);
  public final static native long FdmLinearOp_apply(long jarg1, FdmLinearOp jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_FdmLinearOp(long jarg1);
  public final static native void SparseMatrix_row_idx_set(long jarg1, SparseMatrix jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native long SparseMatrix_row_idx_get(long jarg1, SparseMatrix jarg1_);
  public final static native void SparseMatrix_col_idx_set(long jarg1, SparseMatrix jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native long SparseMatrix_col_idx_get(long jarg1, SparseMatrix jarg1_);
  public final static native void SparseMatrix_data_set(long jarg1, SparseMatrix jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long SparseMatrix_data_get(long jarg1, SparseMatrix jarg1_);
  public final static native long new_SparseMatrix();
  public final static native void delete_SparseMatrix(long jarg1);
  public final static native long FdmLinearOpComposite_size(long jarg1, FdmLinearOpComposite jarg1_);
  public final static native void FdmLinearOpComposite_setTime(long jarg1, FdmLinearOpComposite jarg1_, double jarg2, double jarg3);
  public final static native long FdmLinearOpComposite_apply_mixed(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, Array jarg2_);
  public final static native long FdmLinearOpComposite_apply_direction(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, long jarg3, Array jarg3_);
  public final static native long FdmLinearOpComposite_solve_splitting(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, long jarg3, Array jarg3_, double jarg4);
  public final static native long FdmLinearOpComposite_preconditioner(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native long FdmLinearOpComposite_to_sparse_matrix(long jarg1, FdmLinearOpComposite jarg1_);
  public final static native void delete_FdmLinearOpComposite(long jarg1);
  public final static native long new_FdmLinearOpCompositeProxy(long jarg1, FdmLinearOpCompositeDelegate jarg1_);
  public final static native void delete_FdmLinearOpCompositeProxy(long jarg1);
  public final static native void delete_FdmLinearOpCompositeDelegate(long jarg1);
  public final static native long FdmLinearOpCompositeDelegate_size(long jarg1, FdmLinearOpCompositeDelegate jarg1_);
  public final static native long FdmLinearOpCompositeDelegate_sizeSwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_);
  public final static native void FdmLinearOpCompositeDelegate_setTime(long jarg1, FdmLinearOpCompositeDelegate jarg1_, double jarg2, double jarg3);
  public final static native void FdmLinearOpCompositeDelegate_setTimeSwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_, double jarg2, double jarg3);
  public final static native long FdmLinearOpCompositeDelegate_apply(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long FdmLinearOpCompositeDelegate_applySwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long FdmLinearOpCompositeDelegate_apply_mixed(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long FdmLinearOpCompositeDelegate_apply_mixedSwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, Array jarg2_);
  public final static native long FdmLinearOpCompositeDelegate_apply_direction(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, long jarg3, Array jarg3_);
  public final static native long FdmLinearOpCompositeDelegate_apply_directionSwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, long jarg3, Array jarg3_);
  public final static native long FdmLinearOpCompositeDelegate_solve_splitting(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, long jarg3, Array jarg3_, double jarg4);
  public final static native long FdmLinearOpCompositeDelegate_solve_splittingSwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, long jarg3, Array jarg3_, double jarg4);
  public final static native long FdmLinearOpCompositeDelegate_preconditioner(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native long FdmLinearOpCompositeDelegate_preconditionerSwigExplicitFdmLinearOpCompositeDelegate(long jarg1, FdmLinearOpCompositeDelegate jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native long new_FdmLinearOpCompositeDelegate();
  public final static native void FdmLinearOpCompositeDelegate_director_connect(FdmLinearOpCompositeDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void FdmLinearOpCompositeDelegate_change_ownership(FdmLinearOpCompositeDelegate obj, long cptr, boolean take_or_release);
  public final static native void FdmBoundaryCondition_applyBeforeApplying(long jarg1, FdmBoundaryCondition jarg1_, long jarg2, FdmLinearOp jarg2_);
  public final static native void FdmBoundaryCondition_applyAfterApplying(long jarg1, FdmBoundaryCondition jarg1_, long jarg2, Array jarg2_);
  public final static native void FdmBoundaryCondition_applyBeforeSolving(long jarg1, FdmBoundaryCondition jarg1_, long jarg2, FdmLinearOp jarg2_, long jarg3, Array jarg3_);
  public final static native void FdmBoundaryCondition_applyAfterSolving(long jarg1, FdmBoundaryCondition jarg1_, long jarg2, Array jarg2_);
  public final static native void FdmBoundaryCondition_setTime(long jarg1, FdmBoundaryCondition jarg1_, double jarg2);
  public final static native void delete_FdmBoundaryCondition(long jarg1);
  public final static native long new_FdmBoundaryConditionSet__SWIG_0();
  public final static native long new_FdmBoundaryConditionSet__SWIG_1(long jarg1, FdmBoundaryConditionSet jarg1_);
  public final static native long FdmBoundaryConditionSet_capacity(long jarg1, FdmBoundaryConditionSet jarg1_);
  public final static native void FdmBoundaryConditionSet_reserve(long jarg1, FdmBoundaryConditionSet jarg1_, long jarg2);
  public final static native boolean FdmBoundaryConditionSet_isEmpty(long jarg1, FdmBoundaryConditionSet jarg1_);
  public final static native void FdmBoundaryConditionSet_clear(long jarg1, FdmBoundaryConditionSet jarg1_);
  public final static native long new_FdmBoundaryConditionSet__SWIG_2(int jarg1, long jarg2, FdmBoundaryCondition jarg2_);
  public final static native int FdmBoundaryConditionSet_doSize(long jarg1, FdmBoundaryConditionSet jarg1_);
  public final static native void FdmBoundaryConditionSet_doAdd__SWIG_0(long jarg1, FdmBoundaryConditionSet jarg1_, long jarg2, FdmBoundaryCondition jarg2_);
  public final static native void FdmBoundaryConditionSet_doAdd__SWIG_1(long jarg1, FdmBoundaryConditionSet jarg1_, int jarg2, long jarg3, FdmBoundaryCondition jarg3_);
  public final static native long FdmBoundaryConditionSet_doRemove(long jarg1, FdmBoundaryConditionSet jarg1_, int jarg2);
  public final static native long FdmBoundaryConditionSet_doGet(long jarg1, FdmBoundaryConditionSet jarg1_, int jarg2);
  public final static native long FdmBoundaryConditionSet_doSet(long jarg1, FdmBoundaryConditionSet jarg1_, int jarg2, long jarg3, FdmBoundaryCondition jarg3_);
  public final static native void FdmBoundaryConditionSet_doRemoveRange(long jarg1, FdmBoundaryConditionSet jarg1_, int jarg2, int jarg3);
  public final static native void delete_FdmBoundaryConditionSet(long jarg1);
  public final static native long new_FdmDirichletBoundary(long jarg1, FdmMesher jarg1_, double jarg2, long jarg3, int jarg4);
  public final static native void FdmDirichletBoundary_applyAfterApplying__SWIG_0(long jarg1, FdmDirichletBoundary jarg1_, long jarg2, Array jarg2_);
  public final static native double FdmDirichletBoundary_applyAfterApplying__SWIG_1(long jarg1, FdmDirichletBoundary jarg1_, double jarg2, double jarg3);
  public final static native void delete_FdmDirichletBoundary(long jarg1);
  public final static native long new_FdmDiscountDirichletBoundary(long jarg1, FdmMesher jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, double jarg4, long jarg5, int jarg6);
  public final static native void delete_FdmDiscountDirichletBoundary(long jarg1);
  public final static native long new_FdmTimeDepDirichletBoundary(long jarg1, FdmMesher jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, long jarg3, int jarg4);
  public final static native void delete_FdmTimeDepDirichletBoundary(long jarg1);
  public final static native long new_FdmBatesOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, BatesProcess jarg2_, long jarg3, FdmBoundaryConditionSet jarg3_, long jarg4, long jarg5, FdmQuantoHelper jarg5_);
  public final static native long new_FdmBatesOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, BatesProcess jarg2_, long jarg3, FdmBoundaryConditionSet jarg3_, long jarg4);
  public final static native void delete_FdmBatesOp(long jarg1);
  public final static native long new_FdmBlackScholesOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4, double jarg5, long jarg6, long jarg7, FdmQuantoHelper jarg7_);
  public final static native long new_FdmBlackScholesOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4, double jarg5, long jarg6);
  public final static native long new_FdmBlackScholesOp__SWIG_2(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4, double jarg5);
  public final static native long new_FdmBlackScholesOp__SWIG_3(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4);
  public final static native long new_FdmBlackScholesOp__SWIG_4(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3);
  public final static native void delete_FdmBlackScholesOp(long jarg1);
  public final static native long new_Fdm2dBlackScholesOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, double jarg5, boolean jarg6, double jarg7);
  public final static native long new_Fdm2dBlackScholesOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, double jarg5, boolean jarg6);
  public final static native long new_Fdm2dBlackScholesOp__SWIG_2(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, long jarg3, GeneralizedBlackScholesProcess jarg3_, double jarg4, double jarg5);
  public final static native void delete_Fdm2dBlackScholesOp(long jarg1);
  public final static native long new_FdmCEVOp(long jarg1, FdmMesher jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, double jarg4, double jarg5, long jarg6);
  public final static native void delete_FdmCEVOp(long jarg1);
  public final static native long new_FdmG2Op(long jarg1, FdmMesher jarg1_, long jarg2, G2 jarg2_, long jarg3, long jarg4);
  public final static native void delete_FdmG2Op(long jarg1);
  public final static native long new_FdmHestonHullWhiteOp(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_, long jarg3, HullWhiteProcess jarg3_, double jarg4);
  public final static native void delete_FdmHestonHullWhiteOp(long jarg1);
  public final static native long new_FdmHestonOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_, long jarg3, FdmQuantoHelper jarg3_, long jarg4, LocalVolTermStructure jarg4_);
  public final static native long new_FdmHestonOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_, long jarg3, FdmQuantoHelper jarg3_);
  public final static native long new_FdmHestonOp__SWIG_2(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_);
  public final static native void delete_FdmHestonOp(long jarg1);
  public final static native long new_FdmHullWhiteOp(long jarg1, FdmMesher jarg1_, long jarg2, HullWhite jarg2_, long jarg3);
  public final static native void delete_FdmHullWhiteOp(long jarg1);
  public final static native long new_FdmLocalVolFwdOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, Quote jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, YieldTermStructure jarg4_, long jarg5, LocalVolTermStructure jarg5_, long jarg6);
  public final static native long new_FdmLocalVolFwdOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, Quote jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, YieldTermStructure jarg4_, long jarg5, LocalVolTermStructure jarg5_);
  public final static native void delete_FdmLocalVolFwdOp(long jarg1);
  public final static native long new_FdmOrnsteinUhlenbeckOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, OrnsteinUhlenbeckProcess jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4);
  public final static native long new_FdmOrnsteinUhlenbeckOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, OrnsteinUhlenbeckProcess jarg2_, long jarg3, YieldTermStructure jarg3_);
  public final static native void delete_FdmOrnsteinUhlenbeckOp(long jarg1);
  public final static native long new_FdmSabrOp(long jarg1, FdmMesher jarg1_, long jarg2, YieldTermStructure jarg2_, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);
  public final static native void delete_FdmSabrOp(long jarg1);
  public final static native long new_FdmZabrOp(long jarg1, FdmMesher jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void delete_FdmZabrOp(long jarg1);
  public final static native long new_FdmDupire1dOp(long jarg1, FdmMesher jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_FdmDupire1dOp(long jarg1);
  public final static native long new_FdmBlackScholesFwdOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4, double jarg5, long jarg6);
  public final static native long new_FdmBlackScholesFwdOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4, double jarg5);
  public final static native long new_FdmBlackScholesFwdOp__SWIG_2(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, boolean jarg4);
  public final static native long new_FdmBlackScholesFwdOp__SWIG_3(long jarg1, FdmMesher jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3);
  public final static native void delete_FdmBlackScholesFwdOp(long jarg1);
  public final static native long new_FdmSquareRootFwdOp__SWIG_0(long jarg1, FdmMesher jarg1_, double jarg2, double jarg3, double jarg4, long jarg5, int jarg6);
  public final static native long new_FdmSquareRootFwdOp__SWIG_1(long jarg1, FdmMesher jarg1_, double jarg2, double jarg3, double jarg4, long jarg5);
  public final static native void delete_FdmSquareRootFwdOp(long jarg1);
  public final static native long new_FdmHestonFwdOp__SWIG_0(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_, int jarg3, long jarg4, LocalVolTermStructure jarg4_);
  public final static native long new_FdmHestonFwdOp__SWIG_1(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_, int jarg3);
  public final static native long new_FdmHestonFwdOp__SWIG_2(long jarg1, FdmMesher jarg1_, long jarg2, HestonProcess jarg2_);
  public final static native void delete_FdmHestonFwdOp(long jarg1);
  public final static native long new_TripleBandLinearOp(long jarg1, long jarg2, FdmMesher jarg2_);
  public final static native long TripleBandLinearOp_apply(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_);
  public final static native long TripleBandLinearOp_solve_splitting__SWIG_0(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4);
  public final static native long TripleBandLinearOp_solve_splitting__SWIG_1(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native long TripleBandLinearOp_mult(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_);
  public final static native long TripleBandLinearOp_multR(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_);
  public final static native long TripleBandLinearOp_add__SWIG_0(long jarg1, TripleBandLinearOp jarg1_, long jarg2, TripleBandLinearOp jarg2_);
  public final static native long TripleBandLinearOp_add__SWIG_1(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_);
  public final static native void TripleBandLinearOp_axpyb(long jarg1, TripleBandLinearOp jarg1_, long jarg2, Array jarg2_, long jarg3, TripleBandLinearOp jarg3_, long jarg4, TripleBandLinearOp jarg4_, long jarg5, Array jarg5_);
  public final static native void TripleBandLinearOp_swap(long jarg1, TripleBandLinearOp jarg1_, long jarg2, TripleBandLinearOp jarg2_);
  public final static native void delete_TripleBandLinearOp(long jarg1);
  public final static native long new_FirstDerivativeOp(long jarg1, long jarg2, FdmMesher jarg2_);
  public final static native void delete_FirstDerivativeOp(long jarg1);
  public final static native long new_SecondDerivativeOp(long jarg1, long jarg2, FdmMesher jarg2_);
  public final static native void delete_SecondDerivativeOp(long jarg1);
  public final static native long new_NinePointLinearOp(long jarg1, long jarg2, long jarg3, FdmMesher jarg3_);
  public final static native void delete_NinePointLinearOp(long jarg1);
  public final static native long new_SecondOrderMixedDerivativeOp(long jarg1, long jarg2, long jarg3, FdmMesher jarg3_);
  public final static native void delete_SecondOrderMixedDerivativeOp(long jarg1);
  public final static native long new_NthOrderDerivativeOp(long jarg1, long jarg2, int jarg3, long jarg4, FdmMesher jarg4_);
  public final static native void delete_NthOrderDerivativeOp(long jarg1);
  public final static native long new_CraigSneydScheme__SWIG_0(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_, long jarg4, FdmBoundaryConditionSet jarg4_);
  public final static native long new_CraigSneydScheme__SWIG_1(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native void CraigSneydScheme_step(long jarg1, CraigSneydScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void CraigSneydScheme_setStep(long jarg1, CraigSneydScheme jarg1_, double jarg2);
  public final static native void delete_CraigSneydScheme(long jarg1);
  public final static native long new_ImplicitEulerScheme__SWIG_0(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, FdmBoundaryConditionSet jarg2_, double jarg3, int jarg4);
  public final static native long new_ImplicitEulerScheme__SWIG_1(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, FdmBoundaryConditionSet jarg2_, double jarg3);
  public final static native long new_ImplicitEulerScheme__SWIG_2(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, FdmBoundaryConditionSet jarg2_);
  public final static native long new_ImplicitEulerScheme__SWIG_3(long jarg1, FdmLinearOpComposite jarg1_);
  public final static native void ImplicitEulerScheme_step(long jarg1, ImplicitEulerScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void ImplicitEulerScheme_setStep(long jarg1, ImplicitEulerScheme jarg1_, double jarg2);
  public final static native long ImplicitEulerScheme_numberOfIterations(long jarg1, ImplicitEulerScheme jarg1_);
  public final static native void delete_ImplicitEulerScheme(long jarg1);
  public final static native long new_CrankNicolsonScheme__SWIG_0(double jarg1, long jarg2, FdmLinearOpComposite jarg2_, long jarg3, FdmBoundaryConditionSet jarg3_, double jarg4, int jarg5);
  public final static native long new_CrankNicolsonScheme__SWIG_1(double jarg1, long jarg2, FdmLinearOpComposite jarg2_, long jarg3, FdmBoundaryConditionSet jarg3_, double jarg4);
  public final static native long new_CrankNicolsonScheme__SWIG_2(double jarg1, long jarg2, FdmLinearOpComposite jarg2_, long jarg3, FdmBoundaryConditionSet jarg3_);
  public final static native long new_CrankNicolsonScheme__SWIG_3(double jarg1, long jarg2, FdmLinearOpComposite jarg2_);
  public final static native void CrankNicolsonScheme_step(long jarg1, CrankNicolsonScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void CrankNicolsonScheme_setStep(long jarg1, CrankNicolsonScheme jarg1_, double jarg2);
  public final static native long CrankNicolsonScheme_numberOfIterations(long jarg1, CrankNicolsonScheme jarg1_);
  public final static native void delete_CrankNicolsonScheme(long jarg1);
  public final static native long new_DouglasScheme__SWIG_0(double jarg1, long jarg2, FdmLinearOpComposite jarg2_, long jarg3, FdmBoundaryConditionSet jarg3_);
  public final static native long new_DouglasScheme__SWIG_1(double jarg1, long jarg2, FdmLinearOpComposite jarg2_);
  public final static native void DouglasScheme_step(long jarg1, DouglasScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void DouglasScheme_setStep(long jarg1, DouglasScheme jarg1_, double jarg2);
  public final static native void delete_DouglasScheme(long jarg1);
  public final static native long new_ExplicitEulerScheme__SWIG_0(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, FdmBoundaryConditionSet jarg2_);
  public final static native long new_ExplicitEulerScheme__SWIG_1(long jarg1, FdmLinearOpComposite jarg1_);
  public final static native void ExplicitEulerScheme_step(long jarg1, ExplicitEulerScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void ExplicitEulerScheme_setStep(long jarg1, ExplicitEulerScheme jarg1_, double jarg2);
  public final static native void delete_ExplicitEulerScheme(long jarg1);
  public final static native long new_HundsdorferScheme__SWIG_0(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_, long jarg4, FdmBoundaryConditionSet jarg4_);
  public final static native long new_HundsdorferScheme__SWIG_1(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native void HundsdorferScheme_step(long jarg1, HundsdorferScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void HundsdorferScheme_setStep(long jarg1, HundsdorferScheme jarg1_, double jarg2);
  public final static native void delete_HundsdorferScheme(long jarg1);
  public final static native long new_MethodOfLinesScheme__SWIG_0(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_, long jarg4, FdmBoundaryConditionSet jarg4_);
  public final static native long new_MethodOfLinesScheme__SWIG_1(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native void MethodOfLinesScheme_step(long jarg1, MethodOfLinesScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void MethodOfLinesScheme_setStep(long jarg1, MethodOfLinesScheme jarg1_, double jarg2);
  public final static native void delete_MethodOfLinesScheme(long jarg1);
  public final static native long new_ModifiedCraigSneydScheme__SWIG_0(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_, long jarg4, FdmBoundaryConditionSet jarg4_);
  public final static native long new_ModifiedCraigSneydScheme__SWIG_1(double jarg1, double jarg2, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native void ModifiedCraigSneydScheme_step(long jarg1, ModifiedCraigSneydScheme jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void ModifiedCraigSneydScheme_setStep(long jarg1, ModifiedCraigSneydScheme jarg1_, double jarg2);
  public final static native void delete_ModifiedCraigSneydScheme(long jarg1);
  public final static native void FdmStepCondition_applyTo(long jarg1, FdmStepCondition jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void delete_FdmStepCondition(long jarg1);
  public final static native long new_FdmStepConditionProxy(long jarg1, FdmStepConditionDelegate jarg1_);
  public final static native void delete_FdmStepConditionProxy(long jarg1);
  public final static native void delete_FdmStepConditionDelegate(long jarg1);
  public final static native void FdmStepConditionDelegate_applyTo(long jarg1, FdmStepConditionDelegate jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void FdmStepConditionDelegate_applyToSwigExplicitFdmStepConditionDelegate(long jarg1, FdmStepConditionDelegate jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native long new_FdmStepConditionDelegate();
  public final static native void FdmStepConditionDelegate_director_connect(FdmStepConditionDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void FdmStepConditionDelegate_change_ownership(FdmStepConditionDelegate obj, long cptr, boolean take_or_release);
  public final static native double FdmInnerValueCalculator_innerValue(long jarg1, FdmInnerValueCalculator jarg1_, long jarg2, FdmLinearOpIterator jarg2_, double jarg3);
  public final static native double FdmInnerValueCalculator_avgInnerValue(long jarg1, FdmInnerValueCalculator jarg1_, long jarg2, FdmLinearOpIterator jarg2_, double jarg3);
  public final static native void delete_FdmInnerValueCalculator(long jarg1);
  public final static native long new_FdmInnerValueCalculatorProxy(long jarg1, FdmInnerValueCalculatorDelegate jarg1_);
  public final static native void delete_FdmInnerValueCalculatorProxy(long jarg1);
  public final static native void delete_FdmInnerValueCalculatorDelegate(long jarg1);
  public final static native double FdmInnerValueCalculatorDelegate_innerValue(long jarg1, FdmInnerValueCalculatorDelegate jarg1_, long jarg2, FdmLinearOpIterator jarg2_, double jarg3);
  public final static native double FdmInnerValueCalculatorDelegate_innerValueSwigExplicitFdmInnerValueCalculatorDelegate(long jarg1, FdmInnerValueCalculatorDelegate jarg1_, long jarg2, FdmLinearOpIterator jarg2_, double jarg3);
  public final static native double FdmInnerValueCalculatorDelegate_avgInnerValue(long jarg1, FdmInnerValueCalculatorDelegate jarg1_, long jarg2, FdmLinearOpIterator jarg2_, double jarg3);
  public final static native double FdmInnerValueCalculatorDelegate_avgInnerValueSwigExplicitFdmInnerValueCalculatorDelegate(long jarg1, FdmInnerValueCalculatorDelegate jarg1_, long jarg2, FdmLinearOpIterator jarg2_, double jarg3);
  public final static native long new_FdmInnerValueCalculatorDelegate();
  public final static native void FdmInnerValueCalculatorDelegate_director_connect(FdmInnerValueCalculatorDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void FdmInnerValueCalculatorDelegate_change_ownership(FdmInnerValueCalculatorDelegate obj, long cptr, boolean take_or_release);
  public final static native long new_FdmCellAveragingInnerValue__SWIG_0(long jarg1, Payoff jarg1_, long jarg2, FdmMesher jarg2_, long jarg3, long jarg4, UnaryFunctionDelegate jarg4_);
  public final static native long new_FdmCellAveragingInnerValue__SWIG_1(long jarg1, Payoff jarg1_, long jarg2, FdmMesher jarg2_, long jarg3);
  public final static native void delete_FdmCellAveragingInnerValue(long jarg1);
  public final static native long new_FdmLogInnerValue(long jarg1, Payoff jarg1_, long jarg2, FdmMesher jarg2_, long jarg3);
  public final static native void delete_FdmLogInnerValue(long jarg1);
  public final static native long new_FdmLogBasketInnerValue(long jarg1, BasketPayoff jarg1_, long jarg2, FdmMesher jarg2_);
  public final static native void delete_FdmLogBasketInnerValue(long jarg1);
  public final static native long new_FdmZeroInnerValue();
  public final static native void delete_FdmZeroInnerValue(long jarg1);
  public final static native long new_FdmAffineG2ModelSwapInnerValue(long jarg1, G2 jarg1_, long jarg2, G2 jarg2_, long jarg3, VanillaSwap jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, FdmMesher jarg6_, long jarg7);
  public final static native void delete_FdmAffineG2ModelSwapInnerValue(long jarg1);
  public final static native long new_FdmAffineHullWhiteModelSwapInnerValue(long jarg1, HullWhite jarg1_, long jarg2, HullWhite jarg2_, long jarg3, VanillaSwap jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, DateVector jarg5_, long jarg6, FdmMesher jarg6_, long jarg7);
  public final static native void delete_FdmAffineHullWhiteModelSwapInnerValue(long jarg1);
  public final static native long new_FdmSnapshotCondition(double jarg1);
  public final static native double FdmSnapshotCondition_getTime(long jarg1, FdmSnapshotCondition jarg1_);
  public final static native long FdmSnapshotCondition_getValues(long jarg1, FdmSnapshotCondition jarg1_);
  public final static native void delete_FdmSnapshotCondition(long jarg1);
  public final static native long new_FdmStepConditionVector__SWIG_0();
  public final static native long new_FdmStepConditionVector__SWIG_1(long jarg1, FdmStepConditionVector jarg1_);
  public final static native long FdmStepConditionVector_capacity(long jarg1, FdmStepConditionVector jarg1_);
  public final static native void FdmStepConditionVector_reserve(long jarg1, FdmStepConditionVector jarg1_, long jarg2);
  public final static native boolean FdmStepConditionVector_isEmpty(long jarg1, FdmStepConditionVector jarg1_);
  public final static native void FdmStepConditionVector_clear(long jarg1, FdmStepConditionVector jarg1_);
  public final static native long new_FdmStepConditionVector__SWIG_2(int jarg1, long jarg2, FdmStepCondition jarg2_);
  public final static native int FdmStepConditionVector_doSize(long jarg1, FdmStepConditionVector jarg1_);
  public final static native void FdmStepConditionVector_doAdd__SWIG_0(long jarg1, FdmStepConditionVector jarg1_, long jarg2, FdmStepCondition jarg2_);
  public final static native void FdmStepConditionVector_doAdd__SWIG_1(long jarg1, FdmStepConditionVector jarg1_, int jarg2, long jarg3, FdmStepCondition jarg3_);
  public final static native long FdmStepConditionVector_doRemove(long jarg1, FdmStepConditionVector jarg1_, int jarg2);
  public final static native long FdmStepConditionVector_doGet(long jarg1, FdmStepConditionVector jarg1_, int jarg2);
  public final static native long FdmStepConditionVector_doSet(long jarg1, FdmStepConditionVector jarg1_, int jarg2, long jarg3, FdmStepCondition jarg3_);
  public final static native void FdmStepConditionVector_doRemoveRange(long jarg1, FdmStepConditionVector jarg1_, int jarg2, int jarg3);
  public final static native void delete_FdmStepConditionVector(long jarg1);
  public final static native long new_FdmStepConditionComposite(long jarg1, DoubleVector jarg1_, long jarg2, FdmStepConditionVector jarg2_);
  public final static native long FdmStepConditionComposite_stoppingTimes(long jarg1, FdmStepConditionComposite jarg1_);
  public final static native long FdmStepConditionComposite_conditions(long jarg1, FdmStepConditionComposite jarg1_);
  public final static native long FdmStepConditionComposite_joinConditions(long jarg1, FdmSnapshotCondition jarg1_, long jarg2, FdmStepConditionComposite jarg2_);
  public final static native long FdmStepConditionComposite_vanillaComposite(long jarg1, DividendSchedule jarg1_, long jarg2, Exercise jarg2_, long jarg3, FdmMesher jarg3_, long jarg4, FdmInnerValueCalculator jarg4_, long jarg5, Date jarg5_, long jarg6, DayCounter jarg6_);
  public final static native void delete_FdmStepConditionComposite(long jarg1);
  public final static native long new_FdmAmericanStepCondition(long jarg1, FdmMesher jarg1_, long jarg2, FdmInnerValueCalculator jarg2_);
  public final static native void delete_FdmAmericanStepCondition(long jarg1);
  public final static native long new_FdmArithmeticAverageCondition(long jarg1, DoubleVector jarg1_, double jarg2, long jarg3, long jarg4, FdmMesher jarg4_, long jarg5);
  public final static native void delete_FdmArithmeticAverageCondition(long jarg1);
  public final static native long new_FdmBermudanStepCondition(long jarg1, DateVector jarg1_, long jarg2, Date jarg2_, long jarg3, DayCounter jarg3_, long jarg4, FdmMesher jarg4_, long jarg5, FdmInnerValueCalculator jarg5_);
  public final static native long FdmBermudanStepCondition_exerciseTimes(long jarg1, FdmBermudanStepCondition jarg1_);
  public final static native void delete_FdmBermudanStepCondition(long jarg1);
  public final static native long new_FdmSimpleStorageCondition(long jarg1, DoubleVector jarg1_, long jarg2, FdmMesher jarg2_, long jarg3, FdmInnerValueCalculator jarg3_, double jarg4);
  public final static native void delete_FdmSimpleStorageCondition(long jarg1);
  public final static native long new_FdmSimpleSwingCondition__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, FdmMesher jarg2_, long jarg3, FdmInnerValueCalculator jarg3_, long jarg4, long jarg5);
  public final static native long new_FdmSimpleSwingCondition__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, FdmMesher jarg2_, long jarg3, FdmInnerValueCalculator jarg3_, long jarg4);
  public final static native void delete_FdmSimpleSwingCondition(long jarg1);
  public final static native long new_FdmDividendHandler(long jarg1, DividendSchedule jarg1_, long jarg2, FdmMesher jarg2_, long jarg3, Date jarg3_, long jarg4, DayCounter jarg4_, long jarg5);
  public final static native long FdmDividendHandler_dividendTimes(long jarg1, FdmDividendHandler jarg1_);
  public final static native long FdmDividendHandler_dividendDates(long jarg1, FdmDividendHandler jarg1_);
  public final static native long FdmDividendHandler_dividends(long jarg1, FdmDividendHandler jarg1_);
  public final static native void delete_FdmDividendHandler(long jarg1);
  public final static native long new_FdmSolverDesc(long jarg1, FdmMesher jarg1_, long jarg2, FdmBoundaryConditionSet jarg2_, long jarg3, FdmStepConditionComposite jarg3_, long jarg4, FdmInnerValueCalculator jarg4_, double jarg5, long jarg6, long jarg7);
  public final static native long FdmSolverDesc_getMesher(long jarg1, FdmSolverDesc jarg1_);
  public final static native long FdmSolverDesc_getBcSet(long jarg1, FdmSolverDesc jarg1_);
  public final static native long FdmSolverDesc_getStepConditions(long jarg1, FdmSolverDesc jarg1_);
  public final static native long FdmSolverDesc_getCalculator(long jarg1, FdmSolverDesc jarg1_);
  public final static native double FdmSolverDesc_getMaturity(long jarg1, FdmSolverDesc jarg1_);
  public final static native long FdmSolverDesc_getTimeSteps(long jarg1, FdmSolverDesc jarg1_);
  public final static native long FdmSolverDesc_getDampingSteps(long jarg1, FdmSolverDesc jarg1_);
  public final static native void delete_FdmSolverDesc(long jarg1);
  public final static native long new_Fdm1DimSolver(long jarg1, FdmSolverDesc jarg1_, long jarg2, FdmSchemeDesc jarg2_, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native double Fdm1DimSolver_interpolateAt(long jarg1, Fdm1DimSolver jarg1_, double jarg2);
  public final static native double Fdm1DimSolver_thetaAt(long jarg1, Fdm1DimSolver jarg1_, double jarg2);
  public final static native double Fdm1DimSolver_derivativeX(long jarg1, Fdm1DimSolver jarg1_, double jarg2);
  public final static native double Fdm1DimSolver_derivativeXX(long jarg1, Fdm1DimSolver jarg1_, double jarg2);
  public final static native void delete_Fdm1DimSolver(long jarg1);
  public final static native long new_FdmBackwardSolver(long jarg1, FdmLinearOpComposite jarg1_, long jarg2, FdmBoundaryConditionSet jarg2_, long jarg3, FdmStepConditionComposite jarg3_, long jarg4, FdmSchemeDesc jarg4_);
  public final static native void FdmBackwardSolver_rollback(long jarg1, FdmBackwardSolver jarg1_, long jarg2, Array jarg2_, double jarg3, double jarg4, long jarg5, long jarg6);
  public final static native void delete_FdmBackwardSolver(long jarg1);
  public final static native long new_Fdm2dBlackScholesSolver__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, FdmSolverDesc jarg4_, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6, double jarg7);
  public final static native long new_Fdm2dBlackScholesSolver__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, FdmSolverDesc jarg4_, long jarg5, FdmSchemeDesc jarg5_, boolean jarg6);
  public final static native long new_Fdm2dBlackScholesSolver__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, FdmSolverDesc jarg4_, long jarg5, FdmSchemeDesc jarg5_);
  public final static native long new_Fdm2dBlackScholesSolver__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, GeneralizedBlackScholesProcess jarg2_, double jarg3, long jarg4, FdmSolverDesc jarg4_);
  public final static native double Fdm2dBlackScholesSolver_valueAt(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2dBlackScholesSolver_thetaAt(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2dBlackScholesSolver_deltaXat(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2dBlackScholesSolver_deltaYat(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2dBlackScholesSolver_gammaXat(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2dBlackScholesSolver_gammaYat(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2dBlackScholesSolver_gammaXYat(long jarg1, Fdm2dBlackScholesSolver jarg1_, double jarg2, double jarg3);
  public final static native void delete_Fdm2dBlackScholesSolver(long jarg1);
  public final static native long new_Fdm2DimSolver(long jarg1, FdmSolverDesc jarg1_, long jarg2, FdmSchemeDesc jarg2_, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native double Fdm2DimSolver_interpolateAt(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2DimSolver_thetaAt(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2DimSolver_derivativeX(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2DimSolver_derivativeY(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2DimSolver_derivativeXX(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2DimSolver_derivativeYY(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native double Fdm2DimSolver_derivativeXY(long jarg1, Fdm2DimSolver jarg1_, double jarg2, double jarg3);
  public final static native void delete_Fdm2DimSolver(long jarg1);
  public final static native long new_Fdm3DimSolver(long jarg1, FdmSolverDesc jarg1_, long jarg2, FdmSchemeDesc jarg2_, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native void Fdm3DimSolver_performCalculations(long jarg1, Fdm3DimSolver jarg1_);
  public final static native double Fdm3DimSolver_interpolateAt(long jarg1, Fdm3DimSolver jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double Fdm3DimSolver_thetaAt(long jarg1, Fdm3DimSolver jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void delete_Fdm3DimSolver(long jarg1);
  public final static native long new_FdmG2Solver__SWIG_0(long jarg1, G2 jarg1_, long jarg2, FdmSolverDesc jarg2_, long jarg3, FdmSchemeDesc jarg3_);
  public final static native long new_FdmG2Solver__SWIG_1(long jarg1, G2 jarg1_, long jarg2, FdmSolverDesc jarg2_);
  public final static native double FdmG2Solver_valueAt(long jarg1, FdmG2Solver jarg1_, double jarg2, double jarg3);
  public final static native void delete_FdmG2Solver(long jarg1);
  public final static native long new_FdmHestonHullWhiteSolver__SWIG_0(long jarg1, HestonProcess jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, FdmSolverDesc jarg4_, long jarg5, FdmSchemeDesc jarg5_);
  public final static native long new_FdmHestonHullWhiteSolver__SWIG_1(long jarg1, HestonProcess jarg1_, long jarg2, HullWhiteProcess jarg2_, double jarg3, long jarg4, FdmSolverDesc jarg4_);
  public final static native double FdmHestonHullWhiteSolver_valueAt(long jarg1, FdmHestonHullWhiteSolver jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double FdmHestonHullWhiteSolver_thetaAt(long jarg1, FdmHestonHullWhiteSolver jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double FdmHestonHullWhiteSolver_deltaAt(long jarg1, FdmHestonHullWhiteSolver jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double FdmHestonHullWhiteSolver_gammaAt(long jarg1, FdmHestonHullWhiteSolver jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void delete_FdmHestonHullWhiteSolver(long jarg1);
  public final static native long new_FdmHestonSolver__SWIG_0(long jarg1, HestonProcess jarg1_, long jarg2, FdmSolverDesc jarg2_, long jarg3, FdmSchemeDesc jarg3_, long jarg4, FdmQuantoHelper jarg4_, long jarg5, LocalVolTermStructure jarg5_);
  public final static native long new_FdmHestonSolver__SWIG_1(long jarg1, HestonProcess jarg1_, long jarg2, FdmSolverDesc jarg2_, long jarg3, FdmSchemeDesc jarg3_, long jarg4, FdmQuantoHelper jarg4_);
  public final static native long new_FdmHestonSolver__SWIG_2(long jarg1, HestonProcess jarg1_, long jarg2, FdmSolverDesc jarg2_, long jarg3, FdmSchemeDesc jarg3_);
  public final static native long new_FdmHestonSolver__SWIG_3(long jarg1, HestonProcess jarg1_, long jarg2, FdmSolverDesc jarg2_);
  public final static native double FdmHestonSolver_valueAt(long jarg1, FdmHestonSolver jarg1_, double jarg2, double jarg3);
  public final static native double FdmHestonSolver_thetaAt(long jarg1, FdmHestonSolver jarg1_, double jarg2, double jarg3);
  public final static native double FdmHestonSolver_deltaAt(long jarg1, FdmHestonSolver jarg1_, double jarg2, double jarg3);
  public final static native double FdmHestonSolver_gammaAt(long jarg1, FdmHestonSolver jarg1_, double jarg2, double jarg3);
  public final static native double FdmHestonSolver_meanVarianceDeltaAt(long jarg1, FdmHestonSolver jarg1_, double jarg2, double jarg3);
  public final static native double FdmHestonSolver_meanVarianceGammaAt(long jarg1, FdmHestonSolver jarg1_, double jarg2, double jarg3);
  public final static native void delete_FdmHestonSolver(long jarg1);
  public final static native long new_FdmHullWhiteSolver__SWIG_0(long jarg1, HullWhite jarg1_, long jarg2, FdmSolverDesc jarg2_, long jarg3, FdmSchemeDesc jarg3_);
  public final static native long new_FdmHullWhiteSolver__SWIG_1(long jarg1, HullWhite jarg1_, long jarg2, FdmSolverDesc jarg2_);
  public final static native double FdmHullWhiteSolver_valueAt(long jarg1, FdmHullWhiteSolver jarg1_, double jarg2);
  public final static native void delete_FdmHullWhiteSolver(long jarg1);
  public final static native long new_Fdm4dimSolver(long jarg1, FdmSolverDesc jarg1_, long jarg2, FdmSchemeDesc jarg2_, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native double Fdm4dimSolver_interpolateAt(long jarg1, Fdm4dimSolver jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native double Fdm4dimSolver_thetaAt(long jarg1, Fdm4dimSolver jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_Fdm4dimSolver(long jarg1);
  public final static native long new_Fdm5dimSolver(long jarg1, FdmSolverDesc jarg1_, long jarg2, FdmSchemeDesc jarg2_, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native double Fdm5dimSolver_interpolateAt(long jarg1, Fdm5dimSolver jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native double Fdm5dimSolver_thetaAt(long jarg1, Fdm5dimSolver jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_Fdm5dimSolver(long jarg1);
  public final static native long new_Fdm6dimSolver(long jarg1, FdmSolverDesc jarg1_, long jarg2, FdmSchemeDesc jarg2_, long jarg3, FdmLinearOpComposite jarg3_);
  public final static native double Fdm6dimSolver_interpolateAt(long jarg1, Fdm6dimSolver jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native double Fdm6dimSolver_thetaAt(long jarg1, Fdm6dimSolver jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_Fdm6dimSolver(long jarg1);
  public final static native long new_FdmIndicesOnBoundary(long jarg1, FdmLinearOpLayout jarg1_, long jarg2, int jarg3);
  public final static native long FdmIndicesOnBoundary_getIndices(long jarg1, FdmIndicesOnBoundary jarg1_);
  public final static native void delete_FdmIndicesOnBoundary(long jarg1);
  public final static native double RiskNeutralDensityCalculator_pdf(long jarg1, RiskNeutralDensityCalculator jarg1_, double jarg2, double jarg3);
  public final static native double RiskNeutralDensityCalculator_cdf(long jarg1, RiskNeutralDensityCalculator jarg1_, double jarg2, double jarg3);
  public final static native double RiskNeutralDensityCalculator_invcdf(long jarg1, RiskNeutralDensityCalculator jarg1_, double jarg2, double jarg3);
  public final static native void delete_RiskNeutralDensityCalculator(long jarg1);
  public final static native long new_BSMRNDCalculator(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_BSMRNDCalculator(long jarg1);
  public final static native long new_CEVRNDCalculator(double jarg1, double jarg2, double jarg3);
  public final static native double CEVRNDCalculator_massAtZero(long jarg1, CEVRNDCalculator jarg1_, double jarg2);
  public final static native void delete_CEVRNDCalculator(long jarg1);
  public final static native long new_GBSMRNDCalculator(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_GBSMRNDCalculator(long jarg1);
  public final static native long new_HestonRNDCalculator__SWIG_0(long jarg1, HestonProcess jarg1_, double jarg2, long jarg3);
  public final static native long new_HestonRNDCalculator__SWIG_1(long jarg1, HestonProcess jarg1_, double jarg2);
  public final static native long new_HestonRNDCalculator__SWIG_2(long jarg1, HestonProcess jarg1_);
  public final static native void delete_HestonRNDCalculator(long jarg1);
  public final static native long new_LocalVolRNDCalculator__SWIG_0(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_, long jarg5, long jarg6, double jarg7, double jarg8, long jarg9, double jarg10);
  public final static native long new_LocalVolRNDCalculator__SWIG_1(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_, long jarg5, long jarg6, double jarg7, double jarg8, long jarg9);
  public final static native long new_LocalVolRNDCalculator__SWIG_2(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_, long jarg5, long jarg6, double jarg7, double jarg8);
  public final static native long new_LocalVolRNDCalculator__SWIG_3(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_, long jarg5, long jarg6, double jarg7);
  public final static native long new_LocalVolRNDCalculator__SWIG_4(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_, long jarg5, long jarg6);
  public final static native long new_LocalVolRNDCalculator__SWIG_5(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_, long jarg5);
  public final static native long new_LocalVolRNDCalculator__SWIG_6(long jarg1, Quote jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, YieldTermStructure jarg3_, long jarg4, LocalVolTermStructure jarg4_);
  public final static native long LocalVolRNDCalculator_mesher(long jarg1, LocalVolRNDCalculator jarg1_, double jarg2);
  public final static native long LocalVolRNDCalculator_rescaleTimeSteps(long jarg1, LocalVolRNDCalculator jarg1_);
  public final static native void delete_LocalVolRNDCalculator(long jarg1);
  public final static native long new_SquareRootProcessRNDCalculator(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native double SquareRootProcessRNDCalculator_stationary_pdf(long jarg1, SquareRootProcessRNDCalculator jarg1_, double jarg2);
  public final static native double SquareRootProcessRNDCalculator_stationary_cdf(long jarg1, SquareRootProcessRNDCalculator jarg1_, double jarg2);
  public final static native double SquareRootProcessRNDCalculator_stationary_invcdf(long jarg1, SquareRootProcessRNDCalculator jarg1_, double jarg2);
  public final static native void delete_SquareRootProcessRNDCalculator(long jarg1);
  public final static native void delete_FittingMethod(long jarg1);
  public final static native long FittingMethod_size(long jarg1, FittingMethod jarg1_);
  public final static native long FittingMethod_solution(long jarg1, FittingMethod jarg1_);
  public final static native int FittingMethod_numberOfIterations(long jarg1, FittingMethod jarg1_);
  public final static native double FittingMethod_minimumCostValue(long jarg1, FittingMethod jarg1_);
  public final static native boolean FittingMethod_constrainAtZero(long jarg1, FittingMethod jarg1_);
  public final static native long FittingMethod_weights(long jarg1, FittingMethod jarg1_);
  public final static native long new_FittedBondDiscountCurve__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, long jarg3, BondHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, FittingMethod jarg5_, double jarg6, long jarg7, long jarg8, Array jarg8_, double jarg9);
  public final static native long new_FittedBondDiscountCurve__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, long jarg3, BondHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, FittingMethod jarg5_, double jarg6, long jarg7, long jarg8, Array jarg8_);
  public final static native long new_FittedBondDiscountCurve__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, long jarg3, BondHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, FittingMethod jarg5_, double jarg6, long jarg7);
  public final static native long new_FittedBondDiscountCurve__SWIG_3(long jarg1, long jarg2, Calendar jarg2_, long jarg3, BondHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, FittingMethod jarg5_, double jarg6);
  public final static native long new_FittedBondDiscountCurve__SWIG_4(long jarg1, long jarg2, Calendar jarg2_, long jarg3, BondHelperVector jarg3_, long jarg4, DayCounter jarg4_, long jarg5, FittingMethod jarg5_);
  public final static native long new_FittedBondDiscountCurve__SWIG_5(long jarg1, Date jarg1_, long jarg2, BondHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, FittingMethod jarg4_, double jarg5, long jarg6, long jarg7, Array jarg7_, double jarg8);
  public final static native long new_FittedBondDiscountCurve__SWIG_6(long jarg1, Date jarg1_, long jarg2, BondHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, FittingMethod jarg4_, double jarg5, long jarg6, long jarg7, Array jarg7_);
  public final static native long new_FittedBondDiscountCurve__SWIG_7(long jarg1, Date jarg1_, long jarg2, BondHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, FittingMethod jarg4_, double jarg5, long jarg6);
  public final static native long new_FittedBondDiscountCurve__SWIG_8(long jarg1, Date jarg1_, long jarg2, BondHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, FittingMethod jarg4_, double jarg5);
  public final static native long new_FittedBondDiscountCurve__SWIG_9(long jarg1, Date jarg1_, long jarg2, BondHelperVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, FittingMethod jarg4_);
  public final static native long FittedBondDiscountCurve_fitResults(long jarg1, FittedBondDiscountCurve jarg1_);
  public final static native void delete_FittedBondDiscountCurve(long jarg1);
  public final static native long new_ExponentialSplinesFitting__SWIG_0(boolean jarg1, long jarg2, Array jarg2_, long jarg3, Array jarg3_, double jarg4, double jarg5, long jarg6, double jarg7);
  public final static native long new_ExponentialSplinesFitting__SWIG_1(boolean jarg1, long jarg2, Array jarg2_, long jarg3, Array jarg3_, double jarg4, double jarg5, long jarg6);
  public final static native long new_ExponentialSplinesFitting__SWIG_2(boolean jarg1, long jarg2, Array jarg2_, long jarg3, Array jarg3_, double jarg4, double jarg5);
  public final static native long new_ExponentialSplinesFitting__SWIG_3(boolean jarg1, long jarg2, Array jarg2_, long jarg3, Array jarg3_, double jarg4);
  public final static native long new_ExponentialSplinesFitting__SWIG_4(boolean jarg1, long jarg2, Array jarg2_, long jarg3, Array jarg3_);
  public final static native long new_ExponentialSplinesFitting__SWIG_5(boolean jarg1, long jarg2, Array jarg2_);
  public final static native long new_ExponentialSplinesFitting__SWIG_6(boolean jarg1);
  public final static native long new_ExponentialSplinesFitting__SWIG_7();
  public final static native void delete_ExponentialSplinesFitting(long jarg1);
  public final static native long new_NelsonSiegelFitting__SWIG_0(long jarg1, Array jarg1_);
  public final static native long new_NelsonSiegelFitting__SWIG_1();
  public final static native void delete_NelsonSiegelFitting(long jarg1);
  public final static native long new_SvenssonFitting__SWIG_0(long jarg1, Array jarg1_);
  public final static native long new_SvenssonFitting__SWIG_1();
  public final static native void delete_SvenssonFitting(long jarg1);
  public final static native long new_CubicBSplinesFitting__SWIG_0(long jarg1, DoubleVector jarg1_, boolean jarg2, long jarg3, Array jarg3_);
  public final static native long new_CubicBSplinesFitting__SWIG_1(long jarg1, DoubleVector jarg1_, boolean jarg2);
  public final static native long new_CubicBSplinesFitting__SWIG_2(long jarg1, DoubleVector jarg1_);
  public final static native double CubicBSplinesFitting_basisFunction(long jarg1, CubicBSplinesFitting jarg1_, int jarg2, double jarg3);
  public final static native void delete_CubicBSplinesFitting(long jarg1);
  public final static native long new_SimplePolynomialFitting(long jarg1);
  public final static native void delete_SimplePolynomialFitting(long jarg1);
  public final static native long new_SpreadFittingMethod__SWIG_0(long jarg1, FittingMethod jarg1_, long jarg2, YieldTermStructureHandle jarg2_, double jarg3, double jarg4);
  public final static native long new_SpreadFittingMethod__SWIG_1(long jarg1, FittingMethod jarg1_, long jarg2, YieldTermStructureHandle jarg2_, double jarg3);
  public final static native long new_SpreadFittingMethod__SWIG_2(long jarg1, FittingMethod jarg1_, long jarg2, YieldTermStructureHandle jarg2_);
  public final static native void delete_SpreadFittingMethod(long jarg1);
  public final static native long new_ForwardCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, BackwardFlat jarg5_);
  public final static native long new_ForwardCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_ForwardCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long ForwardCurve_dates(long jarg1, ForwardCurve jarg1_);
  public final static native long ForwardCurve_forwards(long jarg1, ForwardCurve jarg1_);
  public final static native long ForwardCurve_nodes(long jarg1, ForwardCurve jarg1_);
  public final static native void delete_ForwardCurve(long jarg1);
  public final static native long new_Position();
  public final static native void delete_Position(long jarg1);
  public final static native long new_ForwardRateAgreement__SWIG_0(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, double jarg5, long jarg6, IborIndex jarg6_, long jarg7, YieldTermStructureHandle jarg7_, boolean jarg8);
  public final static native long new_ForwardRateAgreement__SWIG_1(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, double jarg5, long jarg6, IborIndex jarg6_, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native long new_ForwardRateAgreement__SWIG_2(long jarg1, Date jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, double jarg5, long jarg6, IborIndex jarg6_);
  public final static native long new_ForwardRateAgreement__SWIG_3(long jarg1, Date jarg1_, int jarg2, double jarg3, double jarg4, long jarg5, IborIndex jarg5_, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_ForwardRateAgreement__SWIG_4(long jarg1, Date jarg1_, int jarg2, double jarg3, double jarg4, long jarg5, IborIndex jarg5_);
  public final static native long new_ForwardRateAgreement__SWIG_5(long jarg1, IborIndex jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, double jarg5, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_ForwardRateAgreement__SWIG_6(long jarg1, IborIndex jarg1_, long jarg2, Date jarg2_, int jarg3, double jarg4, double jarg5);
  public final static native long new_ForwardRateAgreement__SWIG_7(long jarg1, IborIndex jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, int jarg4, double jarg5, double jarg6, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native long new_ForwardRateAgreement__SWIG_8(long jarg1, IborIndex jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, int jarg4, double jarg5, double jarg6);
  public final static native double ForwardRateAgreement_amount(long jarg1, ForwardRateAgreement jarg1_);
  public final static native long ForwardRateAgreement_fixingDate(long jarg1, ForwardRateAgreement jarg1_);
  public final static native long ForwardRateAgreement_forwardRate(long jarg1, ForwardRateAgreement jarg1_);
  public final static native void delete_ForwardRateAgreement(long jarg1);
  public final static native long Gaussian1dModel_stateProcess(long jarg1, Gaussian1dModel jarg1_);
  public final static native double Gaussian1dModel_numeraire__SWIG_0(long jarg1, Gaussian1dModel jarg1_, double jarg2, double jarg3, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native double Gaussian1dModel_numeraire__SWIG_1(long jarg1, Gaussian1dModel jarg1_, double jarg2, double jarg3);
  public final static native double Gaussian1dModel_numeraire__SWIG_2(long jarg1, Gaussian1dModel jarg1_, double jarg2);
  public final static native double Gaussian1dModel_zerobond__SWIG_0(long jarg1, Gaussian1dModel jarg1_, double jarg2, double jarg3, double jarg4, long jarg5, YieldTermStructureHandle jarg5_);
  public final static native double Gaussian1dModel_zerobond__SWIG_1(long jarg1, Gaussian1dModel jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double Gaussian1dModel_zerobond__SWIG_2(long jarg1, Gaussian1dModel jarg1_, double jarg2, double jarg3);
  public final static native double Gaussian1dModel_zerobond__SWIG_3(long jarg1, Gaussian1dModel jarg1_, double jarg2);
  public final static native double Gaussian1dModel_numeraire__SWIG_3(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, double jarg3, long jarg4, YieldTermStructureHandle jarg4_);
  public final static native double Gaussian1dModel_numeraire__SWIG_4(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double Gaussian1dModel_numeraire__SWIG_5(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_);
  public final static native double Gaussian1dModel_zerobond__SWIG_4(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, YieldTermStructureHandle jarg5_);
  public final static native double Gaussian1dModel_zerobond__SWIG_5(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double Gaussian1dModel_zerobond__SWIG_6(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double Gaussian1dModel_zerobond__SWIG_7(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_0(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, YieldTermStructureHandle jarg9_, double jarg10, long jarg11, boolean jarg12, boolean jarg13);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_1(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, YieldTermStructureHandle jarg9_, double jarg10, long jarg11, boolean jarg12);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_2(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, YieldTermStructureHandle jarg9_, double jarg10, long jarg11);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_3(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, YieldTermStructureHandle jarg9_, double jarg10);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_4(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_, double jarg8, long jarg9, YieldTermStructureHandle jarg9_);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_5(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_, double jarg8);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_6(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6, long jarg7, Date jarg7_);
  public final static native double Gaussian1dModel_zerobondOption__SWIG_7(long jarg1, Gaussian1dModel jarg1_, int jarg2, long jarg3, Date jarg3_, long jarg4, Date jarg4_, long jarg5, Date jarg5_, double jarg6);
  public final static native double Gaussian1dModel_forwardRate__SWIG_0(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4, long jarg5, IborIndex jarg5_);
  public final static native double Gaussian1dModel_forwardRate__SWIG_1(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_, double jarg4);
  public final static native double Gaussian1dModel_forwardRate__SWIG_2(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Date jarg3_);
  public final static native double Gaussian1dModel_forwardRate__SWIG_3(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_);
  public final static native double Gaussian1dModel_swapRate__SWIG_0(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, SwapIndex jarg6_);
  public final static native double Gaussian1dModel_swapRate__SWIG_1(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Date jarg4_, double jarg5);
  public final static native double Gaussian1dModel_swapRate__SWIG_2(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Date jarg4_);
  public final static native double Gaussian1dModel_swapRate__SWIG_3(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native double Gaussian1dModel_swapAnnuity__SWIG_0(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Date jarg4_, double jarg5, long jarg6, SwapIndex jarg6_);
  public final static native double Gaussian1dModel_swapAnnuity__SWIG_1(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Date jarg4_, double jarg5);
  public final static native double Gaussian1dModel_swapAnnuity__SWIG_2(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_, long jarg4, Date jarg4_);
  public final static native double Gaussian1dModel_swapAnnuity__SWIG_3(long jarg1, Gaussian1dModel jarg1_, long jarg2, Date jarg2_, long jarg3, Period jarg3_);
  public final static native void delete_Gaussian1dModel(long jarg1);
  public final static native long new_Gsr__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, DateVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandleVector jarg4_, double jarg5);
  public final static native long new_Gsr__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, DateVector jarg2_, long jarg3, QuoteHandleVector jarg3_, long jarg4, QuoteHandleVector jarg4_);
  public final static native void Gsr_calibrateVolatilitiesIterative__SWIG_0(long jarg1, Gsr jarg1_, long jarg2, BlackCalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void Gsr_calibrateVolatilitiesIterative__SWIG_1(long jarg1, Gsr jarg1_, long jarg2, BlackCalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void Gsr_calibrateVolatilitiesIterative__SWIG_2(long jarg1, Gsr jarg1_, long jarg2, BlackCalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native long Gsr_reversion(long jarg1, Gsr jarg1_);
  public final static native long Gsr_volatility(long jarg1, Gsr jarg1_);
  public final static native long Gsr_params(long jarg1, Gsr jarg1_);
  public final static native void Gsr_calibrate__SWIG_0(long jarg1, Gsr jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void Gsr_calibrate__SWIG_1(long jarg1, Gsr jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void Gsr_calibrate__SWIG_2(long jarg1, Gsr jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void Gsr_calibrate__SWIG_3(long jarg1, Gsr jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native void Gsr_setParams(long jarg1, Gsr jarg1_, long jarg2, Array jarg2_);
  public final static native double Gsr_value(long jarg1, Gsr jarg1_, long jarg2, Array jarg2_, long jarg3, CalibrationHelperVector jarg3_);
  public final static native long Gsr_constraint(long jarg1, Gsr jarg1_);
  public final static native int Gsr_endCriteria(long jarg1, Gsr jarg1_);
  public final static native long Gsr_problemValues(long jarg1, Gsr jarg1_);
  public final static native int Gsr_functionEvaluation(long jarg1, Gsr jarg1_);
  public final static native void delete_Gsr(long jarg1);
  public final static native long new_MarkovFunctional__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, SwaptionVolatilityStructureHandle jarg5_, long jarg6, DateVector jarg6_, long jarg7, PeriodVector jarg7_, long jarg8, SwapIndex jarg8_, long jarg9, MarkovFunctionalSettings jarg9_);
  public final static native long new_MarkovFunctional__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, SwaptionVolatilityStructureHandle jarg5_, long jarg6, DateVector jarg6_, long jarg7, PeriodVector jarg7_, long jarg8, SwapIndex jarg8_);
  public final static native long new_MarkovFunctional__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, OptionletVolatilityStructureHandle jarg5_, long jarg6, DateVector jarg6_, long jarg7, IborIndex jarg7_, long jarg8, MarkovFunctionalSettings jarg8_);
  public final static native long new_MarkovFunctional__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, double jarg2, long jarg3, DateVector jarg3_, long jarg4, DoubleVector jarg4_, long jarg5, OptionletVolatilityStructureHandle jarg5_, long jarg6, DateVector jarg6_, long jarg7, IborIndex jarg7_);
  public final static native long MarkovFunctional_volatility(long jarg1, MarkovFunctional jarg1_);
  public final static native void MarkovFunctional_calibrate__SWIG_0(long jarg1, MarkovFunctional jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void MarkovFunctional_calibrate__SWIG_1(long jarg1, MarkovFunctional jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void MarkovFunctional_calibrate__SWIG_2(long jarg1, MarkovFunctional jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void MarkovFunctional_calibrate__SWIG_3(long jarg1, MarkovFunctional jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native long MarkovFunctional_params(long jarg1, MarkovFunctional jarg1_);
  public final static native void MarkovFunctional_setParams(long jarg1, MarkovFunctional jarg1_, long jarg2, Array jarg2_);
  public final static native double MarkovFunctional_value(long jarg1, MarkovFunctional jarg1_, long jarg2, Array jarg2_, long jarg3, CalibrationHelperVector jarg3_);
  public final static native long MarkovFunctional_constraint(long jarg1, MarkovFunctional jarg1_);
  public final static native int MarkovFunctional_endCriteria(long jarg1, MarkovFunctional jarg1_);
  public final static native long MarkovFunctional_problemValues(long jarg1, MarkovFunctional jarg1_);
  public final static native int MarkovFunctional_functionEvaluation(long jarg1, MarkovFunctional jarg1_);
  public final static native void delete_MarkovFunctional(long jarg1);
  public final static native int MarkovFunctionalSettings_AdjustNone_get();
  public final static native int MarkovFunctionalSettings_AdjustDigitals_get();
  public final static native int MarkovFunctionalSettings_AdjustYts_get();
  public final static native int MarkovFunctionalSettings_ExtrapolatePayoffFlat_get();
  public final static native int MarkovFunctionalSettings_NoPayoffExtrapolation_get();
  public final static native int MarkovFunctionalSettings_KahaleSmile_get();
  public final static native int MarkovFunctionalSettings_SmileExponentialExtrapolation_get();
  public final static native int MarkovFunctionalSettings_KahaleInterpolation_get();
  public final static native int MarkovFunctionalSettings_SmileDeleteArbitragePoints_get();
  public final static native int MarkovFunctionalSettings_SabrSmile_get();
  public final static native long new_MarkovFunctionalSettings__SWIG_0();
  public final static native long new_MarkovFunctionalSettings__SWIG_1(long jarg1, double jarg2, long jarg3, double jarg4, double jarg5, double jarg6, double jarg7, int jarg8, long jarg9, DoubleVector jarg9_);
  public final static native long new_MarkovFunctionalSettings__SWIG_2(long jarg1, double jarg2, long jarg3, double jarg4, double jarg5, double jarg6, double jarg7, int jarg8);
  public final static native void MarkovFunctionalSettings_validate(long jarg1, MarkovFunctionalSettings jarg1_);
  public final static native void delete_MarkovFunctionalSettings(long jarg1);
  public final static native long new_Gaussian1dCapFloorEngine__SWIG_0(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_Gaussian1dCapFloorEngine__SWIG_1(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_Gaussian1dCapFloorEngine__SWIG_2(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4);
  public final static native long new_Gaussian1dCapFloorEngine__SWIG_3(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3);
  public final static native long new_Gaussian1dCapFloorEngine__SWIG_4(long jarg1, Gaussian1dModel jarg1_, int jarg2);
  public final static native long new_Gaussian1dCapFloorEngine__SWIG_5(long jarg1, Gaussian1dModel jarg1_);
  public final static native void delete_Gaussian1dCapFloorEngine(long jarg1);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_0(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, YieldTermStructureHandle jarg6_, int jarg7);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_1(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_2(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_3(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_4(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_5(long jarg1, Gaussian1dModel jarg1_, int jarg2);
  public final static native long new_Gaussian1dSwaptionEngine__SWIG_6(long jarg1, Gaussian1dModel jarg1_);
  public final static native void delete_Gaussian1dSwaptionEngine(long jarg1);
  public final static native long new_Gaussian1dJamshidianSwaptionEngine(long jarg1, Gaussian1dModel jarg1_);
  public final static native void delete_Gaussian1dJamshidianSwaptionEngine(long jarg1);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_0(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_, int jarg8);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_1(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_2(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_3(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_4(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_5(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_6(long jarg1, Gaussian1dModel jarg1_, int jarg2);
  public final static native long new_Gaussian1dNonstandardSwaptionEngine__SWIG_7(long jarg1, Gaussian1dModel jarg1_);
  public final static native void delete_Gaussian1dNonstandardSwaptionEngine(long jarg1);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_0(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_, boolean jarg8, int jarg9);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_1(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_, boolean jarg8);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_2(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_, long jarg7, YieldTermStructureHandle jarg7_);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_3(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5, long jarg6, QuoteHandle jarg6_);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_4(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4, boolean jarg5);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_5(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3, boolean jarg4);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_6(long jarg1, Gaussian1dModel jarg1_, int jarg2, double jarg3);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_7(long jarg1, Gaussian1dModel jarg1_, int jarg2);
  public final static native long new_Gaussian1dFloatFloatSwaptionEngine__SWIG_8(long jarg1, Gaussian1dModel jarg1_);
  public final static native void delete_Gaussian1dFloatFloatSwaptionEngine(long jarg1);
  public final static native long new_SegmentIntegral(long jarg1);
  public final static native long SegmentIntegral_numberOfEvaluations(long jarg1, SegmentIntegral jarg1_);
  public final static native double SegmentIntegral_calculate(long jarg1, SegmentIntegral jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_SegmentIntegral(long jarg1);
  public final static native long new_TrapezoidIntegralDefault(double jarg1, long jarg2);
  public final static native long TrapezoidIntegralDefault_numberOfEvaluations(long jarg1, TrapezoidIntegralDefault jarg1_);
  public final static native double TrapezoidIntegralDefault_calculate(long jarg1, TrapezoidIntegralDefault jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_TrapezoidIntegralDefault(long jarg1);
  public final static native long new_TrapezoidIntegralMidPoint(double jarg1, long jarg2);
  public final static native long TrapezoidIntegralMidPoint_numberOfEvaluations(long jarg1, TrapezoidIntegralMidPoint jarg1_);
  public final static native double TrapezoidIntegralMidPoint_calculate(long jarg1, TrapezoidIntegralMidPoint jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_TrapezoidIntegralMidPoint(long jarg1);
  public final static native long new_SimpsonIntegral(double jarg1, long jarg2);
  public final static native long SimpsonIntegral_numberOfEvaluations(long jarg1, SimpsonIntegral jarg1_);
  public final static native double SimpsonIntegral_calculate(long jarg1, SimpsonIntegral jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_SimpsonIntegral(long jarg1);
  public final static native long new_GaussKronrodAdaptive__SWIG_0(double jarg1, long jarg2);
  public final static native long new_GaussKronrodAdaptive__SWIG_1(double jarg1);
  public final static native long GaussKronrodAdaptive_numberOfEvaluations(long jarg1, GaussKronrodAdaptive jarg1_);
  public final static native double GaussKronrodAdaptive_calculate(long jarg1, GaussKronrodAdaptive jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_GaussKronrodAdaptive(long jarg1);
  public final static native long new_GaussKronrodNonAdaptive(double jarg1, long jarg2, double jarg3);
  public final static native long GaussKronrodNonAdaptive_numberOfEvaluations(long jarg1, GaussKronrodNonAdaptive jarg1_);
  public final static native double GaussKronrodNonAdaptive_calculate(long jarg1, GaussKronrodNonAdaptive jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_GaussKronrodNonAdaptive(long jarg1);
  public final static native long new_GaussLobattoIntegral__SWIG_0(long jarg1, double jarg2, double jarg3, boolean jarg4);
  public final static native long new_GaussLobattoIntegral__SWIG_1(long jarg1, double jarg2, double jarg3);
  public final static native long new_GaussLobattoIntegral__SWIG_2(long jarg1, double jarg2);
  public final static native long GaussLobattoIntegral_numberOfEvaluations(long jarg1, GaussLobattoIntegral jarg1_);
  public final static native double GaussLobattoIntegral_calculate(long jarg1, GaussLobattoIntegral jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_GaussLobattoIntegral(long jarg1);
  public final static native long GaussianQuadrature_order(long jarg1, GaussianQuadrature jarg1_);
  public final static native long GaussianQuadrature_weights(long jarg1, GaussianQuadrature jarg1_);
  public final static native long GaussianQuadrature_x(long jarg1, GaussianQuadrature jarg1_);
  public final static native double GaussianQuadrature_calculate(long jarg1, GaussianQuadrature jarg1_, long jarg2, UnaryFunctionDelegate jarg2_);
  public final static native void delete_GaussianQuadrature(long jarg1);
  public final static native long new_GaussLaguerreIntegration__SWIG_0(long jarg1, double jarg2);
  public final static native long new_GaussLaguerreIntegration__SWIG_1(long jarg1);
  public final static native void delete_GaussLaguerreIntegration(long jarg1);
  public final static native long new_GaussHermiteIntegration__SWIG_0(long jarg1, double jarg2);
  public final static native long new_GaussHermiteIntegration__SWIG_1(long jarg1);
  public final static native void delete_GaussHermiteIntegration(long jarg1);
  public final static native long new_GaussJacobiIntegration(long jarg1, double jarg2, double jarg3);
  public final static native void delete_GaussJacobiIntegration(long jarg1);
  public final static native long new_GaussHyperbolicIntegration(long jarg1);
  public final static native void delete_GaussHyperbolicIntegration(long jarg1);
  public final static native long new_GaussLegendreIntegration(long jarg1);
  public final static native void delete_GaussLegendreIntegration(long jarg1);
  public final static native long new_GaussChebyshevIntegration(long jarg1);
  public final static native void delete_GaussChebyshevIntegration(long jarg1);
  public final static native long new_GaussChebyshev2ndIntegration(long jarg1);
  public final static native void delete_GaussChebyshev2ndIntegration(long jarg1);
  public final static native long new_GaussGegenbauerIntegration(long jarg1, double jarg2);
  public final static native void delete_GaussGegenbauerIntegration(long jarg1);
  public final static native long new_TanhSinhIntegral__SWIG_0(double jarg1, long jarg2, double jarg3);
  public final static native long new_TanhSinhIntegral__SWIG_1(double jarg1, long jarg2);
  public final static native long new_TanhSinhIntegral__SWIG_2(double jarg1);
  public final static native long new_TanhSinhIntegral__SWIG_3();
  public final static native long TanhSinhIntegral_numberOfEvaluations(long jarg1, TanhSinhIntegral jarg1_);
  public final static native double TanhSinhIntegral_calculate(long jarg1, TanhSinhIntegral jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_TanhSinhIntegral(long jarg1);
  public final static native long new_ExpSinhIntegral__SWIG_0(double jarg1, long jarg2);
  public final static native long new_ExpSinhIntegral__SWIG_1(double jarg1);
  public final static native long new_ExpSinhIntegral__SWIG_2();
  public final static native double ExpSinhIntegral_integrate(long jarg1, ExpSinhIntegral jarg1_, long jarg2, UnaryFunctionDelegate jarg2_);
  public final static native long ExpSinhIntegral_numberOfEvaluations(long jarg1, ExpSinhIntegral jarg1_);
  public final static native double ExpSinhIntegral_calculate(long jarg1, ExpSinhIntegral jarg1_, long jarg2, UnaryFunctionDelegate jarg2_, double jarg3, double jarg4);
  public final static native void delete_ExpSinhIntegral(long jarg1);
  public final static native long new_LocalConstantVol__SWIG_0(long jarg1, Date jarg1_, double jarg2, long jarg3, DayCounter jarg3_);
  public final static native long new_LocalConstantVol__SWIG_1(long jarg1, Date jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_LocalConstantVol__SWIG_2(int jarg1, long jarg2, Calendar jarg2_, double jarg3, long jarg4, DayCounter jarg4_);
  public final static native long new_LocalConstantVol__SWIG_3(int jarg1, long jarg2, Calendar jarg2_, long jarg3, QuoteHandle jarg3_, long jarg4, DayCounter jarg4_);
  public final static native void delete_LocalConstantVol(long jarg1);
  public final static native long new_LocalVolSurface__SWIG_0(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_);
  public final static native long new_LocalVolSurface__SWIG_1(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, double jarg4);
  public final static native void delete_LocalVolSurface(long jarg1);
  public final static native long new_NoExceptLocalVolSurface__SWIG_0(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, long jarg4, QuoteHandle jarg4_, double jarg5);
  public final static native long new_NoExceptLocalVolSurface__SWIG_1(long jarg1, BlackVolTermStructureHandle jarg1_, long jarg2, YieldTermStructureHandle jarg2_, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5);
  public final static native void delete_NoExceptLocalVolSurface(long jarg1);
  public final static native long new_FixedLocalVolSurface__SWIG_0(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, int jarg6, int jarg7);
  public final static native long new_FixedLocalVolSurface__SWIG_1(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_FixedLocalVolSurface__SWIG_2(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_FixedLocalVolSurface__SWIG_3(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, int jarg6, int jarg7);
  public final static native long new_FixedLocalVolSurface__SWIG_4(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_FixedLocalVolSurface__SWIG_5(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_);
  public final static native long new_FixedLocalVolSurface__SWIG_6(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVectorVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, int jarg6, int jarg7);
  public final static native long new_FixedLocalVolSurface__SWIG_7(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVectorVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_, int jarg6);
  public final static native long new_FixedLocalVolSurface__SWIG_8(long jarg1, Date jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVectorVector jarg3_, long jarg4, Matrix jarg4_, long jarg5, DayCounter jarg5_);
  public final static native void FixedLocalVolSurface_setInterpolation__SWIG_0(long jarg1, FixedLocalVolSurface jarg1_, String jarg2);
  public final static native void FixedLocalVolSurface_setInterpolation__SWIG_1(long jarg1, FixedLocalVolSurface jarg1_);
  public final static native void delete_FixedLocalVolSurface(long jarg1);
  public final static native long new_GridModelLocalVolSurface__SWIG_0(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVectorVector jarg3_, long jarg4, DayCounter jarg4_, int jarg5, int jarg6);
  public final static native long new_GridModelLocalVolSurface__SWIG_1(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVectorVector jarg3_, long jarg4, DayCounter jarg4_, int jarg5);
  public final static native long new_GridModelLocalVolSurface__SWIG_2(long jarg1, Date jarg1_, long jarg2, DateVector jarg2_, long jarg3, DoubleVectorVector jarg3_, long jarg4, DayCounter jarg4_);
  public final static native long GridModelLocalVolSurface_params(long jarg1, GridModelLocalVolSurface jarg1_);
  public final static native void GridModelLocalVolSurface_calibrate__SWIG_0(long jarg1, GridModelLocalVolSurface jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, BoolVector jarg7_);
  public final static native void GridModelLocalVolSurface_calibrate__SWIG_1(long jarg1, GridModelLocalVolSurface jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_, long jarg6, DoubleVector jarg6_);
  public final static native void GridModelLocalVolSurface_calibrate__SWIG_2(long jarg1, GridModelLocalVolSurface jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_, long jarg5, Constraint jarg5_);
  public final static native void GridModelLocalVolSurface_calibrate__SWIG_3(long jarg1, GridModelLocalVolSurface jarg1_, long jarg2, CalibrationHelperVector jarg2_, long jarg3, OptimizationMethod jarg3_, long jarg4, EndCriteria jarg4_);
  public final static native int GridModelLocalVolSurface_endCriteria(long jarg1, GridModelLocalVolSurface jarg1_);
  public final static native void delete_GridModelLocalVolSurface(long jarg1);
  public final static native double SampleNumber_value(long jarg1, SampleNumber jarg1_);
  public final static native double SampleNumber_weight(long jarg1, SampleNumber jarg1_);
  public final static native void delete_SampleNumber(long jarg1);
  public final static native long SampleArray_value(long jarg1, SampleArray jarg1_);
  public final static native double SampleArray_weight(long jarg1, SampleArray jarg1_);
  public final static native void delete_SampleArray(long jarg1);
  public final static native long SampleRealVector_value(long jarg1, SampleRealVector jarg1_);
  public final static native double SampleRealVector_weight(long jarg1, SampleRealVector jarg1_);
  public final static native void delete_SampleRealVector(long jarg1);
  public final static native long new_LecuyerUniformRng__SWIG_0(int jarg1);
  public final static native long new_LecuyerUniformRng__SWIG_1();
  public final static native long LecuyerUniformRng_next(long jarg1, LecuyerUniformRng jarg1_);
  public final static native void delete_LecuyerUniformRng(long jarg1);
  public final static native long new_KnuthUniformRng__SWIG_0(int jarg1);
  public final static native long new_KnuthUniformRng__SWIG_1();
  public final static native long KnuthUniformRng_next(long jarg1, KnuthUniformRng jarg1_);
  public final static native void delete_KnuthUniformRng(long jarg1);
  public final static native long new_MersenneTwisterUniformRng__SWIG_0(int jarg1);
  public final static native long new_MersenneTwisterUniformRng__SWIG_1();
  public final static native long MersenneTwisterUniformRng_next(long jarg1, MersenneTwisterUniformRng jarg1_);
  public final static native void delete_MersenneTwisterUniformRng(long jarg1);
  public final static native long new_Xoshiro256StarStarUniformRng__SWIG_0(int jarg1);
  public final static native long new_Xoshiro256StarStarUniformRng__SWIG_1();
  public final static native long Xoshiro256StarStarUniformRng_next(long jarg1, Xoshiro256StarStarUniformRng jarg1_);
  public final static native void delete_Xoshiro256StarStarUniformRng(long jarg1);
  public final static native long new_UniformRandomGenerator__SWIG_0(int jarg1);
  public final static native long new_UniformRandomGenerator__SWIG_1();
  public final static native long UniformRandomGenerator_next(long jarg1, UniformRandomGenerator jarg1_);
  public final static native double UniformRandomGenerator_nextValue(long jarg1, UniformRandomGenerator jarg1_);
  public final static native void delete_UniformRandomGenerator(long jarg1);
  public final static native long new_CentralLimitLecuyerGaussianRng(long jarg1, LecuyerUniformRng jarg1_);
  public final static native long CentralLimitLecuyerGaussianRng_next(long jarg1, CentralLimitLecuyerGaussianRng jarg1_);
  public final static native void delete_CentralLimitLecuyerGaussianRng(long jarg1);
  public final static native long new_CentralLimitKnuthGaussianRng(long jarg1, KnuthUniformRng jarg1_);
  public final static native long CentralLimitKnuthGaussianRng_next(long jarg1, CentralLimitKnuthGaussianRng jarg1_);
  public final static native void delete_CentralLimitKnuthGaussianRng(long jarg1);
  public final static native long new_CentralLimitMersenneTwisterGaussianRng(long jarg1, MersenneTwisterUniformRng jarg1_);
  public final static native long CentralLimitMersenneTwisterGaussianRng_next(long jarg1, CentralLimitMersenneTwisterGaussianRng jarg1_);
  public final static native void delete_CentralLimitMersenneTwisterGaussianRng(long jarg1);
  public final static native long new_CentralLimitXoshiro256StarStarGaussianRng(long jarg1, Xoshiro256StarStarUniformRng jarg1_);
  public final static native long CentralLimitXoshiro256StarStarGaussianRng_next(long jarg1, CentralLimitXoshiro256StarStarGaussianRng jarg1_);
  public final static native void delete_CentralLimitXoshiro256StarStarGaussianRng(long jarg1);
  public final static native long new_BoxMullerLecuyerGaussianRng(long jarg1, LecuyerUniformRng jarg1_);
  public final static native long BoxMullerLecuyerGaussianRng_next(long jarg1, BoxMullerLecuyerGaussianRng jarg1_);
  public final static native void delete_BoxMullerLecuyerGaussianRng(long jarg1);
  public final static native long new_BoxMullerKnuthGaussianRng(long jarg1, KnuthUniformRng jarg1_);
  public final static native long BoxMullerKnuthGaussianRng_next(long jarg1, BoxMullerKnuthGaussianRng jarg1_);
  public final static native void delete_BoxMullerKnuthGaussianRng(long jarg1);
  public final static native long new_BoxMullerMersenneTwisterGaussianRng(long jarg1, MersenneTwisterUniformRng jarg1_);
  public final static native long BoxMullerMersenneTwisterGaussianRng_next(long jarg1, BoxMullerMersenneTwisterGaussianRng jarg1_);
  public final static native void delete_BoxMullerMersenneTwisterGaussianRng(long jarg1);
  public final static native long new_BoxMullerXoshiro256StarStarGaussianRng(long jarg1, Xoshiro256StarStarUniformRng jarg1_);
  public final static native long BoxMullerXoshiro256StarStarGaussianRng_next(long jarg1, BoxMullerXoshiro256StarStarGaussianRng jarg1_);
  public final static native void delete_BoxMullerXoshiro256StarStarGaussianRng(long jarg1);
  public final static native long new_MoroInvCumulativeLecuyerGaussianRng(long jarg1, LecuyerUniformRng jarg1_);
  public final static native long MoroInvCumulativeLecuyerGaussianRng_next(long jarg1, MoroInvCumulativeLecuyerGaussianRng jarg1_);
  public final static native void delete_MoroInvCumulativeLecuyerGaussianRng(long jarg1);
  public final static native long new_MoroInvCumulativeKnuthGaussianRng(long jarg1, KnuthUniformRng jarg1_);
  public final static native long MoroInvCumulativeKnuthGaussianRng_next(long jarg1, MoroInvCumulativeKnuthGaussianRng jarg1_);
  public final static native void delete_MoroInvCumulativeKnuthGaussianRng(long jarg1);
  public final static native long new_MoroInvCumulativeMersenneTwisterGaussianRng(long jarg1, MersenneTwisterUniformRng jarg1_);
  public final static native long MoroInvCumulativeMersenneTwisterGaussianRng_next(long jarg1, MoroInvCumulativeMersenneTwisterGaussianRng jarg1_);
  public final static native void delete_MoroInvCumulativeMersenneTwisterGaussianRng(long jarg1);
  public final static native long new_MoroInvCumulativeXoshiro256StarStarGaussianRng(long jarg1, Xoshiro256StarStarUniformRng jarg1_);
  public final static native long MoroInvCumulativeXoshiro256StarStarGaussianRng_next(long jarg1, MoroInvCumulativeXoshiro256StarStarGaussianRng jarg1_);
  public final static native void delete_MoroInvCumulativeXoshiro256StarStarGaussianRng(long jarg1);
  public final static native long new_InvCumulativeLecuyerGaussianRng(long jarg1, LecuyerUniformRng jarg1_);
  public final static native long InvCumulativeLecuyerGaussianRng_next(long jarg1, InvCumulativeLecuyerGaussianRng jarg1_);
  public final static native void delete_InvCumulativeLecuyerGaussianRng(long jarg1);
  public final static native long new_InvCumulativeKnuthGaussianRng(long jarg1, KnuthUniformRng jarg1_);
  public final static native long InvCumulativeKnuthGaussianRng_next(long jarg1, InvCumulativeKnuthGaussianRng jarg1_);
  public final static native void delete_InvCumulativeKnuthGaussianRng(long jarg1);
  public final static native long new_InvCumulativeMersenneTwisterGaussianRng(long jarg1, MersenneTwisterUniformRng jarg1_);
  public final static native long InvCumulativeMersenneTwisterGaussianRng_next(long jarg1, InvCumulativeMersenneTwisterGaussianRng jarg1_);
  public final static native void delete_InvCumulativeMersenneTwisterGaussianRng(long jarg1);
  public final static native long new_InvCumulativeXoshiro256StarStarGaussianRng(long jarg1, Xoshiro256StarStarUniformRng jarg1_);
  public final static native long InvCumulativeXoshiro256StarStarGaussianRng_next(long jarg1, InvCumulativeXoshiro256StarStarGaussianRng jarg1_);
  public final static native void delete_InvCumulativeXoshiro256StarStarGaussianRng(long jarg1);
  public final static native long new_GaussianRandomGenerator(long jarg1, UniformRandomGenerator jarg1_);
  public final static native long GaussianRandomGenerator_next(long jarg1, GaussianRandomGenerator jarg1_);
  public final static native double GaussianRandomGenerator_nextValue(long jarg1, GaussianRandomGenerator jarg1_);
  public final static native void delete_GaussianRandomGenerator(long jarg1);
  public final static native long new_HaltonRsg__SWIG_0(long jarg1, long jarg2, boolean jarg3, boolean jarg4);
  public final static native long new_HaltonRsg__SWIG_1(long jarg1, long jarg2, boolean jarg3);
  public final static native long new_HaltonRsg__SWIG_2(long jarg1, long jarg2);
  public final static native long new_HaltonRsg__SWIG_3(long jarg1);
  public final static native long HaltonRsg_nextSequence(long jarg1, HaltonRsg jarg1_);
  public final static native long HaltonRsg_lastSequence(long jarg1, HaltonRsg jarg1_);
  public final static native long HaltonRsg_dimension(long jarg1, HaltonRsg jarg1_);
  public final static native void delete_HaltonRsg(long jarg1);
  public final static native long new_SobolRsg__SWIG_0(long jarg1, int jarg2, int jarg3);
  public final static native long new_SobolRsg__SWIG_1(long jarg1, int jarg2);
  public final static native long new_SobolRsg__SWIG_2(long jarg1);
  public final static native long SobolRsg_nextSequence(long jarg1, SobolRsg jarg1_);
  public final static native long SobolRsg_lastSequence(long jarg1, SobolRsg jarg1_);
  public final static native long SobolRsg_dimension(long jarg1, SobolRsg jarg1_);
  public final static native void SobolRsg_skipTo(long jarg1, SobolRsg jarg1_, long jarg2);
  public final static native long SobolRsg_nextInt32Sequence(long jarg1, SobolRsg jarg1_);
  public final static native void delete_SobolRsg(long jarg1);
  public final static native long new_Burley2020SobolRsg__SWIG_0(long jarg1, int jarg2, int jarg3, int jarg4);
  public final static native long new_Burley2020SobolRsg__SWIG_1(long jarg1, int jarg2, int jarg3);
  public final static native long new_Burley2020SobolRsg__SWIG_2(long jarg1, int jarg2);
  public final static native long new_Burley2020SobolRsg__SWIG_3(long jarg1);
  public final static native long Burley2020SobolRsg_nextSequence(long jarg1, Burley2020SobolRsg jarg1_);
  public final static native long Burley2020SobolRsg_lastSequence(long jarg1, Burley2020SobolRsg jarg1_);
  public final static native long Burley2020SobolRsg_dimension(long jarg1, Burley2020SobolRsg jarg1_);
  public final static native long Burley2020SobolRsg_nextInt32Sequence(long jarg1, Burley2020SobolRsg jarg1_);
  public final static native void delete_Burley2020SobolRsg(long jarg1);
  public final static native long new_SobolBrownianBridgeRsg(long jarg1, long jarg2);
  public final static native long SobolBrownianBridgeRsg_nextSequence(long jarg1, SobolBrownianBridgeRsg jarg1_);
  public final static native long SobolBrownianBridgeRsg_lastSequence(long jarg1, SobolBrownianBridgeRsg jarg1_);
  public final static native long SobolBrownianBridgeRsg_dimension(long jarg1, SobolBrownianBridgeRsg jarg1_);
  public final static native void delete_SobolBrownianBridgeRsg(long jarg1);
  public final static native long new_Burley2020SobolBrownianBridgeRsg(long jarg1, long jarg2);
  public final static native long Burley2020SobolBrownianBridgeRsg_nextSequence(long jarg1, Burley2020SobolBrownianBridgeRsg jarg1_);
  public final static native long Burley2020SobolBrownianBridgeRsg_lastSequence(long jarg1, Burley2020SobolBrownianBridgeRsg jarg1_);
  public final static native long Burley2020SobolBrownianBridgeRsg_dimension(long jarg1, Burley2020SobolBrownianBridgeRsg jarg1_);
  public final static native void delete_Burley2020SobolBrownianBridgeRsg(long jarg1);
  public final static native long new_LecuyerUniformRsg__SWIG_0(long jarg1, long jarg2, LecuyerUniformRng jarg2_);
  public final static native long new_LecuyerUniformRsg__SWIG_1(long jarg1, long jarg2);
  public final static native long new_LecuyerUniformRsg__SWIG_2(long jarg1);
  public final static native long LecuyerUniformRsg_nextSequence(long jarg1, LecuyerUniformRsg jarg1_);
  public final static native long LecuyerUniformRsg_dimension(long jarg1, LecuyerUniformRsg jarg1_);
  public final static native void delete_LecuyerUniformRsg(long jarg1);
  public final static native long new_KnuthUniformRsg__SWIG_0(long jarg1, long jarg2, KnuthUniformRng jarg2_);
  public final static native long new_KnuthUniformRsg__SWIG_1(long jarg1, long jarg2);
  public final static native long new_KnuthUniformRsg__SWIG_2(long jarg1);
  public final static native long KnuthUniformRsg_nextSequence(long jarg1, KnuthUniformRsg jarg1_);
  public final static native long KnuthUniformRsg_dimension(long jarg1, KnuthUniformRsg jarg1_);
  public final static native void delete_KnuthUniformRsg(long jarg1);
  public final static native long new_MersenneTwisterUniformRsg__SWIG_0(long jarg1, long jarg2, MersenneTwisterUniformRng jarg2_);
  public final static native long new_MersenneTwisterUniformRsg__SWIG_1(long jarg1, long jarg2);
  public final static native long new_MersenneTwisterUniformRsg__SWIG_2(long jarg1);
  public final static native long MersenneTwisterUniformRsg_nextSequence(long jarg1, MersenneTwisterUniformRsg jarg1_);
  public final static native long MersenneTwisterUniformRsg_dimension(long jarg1, MersenneTwisterUniformRsg jarg1_);
  public final static native void delete_MersenneTwisterUniformRsg(long jarg1);
  public final static native long new_Xoshiro256StarStarUniformRsg__SWIG_0(long jarg1, long jarg2, Xoshiro256StarStarUniformRng jarg2_);
  public final static native long new_Xoshiro256StarStarUniformRsg__SWIG_1(long jarg1, long jarg2);
  public final static native long new_Xoshiro256StarStarUniformRsg__SWIG_2(long jarg1);
  public final static native long Xoshiro256StarStarUniformRsg_nextSequence(long jarg1, Xoshiro256StarStarUniformRsg jarg1_);
  public final static native long Xoshiro256StarStarUniformRsg_dimension(long jarg1, Xoshiro256StarStarUniformRsg jarg1_);
  public final static native void delete_Xoshiro256StarStarUniformRsg(long jarg1);
  public final static native long new_UniformRandomSequenceGenerator(long jarg1, long jarg2, UniformRandomGenerator jarg2_);
  public final static native long UniformRandomSequenceGenerator_nextSequence(long jarg1, UniformRandomSequenceGenerator jarg1_);
  public final static native long UniformRandomSequenceGenerator_dimension(long jarg1, UniformRandomSequenceGenerator jarg1_);
  public final static native void delete_UniformRandomSequenceGenerator(long jarg1);
  public final static native long new_UniformLowDiscrepancySequenceGenerator__SWIG_0(long jarg1, int jarg2, int jarg3);
  public final static native long new_UniformLowDiscrepancySequenceGenerator__SWIG_1(long jarg1, int jarg2);
  public final static native long new_UniformLowDiscrepancySequenceGenerator__SWIG_2(long jarg1);
  public final static native long UniformLowDiscrepancySequenceGenerator_nextSequence(long jarg1, UniformLowDiscrepancySequenceGenerator jarg1_);
  public final static native long UniformLowDiscrepancySequenceGenerator_dimension(long jarg1, UniformLowDiscrepancySequenceGenerator jarg1_);
  public final static native void delete_UniformLowDiscrepancySequenceGenerator(long jarg1);
  public final static native long new_MoroInvCumulativeLecuyerGaussianRsg__SWIG_0(long jarg1, LecuyerUniformRsg jarg1_);
  public final static native long new_MoroInvCumulativeLecuyerGaussianRsg__SWIG_1(long jarg1, LecuyerUniformRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeLecuyerGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeLecuyerGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeLecuyerGaussianRsg_dimension(long jarg1, MoroInvCumulativeLecuyerGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeLecuyerGaussianRsg(long jarg1);
  public final static native long new_MoroInvCumulativeKnuthGaussianRsg__SWIG_0(long jarg1, KnuthUniformRsg jarg1_);
  public final static native long new_MoroInvCumulativeKnuthGaussianRsg__SWIG_1(long jarg1, KnuthUniformRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeKnuthGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeKnuthGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeKnuthGaussianRsg_dimension(long jarg1, MoroInvCumulativeKnuthGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeKnuthGaussianRsg(long jarg1);
  public final static native long new_MoroInvCumulativeMersenneTwisterGaussianRsg__SWIG_0(long jarg1, MersenneTwisterUniformRsg jarg1_);
  public final static native long new_MoroInvCumulativeMersenneTwisterGaussianRsg__SWIG_1(long jarg1, MersenneTwisterUniformRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeMersenneTwisterGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeMersenneTwisterGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeMersenneTwisterGaussianRsg_dimension(long jarg1, MoroInvCumulativeMersenneTwisterGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeMersenneTwisterGaussianRsg(long jarg1);
  public final static native long new_MoroInvCumulativeXoshiro256StarStarGaussianRsg__SWIG_0(long jarg1, Xoshiro256StarStarUniformRsg jarg1_);
  public final static native long new_MoroInvCumulativeXoshiro256StarStarGaussianRsg__SWIG_1(long jarg1, Xoshiro256StarStarUniformRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeXoshiro256StarStarGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeXoshiro256StarStarGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeXoshiro256StarStarGaussianRsg_dimension(long jarg1, MoroInvCumulativeXoshiro256StarStarGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeXoshiro256StarStarGaussianRsg(long jarg1);
  public final static native long new_MoroInvCumulativeHaltonGaussianRsg__SWIG_0(long jarg1, HaltonRsg jarg1_);
  public final static native long new_MoroInvCumulativeHaltonGaussianRsg__SWIG_1(long jarg1, HaltonRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeHaltonGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeHaltonGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeHaltonGaussianRsg_dimension(long jarg1, MoroInvCumulativeHaltonGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeHaltonGaussianRsg(long jarg1);
  public final static native long new_MoroInvCumulativeSobolGaussianRsg__SWIG_0(long jarg1, SobolRsg jarg1_);
  public final static native long new_MoroInvCumulativeSobolGaussianRsg__SWIG_1(long jarg1, SobolRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeSobolGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeSobolGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeSobolGaussianRsg_dimension(long jarg1, MoroInvCumulativeSobolGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeSobolGaussianRsg(long jarg1);
  public final static native long new_MoroInvCumulativeBurley2020SobolGaussianRsg__SWIG_0(long jarg1, Burley2020SobolRsg jarg1_);
  public final static native long new_MoroInvCumulativeBurley2020SobolGaussianRsg__SWIG_1(long jarg1, Burley2020SobolRsg jarg1_, long jarg2, MoroInverseCumulativeNormal jarg2_);
  public final static native long MoroInvCumulativeBurley2020SobolGaussianRsg_nextSequence(long jarg1, MoroInvCumulativeBurley2020SobolGaussianRsg jarg1_);
  public final static native long MoroInvCumulativeBurley2020SobolGaussianRsg_dimension(long jarg1, MoroInvCumulativeBurley2020SobolGaussianRsg jarg1_);
  public final static native void delete_MoroInvCumulativeBurley2020SobolGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeLecuyerGaussianRsg__SWIG_0(long jarg1, LecuyerUniformRsg jarg1_);
  public final static native long new_InvCumulativeLecuyerGaussianRsg__SWIG_1(long jarg1, LecuyerUniformRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeLecuyerGaussianRsg_nextSequence(long jarg1, InvCumulativeLecuyerGaussianRsg jarg1_);
  public final static native long InvCumulativeLecuyerGaussianRsg_dimension(long jarg1, InvCumulativeLecuyerGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeLecuyerGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeKnuthGaussianRsg__SWIG_0(long jarg1, KnuthUniformRsg jarg1_);
  public final static native long new_InvCumulativeKnuthGaussianRsg__SWIG_1(long jarg1, KnuthUniformRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeKnuthGaussianRsg_nextSequence(long jarg1, InvCumulativeKnuthGaussianRsg jarg1_);
  public final static native long InvCumulativeKnuthGaussianRsg_dimension(long jarg1, InvCumulativeKnuthGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeKnuthGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeMersenneTwisterGaussianRsg__SWIG_0(long jarg1, MersenneTwisterUniformRsg jarg1_);
  public final static native long new_InvCumulativeMersenneTwisterGaussianRsg__SWIG_1(long jarg1, MersenneTwisterUniformRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeMersenneTwisterGaussianRsg_nextSequence(long jarg1, InvCumulativeMersenneTwisterGaussianRsg jarg1_);
  public final static native long InvCumulativeMersenneTwisterGaussianRsg_dimension(long jarg1, InvCumulativeMersenneTwisterGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeMersenneTwisterGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeXoshiro256StarStarGaussianRsg__SWIG_0(long jarg1, Xoshiro256StarStarUniformRsg jarg1_);
  public final static native long new_InvCumulativeXoshiro256StarStarGaussianRsg__SWIG_1(long jarg1, Xoshiro256StarStarUniformRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeXoshiro256StarStarGaussianRsg_nextSequence(long jarg1, InvCumulativeXoshiro256StarStarGaussianRsg jarg1_);
  public final static native long InvCumulativeXoshiro256StarStarGaussianRsg_dimension(long jarg1, InvCumulativeXoshiro256StarStarGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeXoshiro256StarStarGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeHaltonGaussianRsg__SWIG_0(long jarg1, HaltonRsg jarg1_);
  public final static native long new_InvCumulativeHaltonGaussianRsg__SWIG_1(long jarg1, HaltonRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeHaltonGaussianRsg_nextSequence(long jarg1, InvCumulativeHaltonGaussianRsg jarg1_);
  public final static native long InvCumulativeHaltonGaussianRsg_dimension(long jarg1, InvCumulativeHaltonGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeHaltonGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeSobolGaussianRsg__SWIG_0(long jarg1, SobolRsg jarg1_);
  public final static native long new_InvCumulativeSobolGaussianRsg__SWIG_1(long jarg1, SobolRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeSobolGaussianRsg_nextSequence(long jarg1, InvCumulativeSobolGaussianRsg jarg1_);
  public final static native long InvCumulativeSobolGaussianRsg_dimension(long jarg1, InvCumulativeSobolGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeSobolGaussianRsg(long jarg1);
  public final static native long new_InvCumulativeBurley2020SobolGaussianRsg__SWIG_0(long jarg1, Burley2020SobolRsg jarg1_);
  public final static native long new_InvCumulativeBurley2020SobolGaussianRsg__SWIG_1(long jarg1, Burley2020SobolRsg jarg1_, long jarg2, InverseCumulativeNormal jarg2_);
  public final static native long InvCumulativeBurley2020SobolGaussianRsg_nextSequence(long jarg1, InvCumulativeBurley2020SobolGaussianRsg jarg1_);
  public final static native long InvCumulativeBurley2020SobolGaussianRsg_dimension(long jarg1, InvCumulativeBurley2020SobolGaussianRsg jarg1_);
  public final static native void delete_InvCumulativeBurley2020SobolGaussianRsg(long jarg1);
  public final static native long new_GaussianRandomSequenceGenerator(long jarg1, UniformRandomSequenceGenerator jarg1_);
  public final static native long GaussianRandomSequenceGenerator_nextSequence(long jarg1, GaussianRandomSequenceGenerator jarg1_);
  public final static native long GaussianRandomSequenceGenerator_dimension(long jarg1, GaussianRandomSequenceGenerator jarg1_);
  public final static native void delete_GaussianRandomSequenceGenerator(long jarg1);
  public final static native long new_GaussianLowDiscrepancySequenceGenerator(long jarg1, UniformLowDiscrepancySequenceGenerator jarg1_);
  public final static native long GaussianLowDiscrepancySequenceGenerator_nextSequence(long jarg1, GaussianLowDiscrepancySequenceGenerator jarg1_);
  public final static native long GaussianLowDiscrepancySequenceGenerator_dimension(long jarg1, GaussianLowDiscrepancySequenceGenerator jarg1_);
  public final static native void delete_GaussianLowDiscrepancySequenceGenerator(long jarg1);
  public final static native double BrownianGenerator_nextStep(long jarg1, BrownianGenerator jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native double BrownianGenerator_nextPath(long jarg1, BrownianGenerator jarg1_);
  public final static native long BrownianGenerator_numberOfFactors(long jarg1, BrownianGenerator jarg1_);
  public final static native long BrownianGenerator_numberOfSteps(long jarg1, BrownianGenerator jarg1_);
  public final static native void delete_BrownianGenerator(long jarg1);
  public final static native long BrownianGeneratorFactory_create(long jarg1, BrownianGeneratorFactory jarg1_, long jarg2, long jarg3);
  public final static native void delete_BrownianGeneratorFactory(long jarg1);
  public final static native long new_MTBrownianGenerator__SWIG_0(long jarg1, long jarg2, long jarg3);
  public final static native long new_MTBrownianGenerator__SWIG_1(long jarg1, long jarg2);
  public final static native void delete_MTBrownianGenerator(long jarg1);
  public final static native long new_MTBrownianGeneratorFactory__SWIG_0(long jarg1);
  public final static native long new_MTBrownianGeneratorFactory__SWIG_1();
  public final static native void delete_MTBrownianGeneratorFactory(long jarg1);
  public final static native long new_SobolBrownianGenerator__SWIG_0(long jarg1, long jarg2, int jarg3, long jarg4, int jarg5);
  public final static native long new_SobolBrownianGenerator__SWIG_1(long jarg1, long jarg2, int jarg3, long jarg4);
  public final static native long new_SobolBrownianGenerator__SWIG_2(long jarg1, long jarg2, int jarg3);
  public final static native void delete_SobolBrownianGenerator(long jarg1);
  public final static native long new_SobolBrownianGeneratorFactory__SWIG_0(int jarg1, long jarg2, int jarg3);
  public final static native long new_SobolBrownianGeneratorFactory__SWIG_1(int jarg1, long jarg2);
  public final static native long new_SobolBrownianGeneratorFactory__SWIG_2(int jarg1);
  public final static native void delete_SobolBrownianGeneratorFactory(long jarg1);
  public final static native long new_EvolutionDescription__SWIG_0(long jarg1, DoubleVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, UnsignedIntPairVector jarg3_);
  public final static native long new_EvolutionDescription__SWIG_1(long jarg1, DoubleVector jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long new_EvolutionDescription__SWIG_2(long jarg1, DoubleVector jarg1_);
  public final static native long EvolutionDescription_rateTimes(long jarg1, EvolutionDescription jarg1_);
  public final static native long EvolutionDescription_rateTaus(long jarg1, EvolutionDescription jarg1_);
  public final static native long EvolutionDescription_evolutionTimes(long jarg1, EvolutionDescription jarg1_);
  public final static native long EvolutionDescription_firstAliveRate(long jarg1, EvolutionDescription jarg1_);
  public final static native long EvolutionDescription_relevanceRates(long jarg1, EvolutionDescription jarg1_);
  public final static native long EvolutionDescription_numberOfRates(long jarg1, EvolutionDescription jarg1_);
  public final static native long EvolutionDescription_numberOfSteps(long jarg1, EvolutionDescription jarg1_);
  public final static native void delete_EvolutionDescription(long jarg1);
  public final static native void checkCompatibility(long jarg1, EvolutionDescription jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native boolean isInTerminalMeasure(long jarg1, EvolutionDescription jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native boolean isInMoneyMarketPlusMeasure__SWIG_0(long jarg1, EvolutionDescription jarg1_, long jarg2, UnsignedIntVector jarg2_, long jarg3);
  public final static native boolean isInMoneyMarketPlusMeasure__SWIG_1(long jarg1, EvolutionDescription jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native boolean isInMoneyMarketMeasure(long jarg1, EvolutionDescription jarg1_, long jarg2, UnsignedIntVector jarg2_);
  public final static native long terminalMeasure(long jarg1, EvolutionDescription jarg1_);
  public final static native long moneyMarketPlusMeasure__SWIG_0(long jarg1, EvolutionDescription jarg1_, long jarg2);
  public final static native long moneyMarketPlusMeasure__SWIG_1(long jarg1, EvolutionDescription jarg1_);
  public final static native long moneyMarketMeasure(long jarg1, EvolutionDescription jarg1_);
  public final static native long MarketModel_initialRates(long jarg1, MarketModel jarg1_);
  public final static native long MarketModel_displacements(long jarg1, MarketModel jarg1_);
  public final static native long MarketModel_evolution(long jarg1, MarketModel jarg1_);
  public final static native long MarketModel_numberOfRates(long jarg1, MarketModel jarg1_);
  public final static native long MarketModel_numberOfFactors(long jarg1, MarketModel jarg1_);
  public final static native long MarketModel_numberOfSteps(long jarg1, MarketModel jarg1_);
  public final static native long MarketModel_pseudoRoot(long jarg1, MarketModel jarg1_, long jarg2);
  public final static native long MarketModel_covariance(long jarg1, MarketModel jarg1_, long jarg2);
  public final static native long MarketModel_totalCovariance(long jarg1, MarketModel jarg1_, long jarg2);
  public final static native long MarketModel_timeDependentVolatility(long jarg1, MarketModel jarg1_, long jarg2);
  public final static native void delete_MarketModel(long jarg1);
  public final static native long MarketModelFactory_create(long jarg1, MarketModelFactory jarg1_, long jarg2, EvolutionDescription jarg2_, long jarg3);
  public final static native void delete_MarketModelFactory(long jarg1);
  public final static native long PiecewiseConstantCorrelation_times(long jarg1, PiecewiseConstantCorrelation jarg1_);
  public final static native long PiecewiseConstantCorrelation_rateTimes(long jarg1, PiecewiseConstantCorrelation jarg1_);
  public final static native long PiecewiseConstantCorrelation_correlations(long jarg1, PiecewiseConstantCorrelation jarg1_);
  public final static native long PiecewiseConstantCorrelation_correlation(long jarg1, PiecewiseConstantCorrelation jarg1_, long jarg2);
  public final static native long PiecewiseConstantCorrelation_numberOfRates(long jarg1, PiecewiseConstantCorrelation jarg1_);
  public final static native void delete_PiecewiseConstantCorrelation(long jarg1);
  public final static native long new_ExponentialForwardCorrelation__SWIG_0(long jarg1, DoubleVector jarg1_, double jarg2, double jarg3, double jarg4, long jarg5, DoubleVector jarg5_);
  public final static native long new_ExponentialForwardCorrelation__SWIG_1(long jarg1, DoubleVector jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native long new_ExponentialForwardCorrelation__SWIG_2(long jarg1, DoubleVector jarg1_, double jarg2, double jarg3);
  public final static native long new_ExponentialForwardCorrelation__SWIG_3(long jarg1, DoubleVector jarg1_, double jarg2);
  public final static native long new_ExponentialForwardCorrelation__SWIG_4(long jarg1, DoubleVector jarg1_);
  public final static native void delete_ExponentialForwardCorrelation(long jarg1);
  public final static native long CurveState_numberOfRates(long jarg1, CurveState jarg1_);
  public final static native long CurveState_rateTimes(long jarg1, CurveState jarg1_);
  public final static native long CurveState_rateTaus(long jarg1, CurveState jarg1_);
  public final static native double CurveState_discountRatio(long jarg1, CurveState jarg1_, long jarg2, long jarg3);
  public final static native double CurveState_forwardRate(long jarg1, CurveState jarg1_, long jarg2);
  public final static native double CurveState_coterminalSwapAnnuity(long jarg1, CurveState jarg1_, long jarg2, long jarg3);
  public final static native double CurveState_coterminalSwapRate(long jarg1, CurveState jarg1_, long jarg2);
  public final static native double CurveState_cmSwapAnnuity(long jarg1, CurveState jarg1_, long jarg2, long jarg3, long jarg4);
  public final static native double CurveState_cmSwapRate(long jarg1, CurveState jarg1_, long jarg2, long jarg3);
  public final static native long CurveState_forwardRates(long jarg1, CurveState jarg1_);
  public final static native long CurveState_coterminalSwapRates(long jarg1, CurveState jarg1_);
  public final static native long CurveState_cmSwapRates(long jarg1, CurveState jarg1_, long jarg2);
  public final static native double CurveState_swapRate(long jarg1, CurveState jarg1_, long jarg2, long jarg3);
  public final static native void delete_CurveState(long jarg1);
  public final static native long new_LMMCurveState(long jarg1, DoubleVector jarg1_);
  public final static native void LMMCurveState_setOnForwardRates__SWIG_0(long jarg1, LMMCurveState jarg1_, long jarg2, DoubleVector jarg2_, long jarg3);
  public final static native void LMMCurveState_setOnForwardRates__SWIG_1(long jarg1, LMMCurveState jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void LMMCurveState_setOnDiscountRatios__SWIG_0(long jarg1, LMMCurveState jarg1_, long jarg2, DoubleVector jarg2_, long jarg3);
  public final static native void LMMCurveState_setOnDiscountRatios__SWIG_1(long jarg1, LMMCurveState jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void delete_LMMCurveState(long jarg1);
  public final static native long new_LMMDriftCalculator(long jarg1, Matrix jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_, long jarg4, long jarg5);
  public final static native void LMMDriftCalculator_compute__SWIG_0(long jarg1, LMMDriftCalculator jarg1_, long jarg2, LMMCurveState jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void LMMDriftCalculator_compute__SWIG_1(long jarg1, LMMDriftCalculator jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void LMMDriftCalculator_computePlain__SWIG_0(long jarg1, LMMDriftCalculator jarg1_, long jarg2, LMMCurveState jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void LMMDriftCalculator_computePlain__SWIG_1(long jarg1, LMMDriftCalculator jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void LMMDriftCalculator_computeReduced__SWIG_0(long jarg1, LMMDriftCalculator jarg1_, long jarg2, LMMCurveState jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void LMMDriftCalculator_computeReduced__SWIG_1(long jarg1, LMMDriftCalculator jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native void delete_LMMDriftCalculator(long jarg1);
  public final static native long MarketModelEvolver_numeraires(long jarg1, MarketModelEvolver jarg1_);
  public final static native double MarketModelEvolver_startNewPath(long jarg1, MarketModelEvolver jarg1_);
  public final static native double MarketModelEvolver_advanceStep(long jarg1, MarketModelEvolver jarg1_);
  public final static native long MarketModelEvolver_currentStep(long jarg1, MarketModelEvolver jarg1_);
  public final static native long MarketModelEvolver_currentState(long jarg1, MarketModelEvolver jarg1_);
  public final static native void MarketModelEvolver_setInitialState(long jarg1, MarketModelEvolver jarg1_, long jarg2, CurveState jarg2_);
  public final static native void delete_MarketModelEvolver(long jarg1);
  public final static native long new_LogNormalFwdRateIpc__SWIG_0(long jarg1, MarketModel jarg1_, long jarg2, BrownianGeneratorFactory jarg2_, long jarg3, UnsignedIntVector jarg3_, long jarg4);
  public final static native long new_LogNormalFwdRateIpc__SWIG_1(long jarg1, MarketModel jarg1_, long jarg2, BrownianGeneratorFactory jarg2_, long jarg3, UnsignedIntVector jarg3_);
  public final static native void delete_LogNormalFwdRateIpc(long jarg1);
  public final static native long new_AbcdVol(double jarg1, double jarg2, double jarg3, double jarg4, long jarg5, DoubleVector jarg5_, long jarg6, PiecewiseConstantCorrelation jarg6_, long jarg7, EvolutionDescription jarg7_, long jarg8, long jarg9, DoubleVector jarg9_, long jarg10, DoubleVector jarg10_);
  public final static native void delete_AbcdVol(long jarg1);
  public final static native long new_AbcdMathFunction__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native long new_AbcdMathFunction__SWIG_1(double jarg1, double jarg2, double jarg3);
  public final static native long new_AbcdMathFunction__SWIG_2(double jarg1, double jarg2);
  public final static native long new_AbcdMathFunction__SWIG_3(double jarg1);
  public final static native long new_AbcdMathFunction__SWIG_4();
  public final static native long new_AbcdMathFunction__SWIG_5(long jarg1, DoubleVector jarg1_);
  public final static native double AbcdMathFunction_getValue(long jarg1, AbcdMathFunction jarg1_, double jarg2);
  public final static native double AbcdMathFunction_maximumLocation(long jarg1, AbcdMathFunction jarg1_);
  public final static native double AbcdMathFunction_maximumValue(long jarg1, AbcdMathFunction jarg1_);
  public final static native double AbcdMathFunction_longTermValue(long jarg1, AbcdMathFunction jarg1_);
  public final static native double AbcdMathFunction_derivative(long jarg1, AbcdMathFunction jarg1_, double jarg2);
  public final static native double AbcdMathFunction_primitive(long jarg1, AbcdMathFunction jarg1_, double jarg2);
  public final static native double AbcdMathFunction_definiteIntegral(long jarg1, AbcdMathFunction jarg1_, double jarg2, double jarg3);
  public final static native double AbcdMathFunction_a(long jarg1, AbcdMathFunction jarg1_);
  public final static native double AbcdMathFunction_b(long jarg1, AbcdMathFunction jarg1_);
  public final static native double AbcdMathFunction_c(long jarg1, AbcdMathFunction jarg1_);
  public final static native double AbcdMathFunction_d(long jarg1, AbcdMathFunction jarg1_);
  public final static native long AbcdMathFunction_coefficients(long jarg1, AbcdMathFunction jarg1_);
  public final static native long AbcdMathFunction_derivativeCoefficients(long jarg1, AbcdMathFunction jarg1_);
  public final static native long AbcdMathFunction_definiteIntegralCoefficients(long jarg1, AbcdMathFunction jarg1_, double jarg2, double jarg3);
  public final static native long AbcdMathFunction_definiteDerivativeCoefficients(long jarg1, AbcdMathFunction jarg1_, double jarg2, double jarg3);
  public final static native void AbcdMathFunction_validate(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native void delete_AbcdMathFunction(long jarg1);
  public final static native long new_AbcdFunction__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4);
  public final static native long new_AbcdFunction__SWIG_1(double jarg1, double jarg2, double jarg3);
  public final static native long new_AbcdFunction__SWIG_2(double jarg1, double jarg2);
  public final static native long new_AbcdFunction__SWIG_3(double jarg1);
  public final static native long new_AbcdFunction__SWIG_4();
  public final static native double AbcdFunction_maximumVolatility(long jarg1, AbcdFunction jarg1_);
  public final static native double AbcdFunction_shortTermVolatility(long jarg1, AbcdFunction jarg1_);
  public final static native double AbcdFunction_longTermVolatility(long jarg1, AbcdFunction jarg1_);
  public final static native double AbcdFunction_covariance__SWIG_0(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double AbcdFunction_covariance__SWIG_1(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3, double jarg4, double jarg5);
  public final static native double AbcdFunction_volatility(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double AbcdFunction_variance(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double AbcdFunction_instantaneousVolatility(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3);
  public final static native double AbcdFunction_instantaneousVariance(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3);
  public final static native double AbcdFunction_instantaneousCovariance(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native double AbcdFunction_primitive(long jarg1, AbcdFunction jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void delete_AbcdFunction(long jarg1);
  public final static native long new_ContinuousFloatingLookbackOption(double jarg1, long jarg2, TypePayoff jarg2_, long jarg3, Exercise jarg3_);
  public final static native void delete_ContinuousFloatingLookbackOption(long jarg1);
  public final static native long new_ContinuousFixedLookbackOption(double jarg1, long jarg2, StrikedTypePayoff jarg2_, long jarg3, Exercise jarg3_);
  public final static native void delete_ContinuousFixedLookbackOption(long jarg1);
  public final static native long new_ContinuousPartialFloatingLookbackOption(double jarg1, double jarg2, long jarg3, Date jarg3_, long jarg4, TypePayoff jarg4_, long jarg5, Exercise jarg5_);
  public final static native void delete_ContinuousPartialFloatingLookbackOption(long jarg1);
  public final static native long new_ContinuousPartialFixedLookbackOption(long jarg1, Date jarg1_, long jarg2, StrikedTypePayoff jarg2_, long jarg3, Exercise jarg3_);
  public final static native void delete_ContinuousPartialFixedLookbackOption(long jarg1);
  public final static native long new_AnalyticContinuousFloatingLookbackEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticContinuousFloatingLookbackEngine(long jarg1);
  public final static native long new_AnalyticContinuousFixedLookbackEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticContinuousFixedLookbackEngine(long jarg1);
  public final static native long new_AnalyticContinuousPartialFloatingLookbackEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticContinuousPartialFloatingLookbackEngine(long jarg1);
  public final static native long new_AnalyticContinuousPartialFixedLookbackEngine(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_AnalyticContinuousPartialFixedLookbackEngine(long jarg1);
  public final static native long getCovariance(long jarg1, Array jarg1_, long jarg2, Matrix jarg2_);
  public final static native long Path_length(long jarg1, Path jarg1_);
  public final static native double Path_value(long jarg1, Path jarg1_, long jarg2);
  public final static native double Path_front(long jarg1, Path jarg1_);
  public final static native double Path_back(long jarg1, Path jarg1_);
  public final static native double Path_time(long jarg1, Path jarg1_, long jarg2);
  public final static native void delete_Path(long jarg1);
  public final static native long SamplePath_value(long jarg1, SamplePath jarg1_);
  public final static native double SamplePath_weight(long jarg1, SamplePath jarg1_);
  public final static native void delete_SamplePath(long jarg1);
  public final static native long new_GaussianPathGenerator__SWIG_0(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, long jarg4, GaussianRandomSequenceGenerator jarg4_, boolean jarg5);
  public final static native long new_GaussianPathGenerator__SWIG_1(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, GaussianRandomSequenceGenerator jarg3_, boolean jarg4);
  public final static native long GaussianPathGenerator_next(long jarg1, GaussianPathGenerator jarg1_);
  public final static native long GaussianPathGenerator_antithetic(long jarg1, GaussianPathGenerator jarg1_);
  public final static native long GaussianPathGenerator_size(long jarg1, GaussianPathGenerator jarg1_);
  public final static native long GaussianPathGenerator_timeGrid(long jarg1, GaussianPathGenerator jarg1_);
  public final static native void delete_GaussianPathGenerator(long jarg1);
  public final static native long new_GaussianSobolPathGenerator__SWIG_0(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, long jarg4, GaussianLowDiscrepancySequenceGenerator jarg4_, boolean jarg5);
  public final static native long new_GaussianSobolPathGenerator__SWIG_1(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, GaussianLowDiscrepancySequenceGenerator jarg3_, boolean jarg4);
  public final static native long GaussianSobolPathGenerator_next(long jarg1, GaussianSobolPathGenerator jarg1_);
  public final static native long GaussianSobolPathGenerator_antithetic(long jarg1, GaussianSobolPathGenerator jarg1_);
  public final static native long GaussianSobolPathGenerator_size(long jarg1, GaussianSobolPathGenerator jarg1_);
  public final static native long GaussianSobolPathGenerator_timeGrid(long jarg1, GaussianSobolPathGenerator jarg1_);
  public final static native void delete_GaussianSobolPathGenerator(long jarg1);
  public final static native long new_InvCumulativeMersenneTwisterPathGenerator__SWIG_0(long jarg1, StochasticProcess jarg1_, double jarg2, long jarg3, long jarg4, InvCumulativeMersenneTwisterGaussianRsg jarg4_, boolean jarg5);
  public final static native long new_InvCumulativeMersenneTwisterPathGenerator__SWIG_1(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, InvCumulativeMersenneTwisterGaussianRsg jarg3_, boolean jarg4);
  public final static native long InvCumulativeMersenneTwisterPathGenerator_next(long jarg1, InvCumulativeMersenneTwisterPathGenerator jarg1_);
  public final static native long InvCumulativeMersenneTwisterPathGenerator_antithetic(long jarg1, InvCumulativeMersenneTwisterPathGenerator jarg1_);
  public final static native long InvCumulativeMersenneTwisterPathGenerator_size(long jarg1, InvCumulativeMersenneTwisterPathGenerator jarg1_);
  public final static native long InvCumulativeMersenneTwisterPathGenerator_timeGrid(long jarg1, InvCumulativeMersenneTwisterPathGenerator jarg1_);
  public final static native void delete_InvCumulativeMersenneTwisterPathGenerator(long jarg1);
  public final static native long MultiPath_pathSize(long jarg1, MultiPath jarg1_);
  public final static native long MultiPath_assetNumber(long jarg1, MultiPath jarg1_);
  public final static native long MultiPath_at(long jarg1, MultiPath jarg1_, long jarg2);
  public final static native void delete_MultiPath(long jarg1);
  public final static native long SampleMultiPath_value(long jarg1, SampleMultiPath jarg1_);
  public final static native double SampleMultiPath_weight(long jarg1, SampleMultiPath jarg1_);
  public final static native void delete_SampleMultiPath(long jarg1);
  public final static native long new_GaussianMultiPathGenerator__SWIG_0(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, GaussianRandomSequenceGenerator jarg3_, boolean jarg4);
  public final static native long new_GaussianMultiPathGenerator__SWIG_1(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, GaussianRandomSequenceGenerator jarg3_);
  public final static native long new_GaussianMultiPathGenerator__SWIG_2(long jarg1, StochasticProcess jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, GaussianRandomSequenceGenerator jarg3_, boolean jarg4);
  public final static native long new_GaussianMultiPathGenerator__SWIG_3(long jarg1, StochasticProcess jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, GaussianRandomSequenceGenerator jarg3_);
  public final static native long GaussianMultiPathGenerator_next(long jarg1, GaussianMultiPathGenerator jarg1_);
  public final static native long GaussianMultiPathGenerator_antithetic(long jarg1, GaussianMultiPathGenerator jarg1_);
  public final static native void delete_GaussianMultiPathGenerator(long jarg1);
  public final static native long new_GaussianSobolMultiPathGenerator__SWIG_0(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, GaussianLowDiscrepancySequenceGenerator jarg3_, boolean jarg4);
  public final static native long new_GaussianSobolMultiPathGenerator__SWIG_1(long jarg1, StochasticProcess jarg1_, long jarg2, TimeGrid jarg2_, long jarg3, GaussianLowDiscrepancySequenceGenerator jarg3_);
  public final static native long new_GaussianSobolMultiPathGenerator__SWIG_2(long jarg1, StochasticProcess jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, GaussianLowDiscrepancySequenceGenerator jarg3_, boolean jarg4);
  public final static native long new_GaussianSobolMultiPathGenerator__SWIG_3(long jarg1, StochasticProcess jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, GaussianLowDiscrepancySequenceGenerator jarg3_);
  public final static native long GaussianSobolMultiPathGenerator_next(long jarg1, GaussianSobolMultiPathGenerator jarg1_);
  public final static native long GaussianSobolMultiPathGenerator_antithetic(long jarg1, GaussianSobolMultiPathGenerator jarg1_);
  public final static native void delete_GaussianSobolMultiPathGenerator(long jarg1);
  public final static native long new_BrownianBridge__SWIG_0(long jarg1);
  public final static native long new_BrownianBridge__SWIG_1(long jarg1, DoubleVector jarg1_);
  public final static native long new_BrownianBridge__SWIG_2(long jarg1, TimeGrid jarg1_);
  public final static native long BrownianBridge_size(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_times(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_leftWeight(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_rightWeight(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_stdDeviation(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_transform(long jarg1, BrownianBridge jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native long BrownianBridge_bridgeIndex(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_leftIndex(long jarg1, BrownianBridge jarg1_);
  public final static native long BrownianBridge_rightIndex(long jarg1, BrownianBridge jarg1_);
  public final static native void delete_BrownianBridge(long jarg1);
  public final static native void delete_OdeFctDelegate(long jarg1);
  public final static native long OdeFctDelegate_value(long jarg1, OdeFctDelegate jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long OdeFctDelegate_valueSwigExplicitOdeFctDelegate(long jarg1, OdeFctDelegate jarg1_, double jarg2, long jarg3, DoubleVector jarg3_);
  public final static native long new_OdeFctDelegate();
  public final static native void OdeFctDelegate_director_connect(OdeFctDelegate obj, long cptr, boolean mem_own, boolean weak_global);
  public final static native void OdeFctDelegate_change_ownership(OdeFctDelegate obj, long cptr, boolean take_or_release);
  public final static native long new_RungeKutta__SWIG_0(double jarg1, double jarg2, double jarg3);
  public final static native long new_RungeKutta__SWIG_1(double jarg1, double jarg2);
  public final static native long new_RungeKutta__SWIG_2(double jarg1);
  public final static native long new_RungeKutta__SWIG_3();
  public final static native double RungeKutta_getValue__SWIG_0(long jarg1, RungeKutta jarg1_, long jarg2, BinaryFunctionDelegate jarg2_, double jarg3, double jarg4, double jarg5);
  public final static native long RungeKutta_getValue__SWIG_1(long jarg1, RungeKutta jarg1_, long jarg2, OdeFctDelegate jarg2_, long jarg3, DoubleVector jarg3_, double jarg4, double jarg5);
  public final static native void delete_RungeKutta(long jarg1);
  public final static native void delete_DefaultBoundaryCondition(long jarg1);
  public final static native long new_NeumannBC(double jarg1, int jarg2);
  public final static native void delete_NeumannBC(long jarg1);
  public final static native long new_DirichletBC(double jarg1, int jarg2);
  public final static native void delete_DirichletBC(long jarg1);
  public final static native long new_TridiagonalOperator(long jarg1, Array jarg1_, long jarg2, Array jarg2_, long jarg3, Array jarg3_);
  public final static native long TridiagonalOperator_solveFor(long jarg1, TridiagonalOperator jarg1_, long jarg2, Array jarg2_);
  public final static native long TridiagonalOperator_applyTo(long jarg1, TridiagonalOperator jarg1_, long jarg2, Array jarg2_);
  public final static native long TridiagonalOperator_size(long jarg1, TridiagonalOperator jarg1_);
  public final static native void TridiagonalOperator_setFirstRow(long jarg1, TridiagonalOperator jarg1_, double jarg2, double jarg3);
  public final static native void TridiagonalOperator_setMidRow(long jarg1, TridiagonalOperator jarg1_, long jarg2, double jarg3, double jarg4, double jarg5);
  public final static native void TridiagonalOperator_setMidRows(long jarg1, TridiagonalOperator jarg1_, double jarg2, double jarg3, double jarg4);
  public final static native void TridiagonalOperator_setLastRow(long jarg1, TridiagonalOperator jarg1_, double jarg2, double jarg3);
  public final static native long TridiagonalOperator_identity(long jarg1);
  public final static native void delete_TridiagonalOperator(long jarg1);
  public final static native long new_DPlus(long jarg1, double jarg2);
  public final static native void delete_DPlus(long jarg1);
  public final static native long new_DMinus(long jarg1, double jarg2);
  public final static native void delete_DMinus(long jarg1);
  public final static native long new_DZero(long jarg1, double jarg2);
  public final static native void delete_DZero(long jarg1);
  public final static native long new_DPlusDMinus(long jarg1, double jarg2);
  public final static native void delete_DPlusDMinus(long jarg1);
  public final static native long new_SampledCurve__SWIG_0();
  public final static native long new_SampledCurve__SWIG_1(long jarg1, Array jarg1_);
  public final static native long SampledCurve_grid(long jarg1, SampledCurve jarg1_);
  public final static native long SampledCurve_values(long jarg1, SampledCurve jarg1_);
  public final static native double SampledCurve_gridValue(long jarg1, SampledCurve jarg1_, long jarg2);
  public final static native double SampledCurve_value(long jarg1, SampledCurve jarg1_, long jarg2);
  public final static native long SampledCurve_size(long jarg1, SampledCurve jarg1_);
  public final static native boolean SampledCurve_empty(long jarg1, SampledCurve jarg1_);
  public final static native void SampledCurve_setGrid(long jarg1, SampledCurve jarg1_, long jarg2, Array jarg2_);
  public final static native void SampledCurve_setValues(long jarg1, SampledCurve jarg1_, long jarg2, Array jarg2_);
  public final static native void SampledCurve_swap(long jarg1, SampledCurve jarg1_, long jarg2, SampledCurve jarg2_);
  public final static native void SampledCurve_setLogGrid(long jarg1, SampledCurve jarg1_, double jarg2, double jarg3);
  public final static native void SampledCurve_regridLogGrid(long jarg1, SampledCurve jarg1_, double jarg2, double jarg3);
  public final static native void SampledCurve_shiftGrid(long jarg1, SampledCurve jarg1_, double jarg2);
  public final static native void SampledCurve_scaleGrid(long jarg1, SampledCurve jarg1_, double jarg2);
  public final static native void SampledCurve_regrid(long jarg1, SampledCurve jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_SampledCurve(long jarg1);
  public final static native long new_HestonSLVProcess__SWIG_0(long jarg1, HestonProcess jarg1_, long jarg2, LocalVolTermStructure jarg2_, double jarg3);
  public final static native long new_HestonSLVProcess__SWIG_1(long jarg1, HestonProcess jarg1_, long jarg2, LocalVolTermStructure jarg2_);
  public final static native void delete_HestonSLVProcess(long jarg1);
  public final static native long new_HestonSLVMCModel__SWIG_0(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, BrownianGeneratorFactory jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, long jarg7, long jarg8, DateVector jarg8_, double jarg9);
  public final static native long new_HestonSLVMCModel__SWIG_1(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, BrownianGeneratorFactory jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, long jarg7, long jarg8, DateVector jarg8_);
  public final static native long new_HestonSLVMCModel__SWIG_2(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, BrownianGeneratorFactory jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6, long jarg7);
  public final static native long new_HestonSLVMCModel__SWIG_3(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, BrownianGeneratorFactory jarg3_, long jarg4, Date jarg4_, long jarg5, long jarg6);
  public final static native long new_HestonSLVMCModel__SWIG_4(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, BrownianGeneratorFactory jarg3_, long jarg4, Date jarg4_, long jarg5);
  public final static native long new_HestonSLVMCModel__SWIG_5(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, BrownianGeneratorFactory jarg3_, long jarg4, Date jarg4_);
  public final static native long HestonSLVMCModel_hestonProcess(long jarg1, HestonSLVMCModel jarg1_);
  public final static native long HestonSLVMCModel_localVol(long jarg1, HestonSLVMCModel jarg1_);
  public final static native long HestonSLVMCModel_leverageFunction(long jarg1, HestonSLVMCModel jarg1_);
  public final static native void delete_HestonSLVMCModel(long jarg1);
  public final static native void delete_FdmHestonGreensFct(long jarg1);
  public final static native long new_HestonSLVFokkerPlanckFdmParams(long jarg1, long jarg2, long jarg3, long jarg4, double jarg5, long jarg6, long jarg7, double jarg8, double jarg9, long jarg10, double jarg11, double jarg12, double jarg13, double jarg14, double jarg15, double jarg16, double jarg17, int jarg18, int jarg19, long jarg20, FdmSchemeDesc jarg20_);
  public final static native void delete_HestonSLVFokkerPlanckFdmParams(long jarg1);
  public final static native long new_HestonSLVFDMModel__SWIG_0(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, Date jarg3_, long jarg4, HestonSLVFokkerPlanckFdmParams jarg4_, boolean jarg5, long jarg6, DateVector jarg6_, double jarg7);
  public final static native long new_HestonSLVFDMModel__SWIG_1(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, Date jarg3_, long jarg4, HestonSLVFokkerPlanckFdmParams jarg4_, boolean jarg5, long jarg6, DateVector jarg6_);
  public final static native long new_HestonSLVFDMModel__SWIG_2(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, Date jarg3_, long jarg4, HestonSLVFokkerPlanckFdmParams jarg4_, boolean jarg5);
  public final static native long new_HestonSLVFDMModel__SWIG_3(long jarg1, LocalVolTermStructure jarg1_, long jarg2, HestonModel jarg2_, long jarg3, Date jarg3_, long jarg4, HestonSLVFokkerPlanckFdmParams jarg4_);
  public final static native long HestonSLVFDMModel_hestonProcess(long jarg1, HestonSLVFDMModel jarg1_);
  public final static native long HestonSLVFDMModel_localVol(long jarg1, HestonSLVFDMModel jarg1_);
  public final static native long HestonSLVFDMModel_leverageFunction(long jarg1, HestonSLVFDMModel jarg1_);
  public final static native void delete_HestonSLVFDMModel(long jarg1);
  public final static native long new_SpreadOption(long jarg1, PlainVanillaPayoff jarg1_, long jarg2, Exercise jarg2_);
  public final static native void delete_SpreadOption(long jarg1);
  public final static native long new_KirkSpreadOptionEngine(long jarg1, BlackProcess jarg1_, long jarg2, BlackProcess jarg2_, long jarg3, QuoteHandle jarg3_);
  public final static native void delete_KirkSpreadOptionEngine(long jarg1);
  public final static native long Statistics_samples(long jarg1, Statistics jarg1_);
  public final static native double Statistics_weightSum(long jarg1, Statistics jarg1_);
  public final static native double Statistics_mean(long jarg1, Statistics jarg1_);
  public final static native double Statistics_variance(long jarg1, Statistics jarg1_);
  public final static native double Statistics_standardDeviation(long jarg1, Statistics jarg1_);
  public final static native double Statistics_errorEstimate(long jarg1, Statistics jarg1_);
  public final static native double Statistics_skewness(long jarg1, Statistics jarg1_);
  public final static native double Statistics_kurtosis(long jarg1, Statistics jarg1_);
  public final static native double Statistics_min(long jarg1, Statistics jarg1_);
  public final static native double Statistics_max(long jarg1, Statistics jarg1_);
  public final static native void Statistics_reset(long jarg1, Statistics jarg1_);
  public final static native void Statistics_add__SWIG_0(long jarg1, Statistics jarg1_, double jarg2, double jarg3);
  public final static native void Statistics_add__SWIG_1(long jarg1, Statistics jarg1_, double jarg2);
  public final static native void Statistics_add__SWIG_2(long jarg1, Statistics jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void Statistics_add__SWIG_3(long jarg1, Statistics jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native long new_Statistics();
  public final static native void delete_Statistics(long jarg1);
  public final static native long IncrementalStatistics_samples(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_weightSum(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_mean(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_variance(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_standardDeviation(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_errorEstimate(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_skewness(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_kurtosis(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_min(long jarg1, IncrementalStatistics jarg1_);
  public final static native double IncrementalStatistics_max(long jarg1, IncrementalStatistics jarg1_);
  public final static native void IncrementalStatistics_reset(long jarg1, IncrementalStatistics jarg1_);
  public final static native void IncrementalStatistics_add__SWIG_0(long jarg1, IncrementalStatistics jarg1_, double jarg2, double jarg3);
  public final static native void IncrementalStatistics_add__SWIG_1(long jarg1, IncrementalStatistics jarg1_, double jarg2);
  public final static native void IncrementalStatistics_add__SWIG_2(long jarg1, IncrementalStatistics jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void IncrementalStatistics_add__SWIG_3(long jarg1, IncrementalStatistics jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DoubleVector jarg3_);
  public final static native long new_IncrementalStatistics();
  public final static native void delete_IncrementalStatistics(long jarg1);
  public final static native double RiskStatistics_semiVariance(long jarg1, RiskStatistics jarg1_);
  public final static native double RiskStatistics_semiDeviation(long jarg1, RiskStatistics jarg1_);
  public final static native double RiskStatistics_downsideVariance(long jarg1, RiskStatistics jarg1_);
  public final static native double RiskStatistics_downsideDeviation(long jarg1, RiskStatistics jarg1_);
  public final static native double RiskStatistics_regret(long jarg1, RiskStatistics jarg1_, double jarg2);
  public final static native double RiskStatistics_potentialUpside(long jarg1, RiskStatistics jarg1_, double jarg2);
  public final static native double RiskStatistics_valueAtRisk(long jarg1, RiskStatistics jarg1_, double jarg2);
  public final static native double RiskStatistics_expectedShortfall(long jarg1, RiskStatistics jarg1_, double jarg2);
  public final static native double RiskStatistics_shortfall(long jarg1, RiskStatistics jarg1_, double jarg2);
  public final static native double RiskStatistics_averageShortfall(long jarg1, RiskStatistics jarg1_, double jarg2);
  public final static native long new_RiskStatistics();
  public final static native void delete_RiskStatistics(long jarg1);
  public final static native long new_MultipleStatistics(long jarg1);
  public final static native long MultipleStatistics_size(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_samples(long jarg1, MultipleStatistics jarg1_);
  public final static native double MultipleStatistics_weightSum(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_mean(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_variance(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_standardDeviation(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_errorEstimate(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_skewness(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_kurtosis(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_min(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_max(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_covariance(long jarg1, MultipleStatistics jarg1_);
  public final static native long MultipleStatistics_correlation(long jarg1, MultipleStatistics jarg1_);
  public final static native void MultipleStatistics_reset(long jarg1, MultipleStatistics jarg1_);
  public final static native void MultipleStatistics_add__SWIG_0(long jarg1, MultipleStatistics jarg1_, long jarg2, DoubleVector jarg2_, double jarg3);
  public final static native void MultipleStatistics_add__SWIG_1(long jarg1, MultipleStatistics jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void MultipleStatistics_add__SWIG_2(long jarg1, MultipleStatistics jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void MultipleStatistics_add__SWIG_3(long jarg1, MultipleStatistics jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_MultipleStatistics(long jarg1);
  public final static native long new_SequenceStatistics(long jarg1);
  public final static native long SequenceStatistics_size(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_samples(long jarg1, SequenceStatistics jarg1_);
  public final static native double SequenceStatistics_weightSum(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_mean(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_variance(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_standardDeviation(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_errorEstimate(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_skewness(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_kurtosis(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_min(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_max(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_covariance(long jarg1, SequenceStatistics jarg1_);
  public final static native long SequenceStatistics_correlation(long jarg1, SequenceStatistics jarg1_);
  public final static native void SequenceStatistics_reset(long jarg1, SequenceStatistics jarg1_);
  public final static native void SequenceStatistics_add__SWIG_0(long jarg1, SequenceStatistics jarg1_, long jarg2, DoubleVector jarg2_, double jarg3);
  public final static native void SequenceStatistics_add__SWIG_1(long jarg1, SequenceStatistics jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void SequenceStatistics_add__SWIG_2(long jarg1, SequenceStatistics jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void SequenceStatistics_add__SWIG_3(long jarg1, SequenceStatistics jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_SequenceStatistics(long jarg1);
  public final static native long new_MultipleIncrementalStatistics(long jarg1);
  public final static native long MultipleIncrementalStatistics_size(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_samples(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native double MultipleIncrementalStatistics_weightSum(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_mean(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_variance(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_standardDeviation(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_errorEstimate(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_skewness(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_kurtosis(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_min(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_max(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_covariance(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native long MultipleIncrementalStatistics_correlation(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native void MultipleIncrementalStatistics_reset(long jarg1, MultipleIncrementalStatistics jarg1_);
  public final static native void MultipleIncrementalStatistics_add__SWIG_0(long jarg1, MultipleIncrementalStatistics jarg1_, long jarg2, DoubleVector jarg2_, double jarg3);
  public final static native void MultipleIncrementalStatistics_add__SWIG_1(long jarg1, MultipleIncrementalStatistics jarg1_, long jarg2, DoubleVector jarg2_);
  public final static native void MultipleIncrementalStatistics_add__SWIG_2(long jarg1, MultipleIncrementalStatistics jarg1_, long jarg2, Array jarg2_, double jarg3);
  public final static native void MultipleIncrementalStatistics_add__SWIG_3(long jarg1, MultipleIncrementalStatistics jarg1_, long jarg2, Array jarg2_);
  public final static native void delete_MultipleIncrementalStatistics(long jarg1);
  public final static native double CapFloorTermVolatilityStructure_volatility__SWIG_0(long jarg1, CapFloorTermVolatilityStructure jarg1_, long jarg2, Period jarg2_, double jarg3, boolean jarg4);
  public final static native double CapFloorTermVolatilityStructure_volatility__SWIG_1(long jarg1, CapFloorTermVolatilityStructure jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double CapFloorTermVolatilityStructure_volatility__SWIG_2(long jarg1, CapFloorTermVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double CapFloorTermVolatilityStructure_volatility__SWIG_3(long jarg1, CapFloorTermVolatilityStructure jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double CapFloorTermVolatilityStructure_volatility__SWIG_4(long jarg1, CapFloorTermVolatilityStructure jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double CapFloorTermVolatilityStructure_volatility__SWIG_5(long jarg1, CapFloorTermVolatilityStructure jarg1_, double jarg2, double jarg3);
  public final static native void delete_CapFloorTermVolatilityStructure(long jarg1);
  public final static native long new_CapFloorTermVolatilityStructureHandle__SWIG_0(long jarg1, CapFloorTermVolatilityStructure jarg1_);
  public final static native long new_CapFloorTermVolatilityStructureHandle__SWIG_1();
  public final static native long CapFloorTermVolatilityStructureHandle___deref__(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native long CapFloorTermVolatilityStructureHandle_currentLink(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native boolean CapFloorTermVolatilityStructureHandle_empty(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native long CapFloorTermVolatilityStructureHandle_asObservable(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native void delete_CapFloorTermVolatilityStructureHandle(long jarg1);
  public final static native double CapFloorTermVolatilityStructureHandle_volatility__SWIG_0(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, double jarg3, boolean jarg4);
  public final static native double CapFloorTermVolatilityStructureHandle_volatility__SWIG_1(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, long jarg2, Period jarg2_, double jarg3);
  public final static native double CapFloorTermVolatilityStructureHandle_volatility__SWIG_2(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3, boolean jarg4);
  public final static native double CapFloorTermVolatilityStructureHandle_volatility__SWIG_3(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_, double jarg3);
  public final static native double CapFloorTermVolatilityStructureHandle_volatility__SWIG_4(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, double jarg2, double jarg3, boolean jarg4);
  public final static native double CapFloorTermVolatilityStructureHandle_volatility__SWIG_5(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, double jarg2, double jarg3);
  public final static native double CapFloorTermVolatilityStructureHandle_minStrike(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native double CapFloorTermVolatilityStructureHandle_maxStrike(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native long CapFloorTermVolatilityStructureHandle_dayCounter(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native double CapFloorTermVolatilityStructureHandle_timeFromReference(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_, long jarg2, Date jarg2_);
  public final static native long CapFloorTermVolatilityStructureHandle_calendar(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native long CapFloorTermVolatilityStructureHandle_referenceDate(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native long CapFloorTermVolatilityStructureHandle_maxDate(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native double CapFloorTermVolatilityStructureHandle_maxTime(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native void CapFloorTermVolatilityStructureHandle_enableExtrapolation(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native void CapFloorTermVolatilityStructureHandle_disableExtrapolation(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native boolean CapFloorTermVolatilityStructureHandle_allowsExtrapolation(long jarg1, CapFloorTermVolatilityStructureHandle jarg1_);
  public final static native long new_RelinkableCapFloorTermVolatilityStructureHandle__SWIG_0(long jarg1, CapFloorTermVolatilityStructure jarg1_);
  public final static native long new_RelinkableCapFloorTermVolatilityStructureHandle__SWIG_1();
  public final static native void RelinkableCapFloorTermVolatilityStructureHandle_linkTo(long jarg1, RelinkableCapFloorTermVolatilityStructureHandle jarg1_, long jarg2, CapFloorTermVolatilityStructure jarg2_);
  public final static native void RelinkableCapFloorTermVolatilityStructureHandle_reset(long jarg1, RelinkableCapFloorTermVolatilityStructureHandle jarg1_);
  public final static native void delete_RelinkableCapFloorTermVolatilityStructureHandle(long jarg1);
  public final static native long new_CapFloorTermVolCurve__SWIG_0(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_CapFloorTermVolCurve__SWIG_1(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native long new_CapFloorTermVolCurve__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, DayCounter jarg6_);
  public final static native long new_CapFloorTermVolCurve__SWIG_3(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_);
  public final static native void delete_CapFloorTermVolCurve(long jarg1);
  public final static native long new_CapFloorTermVolSurface__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, QuoteHandleVectorVector jarg6_, long jarg7, DayCounter jarg7_);
  public final static native long new_CapFloorTermVolSurface__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, QuoteHandleVectorVector jarg6_);
  public final static native long new_CapFloorTermVolSurface__SWIG_2(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, QuoteHandleVectorVector jarg6_, long jarg7, DayCounter jarg7_);
  public final static native long new_CapFloorTermVolSurface__SWIG_3(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, QuoteHandleVectorVector jarg6_);
  public final static native long new_CapFloorTermVolSurface__SWIG_4(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, Matrix jarg6_, long jarg7, DayCounter jarg7_);
  public final static native long new_CapFloorTermVolSurface__SWIG_5(long jarg1, Date jarg1_, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, Matrix jarg6_);
  public final static native long new_CapFloorTermVolSurface__SWIG_6(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, Matrix jarg6_, long jarg7, DayCounter jarg7_);
  public final static native long new_CapFloorTermVolSurface__SWIG_7(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, PeriodVector jarg4_, long jarg5, DoubleVector jarg5_, long jarg6, Matrix jarg6_);
  public final static native long CapFloorTermVolSurface_maxDate(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native double CapFloorTermVolSurface_minStrike(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native double CapFloorTermVolSurface_maxStrike(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native long CapFloorTermVolSurface_optionTenors(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native long CapFloorTermVolSurface_optionDates(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native long CapFloorTermVolSurface_optionTimes(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native long CapFloorTermVolSurface_strikes(long jarg1, CapFloorTermVolSurface jarg1_);
  public final static native void delete_CapFloorTermVolSurface(long jarg1);
  public final static native long StrippedOptionletBase_optionletStrikes(long jarg1, StrippedOptionletBase jarg1_, long jarg2);
  public final static native long StrippedOptionletBase_optionletVolatilities(long jarg1, StrippedOptionletBase jarg1_, long jarg2);
  public final static native long StrippedOptionletBase_optionletFixingDates(long jarg1, StrippedOptionletBase jarg1_);
  public final static native long StrippedOptionletBase_optionletFixingTimes(long jarg1, StrippedOptionletBase jarg1_);
  public final static native long StrippedOptionletBase_optionletMaturities(long jarg1, StrippedOptionletBase jarg1_);
  public final static native long StrippedOptionletBase_atmOptionletRates(long jarg1, StrippedOptionletBase jarg1_);
  public final static native long StrippedOptionletBase_dayCounter(long jarg1, StrippedOptionletBase jarg1_);
  public final static native long StrippedOptionletBase_calendar(long jarg1, StrippedOptionletBase jarg1_);
  public final static native long StrippedOptionletBase_settlementDays(long jarg1, StrippedOptionletBase jarg1_);
  public final static native int StrippedOptionletBase_businessDayConvention(long jarg1, StrippedOptionletBase jarg1_);
  public final static native int StrippedOptionletBase_volatilityType(long jarg1, StrippedOptionletBase jarg1_);
  public final static native double StrippedOptionletBase_displacement(long jarg1, StrippedOptionletBase jarg1_);
  public final static native void delete_StrippedOptionletBase(long jarg1);
  public final static native long new_StrippedOptionlet__SWIG_0(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, IborIndex jarg4_, long jarg5, DateVector jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, QuoteHandleVectorVector jarg7_, long jarg8, DayCounter jarg8_, int jarg9, double jarg10);
  public final static native long new_StrippedOptionlet__SWIG_1(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, IborIndex jarg4_, long jarg5, DateVector jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, QuoteHandleVectorVector jarg7_, long jarg8, DayCounter jarg8_, int jarg9);
  public final static native long new_StrippedOptionlet__SWIG_2(long jarg1, long jarg2, Calendar jarg2_, int jarg3, long jarg4, IborIndex jarg4_, long jarg5, DateVector jarg5_, long jarg6, DoubleVector jarg6_, long jarg7, QuoteHandleVectorVector jarg7_, long jarg8, DayCounter jarg8_);
  public final static native void delete_StrippedOptionlet(long jarg1);
  public final static native long new_OptionletStripper1__SWIG_0(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3, double jarg4, long jarg5, long jarg6, YieldTermStructureHandle jarg6_, int jarg7, double jarg8, boolean jarg9);
  public final static native long new_OptionletStripper1__SWIG_1(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3, double jarg4, long jarg5, long jarg6, YieldTermStructureHandle jarg6_, int jarg7, double jarg8);
  public final static native long new_OptionletStripper1__SWIG_2(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3, double jarg4, long jarg5, long jarg6, YieldTermStructureHandle jarg6_, int jarg7);
  public final static native long new_OptionletStripper1__SWIG_3(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3, double jarg4, long jarg5, long jarg6, YieldTermStructureHandle jarg6_);
  public final static native long new_OptionletStripper1__SWIG_4(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3, double jarg4, long jarg5);
  public final static native long new_OptionletStripper1__SWIG_5(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3, double jarg4);
  public final static native long new_OptionletStripper1__SWIG_6(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_, double jarg3);
  public final static native long new_OptionletStripper1__SWIG_7(long jarg1, CapFloorTermVolSurface jarg1_, long jarg2, IborIndex jarg2_);
  public final static native long OptionletStripper1_capFloorPrices(long jarg1, OptionletStripper1 jarg1_);
  public final static native long OptionletStripper1_capFloorVolatilities(long jarg1, OptionletStripper1 jarg1_);
  public final static native long OptionletStripper1_optionletPrices(long jarg1, OptionletStripper1 jarg1_);
  public final static native double OptionletStripper1_switchStrike(long jarg1, OptionletStripper1 jarg1_);
  public final static native void delete_OptionletStripper1(long jarg1);
  public final static native long new_StrippedOptionletAdapter(long jarg1, StrippedOptionletBase jarg1_);
  public final static native void delete_StrippedOptionletAdapter(long jarg1);
  public final static native long new_Settlement();
  public final static native void delete_Settlement(long jarg1);
  public final static native long new_Swaption__SWIG_0(long jarg1, VanillaSwap jarg1_, long jarg2, Exercise jarg2_, int jarg3, int jarg4);
  public final static native long new_Swaption__SWIG_1(long jarg1, VanillaSwap jarg1_, long jarg2, Exercise jarg2_, int jarg3);
  public final static native long new_Swaption__SWIG_2(long jarg1, VanillaSwap jarg1_, long jarg2, Exercise jarg2_);
  public final static native int Swaption_settlementType(long jarg1, Swaption jarg1_);
  public final static native int Swaption_settlementMethod(long jarg1, Swaption jarg1_);
  public final static native int Swaption_type(long jarg1, Swaption jarg1_);
  public final static native long Swaption_underlyingSwap(long jarg1, Swaption jarg1_);
  public final static native double Swaption_impliedVolatility__SWIG_0(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8, int jarg9, double jarg10);
  public final static native double Swaption_impliedVolatility__SWIG_1(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8, int jarg9);
  public final static native double Swaption_impliedVolatility__SWIG_2(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7, double jarg8);
  public final static native double Swaption_impliedVolatility__SWIG_3(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6, double jarg7);
  public final static native double Swaption_impliedVolatility__SWIG_4(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5, long jarg6);
  public final static native double Swaption_impliedVolatility__SWIG_5(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4, double jarg5);
  public final static native double Swaption_impliedVolatility__SWIG_6(long jarg1, Swaption jarg1_, double jarg2, long jarg3, YieldTermStructureHandle jarg3_, double jarg4);
  public final static native double Swaption_vega(long jarg1, Swaption jarg1_);
  public final static native double Swaption_delta(long jarg1, Swaption jarg1_);
  public final static native double Swaption_annuity(long jarg1, Swaption jarg1_);
  public final static native void delete_Swaption(long jarg1);
  public final static native long new_NonstandardSwaption__SWIG_0(long jarg1, NonstandardSwap jarg1_, long jarg2, Exercise jarg2_, int jarg3, int jarg4);
  public final static native long new_NonstandardSwaption__SWIG_1(long jarg1, NonstandardSwap jarg1_, long jarg2, Exercise jarg2_, int jarg3);
  public final static native long new_NonstandardSwaption__SWIG_2(long jarg1, NonstandardSwap jarg1_, long jarg2, Exercise jarg2_);
  public final static native long NonstandardSwaption_underlyingSwap(long jarg1, NonstandardSwaption jarg1_);
  public final static native long NonstandardSwaption_calibrationBasket(long jarg1, NonstandardSwaption jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, SwaptionVolatilityStructure jarg3_, String jarg4);
  public final static native long NonstandardSwaption_probabilities(long jarg1, NonstandardSwaption jarg1_);
  public final static native void delete_NonstandardSwaption(long jarg1);
  public final static native long new_FloatFloatSwaption__SWIG_0(long jarg1, FloatFloatSwap jarg1_, long jarg2, Exercise jarg2_, int jarg3, int jarg4);
  public final static native long new_FloatFloatSwaption__SWIG_1(long jarg1, FloatFloatSwap jarg1_, long jarg2, Exercise jarg2_, int jarg3);
  public final static native long new_FloatFloatSwaption__SWIG_2(long jarg1, FloatFloatSwap jarg1_, long jarg2, Exercise jarg2_);
  public final static native long FloatFloatSwaption_underlyingSwap(long jarg1, FloatFloatSwaption jarg1_);
  public final static native long FloatFloatSwaption_calibrationBasket(long jarg1, FloatFloatSwaption jarg1_, long jarg2, SwapIndex jarg2_, long jarg3, SwaptionVolatilityStructure jarg3_, String jarg4);
  public final static native double FloatFloatSwaption_underlyingValue(long jarg1, FloatFloatSwaption jarg1_);
  public final static native long FloatFloatSwaption_probabilities(long jarg1, FloatFloatSwaption jarg1_);
  public final static native void delete_FloatFloatSwaption(long jarg1);
  public final static native long new_BlackSwaptionEngine__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_, double jarg4);
  public final static native long new_BlackSwaptionEngine__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_BlackSwaptionEngine__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native long new_BlackSwaptionEngine__SWIG_3(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, SwaptionVolatilityStructureHandle jarg2_);
  public final static native void delete_BlackSwaptionEngine(long jarg1);
  public final static native long new_BachelierSwaptionEngine__SWIG_0(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long new_BachelierSwaptionEngine__SWIG_1(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, QuoteHandle jarg2_);
  public final static native long new_BachelierSwaptionEngine__SWIG_2(long jarg1, YieldTermStructureHandle jarg1_, long jarg2, SwaptionVolatilityStructureHandle jarg2_);
  public final static native void delete_BachelierSwaptionEngine(long jarg1);
  public final static native long new_VanillaSwingOption(long jarg1, Payoff jarg1_, long jarg2, SwingExercise jarg2_, long jarg3, long jarg4);
  public final static native void delete_VanillaSwingOption(long jarg1);
  public final static native long new_FdSimpleBSSwingEngine__SWIG_0(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3, long jarg4, FdmSchemeDesc jarg4_);
  public final static native long new_FdSimpleBSSwingEngine__SWIG_1(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2, long jarg3);
  public final static native long new_FdSimpleBSSwingEngine__SWIG_2(long jarg1, GeneralizedBlackScholesProcess jarg1_, long jarg2);
  public final static native long new_FdSimpleBSSwingEngine__SWIG_3(long jarg1, GeneralizedBlackScholesProcess jarg1_);
  public final static native void delete_FdSimpleBSSwingEngine(long jarg1);
  public final static native long new_FdSimpleExtOUJumpSwingEngine__SWIG_0(long jarg1, ExtOUWithJumpsProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, DoublePairVector jarg6_, long jarg7, FdmSchemeDesc jarg7_);
  public final static native long new_FdSimpleExtOUJumpSwingEngine__SWIG_1(long jarg1, ExtOUWithJumpsProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4, long jarg5, long jarg6, DoublePairVector jarg6_);
  public final static native long new_FdSimpleExtOUJumpSwingEngine__SWIG_2(long jarg1, ExtOUWithJumpsProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4, long jarg5);
  public final static native long new_FdSimpleExtOUJumpSwingEngine__SWIG_3(long jarg1, ExtOUWithJumpsProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3, long jarg4);
  public final static native long new_FdSimpleExtOUJumpSwingEngine__SWIG_4(long jarg1, ExtOUWithJumpsProcess jarg1_, long jarg2, YieldTermStructure jarg2_, long jarg3);
  public final static native long new_FdSimpleExtOUJumpSwingEngine__SWIG_5(long jarg1, ExtOUWithJumpsProcess jarg1_, long jarg2, YieldTermStructure jarg2_);
  public final static native void delete_FdSimpleExtOUJumpSwingEngine(long jarg1);
  public final static native void enableTracing();
  public final static native void disableTracing();
  public final static native long new_ConstantEstimator(long jarg1);
  public final static native long ConstantEstimator_calculate(long jarg1, ConstantEstimator jarg1_, long jarg2, RealTimeSeries jarg2_);
  public final static native void delete_ConstantEstimator(long jarg1);
  public final static native long new_ParkinsonSigma(double jarg1);
  public final static native long ParkinsonSigma_calculate(long jarg1, ParkinsonSigma jarg1_, long jarg2, IntervalPriceTimeSeries jarg2_);
  public final static native void delete_ParkinsonSigma(long jarg1);
  public final static native long new_GarmanKlassSigma1(double jarg1, double jarg2);
  public final static native long GarmanKlassSigma1_calculate(long jarg1, GarmanKlassSigma1 jarg1_, long jarg2, IntervalPriceTimeSeries jarg2_);
  public final static native void delete_GarmanKlassSigma1(long jarg1);
  public final static native long new_GarmanKlassSigma3(double jarg1, double jarg2);
  public final static native long GarmanKlassSigma3_calculate(long jarg1, GarmanKlassSigma3 jarg1_, long jarg2, IntervalPriceTimeSeries jarg2_);
  public final static native void delete_GarmanKlassSigma3(long jarg1);
  public final static native long new_GarmanKlassSigma4(double jarg1);
  public final static native long GarmanKlassSigma4_calculate(long jarg1, GarmanKlassSigma4 jarg1_, long jarg2, IntervalPriceTimeSeries jarg2_);
  public final static native void delete_GarmanKlassSigma4(long jarg1);
  public final static native long new_GarmanKlassSigma5(double jarg1);
  public final static native long GarmanKlassSigma5_calculate(long jarg1, GarmanKlassSigma5 jarg1_, long jarg2, IntervalPriceTimeSeries jarg2_);
  public final static native void delete_GarmanKlassSigma5(long jarg1);
  public final static native long new_GarmanKlassSigma6(double jarg1, double jarg2);
  public final static native long GarmanKlassSigma6_calculate(long jarg1, GarmanKlassSigma6 jarg1_, long jarg2, IntervalPriceTimeSeries jarg2_);
  public final static native void delete_GarmanKlassSigma6(long jarg1);
  public final static native long new_ZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Linear jarg5_, int jarg6, int jarg7);
  public final static native long new_ZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Linear jarg5_, int jarg6);
  public final static native long new_ZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Linear jarg5_);
  public final static native long new_ZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_ZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long ZeroCurve_times(long jarg1, ZeroCurve jarg1_);
  public final static native long ZeroCurve_data(long jarg1, ZeroCurve jarg1_);
  public final static native long ZeroCurve_dates(long jarg1, ZeroCurve jarg1_);
  public final static native long ZeroCurve_zeroRates(long jarg1, ZeroCurve jarg1_);
  public final static native long ZeroCurve_nodes(long jarg1, ZeroCurve jarg1_);
  public final static native void delete_ZeroCurve(long jarg1);
  public final static native long new_LogLinearZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, LogLinear jarg5_, int jarg6, int jarg7);
  public final static native long new_LogLinearZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, LogLinear jarg5_, int jarg6);
  public final static native long new_LogLinearZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, LogLinear jarg5_);
  public final static native long new_LogLinearZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_LogLinearZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long LogLinearZeroCurve_times(long jarg1, LogLinearZeroCurve jarg1_);
  public final static native long LogLinearZeroCurve_data(long jarg1, LogLinearZeroCurve jarg1_);
  public final static native long LogLinearZeroCurve_dates(long jarg1, LogLinearZeroCurve jarg1_);
  public final static native long LogLinearZeroCurve_zeroRates(long jarg1, LogLinearZeroCurve jarg1_);
  public final static native long LogLinearZeroCurve_nodes(long jarg1, LogLinearZeroCurve jarg1_);
  public final static native void delete_LogLinearZeroCurve(long jarg1);
  public final static native long new_CubicZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Cubic jarg5_, int jarg6, int jarg7);
  public final static native long new_CubicZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Cubic jarg5_, int jarg6);
  public final static native long new_CubicZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Cubic jarg5_);
  public final static native long new_CubicZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_CubicZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long CubicZeroCurve_times(long jarg1, CubicZeroCurve jarg1_);
  public final static native long CubicZeroCurve_data(long jarg1, CubicZeroCurve jarg1_);
  public final static native long CubicZeroCurve_dates(long jarg1, CubicZeroCurve jarg1_);
  public final static native long CubicZeroCurve_zeroRates(long jarg1, CubicZeroCurve jarg1_);
  public final static native long CubicZeroCurve_nodes(long jarg1, CubicZeroCurve jarg1_);
  public final static native void delete_CubicZeroCurve(long jarg1);
  public final static native long new_NaturalCubicZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, SplineCubic jarg5_, int jarg6, int jarg7);
  public final static native long new_NaturalCubicZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, SplineCubic jarg5_, int jarg6);
  public final static native long new_NaturalCubicZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, SplineCubic jarg5_);
  public final static native long new_NaturalCubicZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_NaturalCubicZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long NaturalCubicZeroCurve_times(long jarg1, NaturalCubicZeroCurve jarg1_);
  public final static native long NaturalCubicZeroCurve_data(long jarg1, NaturalCubicZeroCurve jarg1_);
  public final static native long NaturalCubicZeroCurve_dates(long jarg1, NaturalCubicZeroCurve jarg1_);
  public final static native long NaturalCubicZeroCurve_zeroRates(long jarg1, NaturalCubicZeroCurve jarg1_);
  public final static native long NaturalCubicZeroCurve_nodes(long jarg1, NaturalCubicZeroCurve jarg1_);
  public final static native void delete_NaturalCubicZeroCurve(long jarg1);
  public final static native long new_LogCubicZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, DefaultLogCubic jarg5_, int jarg6, int jarg7);
  public final static native long new_LogCubicZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, DefaultLogCubic jarg5_, int jarg6);
  public final static native long new_LogCubicZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, DefaultLogCubic jarg5_);
  public final static native long new_LogCubicZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_LogCubicZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long LogCubicZeroCurve_times(long jarg1, LogCubicZeroCurve jarg1_);
  public final static native long LogCubicZeroCurve_data(long jarg1, LogCubicZeroCurve jarg1_);
  public final static native long LogCubicZeroCurve_dates(long jarg1, LogCubicZeroCurve jarg1_);
  public final static native long LogCubicZeroCurve_zeroRates(long jarg1, LogCubicZeroCurve jarg1_);
  public final static native long LogCubicZeroCurve_nodes(long jarg1, LogCubicZeroCurve jarg1_);
  public final static native void delete_LogCubicZeroCurve(long jarg1);
  public final static native long new_MonotonicCubicZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, MonotonicCubic jarg5_, int jarg6, int jarg7);
  public final static native long new_MonotonicCubicZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, MonotonicCubic jarg5_, int jarg6);
  public final static native long new_MonotonicCubicZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, MonotonicCubic jarg5_);
  public final static native long new_MonotonicCubicZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_MonotonicCubicZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long MonotonicCubicZeroCurve_times(long jarg1, MonotonicCubicZeroCurve jarg1_);
  public final static native long MonotonicCubicZeroCurve_data(long jarg1, MonotonicCubicZeroCurve jarg1_);
  public final static native long MonotonicCubicZeroCurve_dates(long jarg1, MonotonicCubicZeroCurve jarg1_);
  public final static native long MonotonicCubicZeroCurve_zeroRates(long jarg1, MonotonicCubicZeroCurve jarg1_);
  public final static native long MonotonicCubicZeroCurve_nodes(long jarg1, MonotonicCubicZeroCurve jarg1_);
  public final static native void delete_MonotonicCubicZeroCurve(long jarg1);
  public final static native long new_KrugerZeroCurve__SWIG_0(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Kruger jarg5_, int jarg6, int jarg7);
  public final static native long new_KrugerZeroCurve__SWIG_1(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Kruger jarg5_, int jarg6);
  public final static native long new_KrugerZeroCurve__SWIG_2(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_, long jarg5, Kruger jarg5_);
  public final static native long new_KrugerZeroCurve__SWIG_3(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_, long jarg4, Calendar jarg4_);
  public final static native long new_KrugerZeroCurve__SWIG_4(long jarg1, DateVector jarg1_, long jarg2, DoubleVector jarg2_, long jarg3, DayCounter jarg3_);
  public final static native long KrugerZeroCurve_times(long jarg1, KrugerZeroCurve jarg1_);
  public final static native long KrugerZeroCurve_data(long jarg1, KrugerZeroCurve jarg1_);
  public final static native long KrugerZeroCurve_dates(long jarg1, KrugerZeroCurve jarg1_);
  public final static native long KrugerZeroCurve_zeroRates(long jarg1, KrugerZeroCurve jarg1_);
  public final static native long KrugerZeroCurve_nodes(long jarg1, KrugerZeroCurve jarg1_);
  public final static native void delete_KrugerZeroCurve(long jarg1);
  public final static native long Argentina_SWIGUpcast(long jarg1);
  public final static native long Australia_SWIGUpcast(long jarg1);
  public final static native long Austria_SWIGUpcast(long jarg1);
  public final static native long Botswana_SWIGUpcast(long jarg1);
  public final static native long Brazil_SWIGUpcast(long jarg1);
  public final static native long Canada_SWIGUpcast(long jarg1);
  public final static native long Chile_SWIGUpcast(long jarg1);
  public final static native long China_SWIGUpcast(long jarg1);
  public final static native long CzechRepublic_SWIGUpcast(long jarg1);
  public final static native long Denmark_SWIGUpcast(long jarg1);
  public final static native long Finland_SWIGUpcast(long jarg1);
  public final static native long France_SWIGUpcast(long jarg1);
  public final static native long Germany_SWIGUpcast(long jarg1);
  public final static native long HongKong_SWIGUpcast(long jarg1);
  public final static native long Hungary_SWIGUpcast(long jarg1);
  public final static native long Iceland_SWIGUpcast(long jarg1);
  public final static native long India_SWIGUpcast(long jarg1);
  public final static native long Indonesia_SWIGUpcast(long jarg1);
  public final static native long Israel_SWIGUpcast(long jarg1);
  public final static native long Italy_SWIGUpcast(long jarg1);
  public final static native long Japan_SWIGUpcast(long jarg1);
  public final static native long Mexico_SWIGUpcast(long jarg1);
  public final static native long NewZealand_SWIGUpcast(long jarg1);
  public final static native long Norway_SWIGUpcast(long jarg1);
  public final static native long Poland_SWIGUpcast(long jarg1);
  public final static native long Romania_SWIGUpcast(long jarg1);
  public final static native long Russia_SWIGUpcast(long jarg1);
  public final static native long SaudiArabia_SWIGUpcast(long jarg1);
  public final static native long Singapore_SWIGUpcast(long jarg1);
  public final static native long Slovakia_SWIGUpcast(long jarg1);
  public final static native long SouthAfrica_SWIGUpcast(long jarg1);
  public final static native long SouthKorea_SWIGUpcast(long jarg1);
  public final static native long Sweden_SWIGUpcast(long jarg1);
  public final static native long Switzerland_SWIGUpcast(long jarg1);
  public final static native long Taiwan_SWIGUpcast(long jarg1);
  public final static native long TARGET_SWIGUpcast(long jarg1);
  public final static native long Thailand_SWIGUpcast(long jarg1);
  public final static native long Turkey_SWIGUpcast(long jarg1);
  public final static native long Ukraine_SWIGUpcast(long jarg1);
  public final static native long UnitedKingdom_SWIGUpcast(long jarg1);
  public final static native long UnitedStates_SWIGUpcast(long jarg1);
  public final static native long NullCalendar_SWIGUpcast(long jarg1);
  public final static native long WeekendsOnly_SWIGUpcast(long jarg1);
  public final static native long JointCalendar_SWIGUpcast(long jarg1);
  public final static native long BespokeCalendar_SWIGUpcast(long jarg1);
  public final static native long Actual360_SWIGUpcast(long jarg1);
  public final static native long Actual366_SWIGUpcast(long jarg1);
  public final static native long Actual36525_SWIGUpcast(long jarg1);
  public final static native long Actual364_SWIGUpcast(long jarg1);
  public final static native long Actual365Fixed_SWIGUpcast(long jarg1);
  public final static native long Thirty360_SWIGUpcast(long jarg1);
  public final static native long Thirty365_SWIGUpcast(long jarg1);
  public final static native long ActualActual_SWIGUpcast(long jarg1);
  public final static native long OneDayCounter_SWIGUpcast(long jarg1);
  public final static native long SimpleDayCounter_SWIGUpcast(long jarg1);
  public final static native long Business252_SWIGUpcast(long jarg1);
  public final static native long UpRounding_SWIGUpcast(long jarg1);
  public final static native long DownRounding_SWIGUpcast(long jarg1);
  public final static native long ClosestRounding_SWIGUpcast(long jarg1);
  public final static native long CeilingTruncation_SWIGUpcast(long jarg1);
  public final static native long FloorTruncation_SWIGUpcast(long jarg1);
  public final static native long AEDCurrency_SWIGUpcast(long jarg1);
  public final static native long AOACurrency_SWIGUpcast(long jarg1);
  public final static native long ARSCurrency_SWIGUpcast(long jarg1);
  public final static native long ATSCurrency_SWIGUpcast(long jarg1);
  public final static native long AUDCurrency_SWIGUpcast(long jarg1);
  public final static native long BDTCurrency_SWIGUpcast(long jarg1);
  public final static native long BEFCurrency_SWIGUpcast(long jarg1);
  public final static native long BHDCurrency_SWIGUpcast(long jarg1);
  public final static native long BGLCurrency_SWIGUpcast(long jarg1);
  public final static native long BGNCurrency_SWIGUpcast(long jarg1);
  public final static native long BRLCurrency_SWIGUpcast(long jarg1);
  public final static native long BWPCurrency_SWIGUpcast(long jarg1);
  public final static native long BYRCurrency_SWIGUpcast(long jarg1);
  public final static native long CADCurrency_SWIGUpcast(long jarg1);
  public final static native long CHFCurrency_SWIGUpcast(long jarg1);
  public final static native long CLFCurrency_SWIGUpcast(long jarg1);
  public final static native long CLPCurrency_SWIGUpcast(long jarg1);
  public final static native long CNHCurrency_SWIGUpcast(long jarg1);
  public final static native long CNYCurrency_SWIGUpcast(long jarg1);
  public final static native long COPCurrency_SWIGUpcast(long jarg1);
  public final static native long COUCurrency_SWIGUpcast(long jarg1);
  public final static native long CYPCurrency_SWIGUpcast(long jarg1);
  public final static native long CZKCurrency_SWIGUpcast(long jarg1);
  public final static native long DEMCurrency_SWIGUpcast(long jarg1);
  public final static native long DKKCurrency_SWIGUpcast(long jarg1);
  public final static native long EEKCurrency_SWIGUpcast(long jarg1);
  public final static native long EGPCurrency_SWIGUpcast(long jarg1);
  public final static native long ESPCurrency_SWIGUpcast(long jarg1);
  public final static native long ETBCurrency_SWIGUpcast(long jarg1);
  public final static native long EURCurrency_SWIGUpcast(long jarg1);
  public final static native long FIMCurrency_SWIGUpcast(long jarg1);
  public final static native long FRFCurrency_SWIGUpcast(long jarg1);
  public final static native long GELCurrency_SWIGUpcast(long jarg1);
  public final static native long GBPCurrency_SWIGUpcast(long jarg1);
  public final static native long GHSCurrency_SWIGUpcast(long jarg1);
  public final static native long GRDCurrency_SWIGUpcast(long jarg1);
  public final static native long HKDCurrency_SWIGUpcast(long jarg1);
  public final static native long HRKCurrency_SWIGUpcast(long jarg1);
  public final static native long HUFCurrency_SWIGUpcast(long jarg1);
  public final static native long IDRCurrency_SWIGUpcast(long jarg1);
  public final static native long IEPCurrency_SWIGUpcast(long jarg1);
  public final static native long ILSCurrency_SWIGUpcast(long jarg1);
  public final static native long INRCurrency_SWIGUpcast(long jarg1);
  public final static native long IQDCurrency_SWIGUpcast(long jarg1);
  public final static native long IRRCurrency_SWIGUpcast(long jarg1);
  public final static native long ISKCurrency_SWIGUpcast(long jarg1);
  public final static native long ITLCurrency_SWIGUpcast(long jarg1);
  public final static native long JODCurrency_SWIGUpcast(long jarg1);
  public final static native long JPYCurrency_SWIGUpcast(long jarg1);
  public final static native long KESCurrency_SWIGUpcast(long jarg1);
  public final static native long KRWCurrency_SWIGUpcast(long jarg1);
  public final static native long KWDCurrency_SWIGUpcast(long jarg1);
  public final static native long KZTCurrency_SWIGUpcast(long jarg1);
  public final static native long LKRCurrency_SWIGUpcast(long jarg1);
  public final static native long LTLCurrency_SWIGUpcast(long jarg1);
  public final static native long LUFCurrency_SWIGUpcast(long jarg1);
  public final static native long LVLCurrency_SWIGUpcast(long jarg1);
  public final static native long MADCurrency_SWIGUpcast(long jarg1);
  public final static native long MTLCurrency_SWIGUpcast(long jarg1);
  public final static native long MURCurrency_SWIGUpcast(long jarg1);
  public final static native long MXNCurrency_SWIGUpcast(long jarg1);
  public final static native long MXVCurrency_SWIGUpcast(long jarg1);
  public final static native long MYRCurrency_SWIGUpcast(long jarg1);
  public final static native long NGNCurrency_SWIGUpcast(long jarg1);
  public final static native long NLGCurrency_SWIGUpcast(long jarg1);
  public final static native long NOKCurrency_SWIGUpcast(long jarg1);
  public final static native long NPRCurrency_SWIGUpcast(long jarg1);
  public final static native long NZDCurrency_SWIGUpcast(long jarg1);
  public final static native long OMRCurrency_SWIGUpcast(long jarg1);
  public final static native long PEHCurrency_SWIGUpcast(long jarg1);
  public final static native long PEICurrency_SWIGUpcast(long jarg1);
  public final static native long PENCurrency_SWIGUpcast(long jarg1);
  public final static native long PHPCurrency_SWIGUpcast(long jarg1);
  public final static native long PKRCurrency_SWIGUpcast(long jarg1);
  public final static native long PLNCurrency_SWIGUpcast(long jarg1);
  public final static native long PTECurrency_SWIGUpcast(long jarg1);
  public final static native long QARCurrency_SWIGUpcast(long jarg1);
  public final static native long ROLCurrency_SWIGUpcast(long jarg1);
  public final static native long RONCurrency_SWIGUpcast(long jarg1);
  public final static native long RSDCurrency_SWIGUpcast(long jarg1);
  public final static native long RUBCurrency_SWIGUpcast(long jarg1);
  public final static native long SARCurrency_SWIGUpcast(long jarg1);
  public final static native long SEKCurrency_SWIGUpcast(long jarg1);
  public final static native long SGDCurrency_SWIGUpcast(long jarg1);
  public final static native long SITCurrency_SWIGUpcast(long jarg1);
  public final static native long SKKCurrency_SWIGUpcast(long jarg1);
  public final static native long THBCurrency_SWIGUpcast(long jarg1);
  public final static native long TNDCurrency_SWIGUpcast(long jarg1);
  public final static native long TRLCurrency_SWIGUpcast(long jarg1);
  public final static native long TRYCurrency_SWIGUpcast(long jarg1);
  public final static native long TTDCurrency_SWIGUpcast(long jarg1);
  public final static native long TWDCurrency_SWIGUpcast(long jarg1);
  public final static native long UAHCurrency_SWIGUpcast(long jarg1);
  public final static native long UGXCurrency_SWIGUpcast(long jarg1);
  public final static native long USDCurrency_SWIGUpcast(long jarg1);
  public final static native long UYUCurrency_SWIGUpcast(long jarg1);
  public final static native long VEBCurrency_SWIGUpcast(long jarg1);
  public final static native long VNDCurrency_SWIGUpcast(long jarg1);
  public final static native long XOFCurrency_SWIGUpcast(long jarg1);
  public final static native long ZARCurrency_SWIGUpcast(long jarg1);
  public final static native long ZMWCurrency_SWIGUpcast(long jarg1);
  public final static native long BCHCurrency_SWIGUpcast(long jarg1);
  public final static native long BTCCurrency_SWIGUpcast(long jarg1);
  public final static native long DASHCurrency_SWIGUpcast(long jarg1);
  public final static native long ETCCurrency_SWIGUpcast(long jarg1);
  public final static native long ETHCurrency_SWIGUpcast(long jarg1);
  public final static native long LTCCurrency_SWIGUpcast(long jarg1);
  public final static native long XRPCurrency_SWIGUpcast(long jarg1);
  public final static native long ZECCurrency_SWIGUpcast(long jarg1);
  public final static native long Quote_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableQuoteHandle_SWIGUpcast(long jarg1);
  public final static native long SimpleQuote_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LastFixingQuote_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BoundaryConstraint_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NoConstraint_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PositiveConstraint_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CompositeConstraint_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NonhomogeneousBoundaryConstraint_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConjugateGradient_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Simplex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SteepestDescent_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BFGS_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LevenbergMarquardt_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DifferentialEvolution_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GaussianSimulatedAnnealing_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MirrorGaussianSimulatedAnnealing_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LogNormalSimulatedAnnealing_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YieldTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableYieldTermStructureHandle_SWIGUpcast(long jarg1);
  public final static native long ImpliedTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroSpreadedTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ForwardSpreadedTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseZeroSpreadedTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SpreadedLinearZeroInterpolatedTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SpreadedBackwardFlatZeroInterpolatedTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FlatForward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UltimateForwardTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Index_SWIGSmartPtrUpcast(long jarg1);
  public final static native long InterestRateIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IborIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Libor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DailyTenorLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwapIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwapSpreadIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EquityIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AUDLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CADLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CADLiborON_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Cdor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CHFLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DKKLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw1M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw2M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw3M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw4M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw5M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bbsw6M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm1M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm2M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm3M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm4M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm5M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bkbm6M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EuriborSW_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor2W_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor3W_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor1M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor2M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor3M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor4M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor5M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor6M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor7M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor8M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor9M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor10M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor11M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor1Y_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_SW_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_2W_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_3W_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_1M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_2M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_3M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_4M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_5M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_6M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_7M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_8M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_9M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_10M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_11M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Euribor365_1Y_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLiborSW_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor2W_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor1M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor2M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor3M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor4M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor5M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor6M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor7M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor8M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor9M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor10M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor11M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EURLibor1Y_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GBPLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GBPLiborON_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Jibar_SWIGSmartPtrUpcast(long jarg1);
  public final static native long JPYLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Mosprime_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NZDLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Pribor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Robor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SEKLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Shibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Tibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long THBFIX_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TRLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long USDLibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long USDLiborON_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Wibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Zibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Aonia_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Corra_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Destr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Eonia_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Estr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FedFunds_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Nzocr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Sofr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Sonia_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Swestr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EuriborSwapIsdaFixA_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EuriborSwapIsdaFixB_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EuriborSwapIfrFix_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EurLiborSwapIsdaFixA_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EurLiborSwapIsdaFixB_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EurLiborSwapIfrFix_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ChfLiborSwapIsdaFix_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GbpLiborSwapIsdaFix_SWIGSmartPtrUpcast(long jarg1);
  public final static native long JpyLiborSwapIsdaFixAm_SWIGSmartPtrUpcast(long jarg1);
  public final static native long JpyLiborSwapIsdaFixPm_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UsdLiborSwapIsdaFixAm_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UsdLiborSwapIsdaFixPm_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BiborSW_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor1M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor2M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor3M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor6M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor9M_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bibor1Y_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VolatilityTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackVolTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableBlackVolTermStructureHandle_SWIGUpcast(long jarg1);
  public final static native long LocalVolTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableLocalVolTermStructureHandle_SWIGUpcast(long jarg1);
  public final static native long OptionletVolatilityStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableOptionletVolatilityStructureHandle_SWIGUpcast(long jarg1);
  public final static native long YoYOptionletVolatilitySurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableYoYOptionletVolatilitySurfaceHandle_SWIGUpcast(long jarg1);
  public final static native long SmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwaptionVolatilityStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableSwaptionVolatilityStructureHandle_SWIGUpcast(long jarg1);
  public final static native long BlackConstantVol_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackVarianceCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackVarianceSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConstantOptionletVolatility_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConstantSwaptionVolatility_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwaptionVolatilityDiscrete_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwaptionVolatilityMatrix_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SabrSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SviSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SviInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwaptionVolatilityCube_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SabrSwaptionVolatilityCube_SWIGSmartPtrUpcast(long jarg1);
  public final static native long InterpolatedSwaptionVolatilityCube_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConstantYoYOptionletVolatility_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FlatSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LinearInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CubicInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MonotonicCubicInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SplineCubicInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KahaleSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrShortMaturityLognormalSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrShortMaturityNormalSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrLocalVolatilitySmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrFullFdSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrShortMaturityLognormalInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrShortMaturityNormalInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrLocalVolatilityInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZabrFullFdInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NoArbSabrSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NoArbSabrInterpolatedSmileSection_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AndreasenHugeVolatilityInterpl_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AndreasenHugeVolatilityAdapter_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AndreasenHugeLocalVolAdapter_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HestonBlackVolSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CashFlow_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SimpleCashFlow_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Redemption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AmortizingPayment_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IndexedCashFlow_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Coupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FixedRateCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FloatingRateCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIndexedCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CappedFlooredCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IborCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CappedFlooredIborCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SubPeriodsCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IborCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackIborCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SubPeriodsPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CompoundingRatePricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AveragingRatePricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CmsCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CmsSpreadCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CmsCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticHaganPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NumericHaganPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CappedFlooredCmsCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CappedFlooredCmsSpreadCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LinearTsrPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CmsSpreadCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LognormalCmsSpreadPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EquityCashFlow_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EquityQuantoCashFlowPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Dividend_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FixedDividend_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FractionalDividend_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EuropeanExercise_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AmericanExercise_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BermudanExercise_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RebatedExercise_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwingExercise_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StochasticProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StochasticProcess1D_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GeneralizedBlackScholesProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackScholesProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackScholesMertonProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GarmanKohlagenProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Merton76Process_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StochasticProcessArray_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GeometricBrownianMotionProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VarianceGammaProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HestonProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BatesProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HullWhiteProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HullWhiteForwardProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long G2Process_SWIGSmartPtrUpcast(long jarg1);
  public final static native long G2ForwardProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GsrProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OrnsteinUhlenbeckProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExtendedOrnsteinUhlenbeckProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExtOUWithJumpsProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KlugeExtOUProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GJRGARCHProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LazyObject_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PricingEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Instrument_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Stock_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CompositeInstrument_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CalibratedModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TermStructureConsistentModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableCalibratedModelHandle_SWIGUpcast(long jarg1);
  public final static native long ConstantParameter_SWIGUpcast(long jarg1);
  public final static native long NullParameter_SWIGUpcast(long jarg1);
  public final static native long PiecewiseConstantParameter_SWIGUpcast(long jarg1);
  public final static native long Option_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TypePayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FloatingTypePayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StrikedTypePayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DeltaVolQuote_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableDeltaVolQuoteHandle_SWIGUpcast(long jarg1);
  public final static native long OneAssetOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VanillaOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EuropeanOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ForwardVanillaOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoVanillaOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoForwardVanillaOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MultiAssetOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HestonModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseTimeDependentHestonModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long COSHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExponentialFittingHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticPTDHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BatesModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BatesEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IntegralEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialCRRVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJRVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialEQPVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTrigeorgisVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTianVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialLRVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJ4VanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPREuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRAmericanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDAmericanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPREuropeanHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDEuropeanHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRDigitalEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDDigitalEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BaroneAdesiWhaleyApproximationEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BjerksundStenslandApproximationEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long JuQuadraticApproximationEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDigitalAmericanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDigitalAmericanKOEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DividendVanillaOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDividendEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QdPlusAmericanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QdFpLegendreScheme_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QdFpLegendreTanhSinhScheme_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QdFpTanhSinhIterationScheme_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QdFpAmericanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdBlackScholesVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdBlackScholesShoutEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdOrnsteinUhlenbeckVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdBatesVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdHestonVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticCEVEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdCEVVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdSabrVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdHestonHullWhiteVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticHestonHullWhiteEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticH1HWEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ForwardEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoForwardEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticHestonForwardEuropeanEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRForwardEuropeanBSEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDForwardEuropeanBSEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRForwardEuropeanHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDForwardEuropeanHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VarianceGammaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FFTVarianceGammaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GJRGARCHModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticGJRGARCHEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPREuropeanGJRGARCHEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDEuropeanGJRGARCHEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MargrabeOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticEuropeanMargrabeEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticAmericanMargrabeEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CompoundOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticCompoundOptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SimpleChooserOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticSimpleChooserEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ComplexChooserOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticComplexChooserEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ContinuousAveragingAsianOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DiscreteAveragingAsianOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticContinuousGeometricAveragePriceAsianEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticContinuousGeometricAveragePriceAsianHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDiscreteGeometricAveragePriceAsianEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDiscreteGeometricAveragePriceAsianHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDiscreteGeometricAverageStrikeAsianEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRDiscreteArithmeticAPEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDDiscreteArithmeticAPEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRDiscreteArithmeticAPHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDDiscreteArithmeticAPHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRDiscreteArithmeticASEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDDiscreteArithmeticASEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRDiscreteGeometricAPEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDDiscreteGeometricAPEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRDiscreteGeometricAPHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDDiscreteGeometricAPHestonEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ContinuousArithmeticAsianLevyEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdBlackScholesAsianEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TurnbullWakemanAsianEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BarrierOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoBarrierOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PartialBarrier_SWIGUpcast(long jarg1);
  public final static native long PartialTimeBarrierOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticPartialTimeBarrierOptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DividendBarrierOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdBlackScholesBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdBlackScholesRebateEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdHestonBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdHestonRebateEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticBinaryBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialCRRBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJRBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialEQPBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTrigeorgisBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTianBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialLRBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJ4BarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VannaVolgaBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DoubleBarrierOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long QuantoDoubleBarrierOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdHestonDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SuoWangDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VannaVolgaIKDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VannaVolgaWODoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticDoubleBarrierBinaryEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialCRRDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJRDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialEQPDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTrigeorgisDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTianDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialLRDoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJ4DoubleBarrierEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PlainVanillaPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PercentageStrikePayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CashOrNothingPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AssetOrNothingPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SuperSharePayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GapPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VanillaForwardPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BasketPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MinBasketPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MaxBasketPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AverageBasketPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SpreadBasketPayoff_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BasketOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPREuropeanBasketEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDEuropeanBasketEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRAmericanBasketEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDAmericanBasketEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StulzEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KirkEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Fd2dBlackScholesVanillaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EverestOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPREverestEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDEverestEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HimalayaOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRHimalayaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDHimalayaEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Swap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VanillaSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NonstandardSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DiscountingSwapEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AssetSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FloatFloatSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIndexedSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIndexedSwapIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroCouponSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EquityTotalReturnSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ArithmeticAverageOIS_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MultiplicativePriceSeasonality_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KerkhofSeasonality_SWIGSmartPtrUpcast(long jarg1);
  public final static native long InflationTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableYoYInflationTermStructureHandle_SWIGUpcast(long jarg1);
  public final static native long ZeroInflationTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableZeroInflationTermStructureHandle_SWIGUpcast(long jarg1);
  public final static native long CustomRegion_SWIGUpcast(long jarg1);
  public final static native long InflationIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroInflationIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationIndex_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EUHICP_SWIGSmartPtrUpcast(long jarg1);
  public final static native long EUHICPXT_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FRHICP_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UKRPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long USCPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZACPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UKHICP_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYEUHICP_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYEUHICPXT_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYEUHICPr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYFRHICP_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYFRHICPr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYUKRPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYUKRPIr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYUSCPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYUSCPIr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYZACPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YYZACPIr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AUCPI_SWIGSmartPtrUpcast(long jarg1);
  public final static native long InflationCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CPICoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CPICashFlow_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroInflationCashFlow_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYOptionHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroCouponInflationSwapHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YearOnYearInflationSwapHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseZeroInflation_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseYoYInflation_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CappedFlooredYoYInflationCoupon_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackYoYInflationCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UnitDisplacedBlackYoYInflationCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BachelierYoYInflationCouponPricer_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroCouponInflationSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YearOnYearInflationSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CPISwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationCapFloor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationCap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationFloor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationCollar_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroInflationCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYCapFloorTermPriceSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationCapFloorTermPriceSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationBlackCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationUnitDisplacedBlackCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYInflationBachelierCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long YoYOptionletHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long InterpolatedYoYInflationOptionletStripper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long InterpolatedYoYInflationOptionletVolatilityCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KInterpolatedYoYInflationOptionletVolatilitySurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ShortRateModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableShortRateModelHandle_SWIGUpcast(long jarg1);
  public final static native long OneFactorAffineModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Vasicek_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HullWhite_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackKarasinski_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CoxIngersollRoss_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExtendedCoxIngersollRoss_SWIGSmartPtrUpcast(long jarg1);
  public final static native long G2_SWIGSmartPtrUpcast(long jarg1);
  public final static native long JamshidianSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TreeSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TreeCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long G2SwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdG2SwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdHullWhiteSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticBSMHullWhiteEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Bond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroCouponBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FixedRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AmortizingFixedRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AmortizingFloatingRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FloatingRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CmsRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AmortizingCmsRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DiscountingBondEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SoftCallability_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CallableBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CallableFixedRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CallableZeroCouponBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TreeCallableFixedRateBondEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackCallableFixedRateBondEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CPIBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackCalibrationHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwaptionHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CapHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HestonModelHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CapFloor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Cap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Floor_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Collar_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BachelierCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CliquetOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticCliquetEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticPerformanceEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCPRPerformanceEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MCLDPerformanceEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConvertibleZeroCouponBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConvertibleFixedCouponBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConvertibleFloatingRateBond_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialCRRConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJRConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialEQPConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTrigeorgisConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialTianConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialLRConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BinomialJ4ConvertibleEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Forward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BondForward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FixedRateBondForward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIndexFuture_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DepositRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FraRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FuturesRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SwapRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BondHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FixedRateBondHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OISRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DatedOISRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FxSwapRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIndexFutureRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SofrFutureRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ConstNotionalCrossCurrencyBasisSwapRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MtMCrossCurrencyBasisSwapRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IborIborBasisSwapRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OvernightIborBasisSwapRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ArithmeticOISRateHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseFlatForward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseLogLinearDiscount_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseLinearForward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseLinearZero_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseCubicZero_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseLogCubicDiscount_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseSplineCubicDiscount_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseKrugerZero_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseKrugerLogDiscount_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseConvexMonotoneForward_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseConvexMonotoneZero_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseNaturalCubicZero_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseNaturalLogCubicDiscount_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseLogMixedLinearCubicDiscount_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GlobalLinearSimpleZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DefaultProbabilityTermStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableDefaultProbabilityTermStructureHandle_SWIGUpcast(long jarg1);
  public final static native long FlatHazardRate_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HazardRateCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DefaultDensityCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SurvivalProbabilityCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DefaultProbabilityHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SpreadCdsHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long UpfrontCdsHelper_SWIGSmartPtrUpcast(long jarg1);
  public final static native long PiecewiseFlatHazardRate_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RiskyBondEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FaceValueClaim_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FaceValueAccrualClaim_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CreditDefaultSwap_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MidPointCdsEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IntegralCdsEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long IsdaCdsEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CdsOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackCdsOptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MonotonicLogCubicDiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NaturalCubicDiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KrugerLogDiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NaturalLogCubicDiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LogMixedLinearCubicDiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmBlackScholesMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Concentrating1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExponentialJump1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmCEV1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmHestonVarianceMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmHestonLocalVolatilityVarianceMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmSimpleProcess1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Uniform1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Predefined1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Glued1dMesher_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmMesherComposite_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmLinearOpComposite_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmLinearOpCompositeProxy_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmDirichletBoundary_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmDiscountDirichletBoundary_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmTimeDepDirichletBoundary_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmBatesOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmBlackScholesOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Fdm2dBlackScholesOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmCEVOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmG2Op_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmHestonHullWhiteOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmHestonOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmHullWhiteOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmLocalVolFwdOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmOrnsteinUhlenbeckOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmSabrOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmZabrOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmDupire1dOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmBlackScholesFwdOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmSquareRootFwdOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmHestonFwdOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long TripleBandLinearOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FirstDerivativeOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SecondDerivativeOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NinePointLinearOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SecondOrderMixedDerivativeOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NthOrderDerivativeOp_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmStepConditionProxy_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmInnerValueCalculatorProxy_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmCellAveragingInnerValue_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmLogInnerValue_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmLogBasketInnerValue_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmZeroInnerValue_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmAffineG2ModelSwapInnerValue_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmAffineHullWhiteModelSwapInnerValue_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmSnapshotCondition_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmStepConditionComposite_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmAmericanStepCondition_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmArithmeticAverageCondition_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmBermudanStepCondition_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmSimpleStorageCondition_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmSimpleSwingCondition_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdmDividendHandler_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BSMRNDCalculator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CEVRNDCalculator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GBSMRNDCalculator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long HestonRNDCalculator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LocalVolRNDCalculator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SquareRootProcessRNDCalculator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FittedBondDiscountCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExponentialSplinesFitting_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NelsonSiegelFitting_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SvenssonFitting_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CubicBSplinesFitting_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SimplePolynomialFitting_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SpreadFittingMethod_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ForwardCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ForwardRateAgreement_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gaussian1dModel_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gsr_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MarkovFunctional_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gaussian1dCapFloorEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gaussian1dSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gaussian1dJamshidianSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gaussian1dNonstandardSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Gaussian1dFloatFloatSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GaussLaguerreIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussHermiteIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussJacobiIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussHyperbolicIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussLegendreIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussChebyshevIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussChebyshev2ndIntegration_SWIGUpcast(long jarg1);
  public final static native long GaussGegenbauerIntegration_SWIGUpcast(long jarg1);
  public final static native long LocalConstantVol_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LocalVolSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NoExceptLocalVolSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FixedLocalVolSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long GridModelLocalVolSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MTBrownianGenerator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MTBrownianGeneratorFactory_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SobolBrownianGenerator_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SobolBrownianGeneratorFactory_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ExponentialForwardCorrelation_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LMMCurveState_SWIGUpcast(long jarg1);
  public final static native long LogNormalFwdRateIpc_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AbcdVol_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AbcdFunction_SWIGUpcast(long jarg1);
  public final static native long ContinuousFloatingLookbackOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ContinuousFixedLookbackOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ContinuousPartialFloatingLookbackOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ContinuousPartialFixedLookbackOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticContinuousFloatingLookbackEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticContinuousFixedLookbackEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticContinuousPartialFloatingLookbackEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long AnalyticContinuousPartialFixedLookbackEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NeumannBC_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DirichletBC_SWIGSmartPtrUpcast(long jarg1);
  public final static native long DPlus_SWIGUpcast(long jarg1);
  public final static native long DMinus_SWIGUpcast(long jarg1);
  public final static native long DZero_SWIGUpcast(long jarg1);
  public final static native long DPlusDMinus_SWIGUpcast(long jarg1);
  public final static native long HestonSLVProcess_SWIGSmartPtrUpcast(long jarg1);
  public final static native long SpreadOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KirkSpreadOptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RiskStatistics_SWIGUpcast(long jarg1);
  public final static native long CapFloorTermVolatilityStructure_SWIGSmartPtrUpcast(long jarg1);
  public final static native long RelinkableCapFloorTermVolatilityStructureHandle_SWIGUpcast(long jarg1);
  public final static native long CapFloorTermVolCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CapFloorTermVolSurface_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StrippedOptionlet_SWIGSmartPtrUpcast(long jarg1);
  public final static native long OptionletStripper1_SWIGSmartPtrUpcast(long jarg1);
  public final static native long StrippedOptionletAdapter_SWIGSmartPtrUpcast(long jarg1);
  public final static native long Swaption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NonstandardSwaption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FloatFloatSwaption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BlackSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long BachelierSwaptionEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long VanillaSwingOption_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdSimpleBSSwingEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long FdSimpleExtOUJumpSwingEngine_SWIGSmartPtrUpcast(long jarg1);
  public final static native long ZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LogLinearZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long CubicZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long NaturalCubicZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long LogCubicZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long MonotonicCubicZeroCurve_SWIGSmartPtrUpcast(long jarg1);
  public final static native long KrugerZeroCurve_SWIGSmartPtrUpcast(long jarg1);

  public static double SwigDirector_UnaryFunctionDelegate_value(UnaryFunctionDelegate jself, double x) {
    return jself.value(x);
  }
  public static double SwigDirector_BinaryFunctionDelegate_value(BinaryFunctionDelegate jself, double arg0, double arg1) {
    return jself.value(arg0, arg1);
  }
  public static double SwigDirector_CostFunctionDelegate_value(CostFunctionDelegate jself, long x) {
    return jself.value(new Array(x, false));
  }
  public static long SwigDirector_CostFunctionDelegate_values(CostFunctionDelegate jself, long x) {
    return Array.getCPtr(jself.values(new Array(x, false)));
  }
  public static long SwigDirector_FdmLinearOpCompositeDelegate_size(FdmLinearOpCompositeDelegate jself) {
    return jself.size();
  }
  public static void SwigDirector_FdmLinearOpCompositeDelegate_setTime(FdmLinearOpCompositeDelegate jself, double t1, double t2) {
    jself.setTime(t1, t2);
  }
  public static long SwigDirector_FdmLinearOpCompositeDelegate_apply(FdmLinearOpCompositeDelegate jself, long r) {
    return Array.getCPtr(jself.apply(new Array(r, false)));
  }
  public static long SwigDirector_FdmLinearOpCompositeDelegate_apply_mixed(FdmLinearOpCompositeDelegate jself, long r) {
    return Array.getCPtr(jself.apply_mixed(new Array(r, false)));
  }
  public static long SwigDirector_FdmLinearOpCompositeDelegate_apply_direction(FdmLinearOpCompositeDelegate jself, long direction, long r) {
    return Array.getCPtr(jself.apply_direction(direction, new Array(r, false)));
  }
  public static long SwigDirector_FdmLinearOpCompositeDelegate_solve_splitting(FdmLinearOpCompositeDelegate jself, long direction, long r, double s) {
    return Array.getCPtr(jself.solve_splitting(direction, new Array(r, false), s));
  }
  public static long SwigDirector_FdmLinearOpCompositeDelegate_preconditioner(FdmLinearOpCompositeDelegate jself, long r, double dt) {
    return Array.getCPtr(jself.preconditioner(new Array(r, false), dt));
  }
  public static void SwigDirector_FdmStepConditionDelegate_applyTo(FdmStepConditionDelegate jself, long a, double t) {
    jself.applyTo(new Array(a, false), t);
  }
  public static double SwigDirector_FdmInnerValueCalculatorDelegate_innerValue(FdmInnerValueCalculatorDelegate jself, long iter, double t) {
    return jself.innerValue(new FdmLinearOpIterator(iter, false), t);
  }
  public static double SwigDirector_FdmInnerValueCalculatorDelegate_avgInnerValue(FdmInnerValueCalculatorDelegate jself, long iter, double t) {
    return jself.avgInnerValue(new FdmLinearOpIterator(iter, false), t);
  }
  public static long SwigDirector_OdeFctDelegate_value(OdeFctDelegate jself, double x, long y) {
    return DoubleVector.getCPtr(jself.value(x, new DoubleVector(y, false)));
  }

  private final static native void swig_module_init();
  static {
    swig_module_init();
  }
}
